# $Id: AsmTable.pm,v 1.9 2010/10/02 19:41:59 Paulo Exp $
# file generated by build_AsmTable.pl, do not edit

package CPU::Z80::Assembler::AsmTable;

#------------------------------------------------------------------------------
=head1 NAME

CPU::Z80::Assembler::AsmTable - Z80 assembly/disassembly table

=head1 SYNOPSIS

  use CPU::Z80::Assembler::AsmTable;
  asm_table()->{asm}{"adc"}{"a"}{","}{"("}{"hl"}{")"}{""} is [0x8E]
  asm_table()->{disasm}{0x8E}{""} is ["adc", "a", ",", "(", "hl", ")"]

=head1 DESCRIPTION

This module provides a single function that returns a complete Z80 
assembly / disassembly hash table. 

=head1 EXPORTS

By default the "asm_table" subroutine is exported.

=head1 FUNCTIONS

=head2 asm_table

This function returns the assembly/disassembly hash table.

Starting at the "asm" key, and 
following one sub-hash table for each token, with an empty token at the 
end of the list produces an array of opcode bytes of the corresponding Z80 
assembly.

Starting at the "disasm" key, and following one sub-hash table for each 
opcode byte, with an empty byte at the end of the list, produces an array
of tokens of the corresponding disassembled Z80 instruction.

The following special tokens are defined:

=over 4

=item N

One byte;

=item NN

One word;

=item NNl

The low byte of the word;

=item NNh

The high byte of the word;

=item NNo

The offset byte of a JR/DJNZ instruction that is converted to NN by adding
address + 1;

=item DIS

The offset of a (ix+DIS) expression;

=item NDIS

The offset of a (ix-NDIS) expression.

=back

=head1 BUGS and FEEDBACK

See L<CPU::Z80::Assembler|CPU::Z80::Assembler>.

=head1 SEE ALSO

L<CPU::Z80::Assembler|CPU::Z80::Assembler>

=head1 AUTHORS, COPYRIGHT and LICENCE

See L<CPU::Z80::Assembler|CPU::Z80::Assembler>.

=cut
#------------------------------------------------------------------------------

use strict;
use warnings;

our $VERSION = "2.12";

require Exporter;
our @ISA =    qw( Exporter  );
our @EXPORT = qw( asm_table );

my $table = {
  asm => {
    adc  => {
              a  => {
                      "," => {
                               "("   => {
                                          hl => { ")" => { "" => [0x8E] } },
                                          ix => {
                                                  ")" => { "" => [0xDD, 0x8E, 0x00] },
                                                  "+" => { DIS => { ")" => { "" => [0xDD, 0x8E, "DIS"] } } },
                                                  "-" => { NDIS => { ")" => { "" => [0xDD, 0x8E, "NDIS"] } } },
                                                },
                                          iy => {
                                                  ")" => { "" => [0xFD, 0x8E, 0x00] },
                                                  "+" => { DIS => { ")" => { "" => [0xFD, 0x8E, "DIS"] } } },
                                                  "-" => { NDIS => { ")" => { "" => [0xFD, 0x8E, "NDIS"] } } },
                                                },
                                        },
                               "["   => {
                                          hl => { "]" => { "" => [0x8E] } },
                                          ix => {
                                                  "+" => { DIS => { "]" => { "" => [0xDD, 0x8E, "DIS"] } } },
                                                  "-" => { NDIS => { "]" => { "" => [0xDD, 0x8E, "NDIS"] } } },
                                                  "]" => { "" => [0xDD, 0x8E, 0x00] },
                                                },
                                          iy => {
                                                  "+" => { DIS => { "]" => { "" => [0xFD, 0x8E, "DIS"] } } },
                                                  "-" => { NDIS => { "]" => { "" => [0xFD, 0x8E, "NDIS"] } } },
                                                  "]" => { "" => [0xFD, 0x8E, 0x00] },
                                                },
                                        },
                               "a"   => { "" => [0x8F] },
                               "b"   => { "" => [0x88] },
                               "c"   => { "" => [0x89] },
                               "d"   => { "" => [0x8A] },
                               "e"   => { "" => [0x8B] },
                               "h"   => { "" => [0x8C] },
                               "hx"  => { "" => [0xDD, 0x8C] },
                               "hy"  => { "" => [0xFD, 0x8C] },
                               "ixh" => { "" => [0xDD, 0x8C] },
                               "ixl" => { "" => [0xDD, 0x8D] },
                               "iyh" => { "" => [0xFD, 0x8C] },
                               "iyl" => { "" => [0xFD, 0x8D] },
                               "l"   => { "" => [0x8D] },
                               "lx"  => { "" => [0xDD, 0x8D] },
                               "ly"  => { "" => [0xFD, 0x8D] },
                               "N"   => { "" => [0xCE, "N"] },
                               "xh"  => { "" => [0xDD, 0x8C] },
                               "xl"  => { "" => [0xDD, 0x8D] },
                               "yh"  => { "" => [0xFD, 0x8C] },
                               "yl"  => { "" => [0xFD, 0x8D] },
                             },
                    },
              hl => {
                      "," => {
                               bc => { "" => [0xED, 0x4A] },
                               de => { "" => [0xED, 0x5A] },
                               hl => { "" => [0xED, 0x6A] },
                               sp => { "" => [0xED, 0x7A] },
                             },
                    },
            },
    add  => {
              a  => {
                      "," => {
                               "("   => {
                                          hl => { ")" => { "" => [0x86] } },
                                          ix => {
                                                  ")" => { "" => [0xDD, 0x86, 0x00] },
                                                  "+" => { DIS => { ")" => { "" => [0xDD, 0x86, "DIS"] } } },
                                                  "-" => { NDIS => { ")" => { "" => [0xDD, 0x86, "NDIS"] } } },
                                                },
                                          iy => {
                                                  ")" => { "" => [0xFD, 0x86, 0x00] },
                                                  "+" => { DIS => { ")" => { "" => [0xFD, 0x86, "DIS"] } } },
                                                  "-" => { NDIS => { ")" => { "" => [0xFD, 0x86, "NDIS"] } } },
                                                },
                                        },
                               "["   => {
                                          hl => { "]" => { "" => [0x86] } },
                                          ix => {
                                                  "+" => { DIS => { "]" => { "" => [0xDD, 0x86, "DIS"] } } },
                                                  "-" => { NDIS => { "]" => { "" => [0xDD, 0x86, "NDIS"] } } },
                                                  "]" => { "" => [0xDD, 0x86, 0x00] },
                                                },
                                          iy => {
                                                  "+" => { DIS => { "]" => { "" => [0xFD, 0x86, "DIS"] } } },
                                                  "-" => { NDIS => { "]" => { "" => [0xFD, 0x86, "NDIS"] } } },
                                                  "]" => { "" => [0xFD, 0x86, 0x00] },
                                                },
                                        },
                               "a"   => { "" => [0x87] },
                               "b"   => { "" => [0x80] },
                               "c"   => { "" => [0x81] },
                               "d"   => { "" => [0x82] },
                               "e"   => { "" => [0x83] },
                               "h"   => { "" => [0x84] },
                               "hx"  => { "" => [0xDD, 0x84] },
                               "hy"  => { "" => [0xFD, 0x84] },
                               "ixh" => { "" => [0xDD, 0x84] },
                               "ixl" => { "" => [0xDD, 0x85] },
                               "iyh" => { "" => [0xFD, 0x84] },
                               "iyl" => { "" => [0xFD, 0x85] },
                               "l"   => { "" => [0x85] },
                               "lx"  => { "" => [0xDD, 0x85] },
                               "ly"  => { "" => [0xFD, 0x85] },
                               "N"   => { "" => [0xC6, "N"] },
                               "xh"  => { "" => [0xDD, 0x84] },
                               "xl"  => { "" => [0xDD, 0x85] },
                               "yh"  => { "" => [0xFD, 0x84] },
                               "yl"  => { "" => [0xFD, 0x85] },
                             },
                    },
              hl => {
                      "," => {
                               bc => { "" => [0x09] },
                               de => { "" => [0x19] },
                               hl => { "" => [0x29] },
                               sp => { "" => [0x39] },
                             },
                    },
              ix => {
                      "," => {
                               bc => { "" => [0xDD, 0x09] },
                               de => { "" => [0xDD, 0x19] },
                               ix => { "" => [0xDD, 0x29] },
                               sp => { "" => [0xDD, 0x39] },
                             },
                    },
              iy => {
                      "," => {
                               bc => { "" => [0xFD, 0x09] },
                               de => { "" => [0xFD, 0x19] },
                               iy => { "" => [0xFD, 0x29] },
                               sp => { "" => [0xFD, 0x39] },
                             },
                    },
            },
    and  => {
              "("   => {
                         hl => { ")" => { "" => [0xA6] } },
                         ix => {
                                 ")" => { "" => [0xDD, 0xA6, 0x00] },
                                 "+" => { DIS => { ")" => { "" => [0xDD, 0xA6, "DIS"] } } },
                                 "-" => { NDIS => { ")" => { "" => [0xDD, 0xA6, "NDIS"] } } },
                               },
                         iy => {
                                 ")" => { "" => [0xFD, 0xA6, 0x00] },
                                 "+" => { DIS => { ")" => { "" => [0xFD, 0xA6, "DIS"] } } },
                                 "-" => { NDIS => { ")" => { "" => [0xFD, 0xA6, "NDIS"] } } },
                               },
                       },
              "["   => {
                         hl => { "]" => { "" => [0xA6] } },
                         ix => {
                                 "+" => { DIS => { "]" => { "" => [0xDD, 0xA6, "DIS"] } } },
                                 "-" => { NDIS => { "]" => { "" => [0xDD, 0xA6, "NDIS"] } } },
                                 "]" => { "" => [0xDD, 0xA6, 0x00] },
                               },
                         iy => {
                                 "+" => { DIS => { "]" => { "" => [0xFD, 0xA6, "DIS"] } } },
                                 "-" => { NDIS => { "]" => { "" => [0xFD, 0xA6, "NDIS"] } } },
                                 "]" => { "" => [0xFD, 0xA6, 0x00] },
                               },
                       },
              "a"   => { "" => [0xA7] },
              "b"   => { "" => [0xA0] },
              "c"   => { "" => [0xA1] },
              "d"   => { "" => [0xA2] },
              "e"   => { "" => [0xA3] },
              "h"   => { "" => [0xA4] },
              "hx"  => { "" => [0xDD, 0xA4] },
              "hy"  => { "" => [0xFD, 0xA4] },
              "ixh" => { "" => [0xDD, 0xA4] },
              "ixl" => { "" => [0xDD, 0xA5] },
              "iyh" => { "" => [0xFD, 0xA4] },
              "iyl" => { "" => [0xFD, 0xA5] },
              "l"   => { "" => [0xA5] },
              "lx"  => { "" => [0xDD, 0xA5] },
              "ly"  => { "" => [0xFD, 0xA5] },
              "N"   => { "" => [0xE6, "N"] },
              "xh"  => { "" => [0xDD, 0xA4] },
              "xl"  => { "" => [0xDD, 0xA5] },
              "yh"  => { "" => [0xFD, 0xA4] },
              "yl"  => { "" => [0xFD, 0xA5] },
            },
    bit  => {
              0x00 => {
                       "," => {
                                "(" => {
                                         hl => { ")" => { "" => [0xCB, 0x46] } },
                                         ix => {
                                                 ")" => { "" => [0xDD, 0xCB, 0x00, 0x46] },
                                                 "+" => { DIS => { ")" => { "" => [0xDD, 0xCB, "DIS", 0x46] } } },
                                                 "-" => { NDIS => { ")" => { "" => [0xDD, 0xCB, "NDIS", 0x46] } } },
                                               },
                                         iy => {
                                                 ")" => { "" => [0xFD, 0xCB, 0x00, 0x46] },
                                                 "+" => { DIS => { ")" => { "" => [0xFD, 0xCB, "DIS", 0x46] } } },
                                                 "-" => { NDIS => { ")" => { "" => [0xFD, 0xCB, "NDIS", 0x46] } } },
                                               },
                                       },
                                "[" => {
                                         hl => { "]" => { "" => [0xCB, 0x46] } },
                                         ix => {
                                                 "+" => { DIS => { "]" => { "" => [0xDD, 0xCB, "DIS", 0x46] } } },
                                                 "-" => { NDIS => { "]" => { "" => [0xDD, 0xCB, "NDIS", 0x46] } } },
                                                 "]" => { "" => [0xDD, 0xCB, 0x00, 0x46] },
                                               },
                                         iy => {
                                                 "+" => { DIS => { "]" => { "" => [0xFD, 0xCB, "DIS", 0x46] } } },
                                                 "-" => { NDIS => { "]" => { "" => [0xFD, 0xCB, "NDIS", 0x46] } } },
                                                 "]" => { "" => [0xFD, 0xCB, 0x00, 0x46] },
                                               },
                                       },
                                "a" => { "" => [0xCB, 0x47] },
                                "b" => { "" => [0xCB, 0x40] },
                                "c" => { "" => [0xCB, 0x41] },
                                "d" => { "" => [0xCB, 0x42] },
                                "e" => { "" => [0xCB, 0x43] },
                                "h" => { "" => [0xCB, 0x44] },
                                "l" => { "" => [0xCB, 0x45] },
                              },
                     },
              0x01 => {
                       "," => {
                                "(" => {
                                         hl => { ")" => { "" => [0xCB, 0x4E] } },
                                         ix => {
                                                 ")" => { "" => [0xDD, 0xCB, 0x00, 0x4E] },
                                                 "+" => { DIS => { ")" => { "" => [0xDD, 0xCB, "DIS", 0x4E] } } },
                                                 "-" => { NDIS => { ")" => { "" => [0xDD, 0xCB, "NDIS", 0x4E] } } },
                                               },
                                         iy => {
                                                 ")" => { "" => [0xFD, 0xCB, 0x00, 0x4E] },
                                                 "+" => { DIS => { ")" => { "" => [0xFD, 0xCB, "DIS", 0x4E] } } },
                                                 "-" => { NDIS => { ")" => { "" => [0xFD, 0xCB, "NDIS", 0x4E] } } },
                                               },
                                       },
                                "[" => {
                                         hl => { "]" => { "" => [0xCB, 0x4E] } },
                                         ix => {
                                                 "+" => { DIS => { "]" => { "" => [0xDD, 0xCB, "DIS", 0x4E] } } },
                                                 "-" => { NDIS => { "]" => { "" => [0xDD, 0xCB, "NDIS", 0x4E] } } },
                                                 "]" => { "" => [0xDD, 0xCB, 0x00, 0x4E] },
                                               },
                                         iy => {
                                                 "+" => { DIS => { "]" => { "" => [0xFD, 0xCB, "DIS", 0x4E] } } },
                                                 "-" => { NDIS => { "]" => { "" => [0xFD, 0xCB, "NDIS", 0x4E] } } },
                                                 "]" => { "" => [0xFD, 0xCB, 0x00, 0x4E] },
                                               },
                                       },
                                "a" => { "" => [0xCB, 0x4F] },
                                "b" => { "" => [0xCB, 0x48] },
                                "c" => { "" => [0xCB, 0x49] },
                                "d" => { "" => [0xCB, 0x4A] },
                                "e" => { "" => [0xCB, 0x4B] },
                                "h" => { "" => [0xCB, 0x4C] },
                                "l" => { "" => [0xCB, 0x4D] },
                              },
                     },
              0x02 => {
                       "," => {
                                "(" => {
                                         hl => { ")" => { "" => [0xCB, 0x56] } },
                                         ix => {
                                                 ")" => { "" => [0xDD, 0xCB, 0x00, 0x56] },
                                                 "+" => { DIS => { ")" => { "" => [0xDD, 0xCB, "DIS", 0x56] } } },
                                                 "-" => { NDIS => { ")" => { "" => [0xDD, 0xCB, "NDIS", 0x56] } } },
                                               },
                                         iy => {
                                                 ")" => { "" => [0xFD, 0xCB, 0x00, 0x56] },
                                                 "+" => { DIS => { ")" => { "" => [0xFD, 0xCB, "DIS", 0x56] } } },
                                                 "-" => { NDIS => { ")" => { "" => [0xFD, 0xCB, "NDIS", 0x56] } } },
                                               },
                                       },
                                "[" => {
                                         hl => { "]" => { "" => [0xCB, 0x56] } },
                                         ix => {
                                                 "+" => { DIS => { "]" => { "" => [0xDD, 0xCB, "DIS", 0x56] } } },
                                                 "-" => { NDIS => { "]" => { "" => [0xDD, 0xCB, "NDIS", 0x56] } } },
                                                 "]" => { "" => [0xDD, 0xCB, 0x00, 0x56] },
                                               },
                                         iy => {
                                                 "+" => { DIS => { "]" => { "" => [0xFD, 0xCB, "DIS", 0x56] } } },
                                                 "-" => { NDIS => { "]" => { "" => [0xFD, 0xCB, "NDIS", 0x56] } } },
                                                 "]" => { "" => [0xFD, 0xCB, 0x00, 0x56] },
                                               },
                                       },
                                "a" => { "" => [0xCB, 0x57] },
                                "b" => { "" => [0xCB, 0x50] },
                                "c" => { "" => [0xCB, 0x51] },
                                "d" => { "" => [0xCB, 0x52] },
                                "e" => { "" => [0xCB, 0x53] },
                                "h" => { "" => [0xCB, 0x54] },
                                "l" => { "" => [0xCB, 0x55] },
                              },
                     },
              0x03 => {
                       "," => {
                                "(" => {
                                         hl => { ")" => { "" => [0xCB, 0x5E] } },
                                         ix => {
                                                 ")" => { "" => [0xDD, 0xCB, 0x00, 0x5E] },
                                                 "+" => { DIS => { ")" => { "" => [0xDD, 0xCB, "DIS", 0x5E] } } },
                                                 "-" => { NDIS => { ")" => { "" => [0xDD, 0xCB, "NDIS", 0x5E] } } },
                                               },
                                         iy => {
                                                 ")" => { "" => [0xFD, 0xCB, 0x00, 0x5E] },
                                                 "+" => { DIS => { ")" => { "" => [0xFD, 0xCB, "DIS", 0x5E] } } },
                                                 "-" => { NDIS => { ")" => { "" => [0xFD, 0xCB, "NDIS", 0x5E] } } },
                                               },
                                       },
                                "[" => {
                                         hl => { "]" => { "" => [0xCB, 0x5E] } },
                                         ix => {
                                                 "+" => { DIS => { "]" => { "" => [0xDD, 0xCB, "DIS", 0x5E] } } },
                                                 "-" => { NDIS => { "]" => { "" => [0xDD, 0xCB, "NDIS", 0x5E] } } },
                                                 "]" => { "" => [0xDD, 0xCB, 0x00, 0x5E] },
                                               },
                                         iy => {
                                                 "+" => { DIS => { "]" => { "" => [0xFD, 0xCB, "DIS", 0x5E] } } },
                                                 "-" => { NDIS => { "]" => { "" => [0xFD, 0xCB, "NDIS", 0x5E] } } },
                                                 "]" => { "" => [0xFD, 0xCB, 0x00, 0x5E] },
                                               },
                                       },
                                "a" => { "" => [0xCB, 0x5F] },
                                "b" => { "" => [0xCB, 0x58] },
                                "c" => { "" => [0xCB, 0x59] },
                                "d" => { "" => [0xCB, 0x5A] },
                                "e" => { "" => [0xCB, 0x5B] },
                                "h" => { "" => [0xCB, 0x5C] },
                                "l" => { "" => [0xCB, 0x5D] },
                              },
                     },
              0x04 => {
                       "," => {
                                "(" => {
                                         hl => { ")" => { "" => [0xCB, 0x66] } },
                                         ix => {
                                                 ")" => { "" => [0xDD, 0xCB, 0x00, 0x66] },
                                                 "+" => { DIS => { ")" => { "" => [0xDD, 0xCB, "DIS", 0x66] } } },
                                                 "-" => { NDIS => { ")" => { "" => [0xDD, 0xCB, "NDIS", 0x66] } } },
                                               },
                                         iy => {
                                                 ")" => { "" => [0xFD, 0xCB, 0x00, 0x66] },
                                                 "+" => { DIS => { ")" => { "" => [0xFD, 0xCB, "DIS", 0x66] } } },
                                                 "-" => { NDIS => { ")" => { "" => [0xFD, 0xCB, "NDIS", 0x66] } } },
                                               },
                                       },
                                "[" => {
                                         hl => { "]" => { "" => [0xCB, 0x66] } },
                                         ix => {
                                                 "+" => { DIS => { "]" => { "" => [0xDD, 0xCB, "DIS", 0x66] } } },
                                                 "-" => { NDIS => { "]" => { "" => [0xDD, 0xCB, "NDIS", 0x66] } } },
                                                 "]" => { "" => [0xDD, 0xCB, 0x00, 0x66] },
                                               },
                                         iy => {
                                                 "+" => { DIS => { "]" => { "" => [0xFD, 0xCB, "DIS", 0x66] } } },
                                                 "-" => { NDIS => { "]" => { "" => [0xFD, 0xCB, "NDIS", 0x66] } } },
                                                 "]" => { "" => [0xFD, 0xCB, 0x00, 0x66] },
                                               },
                                       },
                                "a" => { "" => [0xCB, 0x67] },
                                "b" => { "" => [0xCB, 0x60] },
                                "c" => { "" => [0xCB, 0x61] },
                                "d" => { "" => [0xCB, 0x62] },
                                "e" => { "" => [0xCB, 0x63] },
                                "h" => { "" => [0xCB, 0x64] },
                                "l" => { "" => [0xCB, 0x65] },
                              },
                     },
              0x05 => {
                       "," => {
                                "(" => {
                                         hl => { ")" => { "" => [0xCB, 0x6E] } },
                                         ix => {
                                                 ")" => { "" => [0xDD, 0xCB, 0x00, 0x6E] },
                                                 "+" => { DIS => { ")" => { "" => [0xDD, 0xCB, "DIS", 0x6E] } } },
                                                 "-" => { NDIS => { ")" => { "" => [0xDD, 0xCB, "NDIS", 0x6E] } } },
                                               },
                                         iy => {
                                                 ")" => { "" => [0xFD, 0xCB, 0x00, 0x6E] },
                                                 "+" => { DIS => { ")" => { "" => [0xFD, 0xCB, "DIS", 0x6E] } } },
                                                 "-" => { NDIS => { ")" => { "" => [0xFD, 0xCB, "NDIS", 0x6E] } } },
                                               },
                                       },
                                "[" => {
                                         hl => { "]" => { "" => [0xCB, 0x6E] } },
                                         ix => {
                                                 "+" => { DIS => { "]" => { "" => [0xDD, 0xCB, "DIS", 0x6E] } } },
                                                 "-" => { NDIS => { "]" => { "" => [0xDD, 0xCB, "NDIS", 0x6E] } } },
                                                 "]" => { "" => [0xDD, 0xCB, 0x00, 0x6E] },
                                               },
                                         iy => {
                                                 "+" => { DIS => { "]" => { "" => [0xFD, 0xCB, "DIS", 0x6E] } } },
                                                 "-" => { NDIS => { "]" => { "" => [0xFD, 0xCB, "NDIS", 0x6E] } } },
                                                 "]" => { "" => [0xFD, 0xCB, 0x00, 0x6E] },
                                               },
                                       },
                                "a" => { "" => [0xCB, 0x6F] },
                                "b" => { "" => [0xCB, 0x68] },
                                "c" => { "" => [0xCB, 0x69] },
                                "d" => { "" => [0xCB, 0x6A] },
                                "e" => { "" => [0xCB, 0x6B] },
                                "h" => { "" => [0xCB, 0x6C] },
                                "l" => { "" => [0xCB, 0x6D] },
                              },
                     },
              0x06 => {
                       "," => {
                                "(" => {
                                         hl => { ")" => { "" => [0xCB, 0x76] } },
                                         ix => {
                                                 ")" => { "" => [0xDD, 0xCB, 0x00, 0x76] },
                                                 "+" => { DIS => { ")" => { "" => [0xDD, 0xCB, "DIS", 0x76] } } },
                                                 "-" => { NDIS => { ")" => { "" => [0xDD, 0xCB, "NDIS", 0x76] } } },
                                               },
                                         iy => {
                                                 ")" => { "" => [0xFD, 0xCB, 0x00, 0x76] },
                                                 "+" => { DIS => { ")" => { "" => [0xFD, 0xCB, "DIS", 0x76] } } },
                                                 "-" => { NDIS => { ")" => { "" => [0xFD, 0xCB, "NDIS", 0x76] } } },
                                               },
                                       },
                                "[" => {
                                         hl => { "]" => { "" => [0xCB, 0x76] } },
                                         ix => {
                                                 "+" => { DIS => { "]" => { "" => [0xDD, 0xCB, "DIS", 0x76] } } },
                                                 "-" => { NDIS => { "]" => { "" => [0xDD, 0xCB, "NDIS", 0x76] } } },
                                                 "]" => { "" => [0xDD, 0xCB, 0x00, 0x76] },
                                               },
                                         iy => {
                                                 "+" => { DIS => { "]" => { "" => [0xFD, 0xCB, "DIS", 0x76] } } },
                                                 "-" => { NDIS => { "]" => { "" => [0xFD, 0xCB, "NDIS", 0x76] } } },
                                                 "]" => { "" => [0xFD, 0xCB, 0x00, 0x76] },
                                               },
                                       },
                                "a" => { "" => [0xCB, 0x77] },
                                "b" => { "" => [0xCB, 0x70] },
                                "c" => { "" => [0xCB, 0x71] },
                                "d" => { "" => [0xCB, 0x72] },
                                "e" => { "" => [0xCB, 0x73] },
                                "h" => { "" => [0xCB, 0x74] },
                                "l" => { "" => [0xCB, 0x75] },
                              },
                     },
              0x07 => {
                       "," => {
                                "(" => {
                                         hl => { ")" => { "" => [0xCB, 0x7E] } },
                                         ix => {
                                                 ")" => { "" => [0xDD, 0xCB, 0x00, 0x7E] },
                                                 "+" => { DIS => { ")" => { "" => [0xDD, 0xCB, "DIS", 0x7E] } } },
                                                 "-" => { NDIS => { ")" => { "" => [0xDD, 0xCB, "NDIS", 0x7E] } } },
                                               },
                                         iy => {
                                                 ")" => { "" => [0xFD, 0xCB, 0x00, 0x7E] },
                                                 "+" => { DIS => { ")" => { "" => [0xFD, 0xCB, "DIS", 0x7E] } } },
                                                 "-" => { NDIS => { ")" => { "" => [0xFD, 0xCB, "NDIS", 0x7E] } } },
                                               },
                                       },
                                "[" => {
                                         hl => { "]" => { "" => [0xCB, 0x7E] } },
                                         ix => {
                                                 "+" => { DIS => { "]" => { "" => [0xDD, 0xCB, "DIS", 0x7E] } } },
                                                 "-" => { NDIS => { "]" => { "" => [0xDD, 0xCB, "NDIS", 0x7E] } } },
                                                 "]" => { "" => [0xDD, 0xCB, 0x00, 0x7E] },
                                               },
                                         iy => {
                                                 "+" => { DIS => { "]" => { "" => [0xFD, 0xCB, "DIS", 0x7E] } } },
                                                 "-" => { NDIS => { "]" => { "" => [0xFD, 0xCB, "NDIS", 0x7E] } } },
                                                 "]" => { "" => [0xFD, 0xCB, 0x00, 0x7E] },
                                               },
                                       },
                                "a" => { "" => [0xCB, 0x7F] },
                                "b" => { "" => [0xCB, 0x78] },
                                "c" => { "" => [0xCB, 0x79] },
                                "d" => { "" => [0xCB, 0x7A] },
                                "e" => { "" => [0xCB, 0x7B] },
                                "h" => { "" => [0xCB, 0x7C] },
                                "l" => { "" => [0xCB, 0x7D] },
                              },
                     },
            },
    call => {
              c  => { "," => { NN => { "" => [0xDC, "NNl", "NNh"] } } },
              m  => { "," => { NN => { "" => [0xFC, "NNl", "NNh"] } } },
              nc => { "," => { NN => { "" => [0xD4, "NNl", "NNh"] } } },
              NN => { "" => [0xCD, "NNl", "NNh"] },
              nz => { "," => { NN => { "" => [0xC4, "NNl", "NNh"] } } },
              p  => { "," => { NN => { "" => [0xF4, "NNl", "NNh"] } } },
              pe => { "," => { NN => { "" => [0xEC, "NNl", "NNh"] } } },
              po => { "," => { NN => { "" => [0xE4, "NNl", "NNh"] } } },
              z  => { "," => { NN => { "" => [0xCC, "NNl", "NNh"] } } },
            },
    ccf  => { "" => [0x3F] },
    cp   => {
              "("   => {
                         hl => { ")" => { "" => [0xBE] } },
                         ix => {
                                 ")" => { "" => [0xDD, 0xBE, 0x00] },
                                 "+" => { DIS => { ")" => { "" => [0xDD, 0xBE, "DIS"] } } },
                                 "-" => { NDIS => { ")" => { "" => [0xDD, 0xBE, "NDIS"] } } },
                               },
                         iy => {
                                 ")" => { "" => [0xFD, 0xBE, 0x00] },
                                 "+" => { DIS => { ")" => { "" => [0xFD, 0xBE, "DIS"] } } },
                                 "-" => { NDIS => { ")" => { "" => [0xFD, 0xBE, "NDIS"] } } },
                               },
                       },
              "["   => {
                         hl => { "]" => { "" => [0xBE] } },
                         ix => {
                                 "+" => { DIS => { "]" => { "" => [0xDD, 0xBE, "DIS"] } } },
                                 "-" => { NDIS => { "]" => { "" => [0xDD, 0xBE, "NDIS"] } } },
                                 "]" => { "" => [0xDD, 0xBE, 0x00] },
                               },
                         iy => {
                                 "+" => { DIS => { "]" => { "" => [0xFD, 0xBE, "DIS"] } } },
                                 "-" => { NDIS => { "]" => { "" => [0xFD, 0xBE, "NDIS"] } } },
                                 "]" => { "" => [0xFD, 0xBE, 0x00] },
                               },
                       },
              "a"   => { "" => [0xBF] },
              "b"   => { "" => [0xB8] },
              "c"   => { "" => [0xB9] },
              "d"   => { "" => [0xBA] },
              "e"   => { "" => [0xBB] },
              "h"   => { "" => [0xBC] },
              "hx"  => { "" => [0xDD, 0xBC] },
              "hy"  => { "" => [0xFD, 0xBC] },
              "ixh" => { "" => [0xDD, 0xBC] },
              "ixl" => { "" => [0xDD, 0xBD] },
              "iyh" => { "" => [0xFD, 0xBC] },
              "iyl" => { "" => [0xFD, 0xBD] },
              "l"   => { "" => [0xBD] },
              "lx"  => { "" => [0xDD, 0xBD] },
              "ly"  => { "" => [0xFD, 0xBD] },
              "N"   => { "" => [0xFE, "N"] },
              "xh"  => { "" => [0xDD, 0xBC] },
              "xl"  => { "" => [0xDD, 0xBD] },
              "yh"  => { "" => [0xFD, 0xBC] },
              "yl"  => { "" => [0xFD, 0xBD] },
            },
    cpd  => { "" => [0xED, 0xA9] },
    cpdr => { "" => [0xED, 0xB9] },
    cpi  => { "" => [0xED, 0xA1] },
    cpir => { "" => [0xED, 0xB1] },
    cpl  => { "" => [0x2F] },
    daa  => { "" => [0x27] },
    dec  => {
              "("   => {
                         hl => { ")" => { "" => [0x35] } },
                         ix => {
                                 ")" => { "" => [0xDD, 0x35, 0x00] },
                                 "+" => { DIS => { ")" => { "" => [0xDD, 0x35, "DIS"] } } },
                                 "-" => { NDIS => { ")" => { "" => [0xDD, 0x35, "NDIS"] } } },
                               },
                         iy => {
                                 ")" => { "" => [0xFD, 0x35, 0x00] },
                                 "+" => { DIS => { ")" => { "" => [0xFD, 0x35, "DIS"] } } },
                                 "-" => { NDIS => { ")" => { "" => [0xFD, 0x35, "NDIS"] } } },
                               },
                       },
              "["   => {
                         hl => { "]" => { "" => [0x35] } },
                         ix => {
                                 "+" => { DIS => { "]" => { "" => [0xDD, 0x35, "DIS"] } } },
                                 "-" => { NDIS => { "]" => { "" => [0xDD, 0x35, "NDIS"] } } },
                                 "]" => { "" => [0xDD, 0x35, 0x00] },
                               },
                         iy => {
                                 "+" => { DIS => { "]" => { "" => [0xFD, 0x35, "DIS"] } } },
                                 "-" => { NDIS => { "]" => { "" => [0xFD, 0x35, "NDIS"] } } },
                                 "]" => { "" => [0xFD, 0x35, 0x00] },
                               },
                       },
              "a"   => { "" => [0x3D] },
              "b"   => { "" => [0x05] },
              "bc"  => { "" => [0x0B] },
              "c"   => { "" => [0x0D] },
              "d"   => { "" => [0x15] },
              "de"  => { "" => [0x1B] },
              "e"   => { "" => [0x1D] },
              "h"   => { "" => [0x25] },
              "hl"  => { "" => [0x2B] },
              "hx"  => { "" => [0xDD, 0x25] },
              "hy"  => { "" => [0xFD, 0x25] },
              "ix"  => { "" => [0xDD, 0x2B] },
              "ixh" => { "" => [0xDD, 0x25] },
              "ixl" => { "" => [0xDD, 0x2D] },
              "iy"  => { "" => [0xFD, 0x2B] },
              "iyh" => { "" => [0xFD, 0x25] },
              "iyl" => { "" => [0xFD, 0x2D] },
              "l"   => { "" => [0x2D] },
              "lx"  => { "" => [0xDD, 0x2D] },
              "ly"  => { "" => [0xFD, 0x2D] },
              "sp"  => { "" => [0x3B] },
              "xh"  => { "" => [0xDD, 0x25] },
              "xl"  => { "" => [0xDD, 0x2D] },
              "yh"  => { "" => [0xFD, 0x25] },
              "yl"  => { "" => [0xFD, 0x2D] },
            },
    di   => { "" => [0xF3] },
    djnz => { NN => { "" => [0x10, "NNo"] } },
    ei   => { "" => [0xFB] },
    ex   => {
              "("  => {
                        sp => {
                                ")" => {
                                         "," => {
                                                  hl => { "" => [0xE3] },
                                                  ix => { "" => [0xDD, 0xE3] },
                                                  iy => { "" => [0xFD, 0xE3] },
                                                },
                                       },
                              },
                      },
              "["  => {
                        sp => {
                                "]" => {
                                         "," => {
                                                  hl => { "" => [0xE3] },
                                                  ix => { "" => [0xDD, 0xE3] },
                                                  iy => { "" => [0xFD, 0xE3] },
                                                },
                                       },
                              },
                      },
              "af" => { "" => [0x08], "," => { "af" => { "" => [0x08] }, "af'" => { "" => [0x08] } } },
              "de" => { "," => { hl => { "" => [0xEB] } } },
            },
    exa  => { "" => [0x08] },
    exx  => { "" => [0xD9] },
    halt => { "" => [0x76] },
    im   => {
              0x00 => { "" => [0xED, 0x46] },
              0x01 => { "" => [0xED, 0x56] },
              0x02 => { "" => [0xED, 0x5E] },
            },
    in   => {
              a => {
                     "," => {
                              "(" => {
                                       c => { ")" => { "" => [0xED, 0x78] } },
                                       N => { ")" => { "" => [0xDB, "N"] } },
                                     },
                              "[" => {
                                       c => { "]" => { "" => [0xED, 0x78] } },
                                       N => { "]" => { "" => [0xDB, "N"] } },
                                     },
                            },
                   },
              b => {
                     "," => {
                              "(" => { c => { ")" => { "" => [0xED, 0x40] } } },
                              "[" => { c => { "]" => { "" => [0xED, 0x40] } } },
                            },
                   },
              c => {
                     "," => {
                              "(" => { c => { ")" => { "" => [0xED, 0x48] } } },
                              "[" => { c => { "]" => { "" => [0xED, 0x48] } } },
                            },
                   },
              d => {
                     "," => {
                              "(" => { c => { ")" => { "" => [0xED, 0x50] } } },
                              "[" => { c => { "]" => { "" => [0xED, 0x50] } } },
                            },
                   },
              e => {
                     "," => {
                              "(" => { c => { ")" => { "" => [0xED, 0x58] } } },
                              "[" => { c => { "]" => { "" => [0xED, 0x58] } } },
                            },
                   },
              f => {
                     "," => {
                              "(" => { c => { ")" => { "" => [0xED, 0x70] } } },
                              "[" => { c => { "]" => { "" => [0xED, 0x70] } } },
                            },
                   },
              h => {
                     "," => {
                              "(" => { c => { ")" => { "" => [0xED, 0x60] } } },
                              "[" => { c => { "]" => { "" => [0xED, 0x60] } } },
                            },
                   },
              l => {
                     "," => {
                              "(" => { c => { ")" => { "" => [0xED, 0x68] } } },
                              "[" => { c => { "]" => { "" => [0xED, 0x68] } } },
                            },
                   },
            },
    inc  => {
              "("   => {
                         hl => { ")" => { "" => [0x34] } },
                         ix => {
                                 ")" => { "" => [0xDD, 0x34, 0x00] },
                                 "+" => { DIS => { ")" => { "" => [0xDD, 0x34, "DIS"] } } },
                                 "-" => { NDIS => { ")" => { "" => [0xDD, 0x34, "NDIS"] } } },
                               },
                         iy => {
                                 ")" => { "" => [0xFD, 0x34, 0x00] },
                                 "+" => { DIS => { ")" => { "" => [0xFD, 0x34, "DIS"] } } },
                                 "-" => { NDIS => { ")" => { "" => [0xFD, 0x34, "NDIS"] } } },
                               },
                       },
              "["   => {
                         hl => { "]" => { "" => [0x34] } },
                         ix => {
                                 "+" => { DIS => { "]" => { "" => [0xDD, 0x34, "DIS"] } } },
                                 "-" => { NDIS => { "]" => { "" => [0xDD, 0x34, "NDIS"] } } },
                                 "]" => { "" => [0xDD, 0x34, 0x00] },
                               },
                         iy => {
                                 "+" => { DIS => { "]" => { "" => [0xFD, 0x34, "DIS"] } } },
                                 "-" => { NDIS => { "]" => { "" => [0xFD, 0x34, "NDIS"] } } },
                                 "]" => { "" => [0xFD, 0x34, 0x00] },
                               },
                       },
              "a"   => { "" => [0x3C] },
              "b"   => { "" => [0x04] },
              "bc"  => { "" => [0x03] },
              "c"   => { "" => [0x0C] },
              "d"   => { "" => [0x14] },
              "de"  => { "" => [0x13] },
              "e"   => { "" => [0x1C] },
              "h"   => { "" => [0x24] },
              "hl"  => { "" => [0x23] },
              "hx"  => { "" => [0xDD, 0x24] },
              "hy"  => { "" => [0xFD, 0x24] },
              "ix"  => { "" => [0xDD, 0x23] },
              "ixh" => { "" => [0xDD, 0x24] },
              "ixl" => { "" => [0xDD, 0x2C] },
              "iy"  => { "" => [0xFD, 0x23] },
              "iyh" => { "" => [0xFD, 0x24] },
              "iyl" => { "" => [0xFD, 0x2C] },
              "l"   => { "" => [0x2C] },
              "lx"  => { "" => [0xDD, 0x2C] },
              "ly"  => { "" => [0xFD, 0x2C] },
              "sp"  => { "" => [0x33] },
              "xh"  => { "" => [0xDD, 0x24] },
              "xl"  => { "" => [0xDD, 0x2C] },
              "yh"  => { "" => [0xFD, 0x24] },
              "yl"  => { "" => [0xFD, 0x2C] },
            },
    ind  => { "" => [0xED, 0xAA] },
    indr => { "" => [0xED, 0xBA] },
    ini  => { "" => [0xED, 0xA2] },
    inir => { "" => [0xED, 0xB2] },
    jp   => {
              "("  => {
                        hl => { ")" => { "" => [0xE9] } },
                        ix => { ")" => { "" => [0xDD, 0xE9] } },
                        iy => { ")" => { "" => [0xFD, 0xE9] } },
                      },
              "["  => {
                        hl => { "]" => { "" => [0xE9] } },
                        ix => { "]" => { "" => [0xDD, 0xE9] } },
                        iy => { "]" => { "" => [0xFD, 0xE9] } },
                      },
              "c"  => { "," => { NN => { "" => [0xDA, "NNl", "NNh"] } } },
              "hl" => { "" => [0xE9] },
              "ix" => { "" => [0xDD, 0xE9] },
              "iy" => { "" => [0xFD, 0xE9] },
              "m"  => { "," => { NN => { "" => [0xFA, "NNl", "NNh"] } } },
              "nc" => { "," => { NN => { "" => [0xD2, "NNl", "NNh"] } } },
              "NN" => { "" => [0xC3, "NNl", "NNh"] },
              "nz" => { "," => { NN => { "" => [0xC2, "NNl", "NNh"] } } },
              "p"  => { "," => { NN => { "" => [0xF2, "NNl", "NNh"] } } },
              "pe" => { "," => { NN => { "" => [0xEA, "NNl", "NNh"] } } },
              "po" => { "," => { NN => { "" => [0xE2, "NNl", "NNh"] } } },
              "z"  => { "," => { NN => { "" => [0xCA, "NNl", "NNh"] } } },
            },
    jr   => {
              c  => { "," => { NN => { "" => [0x38, "NNo"] } } },
              nc => { "," => { NN => { "" => [0x30, "NNo"] } } },
              NN => { "" => [0x18, "NNo"] },
              nz => { "," => { NN => { "" => [0x20, "NNo"] } } },
              z  => { "," => { NN => { "" => [0x28, "NNo"] } } },
            },
    ld   => {
              "("   => {
                         bc => { ")" => { "," => { a => { "" => [0x02] } } } },
                         de => { ")" => { "," => { a => { "" => [0x12] } } } },
                         hl => {
                                 ")" => {
                                          "," => {
                                                   a  => { "" => [0x77] },
                                                   b  => { "" => [0x70] },
                                                   bc => { "" => [0x71, 0x23, 0x70, 0x2B] },
                                                   c  => { "" => [0x71] },
                                                   d  => { "" => [0x72] },
                                                   de => { "" => [0x73, 0x23, 0x72, 0x2B] },
                                                   e  => { "" => [0x73] },
                                                   h  => { "" => [0x74] },
                                                   l  => { "" => [0x75] },
                                                   N  => { "" => [0x36, "N"] },
                                                 },
                                        },
                               },
                         ix => {
                                 ")" => {
                                          "," => {
                                                   a  => { "" => [0xDD, 0x77, 0x00] },
                                                   b  => { "" => [0xDD, 0x70, 0x00] },
                                                   bc => { "" => [0xDD, 0x71, 0x00, 0xDD, 0x70, 0x01] },
                                                   c  => { "" => [0xDD, 0x71, 0x00] },
                                                   d  => { "" => [0xDD, 0x72, 0x00] },
                                                   de => { "" => [0xDD, 0x73, 0x00, 0xDD, 0x72, 0x01] },
                                                   e  => { "" => [0xDD, 0x73, 0x00] },
                                                   h  => { "" => [0xDD, 0x74, 0x00] },
                                                   hl => { "" => [0xDD, 0x75, 0x00, 0xDD, 0x74, 0x01] },
                                                   l  => { "" => [0xDD, 0x75, 0x00] },
                                                   N  => { "" => [0xDD, 0x36, 0x00, "N"] },
                                                 },
                                        },
                                 "+" => {
                                          DIS => {
                                                   ")" => {
                                                            "," => {
                                                                     a  => { "" => [0xDD, 0x77, "DIS"] },
                                                                     b  => { "" => [0xDD, 0x70, "DIS"] },
                                                                     bc => { "" => [0xDD, 0x71, "DIS", 0xDD, 0x70, "DIS+0x01"] },
                                                                     c  => { "" => [0xDD, 0x71, "DIS"] },
                                                                     d  => { "" => [0xDD, 0x72, "DIS"] },
                                                                     de => { "" => [0xDD, 0x73, "DIS", 0xDD, 0x72, "DIS+0x01"] },
                                                                     e  => { "" => [0xDD, 0x73, "DIS"] },
                                                                     h  => { "" => [0xDD, 0x74, "DIS"] },
                                                                     hl => { "" => [0xDD, 0x75, "DIS", 0xDD, 0x74, "DIS+0x01"] },
                                                                     l  => { "" => [0xDD, 0x75, "DIS"] },
                                                                     N  => { "" => [0xDD, 0x36, "DIS", "N"] },
                                                                   },
                                                          },
                                                 },
                                        },
                                 "-" => {
                                          NDIS => {
                                            ")" => {
                                                     "," => {
                                                              a  => { "" => [0xDD, 0x77, "NDIS"] },
                                                              b  => { "" => [0xDD, 0x70, "NDIS"] },
                                                              bc => { "" => [0xDD, 0x71, "NDIS", 0xDD, 0x70, "NDIS+0x01"] },
                                                              c  => { "" => [0xDD, 0x71, "NDIS"] },
                                                              d  => { "" => [0xDD, 0x72, "NDIS"] },
                                                              de => { "" => [0xDD, 0x73, "NDIS", 0xDD, 0x72, "NDIS+0x01"] },
                                                              e  => { "" => [0xDD, 0x73, "NDIS"] },
                                                              h  => { "" => [0xDD, 0x74, "NDIS"] },
                                                              hl => { "" => [0xDD, 0x75, "NDIS", 0xDD, 0x74, "NDIS+0x01"] },
                                                              l  => { "" => [0xDD, 0x75, "NDIS"] },
                                                              N  => { "" => [0xDD, 0x36, "NDIS", "N"] },
                                                            },
                                                   },
                                          },
                                        },
                               },
                         iy => {
                                 ")" => {
                                          "," => {
                                                   a  => { "" => [0xFD, 0x77, 0x00] },
                                                   b  => { "" => [0xFD, 0x70, 0x00] },
                                                   bc => { "" => [0xFD, 0x71, 0x00, 0xFD, 0x70, 0x01] },
                                                   c  => { "" => [0xFD, 0x71, 0x00] },
                                                   d  => { "" => [0xFD, 0x72, 0x00] },
                                                   de => { "" => [0xFD, 0x73, 0x00, 0xFD, 0x72, 0x01] },
                                                   e  => { "" => [0xFD, 0x73, 0x00] },
                                                   h  => { "" => [0xFD, 0x74, 0x00] },
                                                   hl => { "" => [0xFD, 0x75, 0x00, 0xFD, 0x74, 0x01] },
                                                   l  => { "" => [0xFD, 0x75, 0x00] },
                                                   N  => { "" => [0xFD, 0x36, 0x00, "N"] },
                                                 },
                                        },
                                 "+" => {
                                          DIS => {
                                                   ")" => {
                                                            "," => {
                                                                     a  => { "" => [0xFD, 0x77, "DIS"] },
                                                                     b  => { "" => [0xFD, 0x70, "DIS"] },
                                                                     bc => { "" => [0xFD, 0x71, "DIS", 0xFD, 0x70, "DIS+0x01"] },
                                                                     c  => { "" => [0xFD, 0x71, "DIS"] },
                                                                     d  => { "" => [0xFD, 0x72, "DIS"] },
                                                                     de => { "" => [0xFD, 0x73, "DIS", 0xFD, 0x72, "DIS+0x01"] },
                                                                     e  => { "" => [0xFD, 0x73, "DIS"] },
                                                                     h  => { "" => [0xFD, 0x74, "DIS"] },
                                                                     hl => { "" => [0xFD, 0x75, "DIS", 0xFD, 0x74, "DIS+0x01"] },
                                                                     l  => { "" => [0xFD, 0x75, "DIS"] },
                                                                     N  => { "" => [0xFD, 0x36, "DIS", "N"] },
                                                                   },
                                                          },
                                                 },
                                        },
                                 "-" => {
                                          NDIS => {
                                            ")" => {
                                                     "," => {
                                                              a  => { "" => [0xFD, 0x77, "NDIS"] },
                                                              b  => { "" => [0xFD, 0x70, "NDIS"] },
                                                              bc => { "" => [0xFD, 0x71, "NDIS", 0xFD, 0x70, "NDIS+0x01"] },
                                                              c  => { "" => [0xFD, 0x71, "NDIS"] },
                                                              d  => { "" => [0xFD, 0x72, "NDIS"] },
                                                              de => { "" => [0xFD, 0x73, "NDIS", 0xFD, 0x72, "NDIS+0x01"] },
                                                              e  => { "" => [0xFD, 0x73, "NDIS"] },
                                                              h  => { "" => [0xFD, 0x74, "NDIS"] },
                                                              hl => { "" => [0xFD, 0x75, "NDIS", 0xFD, 0x74, "NDIS+0x01"] },
                                                              l  => { "" => [0xFD, 0x75, "NDIS"] },
                                                              N  => { "" => [0xFD, 0x36, "NDIS", "N"] },
                                                            },
                                                   },
                                          },
                                        },
                               },
                         NN => {
                                 ")" => {
                                          "," => {
                                                   a  => { "" => [0x32, "NNl", "NNh"] },
                                                   bc => { "" => [0xED, 0x43, "NNl", "NNh"] },
                                                   de => { "" => [0xED, 0x53, "NNl", "NNh"] },
                                                   hl => { "" => [0x22, "NNl", "NNh"] },
                                                   ix => { "" => [0xDD, 0x22, "NNl", "NNh"] },
                                                   iy => { "" => [0xFD, 0x22, "NNl", "NNh"] },
                                                   sp => { "" => [0xED, 0x73, "NNl", "NNh"] },
                                                 },
                                        },
                               },
                       },
              "["   => {
                         bc => { "]" => { "," => { a => { "" => [0x02] } } } },
                         de => { "]" => { "," => { a => { "" => [0x12] } } } },
                         hl => {
                                 "]" => {
                                          "," => {
                                                   a  => { "" => [0x77] },
                                                   b  => { "" => [0x70] },
                                                   bc => { "" => [0x71, 0x23, 0x70, 0x2B] },
                                                   c  => { "" => [0x71] },
                                                   d  => { "" => [0x72] },
                                                   de => { "" => [0x73, 0x23, 0x72, 0x2B] },
                                                   e  => { "" => [0x73] },
                                                   h  => { "" => [0x74] },
                                                   l  => { "" => [0x75] },
                                                   N  => { "" => [0x36, "N"] },
                                                 },
                                        },
                               },
                         ix => {
                                 "+" => {
                                          DIS => {
                                                   "]" => {
                                                            "," => {
                                                                     a  => { "" => [0xDD, 0x77, "DIS"] },
                                                                     b  => { "" => [0xDD, 0x70, "DIS"] },
                                                                     bc => { "" => [0xDD, 0x71, "DIS", 0xDD, 0x70, "DIS+0x01"] },
                                                                     c  => { "" => [0xDD, 0x71, "DIS"] },
                                                                     d  => { "" => [0xDD, 0x72, "DIS"] },
                                                                     de => { "" => [0xDD, 0x73, "DIS", 0xDD, 0x72, "DIS+0x01"] },
                                                                     e  => { "" => [0xDD, 0x73, "DIS"] },
                                                                     h  => { "" => [0xDD, 0x74, "DIS"] },
                                                                     hl => { "" => [0xDD, 0x75, "DIS", 0xDD, 0x74, "DIS+0x01"] },
                                                                     l  => { "" => [0xDD, 0x75, "DIS"] },
                                                                     N  => { "" => [0xDD, 0x36, "DIS", "N"] },
                                                                   },
                                                          },
                                                 },
                                        },
                                 "-" => {
                                          NDIS => {
                                            "]" => {
                                                     "," => {
                                                              a  => { "" => [0xDD, 0x77, "NDIS"] },
                                                              b  => { "" => [0xDD, 0x70, "NDIS"] },
                                                              bc => { "" => [0xDD, 0x71, "NDIS", 0xDD, 0x70, "NDIS+0x01"] },
                                                              c  => { "" => [0xDD, 0x71, "NDIS"] },
                                                              d  => { "" => [0xDD, 0x72, "NDIS"] },
                                                              de => { "" => [0xDD, 0x73, "NDIS", 0xDD, 0x72, "NDIS+0x01"] },
                                                              e  => { "" => [0xDD, 0x73, "NDIS"] },
                                                              h  => { "" => [0xDD, 0x74, "NDIS"] },
                                                              hl => { "" => [0xDD, 0x75, "NDIS", 0xDD, 0x74, "NDIS+0x01"] },
                                                              l  => { "" => [0xDD, 0x75, "NDIS"] },
                                                              N  => { "" => [0xDD, 0x36, "NDIS", "N"] },
                                                            },
                                                   },
                                          },
                                        },
                                 "]" => {
                                          "," => {
                                                   a  => { "" => [0xDD, 0x77, 0x00] },
                                                   b  => { "" => [0xDD, 0x70, 0x00] },
                                                   bc => { "" => [0xDD, 0x71, 0x00, 0xDD, 0x70, 0x01] },
                                                   c  => { "" => [0xDD, 0x71, 0x00] },
                                                   d  => { "" => [0xDD, 0x72, 0x00] },
                                                   de => { "" => [0xDD, 0x73, 0x00, 0xDD, 0x72, 0x01] },
                                                   e  => { "" => [0xDD, 0x73, 0x00] },
                                                   h  => { "" => [0xDD, 0x74, 0x00] },
                                                   hl => { "" => [0xDD, 0x75, 0x00, 0xDD, 0x74, 0x01] },
                                                   l  => { "" => [0xDD, 0x75, 0x00] },
                                                   N  => { "" => [0xDD, 0x36, 0x00, "N"] },
                                                 },
                                        },
                               },
                         iy => {
                                 "+" => {
                                          DIS => {
                                                   "]" => {
                                                            "," => {
                                                                     a  => { "" => [0xFD, 0x77, "DIS"] },
                                                                     b  => { "" => [0xFD, 0x70, "DIS"] },
                                                                     bc => { "" => [0xFD, 0x71, "DIS", 0xFD, 0x70, "DIS+0x01"] },
                                                                     c  => { "" => [0xFD, 0x71, "DIS"] },
                                                                     d  => { "" => [0xFD, 0x72, "DIS"] },
                                                                     de => { "" => [0xFD, 0x73, "DIS", 0xFD, 0x72, "DIS+0x01"] },
                                                                     e  => { "" => [0xFD, 0x73, "DIS"] },
                                                                     h  => { "" => [0xFD, 0x74, "DIS"] },
                                                                     hl => { "" => [0xFD, 0x75, "DIS", 0xFD, 0x74, "DIS+0x01"] },
                                                                     l  => { "" => [0xFD, 0x75, "DIS"] },
                                                                     N  => { "" => [0xFD, 0x36, "DIS", "N"] },
                                                                   },
                                                          },
                                                 },
                                        },
                                 "-" => {
                                          NDIS => {
                                            "]" => {
                                                     "," => {
                                                              a  => { "" => [0xFD, 0x77, "NDIS"] },
                                                              b  => { "" => [0xFD, 0x70, "NDIS"] },
                                                              bc => { "" => [0xFD, 0x71, "NDIS", 0xFD, 0x70, "NDIS+0x01"] },
                                                              c  => { "" => [0xFD, 0x71, "NDIS"] },
                                                              d  => { "" => [0xFD, 0x72, "NDIS"] },
                                                              de => { "" => [0xFD, 0x73, "NDIS", 0xFD, 0x72, "NDIS+0x01"] },
                                                              e  => { "" => [0xFD, 0x73, "NDIS"] },
                                                              h  => { "" => [0xFD, 0x74, "NDIS"] },
                                                              hl => { "" => [0xFD, 0x75, "NDIS", 0xFD, 0x74, "NDIS+0x01"] },
                                                              l  => { "" => [0xFD, 0x75, "NDIS"] },
                                                              N  => { "" => [0xFD, 0x36, "NDIS", "N"] },
                                                            },
                                                   },
                                          },
                                        },
                                 "]" => {
                                          "," => {
                                                   a  => { "" => [0xFD, 0x77, 0x00] },
                                                   b  => { "" => [0xFD, 0x70, 0x00] },
                                                   bc => { "" => [0xFD, 0x71, 0x00, 0xFD, 0x70, 0x01] },
                                                   c  => { "" => [0xFD, 0x71, 0x00] },
                                                   d  => { "" => [0xFD, 0x72, 0x00] },
                                                   de => { "" => [0xFD, 0x73, 0x00, 0xFD, 0x72, 0x01] },
                                                   e  => { "" => [0xFD, 0x73, 0x00] },
                                                   h  => { "" => [0xFD, 0x74, 0x00] },
                                                   hl => { "" => [0xFD, 0x75, 0x00, 0xFD, 0x74, 0x01] },
                                                   l  => { "" => [0xFD, 0x75, 0x00] },
                                                   N  => { "" => [0xFD, 0x36, 0x00, "N"] },
                                                 },
                                        },
                               },
                         NN => {
                                 "]" => {
                                          "," => {
                                                   a  => { "" => [0x32, "NNl", "NNh"] },
                                                   bc => { "" => [0xED, 0x43, "NNl", "NNh"] },
                                                   de => { "" => [0xED, 0x53, "NNl", "NNh"] },
                                                   hl => { "" => [0x22, "NNl", "NNh"] },
                                                   ix => { "" => [0xDD, 0x22, "NNl", "NNh"] },
                                                   iy => { "" => [0xFD, 0x22, "NNl", "NNh"] },
                                                   sp => { "" => [0xED, 0x73, "NNl", "NNh"] },
                                                 },
                                        },
                               },
                       },
              "a"   => {
                         "," => {
                                  "("   => {
                                             bc => { ")" => { "" => [0x0A] } },
                                             de => { ")" => { "" => [0x1A] } },
                                             hl => { ")" => { "" => [0x7E] } },
                                             ix => {
                                                     ")" => { "" => [0xDD, 0x7E, 0x00] },
                                                     "+" => { DIS => { ")" => { "" => [0xDD, 0x7E, "DIS"] } } },
                                                     "-" => { NDIS => { ")" => { "" => [0xDD, 0x7E, "NDIS"] } } },
                                                   },
                                             iy => {
                                                     ")" => { "" => [0xFD, 0x7E, 0x00] },
                                                     "+" => { DIS => { ")" => { "" => [0xFD, 0x7E, "DIS"] } } },
                                                     "-" => { NDIS => { ")" => { "" => [0xFD, 0x7E, "NDIS"] } } },
                                                   },
                                             NN => { ")" => { "" => [0x3A, "NNl", "NNh"] } },
                                           },
                                  "["   => {
                                             bc => { "]" => { "" => [0x0A] } },
                                             de => { "]" => { "" => [0x1A] } },
                                             hl => { "]" => { "" => [0x7E] } },
                                             ix => {
                                                     "+" => { DIS => { "]" => { "" => [0xDD, 0x7E, "DIS"] } } },
                                                     "-" => { NDIS => { "]" => { "" => [0xDD, 0x7E, "NDIS"] } } },
                                                     "]" => { "" => [0xDD, 0x7E, 0x00] },
                                                   },
                                             iy => {
                                                     "+" => { DIS => { "]" => { "" => [0xFD, 0x7E, "DIS"] } } },
                                                     "-" => { NDIS => { "]" => { "" => [0xFD, 0x7E, "NDIS"] } } },
                                                     "]" => { "" => [0xFD, 0x7E, 0x00] },
                                                   },
                                             NN => { "]" => { "" => [0x3A, "NNl", "NNh"] } },
                                           },
                                  "a"   => { "" => [0x7F] },
                                  "b"   => { "" => [0x78] },
                                  "c"   => { "" => [0x79] },
                                  "d"   => { "" => [0x7A] },
                                  "e"   => { "" => [0x7B] },
                                  "h"   => { "" => [0x7C] },
                                  "hx"  => { "" => [0xDD, 0x7C] },
                                  "hy"  => { "" => [0xFD, 0x7C] },
                                  "i"   => { "" => [0xED, 0x57] },
                                  "ixh" => { "" => [0xDD, 0x7C] },
                                  "ixl" => { "" => [0xDD, 0x7D] },
                                  "iyh" => { "" => [0xFD, 0x7C] },
                                  "iyl" => { "" => [0xFD, 0x7D] },
                                  "l"   => { "" => [0x7D] },
                                  "lx"  => { "" => [0xDD, 0x7D] },
                                  "ly"  => { "" => [0xFD, 0x7D] },
                                  "N"   => { "" => [0x3E, "N"] },
                                  "r"   => { "" => [0xED, 0x5F] },
                                  "xh"  => { "" => [0xDD, 0x7C] },
                                  "xl"  => { "" => [0xDD, 0x7D] },
                                  "yh"  => { "" => [0xFD, 0x7C] },
                                  "yl"  => { "" => [0xFD, 0x7D] },
                                },
                       },
              "b"   => {
                         "," => {
                                  "("   => {
                                             hl => { ")" => { "" => [0x46] } },
                                             ix => {
                                                     ")" => { "" => [0xDD, 0x46, 0x00] },
                                                     "+" => { DIS => { ")" => { "" => [0xDD, 0x46, "DIS"] } } },
                                                     "-" => { NDIS => { ")" => { "" => [0xDD, 0x46, "NDIS"] } } },
                                                   },
                                             iy => {
                                                     ")" => { "" => [0xFD, 0x46, 0x00] },
                                                     "+" => { DIS => { ")" => { "" => [0xFD, 0x46, "DIS"] } } },
                                                     "-" => { NDIS => { ")" => { "" => [0xFD, 0x46, "NDIS"] } } },
                                                   },
                                           },
                                  "["   => {
                                             hl => { "]" => { "" => [0x46] } },
                                             ix => {
                                                     "+" => { DIS => { "]" => { "" => [0xDD, 0x46, "DIS"] } } },
                                                     "-" => { NDIS => { "]" => { "" => [0xDD, 0x46, "NDIS"] } } },
                                                     "]" => { "" => [0xDD, 0x46, 0x00] },
                                                   },
                                             iy => {
                                                     "+" => { DIS => { "]" => { "" => [0xFD, 0x46, "DIS"] } } },
                                                     "-" => { NDIS => { "]" => { "" => [0xFD, 0x46, "NDIS"] } } },
                                                     "]" => { "" => [0xFD, 0x46, 0x00] },
                                                   },
                                           },
                                  "a"   => { "" => [0x47] },
                                  "b"   => { "" => [0x40] },
                                  "c"   => { "" => [0x41] },
                                  "d"   => { "" => [0x42] },
                                  "e"   => { "" => [0x43] },
                                  "h"   => { "" => [0x44] },
                                  "hx"  => { "" => [0xDD, 0x44] },
                                  "hy"  => { "" => [0xFD, 0x44] },
                                  "ixh" => { "" => [0xDD, 0x44] },
                                  "ixl" => { "" => [0xDD, 0x45] },
                                  "iyh" => { "" => [0xFD, 0x44] },
                                  "iyl" => { "" => [0xFD, 0x45] },
                                  "l"   => { "" => [0x45] },
                                  "lx"  => { "" => [0xDD, 0x45] },
                                  "ly"  => { "" => [0xFD, 0x45] },
                                  "N"   => { "" => [0x06, "N"] },
                                  "xh"  => { "" => [0xDD, 0x44] },
                                  "xl"  => { "" => [0xDD, 0x45] },
                                  "yh"  => { "" => [0xFD, 0x44] },
                                  "yl"  => { "" => [0xFD, 0x45] },
                                },
                       },
              "bc"  => {
                         "," => {
                                  "("  => {
                                            hl => { ")" => { "" => [0x4E, 0x23, 0x46, 0x2B] } },
                                            ix => {
                                                    ")" => { "" => [0xDD, 0x4E, 0x00, 0xDD, 0x46, 0x01] },
                                                    "+" => { DIS => { ")" => { "" => [0xDD, 0x4E, "DIS", 0xDD, 0x46, "DIS+0x01"] } } },
                                                    "-" => {
                                                             NDIS => { ")" => { "" => [0xDD, 0x4E, "NDIS", 0xDD, 0x46, "NDIS+0x01"] } },
                                                           },
                                                  },
                                            iy => {
                                                    ")" => { "" => [0xFD, 0x4E, 0x00, 0xFD, 0x46, 0x01] },
                                                    "+" => { DIS => { ")" => { "" => [0xFD, 0x4E, "DIS", 0xFD, 0x46, "DIS+0x01"] } } },
                                                    "-" => {
                                                             NDIS => { ")" => { "" => [0xFD, 0x4E, "NDIS", 0xFD, 0x46, "NDIS+0x01"] } },
                                                           },
                                                  },
                                            NN => { ")" => { "" => [0xED, 0x4B, "NNl", "NNh"] } },
                                          },
                                  "["  => {
                                            hl => { "]" => { "" => [0x4E, 0x23, 0x46, 0x2B] } },
                                            ix => {
                                                    "+" => { DIS => { "]" => { "" => [0xDD, 0x4E, "DIS", 0xDD, 0x46, "DIS+0x01"] } } },
                                                    "-" => {
                                                             NDIS => { "]" => { "" => [0xDD, 0x4E, "NDIS", 0xDD, 0x46, "NDIS+0x01"] } },
                                                           },
                                                    "]" => { "" => [0xDD, 0x4E, 0x00, 0xDD, 0x46, 0x01] },
                                                  },
                                            iy => {
                                                    "+" => { DIS => { "]" => { "" => [0xFD, 0x4E, "DIS", 0xFD, 0x46, "DIS+0x01"] } } },
                                                    "-" => {
                                                             NDIS => { "]" => { "" => [0xFD, 0x4E, "NDIS", 0xFD, 0x46, "NDIS+0x01"] } },
                                                           },
                                                    "]" => { "" => [0xFD, 0x4E, 0x00, 0xFD, 0x46, 0x01] },
                                                  },
                                            NN => { "]" => { "" => [0xED, 0x4B, "NNl", "NNh"] } },
                                          },
                                  "bc" => { "" => [0x40, 0x49] },
                                  "de" => { "" => [0x42, 0x4B] },
                                  "hl" => { "" => [0x44, 0x4D] },
                                  "ix" => { "" => [0xDD, 0x44, 0xDD, 0x4D] },
                                  "iy" => { "" => [0xFD, 0x44, 0xFD, 0x4D] },
                                  "NN" => { "" => [0x01, "NNl", "NNh"] },
                                },
                       },
              "c"   => {
                         "," => {
                                  "("   => {
                                             hl => { ")" => { "" => [0x4E] } },
                                             ix => {
                                                     ")" => { "" => [0xDD, 0x4E, 0x00] },
                                                     "+" => { DIS => { ")" => { "" => [0xDD, 0x4E, "DIS"] } } },
                                                     "-" => { NDIS => { ")" => { "" => [0xDD, 0x4E, "NDIS"] } } },
                                                   },
                                             iy => {
                                                     ")" => { "" => [0xFD, 0x4E, 0x00] },
                                                     "+" => { DIS => { ")" => { "" => [0xFD, 0x4E, "DIS"] } } },
                                                     "-" => { NDIS => { ")" => { "" => [0xFD, 0x4E, "NDIS"] } } },
                                                   },
                                           },
                                  "["   => {
                                             hl => { "]" => { "" => [0x4E] } },
                                             ix => {
                                                     "+" => { DIS => { "]" => { "" => [0xDD, 0x4E, "DIS"] } } },
                                                     "-" => { NDIS => { "]" => { "" => [0xDD, 0x4E, "NDIS"] } } },
                                                     "]" => { "" => [0xDD, 0x4E, 0x00] },
                                                   },
                                             iy => {
                                                     "+" => { DIS => { "]" => { "" => [0xFD, 0x4E, "DIS"] } } },
                                                     "-" => { NDIS => { "]" => { "" => [0xFD, 0x4E, "NDIS"] } } },
                                                     "]" => { "" => [0xFD, 0x4E, 0x00] },
                                                   },
                                           },
                                  "a"   => { "" => [0x4F] },
                                  "b"   => { "" => [0x48] },
                                  "c"   => { "" => [0x49] },
                                  "d"   => { "" => [0x4A] },
                                  "e"   => { "" => [0x4B] },
                                  "h"   => { "" => [0x4C] },
                                  "hx"  => { "" => [0xDD, 0x4C] },
                                  "hy"  => { "" => [0xFD, 0x4C] },
                                  "ixh" => { "" => [0xDD, 0x4C] },
                                  "ixl" => { "" => [0xDD, 0x4D] },
                                  "iyh" => { "" => [0xFD, 0x4C] },
                                  "iyl" => { "" => [0xFD, 0x4D] },
                                  "l"   => { "" => [0x4D] },
                                  "lx"  => { "" => [0xDD, 0x4D] },
                                  "ly"  => { "" => [0xFD, 0x4D] },
                                  "N"   => { "" => [0x0E, "N"] },
                                  "xh"  => { "" => [0xDD, 0x4C] },
                                  "xl"  => { "" => [0xDD, 0x4D] },
                                  "yh"  => { "" => [0xFD, 0x4C] },
                                  "yl"  => { "" => [0xFD, 0x4D] },
                                },
                       },
              "d"   => {
                         "," => {
                                  "("   => {
                                             hl => { ")" => { "" => [0x56] } },
                                             ix => {
                                                     ")" => { "" => [0xDD, 0x56, 0x00] },
                                                     "+" => { DIS => { ")" => { "" => [0xDD, 0x56, "DIS"] } } },
                                                     "-" => { NDIS => { ")" => { "" => [0xDD, 0x56, "NDIS"] } } },
                                                   },
                                             iy => {
                                                     ")" => { "" => [0xFD, 0x56, 0x00] },
                                                     "+" => { DIS => { ")" => { "" => [0xFD, 0x56, "DIS"] } } },
                                                     "-" => { NDIS => { ")" => { "" => [0xFD, 0x56, "NDIS"] } } },
                                                   },
                                           },
                                  "["   => {
                                             hl => { "]" => { "" => [0x56] } },
                                             ix => {
                                                     "+" => { DIS => { "]" => { "" => [0xDD, 0x56, "DIS"] } } },
                                                     "-" => { NDIS => { "]" => { "" => [0xDD, 0x56, "NDIS"] } } },
                                                     "]" => { "" => [0xDD, 0x56, 0x00] },
                                                   },
                                             iy => {
                                                     "+" => { DIS => { "]" => { "" => [0xFD, 0x56, "DIS"] } } },
                                                     "-" => { NDIS => { "]" => { "" => [0xFD, 0x56, "NDIS"] } } },
                                                     "]" => { "" => [0xFD, 0x56, 0x00] },
                                                   },
                                           },
                                  "a"   => { "" => [0x57] },
                                  "b"   => { "" => [0x50] },
                                  "c"   => { "" => [0x51] },
                                  "d"   => { "" => [0x52] },
                                  "e"   => { "" => [0x53] },
                                  "h"   => { "" => [0x54] },
                                  "hx"  => { "" => [0xDD, 0x54] },
                                  "hy"  => { "" => [0xFD, 0x54] },
                                  "ixh" => { "" => [0xDD, 0x54] },
                                  "ixl" => { "" => [0xDD, 0x55] },
                                  "iyh" => { "" => [0xFD, 0x54] },
                                  "iyl" => { "" => [0xFD, 0x55] },
                                  "l"   => { "" => [0x55] },
                                  "lx"  => { "" => [0xDD, 0x55] },
                                  "ly"  => { "" => [0xFD, 0x55] },
                                  "N"   => { "" => [0x16, "N"] },
                                  "xh"  => { "" => [0xDD, 0x54] },
                                  "xl"  => { "" => [0xDD, 0x55] },
                                  "yh"  => { "" => [0xFD, 0x54] },
                                  "yl"  => { "" => [0xFD, 0x55] },
                                },
                       },
              "de"  => {
                         "," => {
                                  "("  => {
                                            hl => { ")" => { "" => [0x5E, 0x23, 0x56, 0x2B] } },
                                            ix => {
                                                    ")" => { "" => [0xDD, 0x5E, 0x00, 0xDD, 0x56, 0x01] },
                                                    "+" => { DIS => { ")" => { "" => [0xDD, 0x5E, "DIS", 0xDD, 0x56, "DIS+0x01"] } } },
                                                    "-" => {
                                                             NDIS => { ")" => { "" => [0xDD, 0x5E, "NDIS", 0xDD, 0x56, "NDIS+0x01"] } },
                                                           },
                                                  },
                                            iy => {
                                                    ")" => { "" => [0xFD, 0x5E, 0x00, 0xFD, 0x56, 0x01] },
                                                    "+" => { DIS => { ")" => { "" => [0xFD, 0x5E, "DIS", 0xFD, 0x56, "DIS+0x01"] } } },
                                                    "-" => {
                                                             NDIS => { ")" => { "" => [0xFD, 0x5E, "NDIS", 0xFD, 0x56, "NDIS+0x01"] } },
                                                           },
                                                  },
                                            NN => { ")" => { "" => [0xED, 0x5B, "NNl", "NNh"] } },
                                          },
                                  "["  => {
                                            hl => { "]" => { "" => [0x5E, 0x23, 0x56, 0x2B] } },
                                            ix => {
                                                    "+" => { DIS => { "]" => { "" => [0xDD, 0x5E, "DIS", 0xDD, 0x56, "DIS+0x01"] } } },
                                                    "-" => {
                                                             NDIS => { "]" => { "" => [0xDD, 0x5E, "NDIS", 0xDD, 0x56, "NDIS+0x01"] } },
                                                           },
                                                    "]" => { "" => [0xDD, 0x5E, 0x00, 0xDD, 0x56, 0x01] },
                                                  },
                                            iy => {
                                                    "+" => { DIS => { "]" => { "" => [0xFD, 0x5E, "DIS", 0xFD, 0x56, "DIS+0x01"] } } },
                                                    "-" => {
                                                             NDIS => { "]" => { "" => [0xFD, 0x5E, "NDIS", 0xFD, 0x56, "NDIS+0x01"] } },
                                                           },
                                                    "]" => { "" => [0xFD, 0x5E, 0x00, 0xFD, 0x56, 0x01] },
                                                  },
                                            NN => { "]" => { "" => [0xED, 0x5B, "NNl", "NNh"] } },
                                          },
                                  "bc" => { "" => [0x50, 0x59] },
                                  "de" => { "" => [0x52, 0x5B] },
                                  "hl" => { "" => [0x54, 0x5D] },
                                  "ix" => { "" => [0xDD, 0x54, 0xDD, 0x5D] },
                                  "iy" => { "" => [0xFD, 0x54, 0xFD, 0x5D] },
                                  "NN" => { "" => [0x11, "NNl", "NNh"] },
                                },
                       },
              "e"   => {
                         "," => {
                                  "("   => {
                                             hl => { ")" => { "" => [0x5E] } },
                                             ix => {
                                                     ")" => { "" => [0xDD, 0x5E, 0x00] },
                                                     "+" => { DIS => { ")" => { "" => [0xDD, 0x5E, "DIS"] } } },
                                                     "-" => { NDIS => { ")" => { "" => [0xDD, 0x5E, "NDIS"] } } },
                                                   },
                                             iy => {
                                                     ")" => { "" => [0xFD, 0x5E, 0x00] },
                                                     "+" => { DIS => { ")" => { "" => [0xFD, 0x5E, "DIS"] } } },
                                                     "-" => { NDIS => { ")" => { "" => [0xFD, 0x5E, "NDIS"] } } },
                                                   },
                                           },
                                  "["   => {
                                             hl => { "]" => { "" => [0x5E] } },
                                             ix => {
                                                     "+" => { DIS => { "]" => { "" => [0xDD, 0x5E, "DIS"] } } },
                                                     "-" => { NDIS => { "]" => { "" => [0xDD, 0x5E, "NDIS"] } } },
                                                     "]" => { "" => [0xDD, 0x5E, 0x00] },
                                                   },
                                             iy => {
                                                     "+" => { DIS => { "]" => { "" => [0xFD, 0x5E, "DIS"] } } },
                                                     "-" => { NDIS => { "]" => { "" => [0xFD, 0x5E, "NDIS"] } } },
                                                     "]" => { "" => [0xFD, 0x5E, 0x00] },
                                                   },
                                           },
                                  "a"   => { "" => [0x5F] },
                                  "b"   => { "" => [0x58] },
                                  "c"   => { "" => [0x59] },
                                  "d"   => { "" => [0x5A] },
                                  "e"   => { "" => [0x5B] },
                                  "h"   => { "" => [0x5C] },
                                  "hx"  => { "" => [0xDD, 0x5C] },
                                  "hy"  => { "" => [0xFD, 0x5C] },
                                  "ixh" => { "" => [0xDD, 0x5C] },
                                  "ixl" => { "" => [0xDD, 0x5D] },
                                  "iyh" => { "" => [0xFD, 0x5C] },
                                  "iyl" => { "" => [0xFD, 0x5D] },
                                  "l"   => { "" => [0x5D] },
                                  "lx"  => { "" => [0xDD, 0x5D] },
                                  "ly"  => { "" => [0xFD, 0x5D] },
                                  "N"   => { "" => [0x1E, "N"] },
                                  "xh"  => { "" => [0xDD, 0x5C] },
                                  "xl"  => { "" => [0xDD, 0x5D] },
                                  "yh"  => { "" => [0xFD, 0x5C] },
                                  "yl"  => { "" => [0xFD, 0x5D] },
                                },
                       },
              "h"   => {
                         "," => {
                                  "(" => {
                                           hl => { ")" => { "" => [0x66] } },
                                           ix => {
                                                   ")" => { "" => [0xDD, 0x66, 0x00] },
                                                   "+" => { DIS => { ")" => { "" => [0xDD, 0x66, "DIS"] } } },
                                                   "-" => { NDIS => { ")" => { "" => [0xDD, 0x66, "NDIS"] } } },
                                                 },
                                           iy => {
                                                   ")" => { "" => [0xFD, 0x66, 0x00] },
                                                   "+" => { DIS => { ")" => { "" => [0xFD, 0x66, "DIS"] } } },
                                                   "-" => { NDIS => { ")" => { "" => [0xFD, 0x66, "NDIS"] } } },
                                                 },
                                         },
                                  "[" => {
                                           hl => { "]" => { "" => [0x66] } },
                                           ix => {
                                                   "+" => { DIS => { "]" => { "" => [0xDD, 0x66, "DIS"] } } },
                                                   "-" => { NDIS => { "]" => { "" => [0xDD, 0x66, "NDIS"] } } },
                                                   "]" => { "" => [0xDD, 0x66, 0x00] },
                                                 },
                                           iy => {
                                                   "+" => { DIS => { "]" => { "" => [0xFD, 0x66, "DIS"] } } },
                                                   "-" => { NDIS => { "]" => { "" => [0xFD, 0x66, "NDIS"] } } },
                                                   "]" => { "" => [0xFD, 0x66, 0x00] },
                                                 },
                                         },
                                  "a" => { "" => [0x67] },
                                  "b" => { "" => [0x60] },
                                  "c" => { "" => [0x61] },
                                  "d" => { "" => [0x62] },
                                  "e" => { "" => [0x63] },
                                  "h" => { "" => [0x64] },
                                  "l" => { "" => [0x65] },
                                  "N" => { "" => [0x26, "N"] },
                                },
                       },
              "hl"  => {
                         "," => {
                                  "("  => {
                                            ix => {
                                                    ")" => { "" => [0xDD, 0x6E, 0x00, 0xDD, 0x66, 0x01] },
                                                    "+" => {
                                                             DIS => { ")" => { "" => [0xDD, 0x6E, "DIS", 0xDD, 0x66, "DIS+0x01"] } },
                                                           },
                                                    "-" => {
                                                             NDIS => { ")" => { "" => [0xDD, 0x6E, "NDIS", 0xDD, 0x66, "NDIS+0x01"] } },
                                                           },
                                                  },
                                            iy => {
                                                    ")" => { "" => [0xFD, 0x6E, 0x00, 0xFD, 0x66, 0x01] },
                                                    "+" => {
                                                             DIS => { ")" => { "" => [0xFD, 0x6E, "DIS", 0xFD, 0x66, "DIS+0x01"] } },
                                                           },
                                                    "-" => {
                                                             NDIS => { ")" => { "" => [0xFD, 0x6E, "NDIS", 0xFD, 0x66, "NDIS+0x01"] } },
                                                           },
                                                  },
                                            NN => { ")" => { "" => [0x2A, "NNl", "NNh"] } },
                                          },
                                  "["  => {
                                            ix => {
                                                    "+" => {
                                                             DIS => { "]" => { "" => [0xDD, 0x6E, "DIS", 0xDD, 0x66, "DIS+0x01"] } },
                                                           },
                                                    "-" => {
                                                             NDIS => { "]" => { "" => [0xDD, 0x6E, "NDIS", 0xDD, 0x66, "NDIS+0x01"] } },
                                                           },
                                                    "]" => { "" => [0xDD, 0x6E, 0x00, 0xDD, 0x66, 0x01] },
                                                  },
                                            iy => {
                                                    "+" => {
                                                             DIS => { "]" => { "" => [0xFD, 0x6E, "DIS", 0xFD, 0x66, "DIS+0x01"] } },
                                                           },
                                                    "-" => {
                                                             NDIS => { "]" => { "" => [0xFD, 0x6E, "NDIS", 0xFD, 0x66, "NDIS+0x01"] } },
                                                           },
                                                    "]" => { "" => [0xFD, 0x6E, 0x00, 0xFD, 0x66, 0x01] },
                                                  },
                                            NN => { "]" => { "" => [0x2A, "NNl", "NNh"] } },
                                          },
                                  "bc" => { "" => [0x60, 0x69] },
                                  "de" => { "" => [0x62, 0x6B] },
                                  "hl" => { "" => [0x64, 0x6D] },
                                  "ix" => { "" => [0xDD, 0xE5, 0xE1] },
                                  "iy" => { "" => [0xFD, 0xE5, 0xE1] },
                                  "NN" => { "" => [0x21, "NNl", "NNh"] },
                                },
                       },
              "hx"  => {
                         "," => {
                                  a  => { "" => [0xDD, 0x67] },
                                  b  => { "" => [0xDD, 0x60] },
                                  c  => { "" => [0xDD, 0x61] },
                                  d  => { "" => [0xDD, 0x62] },
                                  e  => { "" => [0xDD, 0x63] },
                                  hx => { "" => [0xDD, 0x64] },
                                  lx => { "" => [0xDD, 0x65] },
                                  N  => { "" => [0xDD, 0x26, "N"] },
                                },
                       },
              "hy"  => {
                         "," => {
                                  a  => { "" => [0xFD, 0x67] },
                                  b  => { "" => [0xFD, 0x60] },
                                  c  => { "" => [0xFD, 0x61] },
                                  d  => { "" => [0xFD, 0x62] },
                                  e  => { "" => [0xFD, 0x63] },
                                  hy => { "" => [0xFD, 0x64] },
                                  ly => { "" => [0xFD, 0x65] },
                                  N  => { "" => [0xFD, 0x26, "N"] },
                                },
                       },
              "i"   => { "," => { a => { "" => [0xED, 0x47] } } },
              "ix"  => {
                         "," => {
                                  "("  => { NN => { ")" => { "" => [0xDD, 0x2A, "NNl", "NNh"] } } },
                                  "["  => { NN => { "]" => { "" => [0xDD, 0x2A, "NNl", "NNh"] } } },
                                  "bc" => { "" => [0xDD, 0x69, 0xDD, 0x60] },
                                  "de" => { "" => [0xDD, 0x6B, 0xDD, 0x62] },
                                  "hl" => { "" => [0xE5, 0xDD, 0xE1] },
                                  "ix" => { "" => [0xDD, 0x6D, 0xDD, 0x64] },
                                  "iy" => { "" => [0xFD, 0xE5, 0xDD, 0xE1] },
                                  "NN" => { "" => [0xDD, 0x21, "NNl", "NNh"] },
                                },
                       },
              "ixh" => {
                         "," => {
                                  a   => { "" => [0xDD, 0x67] },
                                  b   => { "" => [0xDD, 0x60] },
                                  c   => { "" => [0xDD, 0x61] },
                                  d   => { "" => [0xDD, 0x62] },
                                  e   => { "" => [0xDD, 0x63] },
                                  ixh => { "" => [0xDD, 0x64] },
                                  ixl => { "" => [0xDD, 0x65] },
                                  N   => { "" => [0xDD, 0x26, "N"] },
                                },
                       },
              "ixl" => {
                         "," => {
                                  a   => { "" => [0xDD, 0x6F] },
                                  b   => { "" => [0xDD, 0x68] },
                                  c   => { "" => [0xDD, 0x69] },
                                  d   => { "" => [0xDD, 0x6A] },
                                  e   => { "" => [0xDD, 0x6B] },
                                  ixh => { "" => [0xDD, 0x6C] },
                                  ixl => { "" => [0xDD, 0x6D] },
                                  N   => { "" => [0xDD, 0x2E, "N"] },
                                },
                       },
              "iy"  => {
                         "," => {
                                  "("  => { NN => { ")" => { "" => [0xFD, 0x2A, "NNl", "NNh"] } } },
                                  "["  => { NN => { "]" => { "" => [0xFD, 0x2A, "NNl", "NNh"] } } },
                                  "bc" => { "" => [0xFD, 0x69, 0xFD, 0x60] },
                                  "de" => { "" => [0xFD, 0x6B, 0xFD, 0x62] },
                                  "hl" => { "" => [0xE5, 0xFD, 0xE1] },
                                  "ix" => { "" => [0xDD, 0xE5, 0xFD, 0xE1] },
                                  "iy" => { "" => [0xFD, 0x6D, 0xFD, 0x64] },
                                  "NN" => { "" => [0xFD, 0x21, "NNl", "NNh"] },
                                },
                       },
              "iyh" => {
                         "," => {
                                  a   => { "" => [0xFD, 0x67] },
                                  b   => { "" => [0xFD, 0x60] },
                                  c   => { "" => [0xFD, 0x61] },
                                  d   => { "" => [0xFD, 0x62] },
                                  e   => { "" => [0xFD, 0x63] },
                                  iyh => { "" => [0xFD, 0x64] },
                                  iyl => { "" => [0xFD, 0x65] },
                                  N   => { "" => [0xFD, 0x26, "N"] },
                                },
                       },
              "iyl" => {
                         "," => {
                                  a   => { "" => [0xFD, 0x6F] },
                                  b   => { "" => [0xFD, 0x68] },
                                  c   => { "" => [0xFD, 0x69] },
                                  d   => { "" => [0xFD, 0x6A] },
                                  e   => { "" => [0xFD, 0x6B] },
                                  iyh => { "" => [0xFD, 0x6C] },
                                  iyl => { "" => [0xFD, 0x6D] },
                                  N   => { "" => [0xFD, 0x2E, "N"] },
                                },
                       },
              "l"   => {
                         "," => {
                                  "(" => {
                                           hl => { ")" => { "" => [0x6E] } },
                                           ix => {
                                                   ")" => { "" => [0xDD, 0x6E, 0x00] },
                                                   "+" => { DIS => { ")" => { "" => [0xDD, 0x6E, "DIS"] } } },
                                                   "-" => { NDIS => { ")" => { "" => [0xDD, 0x6E, "NDIS"] } } },
                                                 },
                                           iy => {
                                                   ")" => { "" => [0xFD, 0x6E, 0x00] },
                                                   "+" => { DIS => { ")" => { "" => [0xFD, 0x6E, "DIS"] } } },
                                                   "-" => { NDIS => { ")" => { "" => [0xFD, 0x6E, "NDIS"] } } },
                                                 },
                                         },
                                  "[" => {
                                           hl => { "]" => { "" => [0x6E] } },
                                           ix => {
                                                   "+" => { DIS => { "]" => { "" => [0xDD, 0x6E, "DIS"] } } },
                                                   "-" => { NDIS => { "]" => { "" => [0xDD, 0x6E, "NDIS"] } } },
                                                   "]" => { "" => [0xDD, 0x6E, 0x00] },
                                                 },
                                           iy => {
                                                   "+" => { DIS => { "]" => { "" => [0xFD, 0x6E, "DIS"] } } },
                                                   "-" => { NDIS => { "]" => { "" => [0xFD, 0x6E, "NDIS"] } } },
                                                   "]" => { "" => [0xFD, 0x6E, 0x00] },
                                                 },
                                         },
                                  "a" => { "" => [0x6F] },
                                  "b" => { "" => [0x68] },
                                  "c" => { "" => [0x69] },
                                  "d" => { "" => [0x6A] },
                                  "e" => { "" => [0x6B] },
                                  "h" => { "" => [0x6C] },
                                  "l" => { "" => [0x6D] },
                                  "N" => { "" => [0x2E, "N"] },
                                },
                       },
              "lx"  => {
                         "," => {
                                  a  => { "" => [0xDD, 0x6F] },
                                  b  => { "" => [0xDD, 0x68] },
                                  c  => { "" => [0xDD, 0x69] },
                                  d  => { "" => [0xDD, 0x6A] },
                                  e  => { "" => [0xDD, 0x6B] },
                                  hx => { "" => [0xDD, 0x6C] },
                                  lx => { "" => [0xDD, 0x6D] },
                                  N  => { "" => [0xDD, 0x2E, "N"] },
                                },
                       },
              "ly"  => {
                         "," => {
                                  a  => { "" => [0xFD, 0x6F] },
                                  b  => { "" => [0xFD, 0x68] },
                                  c  => { "" => [0xFD, 0x69] },
                                  d  => { "" => [0xFD, 0x6A] },
                                  e  => { "" => [0xFD, 0x6B] },
                                  hy => { "" => [0xFD, 0x6C] },
                                  ly => { "" => [0xFD, 0x6D] },
                                  N  => { "" => [0xFD, 0x2E, "N"] },
                                },
                       },
              "r"   => { "," => { a => { "" => [0xED, 0x4F] } } },
              "sp"  => {
                         "," => {
                                  "("  => { NN => { ")" => { "" => [0xED, 0x7B, "NNl", "NNh"] } } },
                                  "["  => { NN => { "]" => { "" => [0xED, 0x7B, "NNl", "NNh"] } } },
                                  "hl" => { "" => [0xF9] },
                                  "ix" => { "" => [0xDD, 0xF9] },
                                  "iy" => { "" => [0xFD, 0xF9] },
                                  "NN" => { "" => [0x31, "NNl", "NNh"] },
                                },
                       },
              "xh"  => {
                         "," => {
                                  a  => { "" => [0xDD, 0x67] },
                                  b  => { "" => [0xDD, 0x60] },
                                  c  => { "" => [0xDD, 0x61] },
                                  d  => { "" => [0xDD, 0x62] },
                                  e  => { "" => [0xDD, 0x63] },
                                  N  => { "" => [0xDD, 0x26, "N"] },
                                  xh => { "" => [0xDD, 0x64] },
                                  xl => { "" => [0xDD, 0x65] },
                                },
                       },
              "xl"  => {
                         "," => {
                                  a  => { "" => [0xDD, 0x6F] },
                                  b  => { "" => [0xDD, 0x68] },
                                  c  => { "" => [0xDD, 0x69] },
                                  d  => { "" => [0xDD, 0x6A] },
                                  e  => { "" => [0xDD, 0x6B] },
                                  N  => { "" => [0xDD, 0x2E, "N"] },
                                  xh => { "" => [0xDD, 0x6C] },
                                  xl => { "" => [0xDD, 0x6D] },
                                },
                       },
              "yh"  => {
                         "," => {
                                  a  => { "" => [0xFD, 0x67] },
                                  b  => { "" => [0xFD, 0x60] },
                                  c  => { "" => [0xFD, 0x61] },
                                  d  => { "" => [0xFD, 0x62] },
                                  e  => { "" => [0xFD, 0x63] },
                                  N  => { "" => [0xFD, 0x26, "N"] },
                                  yh => { "" => [0xFD, 0x64] },
                                  yl => { "" => [0xFD, 0x65] },
                                },
                       },
              "yl"  => {
                         "," => {
                                  a  => { "" => [0xFD, 0x6F] },
                                  b  => { "" => [0xFD, 0x68] },
                                  c  => { "" => [0xFD, 0x69] },
                                  d  => { "" => [0xFD, 0x6A] },
                                  e  => { "" => [0xFD, 0x6B] },
                                  N  => { "" => [0xFD, 0x2E, "N"] },
                                  yh => { "" => [0xFD, 0x6C] },
                                  yl => { "" => [0xFD, 0x6D] },
                                },
                       },
            },
    ldd  => {
              ""  => [0xED, 0xA8],
              "(" => {
                       bc => { ")" => { "," => { a => { "" => [0x02, 0x0B] } } } },
                       de => { ")" => { "," => { a => { "" => [0x12, 0x1B] } } } },
                       hl => {
                               ")" => {
                                        "," => {
                                                 a => { "" => [0x77, 0x2B] },
                                                 b => { "" => [0x70, 0x2B] },
                                                 c => { "" => [0x71, 0x2B] },
                                                 d => { "" => [0x72, 0x2B] },
                                                 e => { "" => [0x73, 0x2B] },
                                                 h => { "" => [0x74, 0x2B] },
                                                 l => { "" => [0x75, 0x2B] },
                                                 N => { "" => [0x36, "N", 0x2B] },
                                               },
                                      },
                             },
                       ix => {
                               ")" => {
                                        "," => {
                                                 a => { "" => [0xDD, 0x77, 0x00, 0xDD, 0x2B] },
                                                 b => { "" => [0xDD, 0x70, 0x00, 0xDD, 0x2B] },
                                                 c => { "" => [0xDD, 0x71, 0x00, 0xDD, 0x2B] },
                                                 d => { "" => [0xDD, 0x72, 0x00, 0xDD, 0x2B] },
                                                 e => { "" => [0xDD, 0x73, 0x00, 0xDD, 0x2B] },
                                                 h => { "" => [0xDD, 0x74, 0x00, 0xDD, 0x2B] },
                                                 l => { "" => [0xDD, 0x75, 0x00, 0xDD, 0x2B] },
                                                 N => { "" => [0xDD, 0x36, 0x00, "N", 0xDD, 0x2B] },
                                               },
                                      },
                               "+" => {
                                        DIS => {
                                                 ")" => {
                                                          "," => {
                                                                   a => { "" => [0xDD, 0x77, "DIS", 0xDD, 0x2B] },
                                                                   b => { "" => [0xDD, 0x70, "DIS", 0xDD, 0x2B] },
                                                                   c => { "" => [0xDD, 0x71, "DIS", 0xDD, 0x2B] },
                                                                   d => { "" => [0xDD, 0x72, "DIS", 0xDD, 0x2B] },
                                                                   e => { "" => [0xDD, 0x73, "DIS", 0xDD, 0x2B] },
                                                                   h => { "" => [0xDD, 0x74, "DIS", 0xDD, 0x2B] },
                                                                   l => { "" => [0xDD, 0x75, "DIS", 0xDD, 0x2B] },
                                                                   N => { "" => [0xDD, 0x36, "DIS", "N", 0xDD, 0x2B] },
                                                                 },
                                                        },
                                               },
                                      },
                               "-" => {
                                        NDIS => {
                                          ")" => {
                                                   "," => {
                                                            a => { "" => [0xDD, 0x77, "NDIS", 0xDD, 0x2B] },
                                                            b => { "" => [0xDD, 0x70, "NDIS", 0xDD, 0x2B] },
                                                            c => { "" => [0xDD, 0x71, "NDIS", 0xDD, 0x2B] },
                                                            d => { "" => [0xDD, 0x72, "NDIS", 0xDD, 0x2B] },
                                                            e => { "" => [0xDD, 0x73, "NDIS", 0xDD, 0x2B] },
                                                            h => { "" => [0xDD, 0x74, "NDIS", 0xDD, 0x2B] },
                                                            l => { "" => [0xDD, 0x75, "NDIS", 0xDD, 0x2B] },
                                                            N => { "" => [0xDD, 0x36, "NDIS", "N", 0xDD, 0x2B] },
                                                          },
                                                 },
                                        },
                                      },
                             },
                       iy => {
                               ")" => {
                                        "," => {
                                                 a => { "" => [0xFD, 0x77, 0x00, 0xFD, 0x2B] },
                                                 b => { "" => [0xFD, 0x70, 0x00, 0xFD, 0x2B] },
                                                 c => { "" => [0xFD, 0x71, 0x00, 0xFD, 0x2B] },
                                                 d => { "" => [0xFD, 0x72, 0x00, 0xFD, 0x2B] },
                                                 e => { "" => [0xFD, 0x73, 0x00, 0xFD, 0x2B] },
                                                 h => { "" => [0xFD, 0x74, 0x00, 0xFD, 0x2B] },
                                                 l => { "" => [0xFD, 0x75, 0x00, 0xFD, 0x2B] },
                                                 N => { "" => [0xFD, 0x36, 0x00, "N", 0xFD, 0x2B] },
                                               },
                                      },
                               "+" => {
                                        DIS => {
                                                 ")" => {
                                                          "," => {
                                                                   a => { "" => [0xFD, 0x77, "DIS", 0xFD, 0x2B] },
                                                                   b => { "" => [0xFD, 0x70, "DIS", 0xFD, 0x2B] },
                                                                   c => { "" => [0xFD, 0x71, "DIS", 0xFD, 0x2B] },
                                                                   d => { "" => [0xFD, 0x72, "DIS", 0xFD, 0x2B] },
                                                                   e => { "" => [0xFD, 0x73, "DIS", 0xFD, 0x2B] },
                                                                   h => { "" => [0xFD, 0x74, "DIS", 0xFD, 0x2B] },
                                                                   l => { "" => [0xFD, 0x75, "DIS", 0xFD, 0x2B] },
                                                                   N => { "" => [0xFD, 0x36, "DIS", "N", 0xFD, 0x2B] },
                                                                 },
                                                        },
                                               },
                                      },
                               "-" => {
                                        NDIS => {
                                          ")" => {
                                                   "," => {
                                                            a => { "" => [0xFD, 0x77, "NDIS", 0xFD, 0x2B] },
                                                            b => { "" => [0xFD, 0x70, "NDIS", 0xFD, 0x2B] },
                                                            c => { "" => [0xFD, 0x71, "NDIS", 0xFD, 0x2B] },
                                                            d => { "" => [0xFD, 0x72, "NDIS", 0xFD, 0x2B] },
                                                            e => { "" => [0xFD, 0x73, "NDIS", 0xFD, 0x2B] },
                                                            h => { "" => [0xFD, 0x74, "NDIS", 0xFD, 0x2B] },
                                                            l => { "" => [0xFD, 0x75, "NDIS", 0xFD, 0x2B] },
                                                            N => { "" => [0xFD, 0x36, "NDIS", "N", 0xFD, 0x2B] },
                                                          },
                                                 },
                                        },
                                      },
                             },
                     },
              "[" => {
                       bc => { "]" => { "," => { a => { "" => [0x02, 0x0B] } } } },
                       de => { "]" => { "," => { a => { "" => [0x12, 0x1B] } } } },
                       hl => {
                               "]" => {
                                        "," => {
                                                 a => { "" => [0x77, 0x2B] },
                                                 b => { "" => [0x70, 0x2B] },
                                                 c => { "" => [0x71, 0x2B] },
                                                 d => { "" => [0x72, 0x2B] },
                                                 e => { "" => [0x73, 0x2B] },
                                                 h => { "" => [0x74, 0x2B] },
                                                 l => { "" => [0x75, 0x2B] },
                                                 N => { "" => [0x36, "N", 0x2B] },
                                               },
                                      },
                             },
                       ix => {
                               "+" => {
                                        DIS => {
                                                 "]" => {
                                                          "," => {
                                                                   a => { "" => [0xDD, 0x77, "DIS", 0xDD, 0x2B] },
                                                                   b => { "" => [0xDD, 0x70, "DIS", 0xDD, 0x2B] },
                                                                   c => { "" => [0xDD, 0x71, "DIS", 0xDD, 0x2B] },
                                                                   d => { "" => [0xDD, 0x72, "DIS", 0xDD, 0x2B] },
                                                                   e => { "" => [0xDD, 0x73, "DIS", 0xDD, 0x2B] },
                                                                   h => { "" => [0xDD, 0x74, "DIS", 0xDD, 0x2B] },
                                                                   l => { "" => [0xDD, 0x75, "DIS", 0xDD, 0x2B] },
                                                                   N => { "" => [0xDD, 0x36, "DIS", "N", 0xDD, 0x2B] },
                                                                 },
                                                        },
                                               },
                                      },
                               "-" => {
                                        NDIS => {
                                          "]" => {
                                                   "," => {
                                                            a => { "" => [0xDD, 0x77, "NDIS", 0xDD, 0x2B] },
                                                            b => { "" => [0xDD, 0x70, "NDIS", 0xDD, 0x2B] },
                                                            c => { "" => [0xDD, 0x71, "NDIS", 0xDD, 0x2B] },
                                                            d => { "" => [0xDD, 0x72, "NDIS", 0xDD, 0x2B] },
                                                            e => { "" => [0xDD, 0x73, "NDIS", 0xDD, 0x2B] },
                                                            h => { "" => [0xDD, 0x74, "NDIS", 0xDD, 0x2B] },
                                                            l => { "" => [0xDD, 0x75, "NDIS", 0xDD, 0x2B] },
                                                            N => { "" => [0xDD, 0x36, "NDIS", "N", 0xDD, 0x2B] },
                                                          },
                                                 },
                                        },
                                      },
                               "]" => {
                                        "," => {
                                                 a => { "" => [0xDD, 0x77, 0x00, 0xDD, 0x2B] },
                                                 b => { "" => [0xDD, 0x70, 0x00, 0xDD, 0x2B] },
                                                 c => { "" => [0xDD, 0x71, 0x00, 0xDD, 0x2B] },
                                                 d => { "" => [0xDD, 0x72, 0x00, 0xDD, 0x2B] },
                                                 e => { "" => [0xDD, 0x73, 0x00, 0xDD, 0x2B] },
                                                 h => { "" => [0xDD, 0x74, 0x00, 0xDD, 0x2B] },
                                                 l => { "" => [0xDD, 0x75, 0x00, 0xDD, 0x2B] },
                                                 N => { "" => [0xDD, 0x36, 0x00, "N", 0xDD, 0x2B] },
                                               },
                                      },
                             },
                       iy => {
                               "+" => {
                                        DIS => {
                                                 "]" => {
                                                          "," => {
                                                                   a => { "" => [0xFD, 0x77, "DIS", 0xFD, 0x2B] },
                                                                   b => { "" => [0xFD, 0x70, "DIS", 0xFD, 0x2B] },
                                                                   c => { "" => [0xFD, 0x71, "DIS", 0xFD, 0x2B] },
                                                                   d => { "" => [0xFD, 0x72, "DIS", 0xFD, 0x2B] },
                                                                   e => { "" => [0xFD, 0x73, "DIS", 0xFD, 0x2B] },
                                                                   h => { "" => [0xFD, 0x74, "DIS", 0xFD, 0x2B] },
                                                                   l => { "" => [0xFD, 0x75, "DIS", 0xFD, 0x2B] },
                                                                   N => { "" => [0xFD, 0x36, "DIS", "N", 0xFD, 0x2B] },
                                                                 },
                                                        },
                                               },
                                      },
                               "-" => {
                                        NDIS => {
                                          "]" => {
                                                   "," => {
                                                            a => { "" => [0xFD, 0x77, "NDIS", 0xFD, 0x2B] },
                                                            b => { "" => [0xFD, 0x70, "NDIS", 0xFD, 0x2B] },
                                                            c => { "" => [0xFD, 0x71, "NDIS", 0xFD, 0x2B] },
                                                            d => { "" => [0xFD, 0x72, "NDIS", 0xFD, 0x2B] },
                                                            e => { "" => [0xFD, 0x73, "NDIS", 0xFD, 0x2B] },
                                                            h => { "" => [0xFD, 0x74, "NDIS", 0xFD, 0x2B] },
                                                            l => { "" => [0xFD, 0x75, "NDIS", 0xFD, 0x2B] },
                                                            N => { "" => [0xFD, 0x36, "NDIS", "N", 0xFD, 0x2B] },
                                                          },
                                                 },
                                        },
                                      },
                               "]" => {
                                        "," => {
                                                 a => { "" => [0xFD, 0x77, 0x00, 0xFD, 0x2B] },
                                                 b => { "" => [0xFD, 0x70, 0x00, 0xFD, 0x2B] },
                                                 c => { "" => [0xFD, 0x71, 0x00, 0xFD, 0x2B] },
                                                 d => { "" => [0xFD, 0x72, 0x00, 0xFD, 0x2B] },
                                                 e => { "" => [0xFD, 0x73, 0x00, 0xFD, 0x2B] },
                                                 h => { "" => [0xFD, 0x74, 0x00, 0xFD, 0x2B] },
                                                 l => { "" => [0xFD, 0x75, 0x00, 0xFD, 0x2B] },
                                                 N => { "" => [0xFD, 0x36, 0x00, "N", 0xFD, 0x2B] },
                                               },
                                      },
                             },
                     },
              "a" => {
                       "," => {
                                "(" => {
                                         bc => { ")" => { "" => [0x0A, 0x0B] } },
                                         de => { ")" => { "" => [0x1A, 0x1B] } },
                                         hl => { ")" => { "" => [0x7E, 0x2B] } },
                                         ix => {
                                                 ")" => { "" => [0xDD, 0x7E, 0x00, 0xDD, 0x2B] },
                                                 "+" => { DIS => { ")" => { "" => [0xDD, 0x7E, "DIS", 0xDD, 0x2B] } } },
                                                 "-" => { NDIS => { ")" => { "" => [0xDD, 0x7E, "NDIS", 0xDD, 0x2B] } } },
                                               },
                                         iy => {
                                                 ")" => { "" => [0xFD, 0x7E, 0x00, 0xFD, 0x2B] },
                                                 "+" => { DIS => { ")" => { "" => [0xFD, 0x7E, "DIS", 0xFD, 0x2B] } } },
                                                 "-" => { NDIS => { ")" => { "" => [0xFD, 0x7E, "NDIS", 0xFD, 0x2B] } } },
                                               },
                                       },
                                "[" => {
                                         bc => { "]" => { "" => [0x0A, 0x0B] } },
                                         de => { "]" => { "" => [0x1A, 0x1B] } },
                                         hl => { "]" => { "" => [0x7E, 0x2B] } },
                                         ix => {
                                                 "+" => { DIS => { "]" => { "" => [0xDD, 0x7E, "DIS", 0xDD, 0x2B] } } },
                                                 "-" => { NDIS => { "]" => { "" => [0xDD, 0x7E, "NDIS", 0xDD, 0x2B] } } },
                                                 "]" => { "" => [0xDD, 0x7E, 0x00, 0xDD, 0x2B] },
                                               },
                                         iy => {
                                                 "+" => { DIS => { "]" => { "" => [0xFD, 0x7E, "DIS", 0xFD, 0x2B] } } },
                                                 "-" => { NDIS => { "]" => { "" => [0xFD, 0x7E, "NDIS", 0xFD, 0x2B] } } },
                                                 "]" => { "" => [0xFD, 0x7E, 0x00, 0xFD, 0x2B] },
                                               },
                                       },
                              },
                     },
              "b" => {
                       "," => {
                                "(" => {
                                         hl => { ")" => { "" => [0x46, 0x2B] } },
                                         ix => {
                                                 ")" => { "" => [0xDD, 0x46, 0x00, 0xDD, 0x2B] },
                                                 "+" => { DIS => { ")" => { "" => [0xDD, 0x46, "DIS", 0xDD, 0x2B] } } },
                                                 "-" => { NDIS => { ")" => { "" => [0xDD, 0x46, "NDIS", 0xDD, 0x2B] } } },
                                               },
                                         iy => {
                                                 ")" => { "" => [0xFD, 0x46, 0x00, 0xFD, 0x2B] },
                                                 "+" => { DIS => { ")" => { "" => [0xFD, 0x46, "DIS", 0xFD, 0x2B] } } },
                                                 "-" => { NDIS => { ")" => { "" => [0xFD, 0x46, "NDIS", 0xFD, 0x2B] } } },
                                               },
                                       },
                                "[" => {
                                         hl => { "]" => { "" => [0x46, 0x2B] } },
                                         ix => {
                                                 "+" => { DIS => { "]" => { "" => [0xDD, 0x46, "DIS", 0xDD, 0x2B] } } },
                                                 "-" => { NDIS => { "]" => { "" => [0xDD, 0x46, "NDIS", 0xDD, 0x2B] } } },
                                                 "]" => { "" => [0xDD, 0x46, 0x00, 0xDD, 0x2B] },
                                               },
                                         iy => {
                                                 "+" => { DIS => { "]" => { "" => [0xFD, 0x46, "DIS", 0xFD, 0x2B] } } },
                                                 "-" => { NDIS => { "]" => { "" => [0xFD, 0x46, "NDIS", 0xFD, 0x2B] } } },
                                                 "]" => { "" => [0xFD, 0x46, 0x00, 0xFD, 0x2B] },
                                               },
                                       },
                              },
                     },
              "c" => {
                       "," => {
                                "(" => {
                                         hl => { ")" => { "" => [0x4E, 0x2B] } },
                                         ix => {
                                                 ")" => { "" => [0xDD, 0x4E, 0x00, 0xDD, 0x2B] },
                                                 "+" => { DIS => { ")" => { "" => [0xDD, 0x4E, "DIS", 0xDD, 0x2B] } } },
                                                 "-" => { NDIS => { ")" => { "" => [0xDD, 0x4E, "NDIS", 0xDD, 0x2B] } } },
                                               },
                                         iy => {
                                                 ")" => { "" => [0xFD, 0x4E, 0x00, 0xFD, 0x2B] },
                                                 "+" => { DIS => { ")" => { "" => [0xFD, 0x4E, "DIS", 0xFD, 0x2B] } } },
                                                 "-" => { NDIS => { ")" => { "" => [0xFD, 0x4E, "NDIS", 0xFD, 0x2B] } } },
                                               },
                                       },
                                "[" => {
                                         hl => { "]" => { "" => [0x4E, 0x2B] } },
                                         ix => {
                                                 "+" => { DIS => { "]" => { "" => [0xDD, 0x4E, "DIS", 0xDD, 0x2B] } } },
                                                 "-" => { NDIS => { "]" => { "" => [0xDD, 0x4E, "NDIS", 0xDD, 0x2B] } } },
                                                 "]" => { "" => [0xDD, 0x4E, 0x00, 0xDD, 0x2B] },
                                               },
                                         iy => {
                                                 "+" => { DIS => { "]" => { "" => [0xFD, 0x4E, "DIS", 0xFD, 0x2B] } } },
                                                 "-" => { NDIS => { "]" => { "" => [0xFD, 0x4E, "NDIS", 0xFD, 0x2B] } } },
                                                 "]" => { "" => [0xFD, 0x4E, 0x00, 0xFD, 0x2B] },
                                               },
                                       },
                              },
                     },
              "d" => {
                       "," => {
                                "(" => {
                                         hl => { ")" => { "" => [0x56, 0x2B] } },
                                         ix => {
                                                 ")" => { "" => [0xDD, 0x56, 0x00, 0xDD, 0x2B] },
                                                 "+" => { DIS => { ")" => { "" => [0xDD, 0x56, "DIS", 0xDD, 0x2B] } } },
                                                 "-" => { NDIS => { ")" => { "" => [0xDD, 0x56, "NDIS", 0xDD, 0x2B] } } },
                                               },
                                         iy => {
                                                 ")" => { "" => [0xFD, 0x56, 0x00, 0xFD, 0x2B] },
                                                 "+" => { DIS => { ")" => { "" => [0xFD, 0x56, "DIS", 0xFD, 0x2B] } } },
                                                 "-" => { NDIS => { ")" => { "" => [0xFD, 0x56, "NDIS", 0xFD, 0x2B] } } },
                                               },
                                       },
                                "[" => {
                                         hl => { "]" => { "" => [0x56, 0x2B] } },
                                         ix => {
                                                 "+" => { DIS => { "]" => { "" => [0xDD, 0x56, "DIS", 0xDD, 0x2B] } } },
                                                 "-" => { NDIS => { "]" => { "" => [0xDD, 0x56, "NDIS", 0xDD, 0x2B] } } },
                                                 "]" => { "" => [0xDD, 0x56, 0x00, 0xDD, 0x2B] },
                                               },
                                         iy => {
                                                 "+" => { DIS => { "]" => { "" => [0xFD, 0x56, "DIS", 0xFD, 0x2B] } } },
                                                 "-" => { NDIS => { "]" => { "" => [0xFD, 0x56, "NDIS", 0xFD, 0x2B] } } },
                                                 "]" => { "" => [0xFD, 0x56, 0x00, 0xFD, 0x2B] },
                                               },
                                       },
                              },
                     },
              "e" => {
                       "," => {
                                "(" => {
                                         hl => { ")" => { "" => [0x5E, 0x2B] } },
                                         ix => {
                                                 ")" => { "" => [0xDD, 0x5E, 0x00, 0xDD, 0x2B] },
                                                 "+" => { DIS => { ")" => { "" => [0xDD, 0x5E, "DIS", 0xDD, 0x2B] } } },
                                                 "-" => { NDIS => { ")" => { "" => [0xDD, 0x5E, "NDIS", 0xDD, 0x2B] } } },
                                               },
                                         iy => {
                                                 ")" => { "" => [0xFD, 0x5E, 0x00, 0xFD, 0x2B] },
                                                 "+" => { DIS => { ")" => { "" => [0xFD, 0x5E, "DIS", 0xFD, 0x2B] } } },
                                                 "-" => { NDIS => { ")" => { "" => [0xFD, 0x5E, "NDIS", 0xFD, 0x2B] } } },
                                               },
                                       },
                                "[" => {
                                         hl => { "]" => { "" => [0x5E, 0x2B] } },
                                         ix => {
                                                 "+" => { DIS => { "]" => { "" => [0xDD, 0x5E, "DIS", 0xDD, 0x2B] } } },
                                                 "-" => { NDIS => { "]" => { "" => [0xDD, 0x5E, "NDIS", 0xDD, 0x2B] } } },
                                                 "]" => { "" => [0xDD, 0x5E, 0x00, 0xDD, 0x2B] },
                                               },
                                         iy => {
                                                 "+" => { DIS => { "]" => { "" => [0xFD, 0x5E, "DIS", 0xFD, 0x2B] } } },
                                                 "-" => { NDIS => { "]" => { "" => [0xFD, 0x5E, "NDIS", 0xFD, 0x2B] } } },
                                                 "]" => { "" => [0xFD, 0x5E, 0x00, 0xFD, 0x2B] },
                                               },
                                       },
                              },
                     },
              "h" => {
                       "," => {
                                "(" => {
                                         hl => { ")" => { "" => [0x66, 0x2B] } },
                                         ix => {
                                                 ")" => { "" => [0xDD, 0x66, 0x00, 0xDD, 0x2B] },
                                                 "+" => { DIS => { ")" => { "" => [0xDD, 0x66, "DIS", 0xDD, 0x2B] } } },
                                                 "-" => { NDIS => { ")" => { "" => [0xDD, 0x66, "NDIS", 0xDD, 0x2B] } } },
                                               },
                                         iy => {
                                                 ")" => { "" => [0xFD, 0x66, 0x00, 0xFD, 0x2B] },
                                                 "+" => { DIS => { ")" => { "" => [0xFD, 0x66, "DIS", 0xFD, 0x2B] } } },
                                                 "-" => { NDIS => { ")" => { "" => [0xFD, 0x66, "NDIS", 0xFD, 0x2B] } } },
                                               },
                                       },
                                "[" => {
                                         hl => { "]" => { "" => [0x66, 0x2B] } },
                                         ix => {
                                                 "+" => { DIS => { "]" => { "" => [0xDD, 0x66, "DIS", 0xDD, 0x2B] } } },
                                                 "-" => { NDIS => { "]" => { "" => [0xDD, 0x66, "NDIS", 0xDD, 0x2B] } } },
                                                 "]" => { "" => [0xDD, 0x66, 0x00, 0xDD, 0x2B] },
                                               },
                                         iy => {
                                                 "+" => { DIS => { "]" => { "" => [0xFD, 0x66, "DIS", 0xFD, 0x2B] } } },
                                                 "-" => { NDIS => { "]" => { "" => [0xFD, 0x66, "NDIS", 0xFD, 0x2B] } } },
                                                 "]" => { "" => [0xFD, 0x66, 0x00, 0xFD, 0x2B] },
                                               },
                                       },
                              },
                     },
              "l" => {
                       "," => {
                                "(" => {
                                         hl => { ")" => { "" => [0x6E, 0x2B] } },
                                         ix => {
                                                 ")" => { "" => [0xDD, 0x6E, 0x00, 0xDD, 0x2B] },
                                                 "+" => { DIS => { ")" => { "" => [0xDD, 0x6E, "DIS", 0xDD, 0x2B] } } },
                                                 "-" => { NDIS => { ")" => { "" => [0xDD, 0x6E, "NDIS", 0xDD, 0x2B] } } },
                                               },
                                         iy => {
                                                 ")" => { "" => [0xFD, 0x6E, 0x00, 0xFD, 0x2B] },
                                                 "+" => { DIS => { ")" => { "" => [0xFD, 0x6E, "DIS", 0xFD, 0x2B] } } },
                                                 "-" => { NDIS => { ")" => { "" => [0xFD, 0x6E, "NDIS", 0xFD, 0x2B] } } },
                                               },
                                       },
                                "[" => {
                                         hl => { "]" => { "" => [0x6E, 0x2B] } },
                                         ix => {
                                                 "+" => { DIS => { "]" => { "" => [0xDD, 0x6E, "DIS", 0xDD, 0x2B] } } },
                                                 "-" => { NDIS => { "]" => { "" => [0xDD, 0x6E, "NDIS", 0xDD, 0x2B] } } },
                                                 "]" => { "" => [0xDD, 0x6E, 0x00, 0xDD, 0x2B] },
                                               },
                                         iy => {
                                                 "+" => { DIS => { "]" => { "" => [0xFD, 0x6E, "DIS", 0xFD, 0x2B] } } },
                                                 "-" => { NDIS => { "]" => { "" => [0xFD, 0x6E, "NDIS", 0xFD, 0x2B] } } },
                                                 "]" => { "" => [0xFD, 0x6E, 0x00, 0xFD, 0x2B] },
                                               },
                                       },
                              },
                     },
            },
    lddr => { "" => [0xED, 0xB8] },
    ldi  => {
              ""   => [0xED, 0xA0],
              "("  => {
                        bc => { ")" => { "," => { a => { "" => [0x02, 0x03] } } } },
                        de => { ")" => { "," => { a => { "" => [0x12, 0x13] } } } },
                        hl => {
                                ")" => {
                                         "," => {
                                                  a  => { "" => [0x77, 0x23] },
                                                  b  => { "" => [0x70, 0x23] },
                                                  bc => { "" => [0x71, 0x23, 0x70, 0x23] },
                                                  c  => { "" => [0x71, 0x23] },
                                                  d  => { "" => [0x72, 0x23] },
                                                  de => { "" => [0x73, 0x23, 0x72, 0x23] },
                                                  e  => { "" => [0x73, 0x23] },
                                                  h  => { "" => [0x74, 0x23] },
                                                  l  => { "" => [0x75, 0x23] },
                                                  N  => { "" => [0x36, "N", 0x23] },
                                                },
                                       },
                              },
                        ix => {
                                ")" => {
                                         "," => {
                                                  a  => { "" => [0xDD, 0x77, 0x00, 0xDD, 0x23] },
                                                  b  => { "" => [0xDD, 0x70, 0x00, 0xDD, 0x23] },
                                                  bc => { "" => [0xDD, 0x71, 0x00, 0xDD, 0x23, 0xDD, 0x70, 0x00, 0xDD, 0x23] },
                                                  c  => { "" => [0xDD, 0x71, 0x00, 0xDD, 0x23] },
                                                  d  => { "" => [0xDD, 0x72, 0x00, 0xDD, 0x23] },
                                                  de => { "" => [0xDD, 0x73, 0x00, 0xDD, 0x23, 0xDD, 0x72, 0x00, 0xDD, 0x23] },
                                                  e  => { "" => [0xDD, 0x73, 0x00, 0xDD, 0x23] },
                                                  h  => { "" => [0xDD, 0x74, 0x00, 0xDD, 0x23] },
                                                  hl => { "" => [0xDD, 0x75, 0x00, 0xDD, 0x23, 0xDD, 0x74, 0x00, 0xDD, 0x23] },
                                                  l  => { "" => [0xDD, 0x75, 0x00, 0xDD, 0x23] },
                                                  N  => { "" => [0xDD, 0x36, 0x00, "N", 0xDD, 0x23] },
                                                },
                                       },
                                "+" => {
                                         DIS => {
                                                  ")" => {
                                                           "," => {
                                                                    a  => { "" => [0xDD, 0x77, "DIS", 0xDD, 0x23] },
                                                                    b  => { "" => [0xDD, 0x70, "DIS", 0xDD, 0x23] },
                                                                    bc => { "" => [0xDD, 0x71, "DIS", 0xDD, 0x23, 0xDD, 0x70, "DIS", 0xDD, 0x23] },
                                                                    c  => { "" => [0xDD, 0x71, "DIS", 0xDD, 0x23] },
                                                                    d  => { "" => [0xDD, 0x72, "DIS", 0xDD, 0x23] },
                                                                    de => { "" => [0xDD, 0x73, "DIS", 0xDD, 0x23, 0xDD, 0x72, "DIS", 0xDD, 0x23] },
                                                                    e  => { "" => [0xDD, 0x73, "DIS", 0xDD, 0x23] },
                                                                    h  => { "" => [0xDD, 0x74, "DIS", 0xDD, 0x23] },
                                                                    hl => { "" => [0xDD, 0x75, "DIS", 0xDD, 0x23, 0xDD, 0x74, "DIS", 0xDD, 0x23] },
                                                                    l  => { "" => [0xDD, 0x75, "DIS", 0xDD, 0x23] },
                                                                    N  => { "" => [0xDD, 0x36, "DIS", "N", 0xDD, 0x23] },
                                                                  },
                                                         },
                                                },
                                       },
                                "-" => {
                                         NDIS => {
                                           ")" => {
                                                    "," => {
                                                             a  => { "" => [0xDD, 0x77, "NDIS", 0xDD, 0x23] },
                                                             b  => { "" => [0xDD, 0x70, "NDIS", 0xDD, 0x23] },
                                                             bc => { "" => [0xDD, 0x71, "NDIS", 0xDD, 0x23, 0xDD, 0x70, "NDIS", 0xDD, 0x23] },
                                                             c  => { "" => [0xDD, 0x71, "NDIS", 0xDD, 0x23] },
                                                             d  => { "" => [0xDD, 0x72, "NDIS", 0xDD, 0x23] },
                                                             de => { "" => [0xDD, 0x73, "NDIS", 0xDD, 0x23, 0xDD, 0x72, "NDIS", 0xDD, 0x23] },
                                                             e  => { "" => [0xDD, 0x73, "NDIS", 0xDD, 0x23] },
                                                             h  => { "" => [0xDD, 0x74, "NDIS", 0xDD, 0x23] },
                                                             hl => { "" => [0xDD, 0x75, "NDIS", 0xDD, 0x23, 0xDD, 0x74, "NDIS", 0xDD, 0x23] },
                                                             l  => { "" => [0xDD, 0x75, "NDIS", 0xDD, 0x23] },
                                                             N  => { "" => [0xDD, 0x36, "NDIS", "N", 0xDD, 0x23] },
                                                           },
                                                  },
                                         },
                                       },
                              },
                        iy => {
                                ")" => {
                                         "," => {
                                                  a  => { "" => [0xFD, 0x77, 0x00, 0xFD, 0x23] },
                                                  b  => { "" => [0xFD, 0x70, 0x00, 0xFD, 0x23] },
                                                  bc => { "" => [0xFD, 0x71, 0x00, 0xFD, 0x23, 0xFD, 0x70, 0x00, 0xFD, 0x23] },
                                                  c  => { "" => [0xFD, 0x71, 0x00, 0xFD, 0x23] },
                                                  d  => { "" => [0xFD, 0x72, 0x00, 0xFD, 0x23] },
                                                  de => { "" => [0xFD, 0x73, 0x00, 0xFD, 0x23, 0xFD, 0x72, 0x00, 0xFD, 0x23] },
                                                  e  => { "" => [0xFD, 0x73, 0x00, 0xFD, 0x23] },
                                                  h  => { "" => [0xFD, 0x74, 0x00, 0xFD, 0x23] },
                                                  hl => { "" => [0xFD, 0x75, 0x00, 0xFD, 0x23, 0xFD, 0x74, 0x00, 0xFD, 0x23] },
                                                  l  => { "" => [0xFD, 0x75, 0x00, 0xFD, 0x23] },
                                                  N  => { "" => [0xFD, 0x36, 0x00, "N", 0xFD, 0x23] },
                                                },
                                       },
                                "+" => {
                                         DIS => {
                                                  ")" => {
                                                           "," => {
                                                                    a  => { "" => [0xFD, 0x77, "DIS", 0xFD, 0x23] },
                                                                    b  => { "" => [0xFD, 0x70, "DIS", 0xFD, 0x23] },
                                                                    bc => { "" => [0xFD, 0x71, "DIS", 0xFD, 0x23, 0xFD, 0x70, "DIS", 0xFD, 0x23] },
                                                                    c  => { "" => [0xFD, 0x71, "DIS", 0xFD, 0x23] },
                                                                    d  => { "" => [0xFD, 0x72, "DIS", 0xFD, 0x23] },
                                                                    de => { "" => [0xFD, 0x73, "DIS", 0xFD, 0x23, 0xFD, 0x72, "DIS", 0xFD, 0x23] },
                                                                    e  => { "" => [0xFD, 0x73, "DIS", 0xFD, 0x23] },
                                                                    h  => { "" => [0xFD, 0x74, "DIS", 0xFD, 0x23] },
                                                                    hl => { "" => [0xFD, 0x75, "DIS", 0xFD, 0x23, 0xFD, 0x74, "DIS", 0xFD, 0x23] },
                                                                    l  => { "" => [0xFD, 0x75, "DIS", 0xFD, 0x23] },
                                                                    N  => { "" => [0xFD, 0x36, "DIS", "N", 0xFD, 0x23] },
                                                                  },
                                                         },
                                                },
                                       },
                                "-" => {
                                         NDIS => {
                                           ")" => {
                                                    "," => {
                                                             a  => { "" => [0xFD, 0x77, "NDIS", 0xFD, 0x23] },
                                                             b  => { "" => [0xFD, 0x70, "NDIS", 0xFD, 0x23] },
                                                             bc => { "" => [0xFD, 0x71, "NDIS", 0xFD, 0x23, 0xFD, 0x70, "NDIS", 0xFD, 0x23] },
                                                             c  => { "" => [0xFD, 0x71, "NDIS", 0xFD, 0x23] },
                                                             d  => { "" => [0xFD, 0x72, "NDIS", 0xFD, 0x23] },
                                                             de => { "" => [0xFD, 0x73, "NDIS", 0xFD, 0x23, 0xFD, 0x72, "NDIS", 0xFD, 0x23] },
                                                             e  => { "" => [0xFD, 0x73, "NDIS", 0xFD, 0x23] },
                                                             h  => { "" => [0xFD, 0x74, "NDIS", 0xFD, 0x23] },
                                                             hl => { "" => [0xFD, 0x75, "NDIS", 0xFD, 0x23, 0xFD, 0x74, "NDIS", 0xFD, 0x23] },
                                                             l  => { "" => [0xFD, 0x75, "NDIS", 0xFD, 0x23] },
                                                             N  => { "" => [0xFD, 0x36, "NDIS", "N", 0xFD, 0x23] },
                                                           },
                                                  },
                                         },
                                       },
                              },
                      },
              "["  => {
                        bc => { "]" => { "," => { a => { "" => [0x02, 0x03] } } } },
                        de => { "]" => { "," => { a => { "" => [0x12, 0x13] } } } },
                        hl => {
                                "]" => {
                                         "," => {
                                                  a  => { "" => [0x77, 0x23] },
                                                  b  => { "" => [0x70, 0x23] },
                                                  bc => { "" => [0x71, 0x23, 0x70, 0x23] },
                                                  c  => { "" => [0x71, 0x23] },
                                                  d  => { "" => [0x72, 0x23] },
                                                  de => { "" => [0x73, 0x23, 0x72, 0x23] },
                                                  e  => { "" => [0x73, 0x23] },
                                                  h  => { "" => [0x74, 0x23] },
                                                  l  => { "" => [0x75, 0x23] },
                                                  N  => { "" => [0x36, "N", 0x23] },
                                                },
                                       },
                              },
                        ix => {
                                "+" => {
                                         DIS => {
                                                  "]" => {
                                                           "," => {
                                                                    a  => { "" => [0xDD, 0x77, "DIS", 0xDD, 0x23] },
                                                                    b  => { "" => [0xDD, 0x70, "DIS", 0xDD, 0x23] },
                                                                    bc => { "" => [0xDD, 0x71, "DIS", 0xDD, 0x23, 0xDD, 0x70, "DIS", 0xDD, 0x23] },
                                                                    c  => { "" => [0xDD, 0x71, "DIS", 0xDD, 0x23] },
                                                                    d  => { "" => [0xDD, 0x72, "DIS", 0xDD, 0x23] },
                                                                    de => { "" => [0xDD, 0x73, "DIS", 0xDD, 0x23, 0xDD, 0x72, "DIS", 0xDD, 0x23] },
                                                                    e  => { "" => [0xDD, 0x73, "DIS", 0xDD, 0x23] },
                                                                    h  => { "" => [0xDD, 0x74, "DIS", 0xDD, 0x23] },
                                                                    hl => { "" => [0xDD, 0x75, "DIS", 0xDD, 0x23, 0xDD, 0x74, "DIS", 0xDD, 0x23] },
                                                                    l  => { "" => [0xDD, 0x75, "DIS", 0xDD, 0x23] },
                                                                    N  => { "" => [0xDD, 0x36, "DIS", "N", 0xDD, 0x23] },
                                                                  },
                                                         },
                                                },
                                       },
                                "-" => {
                                         NDIS => {
                                           "]" => {
                                                    "," => {
                                                             a  => { "" => [0xDD, 0x77, "NDIS", 0xDD, 0x23] },
                                                             b  => { "" => [0xDD, 0x70, "NDIS", 0xDD, 0x23] },
                                                             bc => { "" => [0xDD, 0x71, "NDIS", 0xDD, 0x23, 0xDD, 0x70, "NDIS", 0xDD, 0x23] },
                                                             c  => { "" => [0xDD, 0x71, "NDIS", 0xDD, 0x23] },
                                                             d  => { "" => [0xDD, 0x72, "NDIS", 0xDD, 0x23] },
                                                             de => { "" => [0xDD, 0x73, "NDIS", 0xDD, 0x23, 0xDD, 0x72, "NDIS", 0xDD, 0x23] },
                                                             e  => { "" => [0xDD, 0x73, "NDIS", 0xDD, 0x23] },
                                                             h  => { "" => [0xDD, 0x74, "NDIS", 0xDD, 0x23] },
                                                             hl => { "" => [0xDD, 0x75, "NDIS", 0xDD, 0x23, 0xDD, 0x74, "NDIS", 0xDD, 0x23] },
                                                             l  => { "" => [0xDD, 0x75, "NDIS", 0xDD, 0x23] },
                                                             N  => { "" => [0xDD, 0x36, "NDIS", "N", 0xDD, 0x23] },
                                                           },
                                                  },
                                         },
                                       },
                                "]" => {
                                         "," => {
                                                  a  => { "" => [0xDD, 0x77, 0x00, 0xDD, 0x23] },
                                                  b  => { "" => [0xDD, 0x70, 0x00, 0xDD, 0x23] },
                                                  bc => { "" => [0xDD, 0x71, 0x00, 0xDD, 0x23, 0xDD, 0x70, 0x00, 0xDD, 0x23] },
                                                  c  => { "" => [0xDD, 0x71, 0x00, 0xDD, 0x23] },
                                                  d  => { "" => [0xDD, 0x72, 0x00, 0xDD, 0x23] },
                                                  de => { "" => [0xDD, 0x73, 0x00, 0xDD, 0x23, 0xDD, 0x72, 0x00, 0xDD, 0x23] },
                                                  e  => { "" => [0xDD, 0x73, 0x00, 0xDD, 0x23] },
                                                  h  => { "" => [0xDD, 0x74, 0x00, 0xDD, 0x23] },
                                                  hl => { "" => [0xDD, 0x75, 0x00, 0xDD, 0x23, 0xDD, 0x74, 0x00, 0xDD, 0x23] },
                                                  l  => { "" => [0xDD, 0x75, 0x00, 0xDD, 0x23] },
                                                  N  => { "" => [0xDD, 0x36, 0x00, "N", 0xDD, 0x23] },
                                                },
                                       },
                              },
                        iy => {
                                "+" => {
                                         DIS => {
                                                  "]" => {
                                                           "," => {
                                                                    a  => { "" => [0xFD, 0x77, "DIS", 0xFD, 0x23] },
                                                                    b  => { "" => [0xFD, 0x70, "DIS", 0xFD, 0x23] },
                                                                    bc => { "" => [0xFD, 0x71, "DIS", 0xFD, 0x23, 0xFD, 0x70, "DIS", 0xFD, 0x23] },
                                                                    c  => { "" => [0xFD, 0x71, "DIS", 0xFD, 0x23] },
                                                                    d  => { "" => [0xFD, 0x72, "DIS", 0xFD, 0x23] },
                                                                    de => { "" => [0xFD, 0x73, "DIS", 0xFD, 0x23, 0xFD, 0x72, "DIS", 0xFD, 0x23] },
                                                                    e  => { "" => [0xFD, 0x73, "DIS", 0xFD, 0x23] },
                                                                    h  => { "" => [0xFD, 0x74, "DIS", 0xFD, 0x23] },
                                                                    hl => { "" => [0xFD, 0x75, "DIS", 0xFD, 0x23, 0xFD, 0x74, "DIS", 0xFD, 0x23] },
                                                                    l  => { "" => [0xFD, 0x75, "DIS", 0xFD, 0x23] },
                                                                    N  => { "" => [0xFD, 0x36, "DIS", "N", 0xFD, 0x23] },
                                                                  },
                                                         },
                                                },
                                       },
                                "-" => {
                                         NDIS => {
                                           "]" => {
                                                    "," => {
                                                             a  => { "" => [0xFD, 0x77, "NDIS", 0xFD, 0x23] },
                                                             b  => { "" => [0xFD, 0x70, "NDIS", 0xFD, 0x23] },
                                                             bc => { "" => [0xFD, 0x71, "NDIS", 0xFD, 0x23, 0xFD, 0x70, "NDIS", 0xFD, 0x23] },
                                                             c  => { "" => [0xFD, 0x71, "NDIS", 0xFD, 0x23] },
                                                             d  => { "" => [0xFD, 0x72, "NDIS", 0xFD, 0x23] },
                                                             de => { "" => [0xFD, 0x73, "NDIS", 0xFD, 0x23, 0xFD, 0x72, "NDIS", 0xFD, 0x23] },
                                                             e  => { "" => [0xFD, 0x73, "NDIS", 0xFD, 0x23] },
                                                             h  => { "" => [0xFD, 0x74, "NDIS", 0xFD, 0x23] },
                                                             hl => { "" => [0xFD, 0x75, "NDIS", 0xFD, 0x23, 0xFD, 0x74, "NDIS", 0xFD, 0x23] },
                                                             l  => { "" => [0xFD, 0x75, "NDIS", 0xFD, 0x23] },
                                                             N  => { "" => [0xFD, 0x36, "NDIS", "N", 0xFD, 0x23] },
                                                           },
                                                  },
                                         },
                                       },
                                "]" => {
                                         "," => {
                                                  a  => { "" => [0xFD, 0x77, 0x00, 0xFD, 0x23] },
                                                  b  => { "" => [0xFD, 0x70, 0x00, 0xFD, 0x23] },
                                                  bc => { "" => [0xFD, 0x71, 0x00, 0xFD, 0x23, 0xFD, 0x70, 0x00, 0xFD, 0x23] },
                                                  c  => { "" => [0xFD, 0x71, 0x00, 0xFD, 0x23] },
                                                  d  => { "" => [0xFD, 0x72, 0x00, 0xFD, 0x23] },
                                                  de => { "" => [0xFD, 0x73, 0x00, 0xFD, 0x23, 0xFD, 0x72, 0x00, 0xFD, 0x23] },
                                                  e  => { "" => [0xFD, 0x73, 0x00, 0xFD, 0x23] },
                                                  h  => { "" => [0xFD, 0x74, 0x00, 0xFD, 0x23] },
                                                  hl => { "" => [0xFD, 0x75, 0x00, 0xFD, 0x23, 0xFD, 0x74, 0x00, 0xFD, 0x23] },
                                                  l  => { "" => [0xFD, 0x75, 0x00, 0xFD, 0x23] },
                                                  N  => { "" => [0xFD, 0x36, 0x00, "N", 0xFD, 0x23] },
                                                },
                                       },
                              },
                      },
              "a"  => {
                        "," => {
                                 "(" => {
                                          bc => { ")" => { "" => [0x0A, 0x03] } },
                                          de => { ")" => { "" => [0x1A, 0x13] } },
                                          hl => { ")" => { "" => [0x7E, 0x23] } },
                                          ix => {
                                                  ")" => { "" => [0xDD, 0x7E, 0x00, 0xDD, 0x23] },
                                                  "+" => { DIS => { ")" => { "" => [0xDD, 0x7E, "DIS", 0xDD, 0x23] } } },
                                                  "-" => { NDIS => { ")" => { "" => [0xDD, 0x7E, "NDIS", 0xDD, 0x23] } } },
                                                },
                                          iy => {
                                                  ")" => { "" => [0xFD, 0x7E, 0x00, 0xFD, 0x23] },
                                                  "+" => { DIS => { ")" => { "" => [0xFD, 0x7E, "DIS", 0xFD, 0x23] } } },
                                                  "-" => { NDIS => { ")" => { "" => [0xFD, 0x7E, "NDIS", 0xFD, 0x23] } } },
                                                },
                                        },
                                 "[" => {
                                          bc => { "]" => { "" => [0x0A, 0x03] } },
                                          de => { "]" => { "" => [0x1A, 0x13] } },
                                          hl => { "]" => { "" => [0x7E, 0x23] } },
                                          ix => {
                                                  "+" => { DIS => { "]" => { "" => [0xDD, 0x7E, "DIS", 0xDD, 0x23] } } },
                                                  "-" => { NDIS => { "]" => { "" => [0xDD, 0x7E, "NDIS", 0xDD, 0x23] } } },
                                                  "]" => { "" => [0xDD, 0x7E, 0x00, 0xDD, 0x23] },
                                                },
                                          iy => {
                                                  "+" => { DIS => { "]" => { "" => [0xFD, 0x7E, "DIS", 0xFD, 0x23] } } },
                                                  "-" => { NDIS => { "]" => { "" => [0xFD, 0x7E, "NDIS", 0xFD, 0x23] } } },
                                                  "]" => { "" => [0xFD, 0x7E, 0x00, 0xFD, 0x23] },
                                                },
                                        },
                               },
                      },
              "b"  => {
                        "," => {
                                 "(" => {
                                          hl => { ")" => { "" => [0x46, 0x23] } },
                                          ix => {
                                                  ")" => { "" => [0xDD, 0x46, 0x00, 0xDD, 0x23] },
                                                  "+" => { DIS => { ")" => { "" => [0xDD, 0x46, "DIS", 0xDD, 0x23] } } },
                                                  "-" => { NDIS => { ")" => { "" => [0xDD, 0x46, "NDIS", 0xDD, 0x23] } } },
                                                },
                                          iy => {
                                                  ")" => { "" => [0xFD, 0x46, 0x00, 0xFD, 0x23] },
                                                  "+" => { DIS => { ")" => { "" => [0xFD, 0x46, "DIS", 0xFD, 0x23] } } },
                                                  "-" => { NDIS => { ")" => { "" => [0xFD, 0x46, "NDIS", 0xFD, 0x23] } } },
                                                },
                                        },
                                 "[" => {
                                          hl => { "]" => { "" => [0x46, 0x23] } },
                                          ix => {
                                                  "+" => { DIS => { "]" => { "" => [0xDD, 0x46, "DIS", 0xDD, 0x23] } } },
                                                  "-" => { NDIS => { "]" => { "" => [0xDD, 0x46, "NDIS", 0xDD, 0x23] } } },
                                                  "]" => { "" => [0xDD, 0x46, 0x00, 0xDD, 0x23] },
                                                },
                                          iy => {
                                                  "+" => { DIS => { "]" => { "" => [0xFD, 0x46, "DIS", 0xFD, 0x23] } } },
                                                  "-" => { NDIS => { "]" => { "" => [0xFD, 0x46, "NDIS", 0xFD, 0x23] } } },
                                                  "]" => { "" => [0xFD, 0x46, 0x00, 0xFD, 0x23] },
                                                },
                                        },
                               },
                      },
              "bc" => {
                        "," => {
                                 "(" => {
                                          hl => { ")" => { "" => [0x4E, 0x23, 0x46, 0x23] } },
                                          ix => {
                                                  ")" => { "" => [0xDD, 0x4E, 0x00, 0xDD, 0x23, 0xDD, 0x46, 0x00, 0xDD, 0x23] },
                                                  "+" => {
                                                           DIS => {
                                                                    ")" => { "" => [0xDD, 0x4E, "DIS", 0xDD, 0x23, 0xDD, 0x46, "DIS", 0xDD, 0x23] },
                                                                  },
                                                         },
                                                  "-" => {
                                                           NDIS => {
                                                             ")" => { "" => [0xDD, 0x4E, "NDIS", 0xDD, 0x23, 0xDD, 0x46, "NDIS", 0xDD, 0x23] },
                                                           },
                                                         },
                                                },
                                          iy => {
                                                  ")" => { "" => [0xFD, 0x4E, 0x00, 0xFD, 0x23, 0xFD, 0x46, 0x00, 0xFD, 0x23] },
                                                  "+" => {
                                                           DIS => {
                                                                    ")" => { "" => [0xFD, 0x4E, "DIS", 0xFD, 0x23, 0xFD, 0x46, "DIS", 0xFD, 0x23] },
                                                                  },
                                                         },
                                                  "-" => {
                                                           NDIS => {
                                                             ")" => { "" => [0xFD, 0x4E, "NDIS", 0xFD, 0x23, 0xFD, 0x46, "NDIS", 0xFD, 0x23] },
                                                           },
                                                         },
                                                },
                                        },
                                 "[" => {
                                          hl => { "]" => { "" => [0x4E, 0x23, 0x46, 0x23] } },
                                          ix => {
                                                  "+" => {
                                                           DIS => {
                                                                    "]" => { "" => [0xDD, 0x4E, "DIS", 0xDD, 0x23, 0xDD, 0x46, "DIS", 0xDD, 0x23] },
                                                                  },
                                                         },
                                                  "-" => {
                                                           NDIS => {
                                                             "]" => { "" => [0xDD, 0x4E, "NDIS", 0xDD, 0x23, 0xDD, 0x46, "NDIS", 0xDD, 0x23] },
                                                           },
                                                         },
                                                  "]" => { "" => [0xDD, 0x4E, 0x00, 0xDD, 0x23, 0xDD, 0x46, 0x00, 0xDD, 0x23] },
                                                },
                                          iy => {
                                                  "+" => {
                                                           DIS => {
                                                                    "]" => { "" => [0xFD, 0x4E, "DIS", 0xFD, 0x23, 0xFD, 0x46, "DIS", 0xFD, 0x23] },
                                                                  },
                                                         },
                                                  "-" => {
                                                           NDIS => {
                                                             "]" => { "" => [0xFD, 0x4E, "NDIS", 0xFD, 0x23, 0xFD, 0x46, "NDIS", 0xFD, 0x23] },
                                                           },
                                                         },
                                                  "]" => { "" => [0xFD, 0x4E, 0x00, 0xFD, 0x23, 0xFD, 0x46, 0x00, 0xFD, 0x23] },
                                                },
                                        },
                               },
                      },
              "c"  => {
                        "," => {
                                 "(" => {
                                          hl => { ")" => { "" => [0x4E, 0x23] } },
                                          ix => {
                                                  ")" => { "" => [0xDD, 0x4E, 0x00, 0xDD, 0x23] },
                                                  "+" => { DIS => { ")" => { "" => [0xDD, 0x4E, "DIS", 0xDD, 0x23] } } },
                                                  "-" => { NDIS => { ")" => { "" => [0xDD, 0x4E, "NDIS", 0xDD, 0x23] } } },
                                                },
                                          iy => {
                                                  ")" => { "" => [0xFD, 0x4E, 0x00, 0xFD, 0x23] },
                                                  "+" => { DIS => { ")" => { "" => [0xFD, 0x4E, "DIS", 0xFD, 0x23] } } },
                                                  "-" => { NDIS => { ")" => { "" => [0xFD, 0x4E, "NDIS", 0xFD, 0x23] } } },
                                                },
                                        },
                                 "[" => {
                                          hl => { "]" => { "" => [0x4E, 0x23] } },
                                          ix => {
                                                  "+" => { DIS => { "]" => { "" => [0xDD, 0x4E, "DIS", 0xDD, 0x23] } } },
                                                  "-" => { NDIS => { "]" => { "" => [0xDD, 0x4E, "NDIS", 0xDD, 0x23] } } },
                                                  "]" => { "" => [0xDD, 0x4E, 0x00, 0xDD, 0x23] },
                                                },
                                          iy => {
                                                  "+" => { DIS => { "]" => { "" => [0xFD, 0x4E, "DIS", 0xFD, 0x23] } } },
                                                  "-" => { NDIS => { "]" => { "" => [0xFD, 0x4E, "NDIS", 0xFD, 0x23] } } },
                                                  "]" => { "" => [0xFD, 0x4E, 0x00, 0xFD, 0x23] },
                                                },
                                        },
                               },
                      },
              "d"  => {
                        "," => {
                                 "(" => {
                                          hl => { ")" => { "" => [0x56, 0x23] } },
                                          ix => {
                                                  ")" => { "" => [0xDD, 0x56, 0x00, 0xDD, 0x23] },
                                                  "+" => { DIS => { ")" => { "" => [0xDD, 0x56, "DIS", 0xDD, 0x23] } } },
                                                  "-" => { NDIS => { ")" => { "" => [0xDD, 0x56, "NDIS", 0xDD, 0x23] } } },
                                                },
                                          iy => {
                                                  ")" => { "" => [0xFD, 0x56, 0x00, 0xFD, 0x23] },
                                                  "+" => { DIS => { ")" => { "" => [0xFD, 0x56, "DIS", 0xFD, 0x23] } } },
                                                  "-" => { NDIS => { ")" => { "" => [0xFD, 0x56, "NDIS", 0xFD, 0x23] } } },
                                                },
                                        },
                                 "[" => {
                                          hl => { "]" => { "" => [0x56, 0x23] } },
                                          ix => {
                                                  "+" => { DIS => { "]" => { "" => [0xDD, 0x56, "DIS", 0xDD, 0x23] } } },
                                                  "-" => { NDIS => { "]" => { "" => [0xDD, 0x56, "NDIS", 0xDD, 0x23] } } },
                                                  "]" => { "" => [0xDD, 0x56, 0x00, 0xDD, 0x23] },
                                                },
                                          iy => {
                                                  "+" => { DIS => { "]" => { "" => [0xFD, 0x56, "DIS", 0xFD, 0x23] } } },
                                                  "-" => { NDIS => { "]" => { "" => [0xFD, 0x56, "NDIS", 0xFD, 0x23] } } },
                                                  "]" => { "" => [0xFD, 0x56, 0x00, 0xFD, 0x23] },
                                                },
                                        },
                               },
                      },
              "de" => {
                        "," => {
                                 "(" => {
                                          hl => { ")" => { "" => [0x5E, 0x23, 0x56, 0x23] } },
                                          ix => {
                                                  ")" => { "" => [0xDD, 0x5E, 0x00, 0xDD, 0x23, 0xDD, 0x56, 0x00, 0xDD, 0x23] },
                                                  "+" => {
                                                           DIS => {
                                                                    ")" => { "" => [0xDD, 0x5E, "DIS", 0xDD, 0x23, 0xDD, 0x56, "DIS", 0xDD, 0x23] },
                                                                  },
                                                         },
                                                  "-" => {
                                                           NDIS => {
                                                             ")" => { "" => [0xDD, 0x5E, "NDIS", 0xDD, 0x23, 0xDD, 0x56, "NDIS", 0xDD, 0x23] },
                                                           },
                                                         },
                                                },
                                          iy => {
                                                  ")" => { "" => [0xFD, 0x5E, 0x00, 0xFD, 0x23, 0xFD, 0x56, 0x00, 0xFD, 0x23] },
                                                  "+" => {
                                                           DIS => {
                                                                    ")" => { "" => [0xFD, 0x5E, "DIS", 0xFD, 0x23, 0xFD, 0x56, "DIS", 0xFD, 0x23] },
                                                                  },
                                                         },
                                                  "-" => {
                                                           NDIS => {
                                                             ")" => { "" => [0xFD, 0x5E, "NDIS", 0xFD, 0x23, 0xFD, 0x56, "NDIS", 0xFD, 0x23] },
                                                           },
                                                         },
                                                },
                                        },
                                 "[" => {
                                          hl => { "]" => { "" => [0x5E, 0x23, 0x56, 0x23] } },
                                          ix => {
                                                  "+" => {
                                                           DIS => {
                                                                    "]" => { "" => [0xDD, 0x5E, "DIS", 0xDD, 0x23, 0xDD, 0x56, "DIS", 0xDD, 0x23] },
                                                                  },
                                                         },
                                                  "-" => {
                                                           NDIS => {
                                                             "]" => { "" => [0xDD, 0x5E, "NDIS", 0xDD, 0x23, 0xDD, 0x56, "NDIS", 0xDD, 0x23] },
                                                           },
                                                         },
                                                  "]" => { "" => [0xDD, 0x5E, 0x00, 0xDD, 0x23, 0xDD, 0x56, 0x00, 0xDD, 0x23] },
                                                },
                                          iy => {
                                                  "+" => {
                                                           DIS => {
                                                                    "]" => { "" => [0xFD, 0x5E, "DIS", 0xFD, 0x23, 0xFD, 0x56, "DIS", 0xFD, 0x23] },
                                                                  },
                                                         },
                                                  "-" => {
                                                           NDIS => {
                                                             "]" => { "" => [0xFD, 0x5E, "NDIS", 0xFD, 0x23, 0xFD, 0x56, "NDIS", 0xFD, 0x23] },
                                                           },
                                                         },
                                                  "]" => { "" => [0xFD, 0x5E, 0x00, 0xFD, 0x23, 0xFD, 0x56, 0x00, 0xFD, 0x23] },
                                                },
                                        },
                               },
                      },
              "e"  => {
                        "," => {
                                 "(" => {
                                          hl => { ")" => { "" => [0x5E, 0x23] } },
                                          ix => {
                                                  ")" => { "" => [0xDD, 0x5E, 0x00, 0xDD, 0x23] },
                                                  "+" => { DIS => { ")" => { "" => [0xDD, 0x5E, "DIS", 0xDD, 0x23] } } },
                                                  "-" => { NDIS => { ")" => { "" => [0xDD, 0x5E, "NDIS", 0xDD, 0x23] } } },
                                                },
                                          iy => {
                                                  ")" => { "" => [0xFD, 0x5E, 0x00, 0xFD, 0x23] },
                                                  "+" => { DIS => { ")" => { "" => [0xFD, 0x5E, "DIS", 0xFD, 0x23] } } },
                                                  "-" => { NDIS => { ")" => { "" => [0xFD, 0x5E, "NDIS", 0xFD, 0x23] } } },
                                                },
                                        },
                                 "[" => {
                                          hl => { "]" => { "" => [0x5E, 0x23] } },
                                          ix => {
                                                  "+" => { DIS => { "]" => { "" => [0xDD, 0x5E, "DIS", 0xDD, 0x23] } } },
                                                  "-" => { NDIS => { "]" => { "" => [0xDD, 0x5E, "NDIS", 0xDD, 0x23] } } },
                                                  "]" => { "" => [0xDD, 0x5E, 0x00, 0xDD, 0x23] },
                                                },
                                          iy => {
                                                  "+" => { DIS => { "]" => { "" => [0xFD, 0x5E, "DIS", 0xFD, 0x23] } } },
                                                  "-" => { NDIS => { "]" => { "" => [0xFD, 0x5E, "NDIS", 0xFD, 0x23] } } },
                                                  "]" => { "" => [0xFD, 0x5E, 0x00, 0xFD, 0x23] },
                                                },
                                        },
                               },
                      },
              "h"  => {
                        "," => {
                                 "(" => {
                                          hl => { ")" => { "" => [0x66, 0x23] } },
                                          ix => {
                                                  ")" => { "" => [0xDD, 0x66, 0x00, 0xDD, 0x23] },
                                                  "+" => { DIS => { ")" => { "" => [0xDD, 0x66, "DIS", 0xDD, 0x23] } } },
                                                  "-" => { NDIS => { ")" => { "" => [0xDD, 0x66, "NDIS", 0xDD, 0x23] } } },
                                                },
                                          iy => {
                                                  ")" => { "" => [0xFD, 0x66, 0x00, 0xFD, 0x23] },
                                                  "+" => { DIS => { ")" => { "" => [0xFD, 0x66, "DIS", 0xFD, 0x23] } } },
                                                  "-" => { NDIS => { ")" => { "" => [0xFD, 0x66, "NDIS", 0xFD, 0x23] } } },
                                                },
                                        },
                                 "[" => {
                                          hl => { "]" => { "" => [0x66, 0x23] } },
                                          ix => {
                                                  "+" => { DIS => { "]" => { "" => [0xDD, 0x66, "DIS", 0xDD, 0x23] } } },
                                                  "-" => { NDIS => { "]" => { "" => [0xDD, 0x66, "NDIS", 0xDD, 0x23] } } },
                                                  "]" => { "" => [0xDD, 0x66, 0x00, 0xDD, 0x23] },
                                                },
                                          iy => {
                                                  "+" => { DIS => { "]" => { "" => [0xFD, 0x66, "DIS", 0xFD, 0x23] } } },
                                                  "-" => { NDIS => { "]" => { "" => [0xFD, 0x66, "NDIS", 0xFD, 0x23] } } },
                                                  "]" => { "" => [0xFD, 0x66, 0x00, 0xFD, 0x23] },
                                                },
                                        },
                               },
                      },
              "hl" => {
                        "," => {
                                 "(" => {
                                          ix => {
                                                  ")" => { "" => [0xDD, 0x6E, 0x00, 0xDD, 0x23, 0xDD, 0x66, 0x00, 0xDD, 0x23] },
                                                  "+" => {
                                                           DIS => {
                                                                    ")" => { "" => [0xDD, 0x6E, "DIS", 0xDD, 0x23, 0xDD, 0x66, "DIS", 0xDD, 0x23] },
                                                                  },
                                                         },
                                                  "-" => {
                                                           NDIS => {
                                                             ")" => { "" => [0xDD, 0x6E, "NDIS", 0xDD, 0x23, 0xDD, 0x66, "NDIS", 0xDD, 0x23] },
                                                           },
                                                         },
                                                },
                                          iy => {
                                                  ")" => { "" => [0xFD, 0x6E, 0x00, 0xFD, 0x23, 0xFD, 0x66, 0x00, 0xFD, 0x23] },
                                                  "+" => {
                                                           DIS => {
                                                                    ")" => { "" => [0xFD, 0x6E, "DIS", 0xFD, 0x23, 0xFD, 0x66, "DIS", 0xFD, 0x23] },
                                                                  },
                                                         },
                                                  "-" => {
                                                           NDIS => {
                                                             ")" => { "" => [0xFD, 0x6E, "NDIS", 0xFD, 0x23, 0xFD, 0x66, "NDIS", 0xFD, 0x23] },
                                                           },
                                                         },
                                                },
                                        },
                                 "[" => {
                                          ix => {
                                                  "+" => {
                                                           DIS => {
                                                                    "]" => { "" => [0xDD, 0x6E, "DIS", 0xDD, 0x23, 0xDD, 0x66, "DIS", 0xDD, 0x23] },
                                                                  },
                                                         },
                                                  "-" => {
                                                           NDIS => {
                                                             "]" => { "" => [0xDD, 0x6E, "NDIS", 0xDD, 0x23, 0xDD, 0x66, "NDIS", 0xDD, 0x23] },
                                                           },
                                                         },
                                                  "]" => { "" => [0xDD, 0x6E, 0x00, 0xDD, 0x23, 0xDD, 0x66, 0x00, 0xDD, 0x23] },
                                                },
                                          iy => {
                                                  "+" => {
                                                           DIS => {
                                                                    "]" => { "" => [0xFD, 0x6E, "DIS", 0xFD, 0x23, 0xFD, 0x66, "DIS", 0xFD, 0x23] },
                                                                  },
                                                         },
                                                  "-" => {
                                                           NDIS => {
                                                             "]" => { "" => [0xFD, 0x6E, "NDIS", 0xFD, 0x23, 0xFD, 0x66, "NDIS", 0xFD, 0x23] },
                                                           },
                                                         },
                                                  "]" => { "" => [0xFD, 0x6E, 0x00, 0xFD, 0x23, 0xFD, 0x66, 0x00, 0xFD, 0x23] },
                                                },
                                        },
                               },
                      },
              "l"  => {
                        "," => {
                                 "(" => {
                                          hl => { ")" => { "" => [0x6E, 0x23] } },
                                          ix => {
                                                  ")" => { "" => [0xDD, 0x6E, 0x00, 0xDD, 0x23] },
                                                  "+" => { DIS => { ")" => { "" => [0xDD, 0x6E, "DIS", 0xDD, 0x23] } } },
                                                  "-" => { NDIS => { ")" => { "" => [0xDD, 0x6E, "NDIS", 0xDD, 0x23] } } },
                                                },
                                          iy => {
                                                  ")" => { "" => [0xFD, 0x6E, 0x00, 0xFD, 0x23] },
                                                  "+" => { DIS => { ")" => { "" => [0xFD, 0x6E, "DIS", 0xFD, 0x23] } } },
                                                  "-" => { NDIS => { ")" => { "" => [0xFD, 0x6E, "NDIS", 0xFD, 0x23] } } },
                                                },
                                        },
                                 "[" => {
                                          hl => { "]" => { "" => [0x6E, 0x23] } },
                                          ix => {
                                                  "+" => { DIS => { "]" => { "" => [0xDD, 0x6E, "DIS", 0xDD, 0x23] } } },
                                                  "-" => { NDIS => { "]" => { "" => [0xDD, 0x6E, "NDIS", 0xDD, 0x23] } } },
                                                  "]" => { "" => [0xDD, 0x6E, 0x00, 0xDD, 0x23] },
                                                },
                                          iy => {
                                                  "+" => { DIS => { "]" => { "" => [0xFD, 0x6E, "DIS", 0xFD, 0x23] } } },
                                                  "-" => { NDIS => { "]" => { "" => [0xFD, 0x6E, "NDIS", 0xFD, 0x23] } } },
                                                  "]" => { "" => [0xFD, 0x6E, 0x00, 0xFD, 0x23] },
                                                },
                                        },
                               },
                      },
            },
    ldir => { "" => [0xED, 0xB0] },
    neg  => { "" => [0xED, 0x44] },
    nop  => { "" => [0x00] },
    or   => {
              "("   => {
                         hl => { ")" => { "" => [0xB6] } },
                         ix => {
                                 ")" => { "" => [0xDD, 0xB6, 0x00] },
                                 "+" => { DIS => { ")" => { "" => [0xDD, 0xB6, "DIS"] } } },
                                 "-" => { NDIS => { ")" => { "" => [0xDD, 0xB6, "NDIS"] } } },
                               },
                         iy => {
                                 ")" => { "" => [0xFD, 0xB6, 0x00] },
                                 "+" => { DIS => { ")" => { "" => [0xFD, 0xB6, "DIS"] } } },
                                 "-" => { NDIS => { ")" => { "" => [0xFD, 0xB6, "NDIS"] } } },
                               },
                       },
              "["   => {
                         hl => { "]" => { "" => [0xB6] } },
                         ix => {
                                 "+" => { DIS => { "]" => { "" => [0xDD, 0xB6, "DIS"] } } },
                                 "-" => { NDIS => { "]" => { "" => [0xDD, 0xB6, "NDIS"] } } },
                                 "]" => { "" => [0xDD, 0xB6, 0x00] },
                               },
                         iy => {
                                 "+" => { DIS => { "]" => { "" => [0xFD, 0xB6, "DIS"] } } },
                                 "-" => { NDIS => { "]" => { "" => [0xFD, 0xB6, "NDIS"] } } },
                                 "]" => { "" => [0xFD, 0xB6, 0x00] },
                               },
                       },
              "a"   => { "" => [0xB7] },
              "b"   => { "" => [0xB0] },
              "c"   => { "" => [0xB1] },
              "d"   => { "" => [0xB2] },
              "e"   => { "" => [0xB3] },
              "h"   => { "" => [0xB4] },
              "hx"  => { "" => [0xDD, 0xB4] },
              "hy"  => { "" => [0xFD, 0xB4] },
              "ixh" => { "" => [0xDD, 0xB4] },
              "ixl" => { "" => [0xDD, 0xB5] },
              "iyh" => { "" => [0xFD, 0xB4] },
              "iyl" => { "" => [0xFD, 0xB5] },
              "l"   => { "" => [0xB5] },
              "lx"  => { "" => [0xDD, 0xB5] },
              "ly"  => { "" => [0xFD, 0xB5] },
              "N"   => { "" => [0xF6, "N"] },
              "xh"  => { "" => [0xDD, 0xB4] },
              "xl"  => { "" => [0xDD, 0xB5] },
              "yh"  => { "" => [0xFD, 0xB4] },
              "yl"  => { "" => [0xFD, 0xB5] },
            },
    otdr => { "" => [0xED, 0xBB] },
    otir => { "" => [0xED, 0xB3] },
    out  => {
              "(" => {
                       c => {
                              ")" => {
                                       "," => {
                                                0x00 => { "" => [0xED, 0x71] },
                                                "a" => { "" => [0xED, 0x79] },
                                                "b" => { "" => [0xED, 0x41] },
                                                "c" => { "" => [0xED, 0x49] },
                                                "d" => { "" => [0xED, 0x51] },
                                                "e" => { "" => [0xED, 0x59] },
                                                "h" => { "" => [0xED, 0x61] },
                                                "l" => { "" => [0xED, 0x69] },
                                              },
                                     },
                            },
                       N => { ")" => { "," => { a => { "" => [0xD3, "N"] } } } },
                     },
              "[" => {
                       c => {
                              "]" => {
                                       "," => {
                                                0x00 => { "" => [0xED, 0x71] },
                                                "a" => { "" => [0xED, 0x79] },
                                                "b" => { "" => [0xED, 0x41] },
                                                "c" => { "" => [0xED, 0x49] },
                                                "d" => { "" => [0xED, 0x51] },
                                                "e" => { "" => [0xED, 0x59] },
                                                "h" => { "" => [0xED, 0x61] },
                                                "l" => { "" => [0xED, 0x69] },
                                              },
                                     },
                            },
                       N => { "]" => { "," => { a => { "" => [0xD3, "N"] } } } },
                     },
            },
    outd => { "" => [0xED, 0xAB] },
    outi => { "" => [0xED, 0xA3] },
    pop  => {
              af => { "" => [0xF1] },
              bc => { "" => [0xC1] },
              de => { "" => [0xD1] },
              hl => { "" => [0xE1] },
              ix => { "" => [0xDD, 0xE1] },
              iy => { "" => [0xFD, 0xE1] },
            },
    push => {
              af => { "" => [0xF5] },
              bc => { "" => [0xC5] },
              de => { "" => [0xD5] },
              hl => { "" => [0xE5] },
              ix => { "" => [0xDD, 0xE5] },
              iy => { "" => [0xFD, 0xE5] },
            },
    res  => {
              0x00 => {
                       "," => {
                                "(" => {
                                         hl => { ")" => { "" => [0xCB, 0x86] } },
                                         ix => {
                                                 ")" => {
                                                          ""  => [0xDD, 0xCB, 0x00, 0x86],
                                                          "," => {
                                                                   a => { "" => [0xDD, 0xCB, 0x00, 0x87] },
                                                                   b => { "" => [0xDD, 0xCB, 0x00, 0x80] },
                                                                   c => { "" => [0xDD, 0xCB, 0x00, 0x81] },
                                                                   d => { "" => [0xDD, 0xCB, 0x00, 0x82] },
                                                                   e => { "" => [0xDD, 0xCB, 0x00, 0x83] },
                                                                   h => { "" => [0xDD, 0xCB, 0x00, 0x84] },
                                                                   l => { "" => [0xDD, 0xCB, 0x00, 0x85] },
                                                                 },
                                                        },
                                                 "+" => {
                                                          DIS => {
                                                                   ")" => {
                                                                            ""  => [0xDD, 0xCB, "DIS", 0x86],
                                                                            "," => {
                                                                                     a => { "" => [0xDD, 0xCB, "DIS", 0x87] },
                                                                                     b => { "" => [0xDD, 0xCB, "DIS", 0x80] },
                                                                                     c => { "" => [0xDD, 0xCB, "DIS", 0x81] },
                                                                                     d => { "" => [0xDD, 0xCB, "DIS", 0x82] },
                                                                                     e => { "" => [0xDD, 0xCB, "DIS", 0x83] },
                                                                                     h => { "" => [0xDD, 0xCB, "DIS", 0x84] },
                                                                                     l => { "" => [0xDD, 0xCB, "DIS", 0x85] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            ")" => {
                                                                     ""  => [0xDD, 0xCB, "NDIS", 0x86],
                                                                     "," => {
                                                                              a => { "" => [0xDD, 0xCB, "NDIS", 0x87] },
                                                                              b => { "" => [0xDD, 0xCB, "NDIS", 0x80] },
                                                                              c => { "" => [0xDD, 0xCB, "NDIS", 0x81] },
                                                                              d => { "" => [0xDD, 0xCB, "NDIS", 0x82] },
                                                                              e => { "" => [0xDD, 0xCB, "NDIS", 0x83] },
                                                                              h => { "" => [0xDD, 0xCB, "NDIS", 0x84] },
                                                                              l => { "" => [0xDD, 0xCB, "NDIS", 0x85] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                               },
                                         iy => {
                                                 ")" => {
                                                          ""  => [0xFD, 0xCB, 0x00, 0x86],
                                                          "," => {
                                                                   a => { "" => [0xFD, 0xCB, 0x00, 0x87] },
                                                                   b => { "" => [0xFD, 0xCB, 0x00, 0x80] },
                                                                   c => { "" => [0xFD, 0xCB, 0x00, 0x81] },
                                                                   d => { "" => [0xFD, 0xCB, 0x00, 0x82] },
                                                                   e => { "" => [0xFD, 0xCB, 0x00, 0x83] },
                                                                   h => { "" => [0xFD, 0xCB, 0x00, 0x84] },
                                                                   l => { "" => [0xFD, 0xCB, 0x00, 0x85] },
                                                                 },
                                                        },
                                                 "+" => {
                                                          DIS => {
                                                                   ")" => {
                                                                            ""  => [0xFD, 0xCB, "DIS", 0x86],
                                                                            "," => {
                                                                                     a => { "" => [0xFD, 0xCB, "DIS", 0x87] },
                                                                                     b => { "" => [0xFD, 0xCB, "DIS", 0x80] },
                                                                                     c => { "" => [0xFD, 0xCB, "DIS", 0x81] },
                                                                                     d => { "" => [0xFD, 0xCB, "DIS", 0x82] },
                                                                                     e => { "" => [0xFD, 0xCB, "DIS", 0x83] },
                                                                                     h => { "" => [0xFD, 0xCB, "DIS", 0x84] },
                                                                                     l => { "" => [0xFD, 0xCB, "DIS", 0x85] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            ")" => {
                                                                     ""  => [0xFD, 0xCB, "NDIS", 0x86],
                                                                     "," => {
                                                                              a => { "" => [0xFD, 0xCB, "NDIS", 0x87] },
                                                                              b => { "" => [0xFD, 0xCB, "NDIS", 0x80] },
                                                                              c => { "" => [0xFD, 0xCB, "NDIS", 0x81] },
                                                                              d => { "" => [0xFD, 0xCB, "NDIS", 0x82] },
                                                                              e => { "" => [0xFD, 0xCB, "NDIS", 0x83] },
                                                                              h => { "" => [0xFD, 0xCB, "NDIS", 0x84] },
                                                                              l => { "" => [0xFD, 0xCB, "NDIS", 0x85] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                               },
                                       },
                                "[" => {
                                         hl => { "]" => { "" => [0xCB, 0x86] } },
                                         ix => {
                                                 "+" => {
                                                          DIS => {
                                                                   "]" => {
                                                                            ""  => [0xDD, 0xCB, "DIS", 0x86],
                                                                            "," => {
                                                                                     a => { "" => [0xDD, 0xCB, "DIS", 0x87] },
                                                                                     b => { "" => [0xDD, 0xCB, "DIS", 0x80] },
                                                                                     c => { "" => [0xDD, 0xCB, "DIS", 0x81] },
                                                                                     d => { "" => [0xDD, 0xCB, "DIS", 0x82] },
                                                                                     e => { "" => [0xDD, 0xCB, "DIS", 0x83] },
                                                                                     h => { "" => [0xDD, 0xCB, "DIS", 0x84] },
                                                                                     l => { "" => [0xDD, 0xCB, "DIS", 0x85] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            "]" => {
                                                                     ""  => [0xDD, 0xCB, "NDIS", 0x86],
                                                                     "," => {
                                                                              a => { "" => [0xDD, 0xCB, "NDIS", 0x87] },
                                                                              b => { "" => [0xDD, 0xCB, "NDIS", 0x80] },
                                                                              c => { "" => [0xDD, 0xCB, "NDIS", 0x81] },
                                                                              d => { "" => [0xDD, 0xCB, "NDIS", 0x82] },
                                                                              e => { "" => [0xDD, 0xCB, "NDIS", 0x83] },
                                                                              h => { "" => [0xDD, 0xCB, "NDIS", 0x84] },
                                                                              l => { "" => [0xDD, 0xCB, "NDIS", 0x85] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                                 "]" => {
                                                          ""  => [0xDD, 0xCB, 0x00, 0x86],
                                                          "," => {
                                                                   a => { "" => [0xDD, 0xCB, 0x00, 0x87] },
                                                                   b => { "" => [0xDD, 0xCB, 0x00, 0x80] },
                                                                   c => { "" => [0xDD, 0xCB, 0x00, 0x81] },
                                                                   d => { "" => [0xDD, 0xCB, 0x00, 0x82] },
                                                                   e => { "" => [0xDD, 0xCB, 0x00, 0x83] },
                                                                   h => { "" => [0xDD, 0xCB, 0x00, 0x84] },
                                                                   l => { "" => [0xDD, 0xCB, 0x00, 0x85] },
                                                                 },
                                                        },
                                               },
                                         iy => {
                                                 "+" => {
                                                          DIS => {
                                                                   "]" => {
                                                                            ""  => [0xFD, 0xCB, "DIS", 0x86],
                                                                            "," => {
                                                                                     a => { "" => [0xFD, 0xCB, "DIS", 0x87] },
                                                                                     b => { "" => [0xFD, 0xCB, "DIS", 0x80] },
                                                                                     c => { "" => [0xFD, 0xCB, "DIS", 0x81] },
                                                                                     d => { "" => [0xFD, 0xCB, "DIS", 0x82] },
                                                                                     e => { "" => [0xFD, 0xCB, "DIS", 0x83] },
                                                                                     h => { "" => [0xFD, 0xCB, "DIS", 0x84] },
                                                                                     l => { "" => [0xFD, 0xCB, "DIS", 0x85] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            "]" => {
                                                                     ""  => [0xFD, 0xCB, "NDIS", 0x86],
                                                                     "," => {
                                                                              a => { "" => [0xFD, 0xCB, "NDIS", 0x87] },
                                                                              b => { "" => [0xFD, 0xCB, "NDIS", 0x80] },
                                                                              c => { "" => [0xFD, 0xCB, "NDIS", 0x81] },
                                                                              d => { "" => [0xFD, 0xCB, "NDIS", 0x82] },
                                                                              e => { "" => [0xFD, 0xCB, "NDIS", 0x83] },
                                                                              h => { "" => [0xFD, 0xCB, "NDIS", 0x84] },
                                                                              l => { "" => [0xFD, 0xCB, "NDIS", 0x85] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                                 "]" => {
                                                          ""  => [0xFD, 0xCB, 0x00, 0x86],
                                                          "," => {
                                                                   a => { "" => [0xFD, 0xCB, 0x00, 0x87] },
                                                                   b => { "" => [0xFD, 0xCB, 0x00, 0x80] },
                                                                   c => { "" => [0xFD, 0xCB, 0x00, 0x81] },
                                                                   d => { "" => [0xFD, 0xCB, 0x00, 0x82] },
                                                                   e => { "" => [0xFD, 0xCB, 0x00, 0x83] },
                                                                   h => { "" => [0xFD, 0xCB, 0x00, 0x84] },
                                                                   l => { "" => [0xFD, 0xCB, 0x00, 0x85] },
                                                                 },
                                                        },
                                               },
                                       },
                                "a" => { "" => [0xCB, 0x87] },
                                "b" => { "" => [0xCB, 0x80] },
                                "c" => { "" => [0xCB, 0x81] },
                                "d" => { "" => [0xCB, 0x82] },
                                "e" => { "" => [0xCB, 0x83] },
                                "h" => { "" => [0xCB, 0x84] },
                                "l" => { "" => [0xCB, 0x85] },
                              },
                     },
              0x01 => {
                       "," => {
                                "(" => {
                                         hl => { ")" => { "" => [0xCB, 0x8E] } },
                                         ix => {
                                                 ")" => {
                                                          ""  => [0xDD, 0xCB, 0x00, 0x8E],
                                                          "," => {
                                                                   a => { "" => [0xDD, 0xCB, 0x00, 0x8F] },
                                                                   b => { "" => [0xDD, 0xCB, 0x00, 0x88] },
                                                                   c => { "" => [0xDD, 0xCB, 0x00, 0x89] },
                                                                   d => { "" => [0xDD, 0xCB, 0x00, 0x8A] },
                                                                   e => { "" => [0xDD, 0xCB, 0x00, 0x8B] },
                                                                   h => { "" => [0xDD, 0xCB, 0x00, 0x8C] },
                                                                   l => { "" => [0xDD, 0xCB, 0x00, 0x8D] },
                                                                 },
                                                        },
                                                 "+" => {
                                                          DIS => {
                                                                   ")" => {
                                                                            ""  => [0xDD, 0xCB, "DIS", 0x8E],
                                                                            "," => {
                                                                                     a => { "" => [0xDD, 0xCB, "DIS", 0x8F] },
                                                                                     b => { "" => [0xDD, 0xCB, "DIS", 0x88] },
                                                                                     c => { "" => [0xDD, 0xCB, "DIS", 0x89] },
                                                                                     d => { "" => [0xDD, 0xCB, "DIS", 0x8A] },
                                                                                     e => { "" => [0xDD, 0xCB, "DIS", 0x8B] },
                                                                                     h => { "" => [0xDD, 0xCB, "DIS", 0x8C] },
                                                                                     l => { "" => [0xDD, 0xCB, "DIS", 0x8D] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            ")" => {
                                                                     ""  => [0xDD, 0xCB, "NDIS", 0x8E],
                                                                     "," => {
                                                                              a => { "" => [0xDD, 0xCB, "NDIS", 0x8F] },
                                                                              b => { "" => [0xDD, 0xCB, "NDIS", 0x88] },
                                                                              c => { "" => [0xDD, 0xCB, "NDIS", 0x89] },
                                                                              d => { "" => [0xDD, 0xCB, "NDIS", 0x8A] },
                                                                              e => { "" => [0xDD, 0xCB, "NDIS", 0x8B] },
                                                                              h => { "" => [0xDD, 0xCB, "NDIS", 0x8C] },
                                                                              l => { "" => [0xDD, 0xCB, "NDIS", 0x8D] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                               },
                                         iy => {
                                                 ")" => {
                                                          ""  => [0xFD, 0xCB, 0x00, 0x8E],
                                                          "," => {
                                                                   a => { "" => [0xFD, 0xCB, 0x00, 0x8F] },
                                                                   b => { "" => [0xFD, 0xCB, 0x00, 0x88] },
                                                                   c => { "" => [0xFD, 0xCB, 0x00, 0x89] },
                                                                   d => { "" => [0xFD, 0xCB, 0x00, 0x8A] },
                                                                   e => { "" => [0xFD, 0xCB, 0x00, 0x8B] },
                                                                   h => { "" => [0xFD, 0xCB, 0x00, 0x8C] },
                                                                   l => { "" => [0xFD, 0xCB, 0x00, 0x8D] },
                                                                 },
                                                        },
                                                 "+" => {
                                                          DIS => {
                                                                   ")" => {
                                                                            ""  => [0xFD, 0xCB, "DIS", 0x8E],
                                                                            "," => {
                                                                                     a => { "" => [0xFD, 0xCB, "DIS", 0x8F] },
                                                                                     b => { "" => [0xFD, 0xCB, "DIS", 0x88] },
                                                                                     c => { "" => [0xFD, 0xCB, "DIS", 0x89] },
                                                                                     d => { "" => [0xFD, 0xCB, "DIS", 0x8A] },
                                                                                     e => { "" => [0xFD, 0xCB, "DIS", 0x8B] },
                                                                                     h => { "" => [0xFD, 0xCB, "DIS", 0x8C] },
                                                                                     l => { "" => [0xFD, 0xCB, "DIS", 0x8D] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            ")" => {
                                                                     ""  => [0xFD, 0xCB, "NDIS", 0x8E],
                                                                     "," => {
                                                                              a => { "" => [0xFD, 0xCB, "NDIS", 0x8F] },
                                                                              b => { "" => [0xFD, 0xCB, "NDIS", 0x88] },
                                                                              c => { "" => [0xFD, 0xCB, "NDIS", 0x89] },
                                                                              d => { "" => [0xFD, 0xCB, "NDIS", 0x8A] },
                                                                              e => { "" => [0xFD, 0xCB, "NDIS", 0x8B] },
                                                                              h => { "" => [0xFD, 0xCB, "NDIS", 0x8C] },
                                                                              l => { "" => [0xFD, 0xCB, "NDIS", 0x8D] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                               },
                                       },
                                "[" => {
                                         hl => { "]" => { "" => [0xCB, 0x8E] } },
                                         ix => {
                                                 "+" => {
                                                          DIS => {
                                                                   "]" => {
                                                                            ""  => [0xDD, 0xCB, "DIS", 0x8E],
                                                                            "," => {
                                                                                     a => { "" => [0xDD, 0xCB, "DIS", 0x8F] },
                                                                                     b => { "" => [0xDD, 0xCB, "DIS", 0x88] },
                                                                                     c => { "" => [0xDD, 0xCB, "DIS", 0x89] },
                                                                                     d => { "" => [0xDD, 0xCB, "DIS", 0x8A] },
                                                                                     e => { "" => [0xDD, 0xCB, "DIS", 0x8B] },
                                                                                     h => { "" => [0xDD, 0xCB, "DIS", 0x8C] },
                                                                                     l => { "" => [0xDD, 0xCB, "DIS", 0x8D] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            "]" => {
                                                                     ""  => [0xDD, 0xCB, "NDIS", 0x8E],
                                                                     "," => {
                                                                              a => { "" => [0xDD, 0xCB, "NDIS", 0x8F] },
                                                                              b => { "" => [0xDD, 0xCB, "NDIS", 0x88] },
                                                                              c => { "" => [0xDD, 0xCB, "NDIS", 0x89] },
                                                                              d => { "" => [0xDD, 0xCB, "NDIS", 0x8A] },
                                                                              e => { "" => [0xDD, 0xCB, "NDIS", 0x8B] },
                                                                              h => { "" => [0xDD, 0xCB, "NDIS", 0x8C] },
                                                                              l => { "" => [0xDD, 0xCB, "NDIS", 0x8D] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                                 "]" => {
                                                          ""  => [0xDD, 0xCB, 0x00, 0x8E],
                                                          "," => {
                                                                   a => { "" => [0xDD, 0xCB, 0x00, 0x8F] },
                                                                   b => { "" => [0xDD, 0xCB, 0x00, 0x88] },
                                                                   c => { "" => [0xDD, 0xCB, 0x00, 0x89] },
                                                                   d => { "" => [0xDD, 0xCB, 0x00, 0x8A] },
                                                                   e => { "" => [0xDD, 0xCB, 0x00, 0x8B] },
                                                                   h => { "" => [0xDD, 0xCB, 0x00, 0x8C] },
                                                                   l => { "" => [0xDD, 0xCB, 0x00, 0x8D] },
                                                                 },
                                                        },
                                               },
                                         iy => {
                                                 "+" => {
                                                          DIS => {
                                                                   "]" => {
                                                                            ""  => [0xFD, 0xCB, "DIS", 0x8E],
                                                                            "," => {
                                                                                     a => { "" => [0xFD, 0xCB, "DIS", 0x8F] },
                                                                                     b => { "" => [0xFD, 0xCB, "DIS", 0x88] },
                                                                                     c => { "" => [0xFD, 0xCB, "DIS", 0x89] },
                                                                                     d => { "" => [0xFD, 0xCB, "DIS", 0x8A] },
                                                                                     e => { "" => [0xFD, 0xCB, "DIS", 0x8B] },
                                                                                     h => { "" => [0xFD, 0xCB, "DIS", 0x8C] },
                                                                                     l => { "" => [0xFD, 0xCB, "DIS", 0x8D] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            "]" => {
                                                                     ""  => [0xFD, 0xCB, "NDIS", 0x8E],
                                                                     "," => {
                                                                              a => { "" => [0xFD, 0xCB, "NDIS", 0x8F] },
                                                                              b => { "" => [0xFD, 0xCB, "NDIS", 0x88] },
                                                                              c => { "" => [0xFD, 0xCB, "NDIS", 0x89] },
                                                                              d => { "" => [0xFD, 0xCB, "NDIS", 0x8A] },
                                                                              e => { "" => [0xFD, 0xCB, "NDIS", 0x8B] },
                                                                              h => { "" => [0xFD, 0xCB, "NDIS", 0x8C] },
                                                                              l => { "" => [0xFD, 0xCB, "NDIS", 0x8D] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                                 "]" => {
                                                          ""  => [0xFD, 0xCB, 0x00, 0x8E],
                                                          "," => {
                                                                   a => { "" => [0xFD, 0xCB, 0x00, 0x8F] },
                                                                   b => { "" => [0xFD, 0xCB, 0x00, 0x88] },
                                                                   c => { "" => [0xFD, 0xCB, 0x00, 0x89] },
                                                                   d => { "" => [0xFD, 0xCB, 0x00, 0x8A] },
                                                                   e => { "" => [0xFD, 0xCB, 0x00, 0x8B] },
                                                                   h => { "" => [0xFD, 0xCB, 0x00, 0x8C] },
                                                                   l => { "" => [0xFD, 0xCB, 0x00, 0x8D] },
                                                                 },
                                                        },
                                               },
                                       },
                                "a" => { "" => [0xCB, 0x8F] },
                                "b" => { "" => [0xCB, 0x88] },
                                "c" => { "" => [0xCB, 0x89] },
                                "d" => { "" => [0xCB, 0x8A] },
                                "e" => { "" => [0xCB, 0x8B] },
                                "h" => { "" => [0xCB, 0x8C] },
                                "l" => { "" => [0xCB, 0x8D] },
                              },
                     },
              0x02 => {
                       "," => {
                                "(" => {
                                         hl => { ")" => { "" => [0xCB, 0x96] } },
                                         ix => {
                                                 ")" => {
                                                          ""  => [0xDD, 0xCB, 0x00, 0x96],
                                                          "," => {
                                                                   a => { "" => [0xDD, 0xCB, 0x00, 0x97] },
                                                                   b => { "" => [0xDD, 0xCB, 0x00, 0x90] },
                                                                   c => { "" => [0xDD, 0xCB, 0x00, 0x91] },
                                                                   d => { "" => [0xDD, 0xCB, 0x00, 0x92] },
                                                                   e => { "" => [0xDD, 0xCB, 0x00, 0x93] },
                                                                   h => { "" => [0xDD, 0xCB, 0x00, 0x94] },
                                                                   l => { "" => [0xDD, 0xCB, 0x00, 0x95] },
                                                                 },
                                                        },
                                                 "+" => {
                                                          DIS => {
                                                                   ")" => {
                                                                            ""  => [0xDD, 0xCB, "DIS", 0x96],
                                                                            "," => {
                                                                                     a => { "" => [0xDD, 0xCB, "DIS", 0x97] },
                                                                                     b => { "" => [0xDD, 0xCB, "DIS", 0x90] },
                                                                                     c => { "" => [0xDD, 0xCB, "DIS", 0x91] },
                                                                                     d => { "" => [0xDD, 0xCB, "DIS", 0x92] },
                                                                                     e => { "" => [0xDD, 0xCB, "DIS", 0x93] },
                                                                                     h => { "" => [0xDD, 0xCB, "DIS", 0x94] },
                                                                                     l => { "" => [0xDD, 0xCB, "DIS", 0x95] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            ")" => {
                                                                     ""  => [0xDD, 0xCB, "NDIS", 0x96],
                                                                     "," => {
                                                                              a => { "" => [0xDD, 0xCB, "NDIS", 0x97] },
                                                                              b => { "" => [0xDD, 0xCB, "NDIS", 0x90] },
                                                                              c => { "" => [0xDD, 0xCB, "NDIS", 0x91] },
                                                                              d => { "" => [0xDD, 0xCB, "NDIS", 0x92] },
                                                                              e => { "" => [0xDD, 0xCB, "NDIS", 0x93] },
                                                                              h => { "" => [0xDD, 0xCB, "NDIS", 0x94] },
                                                                              l => { "" => [0xDD, 0xCB, "NDIS", 0x95] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                               },
                                         iy => {
                                                 ")" => {
                                                          ""  => [0xFD, 0xCB, 0x00, 0x96],
                                                          "," => {
                                                                   a => { "" => [0xFD, 0xCB, 0x00, 0x97] },
                                                                   b => { "" => [0xFD, 0xCB, 0x00, 0x90] },
                                                                   c => { "" => [0xFD, 0xCB, 0x00, 0x91] },
                                                                   d => { "" => [0xFD, 0xCB, 0x00, 0x92] },
                                                                   e => { "" => [0xFD, 0xCB, 0x00, 0x93] },
                                                                   h => { "" => [0xFD, 0xCB, 0x00, 0x94] },
                                                                   l => { "" => [0xFD, 0xCB, 0x00, 0x95] },
                                                                 },
                                                        },
                                                 "+" => {
                                                          DIS => {
                                                                   ")" => {
                                                                            ""  => [0xFD, 0xCB, "DIS", 0x96],
                                                                            "," => {
                                                                                     a => { "" => [0xFD, 0xCB, "DIS", 0x97] },
                                                                                     b => { "" => [0xFD, 0xCB, "DIS", 0x90] },
                                                                                     c => { "" => [0xFD, 0xCB, "DIS", 0x91] },
                                                                                     d => { "" => [0xFD, 0xCB, "DIS", 0x92] },
                                                                                     e => { "" => [0xFD, 0xCB, "DIS", 0x93] },
                                                                                     h => { "" => [0xFD, 0xCB, "DIS", 0x94] },
                                                                                     l => { "" => [0xFD, 0xCB, "DIS", 0x95] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            ")" => {
                                                                     ""  => [0xFD, 0xCB, "NDIS", 0x96],
                                                                     "," => {
                                                                              a => { "" => [0xFD, 0xCB, "NDIS", 0x97] },
                                                                              b => { "" => [0xFD, 0xCB, "NDIS", 0x90] },
                                                                              c => { "" => [0xFD, 0xCB, "NDIS", 0x91] },
                                                                              d => { "" => [0xFD, 0xCB, "NDIS", 0x92] },
                                                                              e => { "" => [0xFD, 0xCB, "NDIS", 0x93] },
                                                                              h => { "" => [0xFD, 0xCB, "NDIS", 0x94] },
                                                                              l => { "" => [0xFD, 0xCB, "NDIS", 0x95] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                               },
                                       },
                                "[" => {
                                         hl => { "]" => { "" => [0xCB, 0x96] } },
                                         ix => {
                                                 "+" => {
                                                          DIS => {
                                                                   "]" => {
                                                                            ""  => [0xDD, 0xCB, "DIS", 0x96],
                                                                            "," => {
                                                                                     a => { "" => [0xDD, 0xCB, "DIS", 0x97] },
                                                                                     b => { "" => [0xDD, 0xCB, "DIS", 0x90] },
                                                                                     c => { "" => [0xDD, 0xCB, "DIS", 0x91] },
                                                                                     d => { "" => [0xDD, 0xCB, "DIS", 0x92] },
                                                                                     e => { "" => [0xDD, 0xCB, "DIS", 0x93] },
                                                                                     h => { "" => [0xDD, 0xCB, "DIS", 0x94] },
                                                                                     l => { "" => [0xDD, 0xCB, "DIS", 0x95] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            "]" => {
                                                                     ""  => [0xDD, 0xCB, "NDIS", 0x96],
                                                                     "," => {
                                                                              a => { "" => [0xDD, 0xCB, "NDIS", 0x97] },
                                                                              b => { "" => [0xDD, 0xCB, "NDIS", 0x90] },
                                                                              c => { "" => [0xDD, 0xCB, "NDIS", 0x91] },
                                                                              d => { "" => [0xDD, 0xCB, "NDIS", 0x92] },
                                                                              e => { "" => [0xDD, 0xCB, "NDIS", 0x93] },
                                                                              h => { "" => [0xDD, 0xCB, "NDIS", 0x94] },
                                                                              l => { "" => [0xDD, 0xCB, "NDIS", 0x95] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                                 "]" => {
                                                          ""  => [0xDD, 0xCB, 0x00, 0x96],
                                                          "," => {
                                                                   a => { "" => [0xDD, 0xCB, 0x00, 0x97] },
                                                                   b => { "" => [0xDD, 0xCB, 0x00, 0x90] },
                                                                   c => { "" => [0xDD, 0xCB, 0x00, 0x91] },
                                                                   d => { "" => [0xDD, 0xCB, 0x00, 0x92] },
                                                                   e => { "" => [0xDD, 0xCB, 0x00, 0x93] },
                                                                   h => { "" => [0xDD, 0xCB, 0x00, 0x94] },
                                                                   l => { "" => [0xDD, 0xCB, 0x00, 0x95] },
                                                                 },
                                                        },
                                               },
                                         iy => {
                                                 "+" => {
                                                          DIS => {
                                                                   "]" => {
                                                                            ""  => [0xFD, 0xCB, "DIS", 0x96],
                                                                            "," => {
                                                                                     a => { "" => [0xFD, 0xCB, "DIS", 0x97] },
                                                                                     b => { "" => [0xFD, 0xCB, "DIS", 0x90] },
                                                                                     c => { "" => [0xFD, 0xCB, "DIS", 0x91] },
                                                                                     d => { "" => [0xFD, 0xCB, "DIS", 0x92] },
                                                                                     e => { "" => [0xFD, 0xCB, "DIS", 0x93] },
                                                                                     h => { "" => [0xFD, 0xCB, "DIS", 0x94] },
                                                                                     l => { "" => [0xFD, 0xCB, "DIS", 0x95] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            "]" => {
                                                                     ""  => [0xFD, 0xCB, "NDIS", 0x96],
                                                                     "," => {
                                                                              a => { "" => [0xFD, 0xCB, "NDIS", 0x97] },
                                                                              b => { "" => [0xFD, 0xCB, "NDIS", 0x90] },
                                                                              c => { "" => [0xFD, 0xCB, "NDIS", 0x91] },
                                                                              d => { "" => [0xFD, 0xCB, "NDIS", 0x92] },
                                                                              e => { "" => [0xFD, 0xCB, "NDIS", 0x93] },
                                                                              h => { "" => [0xFD, 0xCB, "NDIS", 0x94] },
                                                                              l => { "" => [0xFD, 0xCB, "NDIS", 0x95] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                                 "]" => {
                                                          ""  => [0xFD, 0xCB, 0x00, 0x96],
                                                          "," => {
                                                                   a => { "" => [0xFD, 0xCB, 0x00, 0x97] },
                                                                   b => { "" => [0xFD, 0xCB, 0x00, 0x90] },
                                                                   c => { "" => [0xFD, 0xCB, 0x00, 0x91] },
                                                                   d => { "" => [0xFD, 0xCB, 0x00, 0x92] },
                                                                   e => { "" => [0xFD, 0xCB, 0x00, 0x93] },
                                                                   h => { "" => [0xFD, 0xCB, 0x00, 0x94] },
                                                                   l => { "" => [0xFD, 0xCB, 0x00, 0x95] },
                                                                 },
                                                        },
                                               },
                                       },
                                "a" => { "" => [0xCB, 0x97] },
                                "b" => { "" => [0xCB, 0x90] },
                                "c" => { "" => [0xCB, 0x91] },
                                "d" => { "" => [0xCB, 0x92] },
                                "e" => { "" => [0xCB, 0x93] },
                                "h" => { "" => [0xCB, 0x94] },
                                "l" => { "" => [0xCB, 0x95] },
                              },
                     },
              0x03 => {
                       "," => {
                                "(" => {
                                         hl => { ")" => { "" => [0xCB, 0x9E] } },
                                         ix => {
                                                 ")" => {
                                                          ""  => [0xDD, 0xCB, 0x00, 0x9E],
                                                          "," => {
                                                                   a => { "" => [0xDD, 0xCB, 0x00, 0x9F] },
                                                                   b => { "" => [0xDD, 0xCB, 0x00, 0x98] },
                                                                   c => { "" => [0xDD, 0xCB, 0x00, 0x99] },
                                                                   d => { "" => [0xDD, 0xCB, 0x00, 0x9A] },
                                                                   e => { "" => [0xDD, 0xCB, 0x00, 0x9B] },
                                                                   h => { "" => [0xDD, 0xCB, 0x00, 0x9C] },
                                                                   l => { "" => [0xDD, 0xCB, 0x00, 0x9D] },
                                                                 },
                                                        },
                                                 "+" => {
                                                          DIS => {
                                                                   ")" => {
                                                                            ""  => [0xDD, 0xCB, "DIS", 0x9E],
                                                                            "," => {
                                                                                     a => { "" => [0xDD, 0xCB, "DIS", 0x9F] },
                                                                                     b => { "" => [0xDD, 0xCB, "DIS", 0x98] },
                                                                                     c => { "" => [0xDD, 0xCB, "DIS", 0x99] },
                                                                                     d => { "" => [0xDD, 0xCB, "DIS", 0x9A] },
                                                                                     e => { "" => [0xDD, 0xCB, "DIS", 0x9B] },
                                                                                     h => { "" => [0xDD, 0xCB, "DIS", 0x9C] },
                                                                                     l => { "" => [0xDD, 0xCB, "DIS", 0x9D] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            ")" => {
                                                                     ""  => [0xDD, 0xCB, "NDIS", 0x9E],
                                                                     "," => {
                                                                              a => { "" => [0xDD, 0xCB, "NDIS", 0x9F] },
                                                                              b => { "" => [0xDD, 0xCB, "NDIS", 0x98] },
                                                                              c => { "" => [0xDD, 0xCB, "NDIS", 0x99] },
                                                                              d => { "" => [0xDD, 0xCB, "NDIS", 0x9A] },
                                                                              e => { "" => [0xDD, 0xCB, "NDIS", 0x9B] },
                                                                              h => { "" => [0xDD, 0xCB, "NDIS", 0x9C] },
                                                                              l => { "" => [0xDD, 0xCB, "NDIS", 0x9D] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                               },
                                         iy => {
                                                 ")" => {
                                                          ""  => [0xFD, 0xCB, 0x00, 0x9E],
                                                          "," => {
                                                                   a => { "" => [0xFD, 0xCB, 0x00, 0x9F] },
                                                                   b => { "" => [0xFD, 0xCB, 0x00, 0x98] },
                                                                   c => { "" => [0xFD, 0xCB, 0x00, 0x99] },
                                                                   d => { "" => [0xFD, 0xCB, 0x00, 0x9A] },
                                                                   e => { "" => [0xFD, 0xCB, 0x00, 0x9B] },
                                                                   h => { "" => [0xFD, 0xCB, 0x00, 0x9C] },
                                                                   l => { "" => [0xFD, 0xCB, 0x00, 0x9D] },
                                                                 },
                                                        },
                                                 "+" => {
                                                          DIS => {
                                                                   ")" => {
                                                                            ""  => [0xFD, 0xCB, "DIS", 0x9E],
                                                                            "," => {
                                                                                     a => { "" => [0xFD, 0xCB, "DIS", 0x9F] },
                                                                                     b => { "" => [0xFD, 0xCB, "DIS", 0x98] },
                                                                                     c => { "" => [0xFD, 0xCB, "DIS", 0x99] },
                                                                                     d => { "" => [0xFD, 0xCB, "DIS", 0x9A] },
                                                                                     e => { "" => [0xFD, 0xCB, "DIS", 0x9B] },
                                                                                     h => { "" => [0xFD, 0xCB, "DIS", 0x9C] },
                                                                                     l => { "" => [0xFD, 0xCB, "DIS", 0x9D] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            ")" => {
                                                                     ""  => [0xFD, 0xCB, "NDIS", 0x9E],
                                                                     "," => {
                                                                              a => { "" => [0xFD, 0xCB, "NDIS", 0x9F] },
                                                                              b => { "" => [0xFD, 0xCB, "NDIS", 0x98] },
                                                                              c => { "" => [0xFD, 0xCB, "NDIS", 0x99] },
                                                                              d => { "" => [0xFD, 0xCB, "NDIS", 0x9A] },
                                                                              e => { "" => [0xFD, 0xCB, "NDIS", 0x9B] },
                                                                              h => { "" => [0xFD, 0xCB, "NDIS", 0x9C] },
                                                                              l => { "" => [0xFD, 0xCB, "NDIS", 0x9D] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                               },
                                       },
                                "[" => {
                                         hl => { "]" => { "" => [0xCB, 0x9E] } },
                                         ix => {
                                                 "+" => {
                                                          DIS => {
                                                                   "]" => {
                                                                            ""  => [0xDD, 0xCB, "DIS", 0x9E],
                                                                            "," => {
                                                                                     a => { "" => [0xDD, 0xCB, "DIS", 0x9F] },
                                                                                     b => { "" => [0xDD, 0xCB, "DIS", 0x98] },
                                                                                     c => { "" => [0xDD, 0xCB, "DIS", 0x99] },
                                                                                     d => { "" => [0xDD, 0xCB, "DIS", 0x9A] },
                                                                                     e => { "" => [0xDD, 0xCB, "DIS", 0x9B] },
                                                                                     h => { "" => [0xDD, 0xCB, "DIS", 0x9C] },
                                                                                     l => { "" => [0xDD, 0xCB, "DIS", 0x9D] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            "]" => {
                                                                     ""  => [0xDD, 0xCB, "NDIS", 0x9E],
                                                                     "," => {
                                                                              a => { "" => [0xDD, 0xCB, "NDIS", 0x9F] },
                                                                              b => { "" => [0xDD, 0xCB, "NDIS", 0x98] },
                                                                              c => { "" => [0xDD, 0xCB, "NDIS", 0x99] },
                                                                              d => { "" => [0xDD, 0xCB, "NDIS", 0x9A] },
                                                                              e => { "" => [0xDD, 0xCB, "NDIS", 0x9B] },
                                                                              h => { "" => [0xDD, 0xCB, "NDIS", 0x9C] },
                                                                              l => { "" => [0xDD, 0xCB, "NDIS", 0x9D] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                                 "]" => {
                                                          ""  => [0xDD, 0xCB, 0x00, 0x9E],
                                                          "," => {
                                                                   a => { "" => [0xDD, 0xCB, 0x00, 0x9F] },
                                                                   b => { "" => [0xDD, 0xCB, 0x00, 0x98] },
                                                                   c => { "" => [0xDD, 0xCB, 0x00, 0x99] },
                                                                   d => { "" => [0xDD, 0xCB, 0x00, 0x9A] },
                                                                   e => { "" => [0xDD, 0xCB, 0x00, 0x9B] },
                                                                   h => { "" => [0xDD, 0xCB, 0x00, 0x9C] },
                                                                   l => { "" => [0xDD, 0xCB, 0x00, 0x9D] },
                                                                 },
                                                        },
                                               },
                                         iy => {
                                                 "+" => {
                                                          DIS => {
                                                                   "]" => {
                                                                            ""  => [0xFD, 0xCB, "DIS", 0x9E],
                                                                            "," => {
                                                                                     a => { "" => [0xFD, 0xCB, "DIS", 0x9F] },
                                                                                     b => { "" => [0xFD, 0xCB, "DIS", 0x98] },
                                                                                     c => { "" => [0xFD, 0xCB, "DIS", 0x99] },
                                                                                     d => { "" => [0xFD, 0xCB, "DIS", 0x9A] },
                                                                                     e => { "" => [0xFD, 0xCB, "DIS", 0x9B] },
                                                                                     h => { "" => [0xFD, 0xCB, "DIS", 0x9C] },
                                                                                     l => { "" => [0xFD, 0xCB, "DIS", 0x9D] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            "]" => {
                                                                     ""  => [0xFD, 0xCB, "NDIS", 0x9E],
                                                                     "," => {
                                                                              a => { "" => [0xFD, 0xCB, "NDIS", 0x9F] },
                                                                              b => { "" => [0xFD, 0xCB, "NDIS", 0x98] },
                                                                              c => { "" => [0xFD, 0xCB, "NDIS", 0x99] },
                                                                              d => { "" => [0xFD, 0xCB, "NDIS", 0x9A] },
                                                                              e => { "" => [0xFD, 0xCB, "NDIS", 0x9B] },
                                                                              h => { "" => [0xFD, 0xCB, "NDIS", 0x9C] },
                                                                              l => { "" => [0xFD, 0xCB, "NDIS", 0x9D] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                                 "]" => {
                                                          ""  => [0xFD, 0xCB, 0x00, 0x9E],
                                                          "," => {
                                                                   a => { "" => [0xFD, 0xCB, 0x00, 0x9F] },
                                                                   b => { "" => [0xFD, 0xCB, 0x00, 0x98] },
                                                                   c => { "" => [0xFD, 0xCB, 0x00, 0x99] },
                                                                   d => { "" => [0xFD, 0xCB, 0x00, 0x9A] },
                                                                   e => { "" => [0xFD, 0xCB, 0x00, 0x9B] },
                                                                   h => { "" => [0xFD, 0xCB, 0x00, 0x9C] },
                                                                   l => { "" => [0xFD, 0xCB, 0x00, 0x9D] },
                                                                 },
                                                        },
                                               },
                                       },
                                "a" => { "" => [0xCB, 0x9F] },
                                "b" => { "" => [0xCB, 0x98] },
                                "c" => { "" => [0xCB, 0x99] },
                                "d" => { "" => [0xCB, 0x9A] },
                                "e" => { "" => [0xCB, 0x9B] },
                                "h" => { "" => [0xCB, 0x9C] },
                                "l" => { "" => [0xCB, 0x9D] },
                              },
                     },
              0x04 => {
                       "," => {
                                "(" => {
                                         hl => { ")" => { "" => [0xCB, 0xA6] } },
                                         ix => {
                                                 ")" => {
                                                          ""  => [0xDD, 0xCB, 0x00, 0xA6],
                                                          "," => {
                                                                   a => { "" => [0xDD, 0xCB, 0x00, 0xA7] },
                                                                   b => { "" => [0xDD, 0xCB, 0x00, 0xA0] },
                                                                   c => { "" => [0xDD, 0xCB, 0x00, 0xA1] },
                                                                   d => { "" => [0xDD, 0xCB, 0x00, 0xA2] },
                                                                   e => { "" => [0xDD, 0xCB, 0x00, 0xA3] },
                                                                   h => { "" => [0xDD, 0xCB, 0x00, 0xA4] },
                                                                   l => { "" => [0xDD, 0xCB, 0x00, 0xA5] },
                                                                 },
                                                        },
                                                 "+" => {
                                                          DIS => {
                                                                   ")" => {
                                                                            ""  => [0xDD, 0xCB, "DIS", 0xA6],
                                                                            "," => {
                                                                                     a => { "" => [0xDD, 0xCB, "DIS", 0xA7] },
                                                                                     b => { "" => [0xDD, 0xCB, "DIS", 0xA0] },
                                                                                     c => { "" => [0xDD, 0xCB, "DIS", 0xA1] },
                                                                                     d => { "" => [0xDD, 0xCB, "DIS", 0xA2] },
                                                                                     e => { "" => [0xDD, 0xCB, "DIS", 0xA3] },
                                                                                     h => { "" => [0xDD, 0xCB, "DIS", 0xA4] },
                                                                                     l => { "" => [0xDD, 0xCB, "DIS", 0xA5] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            ")" => {
                                                                     ""  => [0xDD, 0xCB, "NDIS", 0xA6],
                                                                     "," => {
                                                                              a => { "" => [0xDD, 0xCB, "NDIS", 0xA7] },
                                                                              b => { "" => [0xDD, 0xCB, "NDIS", 0xA0] },
                                                                              c => { "" => [0xDD, 0xCB, "NDIS", 0xA1] },
                                                                              d => { "" => [0xDD, 0xCB, "NDIS", 0xA2] },
                                                                              e => { "" => [0xDD, 0xCB, "NDIS", 0xA3] },
                                                                              h => { "" => [0xDD, 0xCB, "NDIS", 0xA4] },
                                                                              l => { "" => [0xDD, 0xCB, "NDIS", 0xA5] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                               },
                                         iy => {
                                                 ")" => {
                                                          ""  => [0xFD, 0xCB, 0x00, 0xA6],
                                                          "," => {
                                                                   a => { "" => [0xFD, 0xCB, 0x00, 0xA7] },
                                                                   b => { "" => [0xFD, 0xCB, 0x00, 0xA0] },
                                                                   c => { "" => [0xFD, 0xCB, 0x00, 0xA1] },
                                                                   d => { "" => [0xFD, 0xCB, 0x00, 0xA2] },
                                                                   e => { "" => [0xFD, 0xCB, 0x00, 0xA3] },
                                                                   h => { "" => [0xFD, 0xCB, 0x00, 0xA4] },
                                                                   l => { "" => [0xFD, 0xCB, 0x00, 0xA5] },
                                                                 },
                                                        },
                                                 "+" => {
                                                          DIS => {
                                                                   ")" => {
                                                                            ""  => [0xFD, 0xCB, "DIS", 0xA6],
                                                                            "," => {
                                                                                     a => { "" => [0xFD, 0xCB, "DIS", 0xA7] },
                                                                                     b => { "" => [0xFD, 0xCB, "DIS", 0xA0] },
                                                                                     c => { "" => [0xFD, 0xCB, "DIS", 0xA1] },
                                                                                     d => { "" => [0xFD, 0xCB, "DIS", 0xA2] },
                                                                                     e => { "" => [0xFD, 0xCB, "DIS", 0xA3] },
                                                                                     h => { "" => [0xFD, 0xCB, "DIS", 0xA4] },
                                                                                     l => { "" => [0xFD, 0xCB, "DIS", 0xA5] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            ")" => {
                                                                     ""  => [0xFD, 0xCB, "NDIS", 0xA6],
                                                                     "," => {
                                                                              a => { "" => [0xFD, 0xCB, "NDIS", 0xA7] },
                                                                              b => { "" => [0xFD, 0xCB, "NDIS", 0xA0] },
                                                                              c => { "" => [0xFD, 0xCB, "NDIS", 0xA1] },
                                                                              d => { "" => [0xFD, 0xCB, "NDIS", 0xA2] },
                                                                              e => { "" => [0xFD, 0xCB, "NDIS", 0xA3] },
                                                                              h => { "" => [0xFD, 0xCB, "NDIS", 0xA4] },
                                                                              l => { "" => [0xFD, 0xCB, "NDIS", 0xA5] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                               },
                                       },
                                "[" => {
                                         hl => { "]" => { "" => [0xCB, 0xA6] } },
                                         ix => {
                                                 "+" => {
                                                          DIS => {
                                                                   "]" => {
                                                                            ""  => [0xDD, 0xCB, "DIS", 0xA6],
                                                                            "," => {
                                                                                     a => { "" => [0xDD, 0xCB, "DIS", 0xA7] },
                                                                                     b => { "" => [0xDD, 0xCB, "DIS", 0xA0] },
                                                                                     c => { "" => [0xDD, 0xCB, "DIS", 0xA1] },
                                                                                     d => { "" => [0xDD, 0xCB, "DIS", 0xA2] },
                                                                                     e => { "" => [0xDD, 0xCB, "DIS", 0xA3] },
                                                                                     h => { "" => [0xDD, 0xCB, "DIS", 0xA4] },
                                                                                     l => { "" => [0xDD, 0xCB, "DIS", 0xA5] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            "]" => {
                                                                     ""  => [0xDD, 0xCB, "NDIS", 0xA6],
                                                                     "," => {
                                                                              a => { "" => [0xDD, 0xCB, "NDIS", 0xA7] },
                                                                              b => { "" => [0xDD, 0xCB, "NDIS", 0xA0] },
                                                                              c => { "" => [0xDD, 0xCB, "NDIS", 0xA1] },
                                                                              d => { "" => [0xDD, 0xCB, "NDIS", 0xA2] },
                                                                              e => { "" => [0xDD, 0xCB, "NDIS", 0xA3] },
                                                                              h => { "" => [0xDD, 0xCB, "NDIS", 0xA4] },
                                                                              l => { "" => [0xDD, 0xCB, "NDIS", 0xA5] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                                 "]" => {
                                                          ""  => [0xDD, 0xCB, 0x00, 0xA6],
                                                          "," => {
                                                                   a => { "" => [0xDD, 0xCB, 0x00, 0xA7] },
                                                                   b => { "" => [0xDD, 0xCB, 0x00, 0xA0] },
                                                                   c => { "" => [0xDD, 0xCB, 0x00, 0xA1] },
                                                                   d => { "" => [0xDD, 0xCB, 0x00, 0xA2] },
                                                                   e => { "" => [0xDD, 0xCB, 0x00, 0xA3] },
                                                                   h => { "" => [0xDD, 0xCB, 0x00, 0xA4] },
                                                                   l => { "" => [0xDD, 0xCB, 0x00, 0xA5] },
                                                                 },
                                                        },
                                               },
                                         iy => {
                                                 "+" => {
                                                          DIS => {
                                                                   "]" => {
                                                                            ""  => [0xFD, 0xCB, "DIS", 0xA6],
                                                                            "," => {
                                                                                     a => { "" => [0xFD, 0xCB, "DIS", 0xA7] },
                                                                                     b => { "" => [0xFD, 0xCB, "DIS", 0xA0] },
                                                                                     c => { "" => [0xFD, 0xCB, "DIS", 0xA1] },
                                                                                     d => { "" => [0xFD, 0xCB, "DIS", 0xA2] },
                                                                                     e => { "" => [0xFD, 0xCB, "DIS", 0xA3] },
                                                                                     h => { "" => [0xFD, 0xCB, "DIS", 0xA4] },
                                                                                     l => { "" => [0xFD, 0xCB, "DIS", 0xA5] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            "]" => {
                                                                     ""  => [0xFD, 0xCB, "NDIS", 0xA6],
                                                                     "," => {
                                                                              a => { "" => [0xFD, 0xCB, "NDIS", 0xA7] },
                                                                              b => { "" => [0xFD, 0xCB, "NDIS", 0xA0] },
                                                                              c => { "" => [0xFD, 0xCB, "NDIS", 0xA1] },
                                                                              d => { "" => [0xFD, 0xCB, "NDIS", 0xA2] },
                                                                              e => { "" => [0xFD, 0xCB, "NDIS", 0xA3] },
                                                                              h => { "" => [0xFD, 0xCB, "NDIS", 0xA4] },
                                                                              l => { "" => [0xFD, 0xCB, "NDIS", 0xA5] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                                 "]" => {
                                                          ""  => [0xFD, 0xCB, 0x00, 0xA6],
                                                          "," => {
                                                                   a => { "" => [0xFD, 0xCB, 0x00, 0xA7] },
                                                                   b => { "" => [0xFD, 0xCB, 0x00, 0xA0] },
                                                                   c => { "" => [0xFD, 0xCB, 0x00, 0xA1] },
                                                                   d => { "" => [0xFD, 0xCB, 0x00, 0xA2] },
                                                                   e => { "" => [0xFD, 0xCB, 0x00, 0xA3] },
                                                                   h => { "" => [0xFD, 0xCB, 0x00, 0xA4] },
                                                                   l => { "" => [0xFD, 0xCB, 0x00, 0xA5] },
                                                                 },
                                                        },
                                               },
                                       },
                                "a" => { "" => [0xCB, 0xA7] },
                                "b" => { "" => [0xCB, 0xA0] },
                                "c" => { "" => [0xCB, 0xA1] },
                                "d" => { "" => [0xCB, 0xA2] },
                                "e" => { "" => [0xCB, 0xA3] },
                                "h" => { "" => [0xCB, 0xA4] },
                                "l" => { "" => [0xCB, 0xA5] },
                              },
                     },
              0x05 => {
                       "," => {
                                "(" => {
                                         hl => { ")" => { "" => [0xCB, 0xAE] } },
                                         ix => {
                                                 ")" => {
                                                          ""  => [0xDD, 0xCB, 0x00, 0xAE],
                                                          "," => {
                                                                   a => { "" => [0xDD, 0xCB, 0x00, 0xAF] },
                                                                   b => { "" => [0xDD, 0xCB, 0x00, 0xA8] },
                                                                   c => { "" => [0xDD, 0xCB, 0x00, 0xA9] },
                                                                   d => { "" => [0xDD, 0xCB, 0x00, 0xAA] },
                                                                   e => { "" => [0xDD, 0xCB, 0x00, 0xAB] },
                                                                   h => { "" => [0xDD, 0xCB, 0x00, 0xAC] },
                                                                   l => { "" => [0xDD, 0xCB, 0x00, 0xAD] },
                                                                 },
                                                        },
                                                 "+" => {
                                                          DIS => {
                                                                   ")" => {
                                                                            ""  => [0xDD, 0xCB, "DIS", 0xAE],
                                                                            "," => {
                                                                                     a => { "" => [0xDD, 0xCB, "DIS", 0xAF] },
                                                                                     b => { "" => [0xDD, 0xCB, "DIS", 0xA8] },
                                                                                     c => { "" => [0xDD, 0xCB, "DIS", 0xA9] },
                                                                                     d => { "" => [0xDD, 0xCB, "DIS", 0xAA] },
                                                                                     e => { "" => [0xDD, 0xCB, "DIS", 0xAB] },
                                                                                     h => { "" => [0xDD, 0xCB, "DIS", 0xAC] },
                                                                                     l => { "" => [0xDD, 0xCB, "DIS", 0xAD] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            ")" => {
                                                                     ""  => [0xDD, 0xCB, "NDIS", 0xAE],
                                                                     "," => {
                                                                              a => { "" => [0xDD, 0xCB, "NDIS", 0xAF] },
                                                                              b => { "" => [0xDD, 0xCB, "NDIS", 0xA8] },
                                                                              c => { "" => [0xDD, 0xCB, "NDIS", 0xA9] },
                                                                              d => { "" => [0xDD, 0xCB, "NDIS", 0xAA] },
                                                                              e => { "" => [0xDD, 0xCB, "NDIS", 0xAB] },
                                                                              h => { "" => [0xDD, 0xCB, "NDIS", 0xAC] },
                                                                              l => { "" => [0xDD, 0xCB, "NDIS", 0xAD] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                               },
                                         iy => {
                                                 ")" => {
                                                          ""  => [0xFD, 0xCB, 0x00, 0xAE],
                                                          "," => {
                                                                   a => { "" => [0xFD, 0xCB, 0x00, 0xAF] },
                                                                   b => { "" => [0xFD, 0xCB, 0x00, 0xA8] },
                                                                   c => { "" => [0xFD, 0xCB, 0x00, 0xA9] },
                                                                   d => { "" => [0xFD, 0xCB, 0x00, 0xAA] },
                                                                   e => { "" => [0xFD, 0xCB, 0x00, 0xAB] },
                                                                   h => { "" => [0xFD, 0xCB, 0x00, 0xAC] },
                                                                   l => { "" => [0xFD, 0xCB, 0x00, 0xAD] },
                                                                 },
                                                        },
                                                 "+" => {
                                                          DIS => {
                                                                   ")" => {
                                                                            ""  => [0xFD, 0xCB, "DIS", 0xAE],
                                                                            "," => {
                                                                                     a => { "" => [0xFD, 0xCB, "DIS", 0xAF] },
                                                                                     b => { "" => [0xFD, 0xCB, "DIS", 0xA8] },
                                                                                     c => { "" => [0xFD, 0xCB, "DIS", 0xA9] },
                                                                                     d => { "" => [0xFD, 0xCB, "DIS", 0xAA] },
                                                                                     e => { "" => [0xFD, 0xCB, "DIS", 0xAB] },
                                                                                     h => { "" => [0xFD, 0xCB, "DIS", 0xAC] },
                                                                                     l => { "" => [0xFD, 0xCB, "DIS", 0xAD] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            ")" => {
                                                                     ""  => [0xFD, 0xCB, "NDIS", 0xAE],
                                                                     "," => {
                                                                              a => { "" => [0xFD, 0xCB, "NDIS", 0xAF] },
                                                                              b => { "" => [0xFD, 0xCB, "NDIS", 0xA8] },
                                                                              c => { "" => [0xFD, 0xCB, "NDIS", 0xA9] },
                                                                              d => { "" => [0xFD, 0xCB, "NDIS", 0xAA] },
                                                                              e => { "" => [0xFD, 0xCB, "NDIS", 0xAB] },
                                                                              h => { "" => [0xFD, 0xCB, "NDIS", 0xAC] },
                                                                              l => { "" => [0xFD, 0xCB, "NDIS", 0xAD] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                               },
                                       },
                                "[" => {
                                         hl => { "]" => { "" => [0xCB, 0xAE] } },
                                         ix => {
                                                 "+" => {
                                                          DIS => {
                                                                   "]" => {
                                                                            ""  => [0xDD, 0xCB, "DIS", 0xAE],
                                                                            "," => {
                                                                                     a => { "" => [0xDD, 0xCB, "DIS", 0xAF] },
                                                                                     b => { "" => [0xDD, 0xCB, "DIS", 0xA8] },
                                                                                     c => { "" => [0xDD, 0xCB, "DIS", 0xA9] },
                                                                                     d => { "" => [0xDD, 0xCB, "DIS", 0xAA] },
                                                                                     e => { "" => [0xDD, 0xCB, "DIS", 0xAB] },
                                                                                     h => { "" => [0xDD, 0xCB, "DIS", 0xAC] },
                                                                                     l => { "" => [0xDD, 0xCB, "DIS", 0xAD] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            "]" => {
                                                                     ""  => [0xDD, 0xCB, "NDIS", 0xAE],
                                                                     "," => {
                                                                              a => { "" => [0xDD, 0xCB, "NDIS", 0xAF] },
                                                                              b => { "" => [0xDD, 0xCB, "NDIS", 0xA8] },
                                                                              c => { "" => [0xDD, 0xCB, "NDIS", 0xA9] },
                                                                              d => { "" => [0xDD, 0xCB, "NDIS", 0xAA] },
                                                                              e => { "" => [0xDD, 0xCB, "NDIS", 0xAB] },
                                                                              h => { "" => [0xDD, 0xCB, "NDIS", 0xAC] },
                                                                              l => { "" => [0xDD, 0xCB, "NDIS", 0xAD] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                                 "]" => {
                                                          ""  => [0xDD, 0xCB, 0x00, 0xAE],
                                                          "," => {
                                                                   a => { "" => [0xDD, 0xCB, 0x00, 0xAF] },
                                                                   b => { "" => [0xDD, 0xCB, 0x00, 0xA8] },
                                                                   c => { "" => [0xDD, 0xCB, 0x00, 0xA9] },
                                                                   d => { "" => [0xDD, 0xCB, 0x00, 0xAA] },
                                                                   e => { "" => [0xDD, 0xCB, 0x00, 0xAB] },
                                                                   h => { "" => [0xDD, 0xCB, 0x00, 0xAC] },
                                                                   l => { "" => [0xDD, 0xCB, 0x00, 0xAD] },
                                                                 },
                                                        },
                                               },
                                         iy => {
                                                 "+" => {
                                                          DIS => {
                                                                   "]" => {
                                                                            ""  => [0xFD, 0xCB, "DIS", 0xAE],
                                                                            "," => {
                                                                                     a => { "" => [0xFD, 0xCB, "DIS", 0xAF] },
                                                                                     b => { "" => [0xFD, 0xCB, "DIS", 0xA8] },
                                                                                     c => { "" => [0xFD, 0xCB, "DIS", 0xA9] },
                                                                                     d => { "" => [0xFD, 0xCB, "DIS", 0xAA] },
                                                                                     e => { "" => [0xFD, 0xCB, "DIS", 0xAB] },
                                                                                     h => { "" => [0xFD, 0xCB, "DIS", 0xAC] },
                                                                                     l => { "" => [0xFD, 0xCB, "DIS", 0xAD] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            "]" => {
                                                                     ""  => [0xFD, 0xCB, "NDIS", 0xAE],
                                                                     "," => {
                                                                              a => { "" => [0xFD, 0xCB, "NDIS", 0xAF] },
                                                                              b => { "" => [0xFD, 0xCB, "NDIS", 0xA8] },
                                                                              c => { "" => [0xFD, 0xCB, "NDIS", 0xA9] },
                                                                              d => { "" => [0xFD, 0xCB, "NDIS", 0xAA] },
                                                                              e => { "" => [0xFD, 0xCB, "NDIS", 0xAB] },
                                                                              h => { "" => [0xFD, 0xCB, "NDIS", 0xAC] },
                                                                              l => { "" => [0xFD, 0xCB, "NDIS", 0xAD] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                                 "]" => {
                                                          ""  => [0xFD, 0xCB, 0x00, 0xAE],
                                                          "," => {
                                                                   a => { "" => [0xFD, 0xCB, 0x00, 0xAF] },
                                                                   b => { "" => [0xFD, 0xCB, 0x00, 0xA8] },
                                                                   c => { "" => [0xFD, 0xCB, 0x00, 0xA9] },
                                                                   d => { "" => [0xFD, 0xCB, 0x00, 0xAA] },
                                                                   e => { "" => [0xFD, 0xCB, 0x00, 0xAB] },
                                                                   h => { "" => [0xFD, 0xCB, 0x00, 0xAC] },
                                                                   l => { "" => [0xFD, 0xCB, 0x00, 0xAD] },
                                                                 },
                                                        },
                                               },
                                       },
                                "a" => { "" => [0xCB, 0xAF] },
                                "b" => { "" => [0xCB, 0xA8] },
                                "c" => { "" => [0xCB, 0xA9] },
                                "d" => { "" => [0xCB, 0xAA] },
                                "e" => { "" => [0xCB, 0xAB] },
                                "h" => { "" => [0xCB, 0xAC] },
                                "l" => { "" => [0xCB, 0xAD] },
                              },
                     },
              0x06 => {
                       "," => {
                                "(" => {
                                         hl => { ")" => { "" => [0xCB, 0xB6] } },
                                         ix => {
                                                 ")" => {
                                                          ""  => [0xDD, 0xCB, 0x00, 0xB6],
                                                          "," => {
                                                                   a => { "" => [0xDD, 0xCB, 0x00, 0xB7] },
                                                                   b => { "" => [0xDD, 0xCB, 0x00, 0xB0] },
                                                                   c => { "" => [0xDD, 0xCB, 0x00, 0xB1] },
                                                                   d => { "" => [0xDD, 0xCB, 0x00, 0xB2] },
                                                                   e => { "" => [0xDD, 0xCB, 0x00, 0xB3] },
                                                                   h => { "" => [0xDD, 0xCB, 0x00, 0xB4] },
                                                                   l => { "" => [0xDD, 0xCB, 0x00, 0xB5] },
                                                                 },
                                                        },
                                                 "+" => {
                                                          DIS => {
                                                                   ")" => {
                                                                            ""  => [0xDD, 0xCB, "DIS", 0xB6],
                                                                            "," => {
                                                                                     a => { "" => [0xDD, 0xCB, "DIS", 0xB7] },
                                                                                     b => { "" => [0xDD, 0xCB, "DIS", 0xB0] },
                                                                                     c => { "" => [0xDD, 0xCB, "DIS", 0xB1] },
                                                                                     d => { "" => [0xDD, 0xCB, "DIS", 0xB2] },
                                                                                     e => { "" => [0xDD, 0xCB, "DIS", 0xB3] },
                                                                                     h => { "" => [0xDD, 0xCB, "DIS", 0xB4] },
                                                                                     l => { "" => [0xDD, 0xCB, "DIS", 0xB5] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            ")" => {
                                                                     ""  => [0xDD, 0xCB, "NDIS", 0xB6],
                                                                     "," => {
                                                                              a => { "" => [0xDD, 0xCB, "NDIS", 0xB7] },
                                                                              b => { "" => [0xDD, 0xCB, "NDIS", 0xB0] },
                                                                              c => { "" => [0xDD, 0xCB, "NDIS", 0xB1] },
                                                                              d => { "" => [0xDD, 0xCB, "NDIS", 0xB2] },
                                                                              e => { "" => [0xDD, 0xCB, "NDIS", 0xB3] },
                                                                              h => { "" => [0xDD, 0xCB, "NDIS", 0xB4] },
                                                                              l => { "" => [0xDD, 0xCB, "NDIS", 0xB5] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                               },
                                         iy => {
                                                 ")" => {
                                                          ""  => [0xFD, 0xCB, 0x00, 0xB6],
                                                          "," => {
                                                                   a => { "" => [0xFD, 0xCB, 0x00, 0xB7] },
                                                                   b => { "" => [0xFD, 0xCB, 0x00, 0xB0] },
                                                                   c => { "" => [0xFD, 0xCB, 0x00, 0xB1] },
                                                                   d => { "" => [0xFD, 0xCB, 0x00, 0xB2] },
                                                                   e => { "" => [0xFD, 0xCB, 0x00, 0xB3] },
                                                                   h => { "" => [0xFD, 0xCB, 0x00, 0xB4] },
                                                                   l => { "" => [0xFD, 0xCB, 0x00, 0xB5] },
                                                                 },
                                                        },
                                                 "+" => {
                                                          DIS => {
                                                                   ")" => {
                                                                            ""  => [0xFD, 0xCB, "DIS", 0xB6],
                                                                            "," => {
                                                                                     a => { "" => [0xFD, 0xCB, "DIS", 0xB7] },
                                                                                     b => { "" => [0xFD, 0xCB, "DIS", 0xB0] },
                                                                                     c => { "" => [0xFD, 0xCB, "DIS", 0xB1] },
                                                                                     d => { "" => [0xFD, 0xCB, "DIS", 0xB2] },
                                                                                     e => { "" => [0xFD, 0xCB, "DIS", 0xB3] },
                                                                                     h => { "" => [0xFD, 0xCB, "DIS", 0xB4] },
                                                                                     l => { "" => [0xFD, 0xCB, "DIS", 0xB5] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            ")" => {
                                                                     ""  => [0xFD, 0xCB, "NDIS", 0xB6],
                                                                     "," => {
                                                                              a => { "" => [0xFD, 0xCB, "NDIS", 0xB7] },
                                                                              b => { "" => [0xFD, 0xCB, "NDIS", 0xB0] },
                                                                              c => { "" => [0xFD, 0xCB, "NDIS", 0xB1] },
                                                                              d => { "" => [0xFD, 0xCB, "NDIS", 0xB2] },
                                                                              e => { "" => [0xFD, 0xCB, "NDIS", 0xB3] },
                                                                              h => { "" => [0xFD, 0xCB, "NDIS", 0xB4] },
                                                                              l => { "" => [0xFD, 0xCB, "NDIS", 0xB5] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                               },
                                       },
                                "[" => {
                                         hl => { "]" => { "" => [0xCB, 0xB6] } },
                                         ix => {
                                                 "+" => {
                                                          DIS => {
                                                                   "]" => {
                                                                            ""  => [0xDD, 0xCB, "DIS", 0xB6],
                                                                            "," => {
                                                                                     a => { "" => [0xDD, 0xCB, "DIS", 0xB7] },
                                                                                     b => { "" => [0xDD, 0xCB, "DIS", 0xB0] },
                                                                                     c => { "" => [0xDD, 0xCB, "DIS", 0xB1] },
                                                                                     d => { "" => [0xDD, 0xCB, "DIS", 0xB2] },
                                                                                     e => { "" => [0xDD, 0xCB, "DIS", 0xB3] },
                                                                                     h => { "" => [0xDD, 0xCB, "DIS", 0xB4] },
                                                                                     l => { "" => [0xDD, 0xCB, "DIS", 0xB5] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            "]" => {
                                                                     ""  => [0xDD, 0xCB, "NDIS", 0xB6],
                                                                     "," => {
                                                                              a => { "" => [0xDD, 0xCB, "NDIS", 0xB7] },
                                                                              b => { "" => [0xDD, 0xCB, "NDIS", 0xB0] },
                                                                              c => { "" => [0xDD, 0xCB, "NDIS", 0xB1] },
                                                                              d => { "" => [0xDD, 0xCB, "NDIS", 0xB2] },
                                                                              e => { "" => [0xDD, 0xCB, "NDIS", 0xB3] },
                                                                              h => { "" => [0xDD, 0xCB, "NDIS", 0xB4] },
                                                                              l => { "" => [0xDD, 0xCB, "NDIS", 0xB5] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                                 "]" => {
                                                          ""  => [0xDD, 0xCB, 0x00, 0xB6],
                                                          "," => {
                                                                   a => { "" => [0xDD, 0xCB, 0x00, 0xB7] },
                                                                   b => { "" => [0xDD, 0xCB, 0x00, 0xB0] },
                                                                   c => { "" => [0xDD, 0xCB, 0x00, 0xB1] },
                                                                   d => { "" => [0xDD, 0xCB, 0x00, 0xB2] },
                                                                   e => { "" => [0xDD, 0xCB, 0x00, 0xB3] },
                                                                   h => { "" => [0xDD, 0xCB, 0x00, 0xB4] },
                                                                   l => { "" => [0xDD, 0xCB, 0x00, 0xB5] },
                                                                 },
                                                        },
                                               },
                                         iy => {
                                                 "+" => {
                                                          DIS => {
                                                                   "]" => {
                                                                            ""  => [0xFD, 0xCB, "DIS", 0xB6],
                                                                            "," => {
                                                                                     a => { "" => [0xFD, 0xCB, "DIS", 0xB7] },
                                                                                     b => { "" => [0xFD, 0xCB, "DIS", 0xB0] },
                                                                                     c => { "" => [0xFD, 0xCB, "DIS", 0xB1] },
                                                                                     d => { "" => [0xFD, 0xCB, "DIS", 0xB2] },
                                                                                     e => { "" => [0xFD, 0xCB, "DIS", 0xB3] },
                                                                                     h => { "" => [0xFD, 0xCB, "DIS", 0xB4] },
                                                                                     l => { "" => [0xFD, 0xCB, "DIS", 0xB5] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            "]" => {
                                                                     ""  => [0xFD, 0xCB, "NDIS", 0xB6],
                                                                     "," => {
                                                                              a => { "" => [0xFD, 0xCB, "NDIS", 0xB7] },
                                                                              b => { "" => [0xFD, 0xCB, "NDIS", 0xB0] },
                                                                              c => { "" => [0xFD, 0xCB, "NDIS", 0xB1] },
                                                                              d => { "" => [0xFD, 0xCB, "NDIS", 0xB2] },
                                                                              e => { "" => [0xFD, 0xCB, "NDIS", 0xB3] },
                                                                              h => { "" => [0xFD, 0xCB, "NDIS", 0xB4] },
                                                                              l => { "" => [0xFD, 0xCB, "NDIS", 0xB5] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                                 "]" => {
                                                          ""  => [0xFD, 0xCB, 0x00, 0xB6],
                                                          "," => {
                                                                   a => { "" => [0xFD, 0xCB, 0x00, 0xB7] },
                                                                   b => { "" => [0xFD, 0xCB, 0x00, 0xB0] },
                                                                   c => { "" => [0xFD, 0xCB, 0x00, 0xB1] },
                                                                   d => { "" => [0xFD, 0xCB, 0x00, 0xB2] },
                                                                   e => { "" => [0xFD, 0xCB, 0x00, 0xB3] },
                                                                   h => { "" => [0xFD, 0xCB, 0x00, 0xB4] },
                                                                   l => { "" => [0xFD, 0xCB, 0x00, 0xB5] },
                                                                 },
                                                        },
                                               },
                                       },
                                "a" => { "" => [0xCB, 0xB7] },
                                "b" => { "" => [0xCB, 0xB0] },
                                "c" => { "" => [0xCB, 0xB1] },
                                "d" => { "" => [0xCB, 0xB2] },
                                "e" => { "" => [0xCB, 0xB3] },
                                "h" => { "" => [0xCB, 0xB4] },
                                "l" => { "" => [0xCB, 0xB5] },
                              },
                     },
              0x07 => {
                       "," => {
                                "(" => {
                                         hl => { ")" => { "" => [0xCB, 0xBE] } },
                                         ix => {
                                                 ")" => {
                                                          ""  => [0xDD, 0xCB, 0x00, 0xBE],
                                                          "," => {
                                                                   a => { "" => [0xDD, 0xCB, 0x00, 0xBF] },
                                                                   b => { "" => [0xDD, 0xCB, 0x00, 0xB8] },
                                                                   c => { "" => [0xDD, 0xCB, 0x00, 0xB9] },
                                                                   d => { "" => [0xDD, 0xCB, 0x00, 0xBA] },
                                                                   e => { "" => [0xDD, 0xCB, 0x00, 0xBB] },
                                                                   h => { "" => [0xDD, 0xCB, 0x00, 0xBC] },
                                                                   l => { "" => [0xDD, 0xCB, 0x00, 0xBD] },
                                                                 },
                                                        },
                                                 "+" => {
                                                          DIS => {
                                                                   ")" => {
                                                                            ""  => [0xDD, 0xCB, "DIS", 0xBE],
                                                                            "," => {
                                                                                     a => { "" => [0xDD, 0xCB, "DIS", 0xBF] },
                                                                                     b => { "" => [0xDD, 0xCB, "DIS", 0xB8] },
                                                                                     c => { "" => [0xDD, 0xCB, "DIS", 0xB9] },
                                                                                     d => { "" => [0xDD, 0xCB, "DIS", 0xBA] },
                                                                                     e => { "" => [0xDD, 0xCB, "DIS", 0xBB] },
                                                                                     h => { "" => [0xDD, 0xCB, "DIS", 0xBC] },
                                                                                     l => { "" => [0xDD, 0xCB, "DIS", 0xBD] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            ")" => {
                                                                     ""  => [0xDD, 0xCB, "NDIS", 0xBE],
                                                                     "," => {
                                                                              a => { "" => [0xDD, 0xCB, "NDIS", 0xBF] },
                                                                              b => { "" => [0xDD, 0xCB, "NDIS", 0xB8] },
                                                                              c => { "" => [0xDD, 0xCB, "NDIS", 0xB9] },
                                                                              d => { "" => [0xDD, 0xCB, "NDIS", 0xBA] },
                                                                              e => { "" => [0xDD, 0xCB, "NDIS", 0xBB] },
                                                                              h => { "" => [0xDD, 0xCB, "NDIS", 0xBC] },
                                                                              l => { "" => [0xDD, 0xCB, "NDIS", 0xBD] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                               },
                                         iy => {
                                                 ")" => {
                                                          ""  => [0xFD, 0xCB, 0x00, 0xBE],
                                                          "," => {
                                                                   a => { "" => [0xFD, 0xCB, 0x00, 0xBF] },
                                                                   b => { "" => [0xFD, 0xCB, 0x00, 0xB8] },
                                                                   c => { "" => [0xFD, 0xCB, 0x00, 0xB9] },
                                                                   d => { "" => [0xFD, 0xCB, 0x00, 0xBA] },
                                                                   e => { "" => [0xFD, 0xCB, 0x00, 0xBB] },
                                                                   h => { "" => [0xFD, 0xCB, 0x00, 0xBC] },
                                                                   l => { "" => [0xFD, 0xCB, 0x00, 0xBD] },
                                                                 },
                                                        },
                                                 "+" => {
                                                          DIS => {
                                                                   ")" => {
                                                                            ""  => [0xFD, 0xCB, "DIS", 0xBE],
                                                                            "," => {
                                                                                     a => { "" => [0xFD, 0xCB, "DIS", 0xBF] },
                                                                                     b => { "" => [0xFD, 0xCB, "DIS", 0xB8] },
                                                                                     c => { "" => [0xFD, 0xCB, "DIS", 0xB9] },
                                                                                     d => { "" => [0xFD, 0xCB, "DIS", 0xBA] },
                                                                                     e => { "" => [0xFD, 0xCB, "DIS", 0xBB] },
                                                                                     h => { "" => [0xFD, 0xCB, "DIS", 0xBC] },
                                                                                     l => { "" => [0xFD, 0xCB, "DIS", 0xBD] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            ")" => {
                                                                     ""  => [0xFD, 0xCB, "NDIS", 0xBE],
                                                                     "," => {
                                                                              a => { "" => [0xFD, 0xCB, "NDIS", 0xBF] },
                                                                              b => { "" => [0xFD, 0xCB, "NDIS", 0xB8] },
                                                                              c => { "" => [0xFD, 0xCB, "NDIS", 0xB9] },
                                                                              d => { "" => [0xFD, 0xCB, "NDIS", 0xBA] },
                                                                              e => { "" => [0xFD, 0xCB, "NDIS", 0xBB] },
                                                                              h => { "" => [0xFD, 0xCB, "NDIS", 0xBC] },
                                                                              l => { "" => [0xFD, 0xCB, "NDIS", 0xBD] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                               },
                                       },
                                "[" => {
                                         hl => { "]" => { "" => [0xCB, 0xBE] } },
                                         ix => {
                                                 "+" => {
                                                          DIS => {
                                                                   "]" => {
                                                                            ""  => [0xDD, 0xCB, "DIS", 0xBE],
                                                                            "," => {
                                                                                     a => { "" => [0xDD, 0xCB, "DIS", 0xBF] },
                                                                                     b => { "" => [0xDD, 0xCB, "DIS", 0xB8] },
                                                                                     c => { "" => [0xDD, 0xCB, "DIS", 0xB9] },
                                                                                     d => { "" => [0xDD, 0xCB, "DIS", 0xBA] },
                                                                                     e => { "" => [0xDD, 0xCB, "DIS", 0xBB] },
                                                                                     h => { "" => [0xDD, 0xCB, "DIS", 0xBC] },
                                                                                     l => { "" => [0xDD, 0xCB, "DIS", 0xBD] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            "]" => {
                                                                     ""  => [0xDD, 0xCB, "NDIS", 0xBE],
                                                                     "," => {
                                                                              a => { "" => [0xDD, 0xCB, "NDIS", 0xBF] },
                                                                              b => { "" => [0xDD, 0xCB, "NDIS", 0xB8] },
                                                                              c => { "" => [0xDD, 0xCB, "NDIS", 0xB9] },
                                                                              d => { "" => [0xDD, 0xCB, "NDIS", 0xBA] },
                                                                              e => { "" => [0xDD, 0xCB, "NDIS", 0xBB] },
                                                                              h => { "" => [0xDD, 0xCB, "NDIS", 0xBC] },
                                                                              l => { "" => [0xDD, 0xCB, "NDIS", 0xBD] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                                 "]" => {
                                                          ""  => [0xDD, 0xCB, 0x00, 0xBE],
                                                          "," => {
                                                                   a => { "" => [0xDD, 0xCB, 0x00, 0xBF] },
                                                                   b => { "" => [0xDD, 0xCB, 0x00, 0xB8] },
                                                                   c => { "" => [0xDD, 0xCB, 0x00, 0xB9] },
                                                                   d => { "" => [0xDD, 0xCB, 0x00, 0xBA] },
                                                                   e => { "" => [0xDD, 0xCB, 0x00, 0xBB] },
                                                                   h => { "" => [0xDD, 0xCB, 0x00, 0xBC] },
                                                                   l => { "" => [0xDD, 0xCB, 0x00, 0xBD] },
                                                                 },
                                                        },
                                               },
                                         iy => {
                                                 "+" => {
                                                          DIS => {
                                                                   "]" => {
                                                                            ""  => [0xFD, 0xCB, "DIS", 0xBE],
                                                                            "," => {
                                                                                     a => { "" => [0xFD, 0xCB, "DIS", 0xBF] },
                                                                                     b => { "" => [0xFD, 0xCB, "DIS", 0xB8] },
                                                                                     c => { "" => [0xFD, 0xCB, "DIS", 0xB9] },
                                                                                     d => { "" => [0xFD, 0xCB, "DIS", 0xBA] },
                                                                                     e => { "" => [0xFD, 0xCB, "DIS", 0xBB] },
                                                                                     h => { "" => [0xFD, 0xCB, "DIS", 0xBC] },
                                                                                     l => { "" => [0xFD, 0xCB, "DIS", 0xBD] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            "]" => {
                                                                     ""  => [0xFD, 0xCB, "NDIS", 0xBE],
                                                                     "," => {
                                                                              a => { "" => [0xFD, 0xCB, "NDIS", 0xBF] },
                                                                              b => { "" => [0xFD, 0xCB, "NDIS", 0xB8] },
                                                                              c => { "" => [0xFD, 0xCB, "NDIS", 0xB9] },
                                                                              d => { "" => [0xFD, 0xCB, "NDIS", 0xBA] },
                                                                              e => { "" => [0xFD, 0xCB, "NDIS", 0xBB] },
                                                                              h => { "" => [0xFD, 0xCB, "NDIS", 0xBC] },
                                                                              l => { "" => [0xFD, 0xCB, "NDIS", 0xBD] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                                 "]" => {
                                                          ""  => [0xFD, 0xCB, 0x00, 0xBE],
                                                          "," => {
                                                                   a => { "" => [0xFD, 0xCB, 0x00, 0xBF] },
                                                                   b => { "" => [0xFD, 0xCB, 0x00, 0xB8] },
                                                                   c => { "" => [0xFD, 0xCB, 0x00, 0xB9] },
                                                                   d => { "" => [0xFD, 0xCB, 0x00, 0xBA] },
                                                                   e => { "" => [0xFD, 0xCB, 0x00, 0xBB] },
                                                                   h => { "" => [0xFD, 0xCB, 0x00, 0xBC] },
                                                                   l => { "" => [0xFD, 0xCB, 0x00, 0xBD] },
                                                                 },
                                                        },
                                               },
                                       },
                                "a" => { "" => [0xCB, 0xBF] },
                                "b" => { "" => [0xCB, 0xB8] },
                                "c" => { "" => [0xCB, 0xB9] },
                                "d" => { "" => [0xCB, 0xBA] },
                                "e" => { "" => [0xCB, 0xBB] },
                                "h" => { "" => [0xCB, 0xBC] },
                                "l" => { "" => [0xCB, 0xBD] },
                              },
                     },
            },
    ret  => {
              ""   => [0xC9],
              "c"  => { "" => [0xD8] },
              "m"  => { "" => [0xF8] },
              "nc" => { "" => [0xD0] },
              "nz" => { "" => [0xC0] },
              "p"  => { "" => [0xF0] },
              "pe" => { "" => [0xE8] },
              "po" => { "" => [0xE0] },
              "z"  => { "" => [0xC8] },
            },
    reti => { "" => [0xED, 0x4D] },
    retn => { "" => [0xED, 0x45] },
    rl   => {
              "("  => {
                        hl => { ")" => { "" => [0xCB, 0x16] } },
                        ix => {
                                ")" => {
                                         ""  => [0xDD, 0xCB, 0x00, 0x16],
                                         "," => {
                                                  a => { "" => [0xDD, 0xCB, 0x00, 0x17] },
                                                  b => { "" => [0xDD, 0xCB, 0x00, 0x10] },
                                                  c => { "" => [0xDD, 0xCB, 0x00, 0x11] },
                                                  d => { "" => [0xDD, 0xCB, 0x00, 0x12] },
                                                  e => { "" => [0xDD, 0xCB, 0x00, 0x13] },
                                                  h => { "" => [0xDD, 0xCB, 0x00, 0x14] },
                                                  l => { "" => [0xDD, 0xCB, 0x00, 0x15] },
                                                },
                                       },
                                "+" => {
                                         DIS => {
                                                  ")" => {
                                                           ""  => [0xDD, 0xCB, "DIS", 0x16],
                                                           "," => {
                                                                    a => { "" => [0xDD, 0xCB, "DIS", 0x17] },
                                                                    b => { "" => [0xDD, 0xCB, "DIS", 0x10] },
                                                                    c => { "" => [0xDD, 0xCB, "DIS", 0x11] },
                                                                    d => { "" => [0xDD, 0xCB, "DIS", 0x12] },
                                                                    e => { "" => [0xDD, 0xCB, "DIS", 0x13] },
                                                                    h => { "" => [0xDD, 0xCB, "DIS", 0x14] },
                                                                    l => { "" => [0xDD, 0xCB, "DIS", 0x15] },
                                                                  },
                                                         },
                                                },
                                       },
                                "-" => {
                                         NDIS => {
                                           ")" => {
                                                    ""  => [0xDD, 0xCB, "NDIS", 0x16],
                                                    "," => {
                                                             a => { "" => [0xDD, 0xCB, "NDIS", 0x17] },
                                                             b => { "" => [0xDD, 0xCB, "NDIS", 0x10] },
                                                             c => { "" => [0xDD, 0xCB, "NDIS", 0x11] },
                                                             d => { "" => [0xDD, 0xCB, "NDIS", 0x12] },
                                                             e => { "" => [0xDD, 0xCB, "NDIS", 0x13] },
                                                             h => { "" => [0xDD, 0xCB, "NDIS", 0x14] },
                                                             l => { "" => [0xDD, 0xCB, "NDIS", 0x15] },
                                                           },
                                                  },
                                         },
                                       },
                              },
                        iy => {
                                ")" => {
                                         ""  => [0xFD, 0xCB, 0x00, 0x16],
                                         "," => {
                                                  a => { "" => [0xFD, 0xCB, 0x00, 0x17] },
                                                  b => { "" => [0xFD, 0xCB, 0x00, 0x10] },
                                                  c => { "" => [0xFD, 0xCB, 0x00, 0x11] },
                                                  d => { "" => [0xFD, 0xCB, 0x00, 0x12] },
                                                  e => { "" => [0xFD, 0xCB, 0x00, 0x13] },
                                                  h => { "" => [0xFD, 0xCB, 0x00, 0x14] },
                                                  l => { "" => [0xFD, 0xCB, 0x00, 0x15] },
                                                },
                                       },
                                "+" => {
                                         DIS => {
                                                  ")" => {
                                                           ""  => [0xFD, 0xCB, "DIS", 0x16],
                                                           "," => {
                                                                    a => { "" => [0xFD, 0xCB, "DIS", 0x17] },
                                                                    b => { "" => [0xFD, 0xCB, "DIS", 0x10] },
                                                                    c => { "" => [0xFD, 0xCB, "DIS", 0x11] },
                                                                    d => { "" => [0xFD, 0xCB, "DIS", 0x12] },
                                                                    e => { "" => [0xFD, 0xCB, "DIS", 0x13] },
                                                                    h => { "" => [0xFD, 0xCB, "DIS", 0x14] },
                                                                    l => { "" => [0xFD, 0xCB, "DIS", 0x15] },
                                                                  },
                                                         },
                                                },
                                       },
                                "-" => {
                                         NDIS => {
                                           ")" => {
                                                    ""  => [0xFD, 0xCB, "NDIS", 0x16],
                                                    "," => {
                                                             a => { "" => [0xFD, 0xCB, "NDIS", 0x17] },
                                                             b => { "" => [0xFD, 0xCB, "NDIS", 0x10] },
                                                             c => { "" => [0xFD, 0xCB, "NDIS", 0x11] },
                                                             d => { "" => [0xFD, 0xCB, "NDIS", 0x12] },
                                                             e => { "" => [0xFD, 0xCB, "NDIS", 0x13] },
                                                             h => { "" => [0xFD, 0xCB, "NDIS", 0x14] },
                                                             l => { "" => [0xFD, 0xCB, "NDIS", 0x15] },
                                                           },
                                                  },
                                         },
                                       },
                              },
                      },
              "["  => {
                        hl => { "]" => { "" => [0xCB, 0x16] } },
                        ix => {
                                "+" => {
                                         DIS => {
                                                  "]" => {
                                                           ""  => [0xDD, 0xCB, "DIS", 0x16],
                                                           "," => {
                                                                    a => { "" => [0xDD, 0xCB, "DIS", 0x17] },
                                                                    b => { "" => [0xDD, 0xCB, "DIS", 0x10] },
                                                                    c => { "" => [0xDD, 0xCB, "DIS", 0x11] },
                                                                    d => { "" => [0xDD, 0xCB, "DIS", 0x12] },
                                                                    e => { "" => [0xDD, 0xCB, "DIS", 0x13] },
                                                                    h => { "" => [0xDD, 0xCB, "DIS", 0x14] },
                                                                    l => { "" => [0xDD, 0xCB, "DIS", 0x15] },
                                                                  },
                                                         },
                                                },
                                       },
                                "-" => {
                                         NDIS => {
                                           "]" => {
                                                    ""  => [0xDD, 0xCB, "NDIS", 0x16],
                                                    "," => {
                                                             a => { "" => [0xDD, 0xCB, "NDIS", 0x17] },
                                                             b => { "" => [0xDD, 0xCB, "NDIS", 0x10] },
                                                             c => { "" => [0xDD, 0xCB, "NDIS", 0x11] },
                                                             d => { "" => [0xDD, 0xCB, "NDIS", 0x12] },
                                                             e => { "" => [0xDD, 0xCB, "NDIS", 0x13] },
                                                             h => { "" => [0xDD, 0xCB, "NDIS", 0x14] },
                                                             l => { "" => [0xDD, 0xCB, "NDIS", 0x15] },
                                                           },
                                                  },
                                         },
                                       },
                                "]" => {
                                         ""  => [0xDD, 0xCB, 0x00, 0x16],
                                         "," => {
                                                  a => { "" => [0xDD, 0xCB, 0x00, 0x17] },
                                                  b => { "" => [0xDD, 0xCB, 0x00, 0x10] },
                                                  c => { "" => [0xDD, 0xCB, 0x00, 0x11] },
                                                  d => { "" => [0xDD, 0xCB, 0x00, 0x12] },
                                                  e => { "" => [0xDD, 0xCB, 0x00, 0x13] },
                                                  h => { "" => [0xDD, 0xCB, 0x00, 0x14] },
                                                  l => { "" => [0xDD, 0xCB, 0x00, 0x15] },
                                                },
                                       },
                              },
                        iy => {
                                "+" => {
                                         DIS => {
                                                  "]" => {
                                                           ""  => [0xFD, 0xCB, "DIS", 0x16],
                                                           "," => {
                                                                    a => { "" => [0xFD, 0xCB, "DIS", 0x17] },
                                                                    b => { "" => [0xFD, 0xCB, "DIS", 0x10] },
                                                                    c => { "" => [0xFD, 0xCB, "DIS", 0x11] },
                                                                    d => { "" => [0xFD, 0xCB, "DIS", 0x12] },
                                                                    e => { "" => [0xFD, 0xCB, "DIS", 0x13] },
                                                                    h => { "" => [0xFD, 0xCB, "DIS", 0x14] },
                                                                    l => { "" => [0xFD, 0xCB, "DIS", 0x15] },
                                                                  },
                                                         },
                                                },
                                       },
                                "-" => {
                                         NDIS => {
                                           "]" => {
                                                    ""  => [0xFD, 0xCB, "NDIS", 0x16],
                                                    "," => {
                                                             a => { "" => [0xFD, 0xCB, "NDIS", 0x17] },
                                                             b => { "" => [0xFD, 0xCB, "NDIS", 0x10] },
                                                             c => { "" => [0xFD, 0xCB, "NDIS", 0x11] },
                                                             d => { "" => [0xFD, 0xCB, "NDIS", 0x12] },
                                                             e => { "" => [0xFD, 0xCB, "NDIS", 0x13] },
                                                             h => { "" => [0xFD, 0xCB, "NDIS", 0x14] },
                                                             l => { "" => [0xFD, 0xCB, "NDIS", 0x15] },
                                                           },
                                                  },
                                         },
                                       },
                                "]" => {
                                         ""  => [0xFD, 0xCB, 0x00, 0x16],
                                         "," => {
                                                  a => { "" => [0xFD, 0xCB, 0x00, 0x17] },
                                                  b => { "" => [0xFD, 0xCB, 0x00, 0x10] },
                                                  c => { "" => [0xFD, 0xCB, 0x00, 0x11] },
                                                  d => { "" => [0xFD, 0xCB, 0x00, 0x12] },
                                                  e => { "" => [0xFD, 0xCB, 0x00, 0x13] },
                                                  h => { "" => [0xFD, 0xCB, 0x00, 0x14] },
                                                  l => { "" => [0xFD, 0xCB, 0x00, 0x15] },
                                                },
                                       },
                              },
                      },
              "a"  => { "" => [0xCB, 0x17] },
              "b"  => { "" => [0xCB, 0x10] },
              "bc" => { "" => [0xCB, 0x11, 0xCB, 0x10] },
              "c"  => { "" => [0xCB, 0x11] },
              "d"  => { "" => [0xCB, 0x12] },
              "de" => { "" => [0xCB, 0x13, 0xCB, 0x12] },
              "e"  => { "" => [0xCB, 0x13] },
              "h"  => { "" => [0xCB, 0x14] },
              "hl" => { "" => [0xCB, 0x15, 0xCB, 0x14] },
              "l"  => { "" => [0xCB, 0x15] },
            },
    rla  => { "" => [0x17] },
    rlc  => {
              "(" => {
                       hl => { ")" => { "" => [0xCB, 0x06] } },
                       ix => {
                               ")" => {
                                        ""  => [0xDD, 0xCB, 0x00, 0x06],
                                        "," => {
                                                 a => { "" => [0xDD, 0xCB, 0x00, 0x07] },
                                                 b => { "" => [0xDD, 0xCB, 0x00, 0x00] },
                                                 c => { "" => [0xDD, 0xCB, 0x00, 0x01] },
                                                 d => { "" => [0xDD, 0xCB, 0x00, 0x02] },
                                                 e => { "" => [0xDD, 0xCB, 0x00, 0x03] },
                                                 h => { "" => [0xDD, 0xCB, 0x00, 0x04] },
                                                 l => { "" => [0xDD, 0xCB, 0x00, 0x05] },
                                               },
                                      },
                               "+" => {
                                        DIS => {
                                                 ")" => {
                                                          ""  => [0xDD, 0xCB, "DIS", 0x06],
                                                          "," => {
                                                                   a => { "" => [0xDD, 0xCB, "DIS", 0x07] },
                                                                   b => { "" => [0xDD, 0xCB, "DIS", 0x00] },
                                                                   c => { "" => [0xDD, 0xCB, "DIS", 0x01] },
                                                                   d => { "" => [0xDD, 0xCB, "DIS", 0x02] },
                                                                   e => { "" => [0xDD, 0xCB, "DIS", 0x03] },
                                                                   h => { "" => [0xDD, 0xCB, "DIS", 0x04] },
                                                                   l => { "" => [0xDD, 0xCB, "DIS", 0x05] },
                                                                 },
                                                        },
                                               },
                                      },
                               "-" => {
                                        NDIS => {
                                          ")" => {
                                                   ""  => [0xDD, 0xCB, "NDIS", 0x06],
                                                   "," => {
                                                            a => { "" => [0xDD, 0xCB, "NDIS", 0x07] },
                                                            b => { "" => [0xDD, 0xCB, "NDIS", 0x00] },
                                                            c => { "" => [0xDD, 0xCB, "NDIS", 0x01] },
                                                            d => { "" => [0xDD, 0xCB, "NDIS", 0x02] },
                                                            e => { "" => [0xDD, 0xCB, "NDIS", 0x03] },
                                                            h => { "" => [0xDD, 0xCB, "NDIS", 0x04] },
                                                            l => { "" => [0xDD, 0xCB, "NDIS", 0x05] },
                                                          },
                                                 },
                                        },
                                      },
                             },
                       iy => {
                               ")" => {
                                        ""  => [0xFD, 0xCB, 0x00, 0x06],
                                        "," => {
                                                 a => { "" => [0xFD, 0xCB, 0x00, 0x07] },
                                                 b => { "" => [0xFD, 0xCB, 0x00, 0x00] },
                                                 c => { "" => [0xFD, 0xCB, 0x00, 0x01] },
                                                 d => { "" => [0xFD, 0xCB, 0x00, 0x02] },
                                                 e => { "" => [0xFD, 0xCB, 0x00, 0x03] },
                                                 h => { "" => [0xFD, 0xCB, 0x00, 0x04] },
                                                 l => { "" => [0xFD, 0xCB, 0x00, 0x05] },
                                               },
                                      },
                               "+" => {
                                        DIS => {
                                                 ")" => {
                                                          ""  => [0xFD, 0xCB, "DIS", 0x06],
                                                          "," => {
                                                                   a => { "" => [0xFD, 0xCB, "DIS", 0x07] },
                                                                   b => { "" => [0xFD, 0xCB, "DIS", 0x00] },
                                                                   c => { "" => [0xFD, 0xCB, "DIS", 0x01] },
                                                                   d => { "" => [0xFD, 0xCB, "DIS", 0x02] },
                                                                   e => { "" => [0xFD, 0xCB, "DIS", 0x03] },
                                                                   h => { "" => [0xFD, 0xCB, "DIS", 0x04] },
                                                                   l => { "" => [0xFD, 0xCB, "DIS", 0x05] },
                                                                 },
                                                        },
                                               },
                                      },
                               "-" => {
                                        NDIS => {
                                          ")" => {
                                                   ""  => [0xFD, 0xCB, "NDIS", 0x06],
                                                   "," => {
                                                            a => { "" => [0xFD, 0xCB, "NDIS", 0x07] },
                                                            b => { "" => [0xFD, 0xCB, "NDIS", 0x00] },
                                                            c => { "" => [0xFD, 0xCB, "NDIS", 0x01] },
                                                            d => { "" => [0xFD, 0xCB, "NDIS", 0x02] },
                                                            e => { "" => [0xFD, 0xCB, "NDIS", 0x03] },
                                                            h => { "" => [0xFD, 0xCB, "NDIS", 0x04] },
                                                            l => { "" => [0xFD, 0xCB, "NDIS", 0x05] },
                                                          },
                                                 },
                                        },
                                      },
                             },
                     },
              "[" => {
                       hl => { "]" => { "" => [0xCB, 0x06] } },
                       ix => {
                               "+" => {
                                        DIS => {
                                                 "]" => {
                                                          ""  => [0xDD, 0xCB, "DIS", 0x06],
                                                          "," => {
                                                                   a => { "" => [0xDD, 0xCB, "DIS", 0x07] },
                                                                   b => { "" => [0xDD, 0xCB, "DIS", 0x00] },
                                                                   c => { "" => [0xDD, 0xCB, "DIS", 0x01] },
                                                                   d => { "" => [0xDD, 0xCB, "DIS", 0x02] },
                                                                   e => { "" => [0xDD, 0xCB, "DIS", 0x03] },
                                                                   h => { "" => [0xDD, 0xCB, "DIS", 0x04] },
                                                                   l => { "" => [0xDD, 0xCB, "DIS", 0x05] },
                                                                 },
                                                        },
                                               },
                                      },
                               "-" => {
                                        NDIS => {
                                          "]" => {
                                                   ""  => [0xDD, 0xCB, "NDIS", 0x06],
                                                   "," => {
                                                            a => { "" => [0xDD, 0xCB, "NDIS", 0x07] },
                                                            b => { "" => [0xDD, 0xCB, "NDIS", 0x00] },
                                                            c => { "" => [0xDD, 0xCB, "NDIS", 0x01] },
                                                            d => { "" => [0xDD, 0xCB, "NDIS", 0x02] },
                                                            e => { "" => [0xDD, 0xCB, "NDIS", 0x03] },
                                                            h => { "" => [0xDD, 0xCB, "NDIS", 0x04] },
                                                            l => { "" => [0xDD, 0xCB, "NDIS", 0x05] },
                                                          },
                                                 },
                                        },
                                      },
                               "]" => {
                                        ""  => [0xDD, 0xCB, 0x00, 0x06],
                                        "," => {
                                                 a => { "" => [0xDD, 0xCB, 0x00, 0x07] },
                                                 b => { "" => [0xDD, 0xCB, 0x00, 0x00] },
                                                 c => { "" => [0xDD, 0xCB, 0x00, 0x01] },
                                                 d => { "" => [0xDD, 0xCB, 0x00, 0x02] },
                                                 e => { "" => [0xDD, 0xCB, 0x00, 0x03] },
                                                 h => { "" => [0xDD, 0xCB, 0x00, 0x04] },
                                                 l => { "" => [0xDD, 0xCB, 0x00, 0x05] },
                                               },
                                      },
                             },
                       iy => {
                               "+" => {
                                        DIS => {
                                                 "]" => {
                                                          ""  => [0xFD, 0xCB, "DIS", 0x06],
                                                          "," => {
                                                                   a => { "" => [0xFD, 0xCB, "DIS", 0x07] },
                                                                   b => { "" => [0xFD, 0xCB, "DIS", 0x00] },
                                                                   c => { "" => [0xFD, 0xCB, "DIS", 0x01] },
                                                                   d => { "" => [0xFD, 0xCB, "DIS", 0x02] },
                                                                   e => { "" => [0xFD, 0xCB, "DIS", 0x03] },
                                                                   h => { "" => [0xFD, 0xCB, "DIS", 0x04] },
                                                                   l => { "" => [0xFD, 0xCB, "DIS", 0x05] },
                                                                 },
                                                        },
                                               },
                                      },
                               "-" => {
                                        NDIS => {
                                          "]" => {
                                                   ""  => [0xFD, 0xCB, "NDIS", 0x06],
                                                   "," => {
                                                            a => { "" => [0xFD, 0xCB, "NDIS", 0x07] },
                                                            b => { "" => [0xFD, 0xCB, "NDIS", 0x00] },
                                                            c => { "" => [0xFD, 0xCB, "NDIS", 0x01] },
                                                            d => { "" => [0xFD, 0xCB, "NDIS", 0x02] },
                                                            e => { "" => [0xFD, 0xCB, "NDIS", 0x03] },
                                                            h => { "" => [0xFD, 0xCB, "NDIS", 0x04] },
                                                            l => { "" => [0xFD, 0xCB, "NDIS", 0x05] },
                                                          },
                                                 },
                                        },
                                      },
                               "]" => {
                                        ""  => [0xFD, 0xCB, 0x00, 0x06],
                                        "," => {
                                                 a => { "" => [0xFD, 0xCB, 0x00, 0x07] },
                                                 b => { "" => [0xFD, 0xCB, 0x00, 0x00] },
                                                 c => { "" => [0xFD, 0xCB, 0x00, 0x01] },
                                                 d => { "" => [0xFD, 0xCB, 0x00, 0x02] },
                                                 e => { "" => [0xFD, 0xCB, 0x00, 0x03] },
                                                 h => { "" => [0xFD, 0xCB, 0x00, 0x04] },
                                                 l => { "" => [0xFD, 0xCB, 0x00, 0x05] },
                                               },
                                      },
                             },
                     },
              "a" => { "" => [0xCB, 0x07] },
              "b" => { "" => [0xCB, 0x00] },
              "c" => { "" => [0xCB, 0x01] },
              "d" => { "" => [0xCB, 0x02] },
              "e" => { "" => [0xCB, 0x03] },
              "h" => { "" => [0xCB, 0x04] },
              "l" => { "" => [0xCB, 0x05] },
            },
    rlca => { "" => [0x07] },
    rld  => { "" => [0xED, 0x6F] },
    rr   => {
              "("  => {
                        hl => { ")" => { "" => [0xCB, 0x1E] } },
                        ix => {
                                ")" => {
                                         ""  => [0xDD, 0xCB, 0x00, 0x1E],
                                         "," => {
                                                  a => { "" => [0xDD, 0xCB, 0x00, 0x1F] },
                                                  b => { "" => [0xDD, 0xCB, 0x00, 0x18] },
                                                  c => { "" => [0xDD, 0xCB, 0x00, 0x19] },
                                                  d => { "" => [0xDD, 0xCB, 0x00, 0x1A] },
                                                  e => { "" => [0xDD, 0xCB, 0x00, 0x1B] },
                                                  h => { "" => [0xDD, 0xCB, 0x00, 0x1C] },
                                                  l => { "" => [0xDD, 0xCB, 0x00, 0x1D] },
                                                },
                                       },
                                "+" => {
                                         DIS => {
                                                  ")" => {
                                                           ""  => [0xDD, 0xCB, "DIS", 0x1E],
                                                           "," => {
                                                                    a => { "" => [0xDD, 0xCB, "DIS", 0x1F] },
                                                                    b => { "" => [0xDD, 0xCB, "DIS", 0x18] },
                                                                    c => { "" => [0xDD, 0xCB, "DIS", 0x19] },
                                                                    d => { "" => [0xDD, 0xCB, "DIS", 0x1A] },
                                                                    e => { "" => [0xDD, 0xCB, "DIS", 0x1B] },
                                                                    h => { "" => [0xDD, 0xCB, "DIS", 0x1C] },
                                                                    l => { "" => [0xDD, 0xCB, "DIS", 0x1D] },
                                                                  },
                                                         },
                                                },
                                       },
                                "-" => {
                                         NDIS => {
                                           ")" => {
                                                    ""  => [0xDD, 0xCB, "NDIS", 0x1E],
                                                    "," => {
                                                             a => { "" => [0xDD, 0xCB, "NDIS", 0x1F] },
                                                             b => { "" => [0xDD, 0xCB, "NDIS", 0x18] },
                                                             c => { "" => [0xDD, 0xCB, "NDIS", 0x19] },
                                                             d => { "" => [0xDD, 0xCB, "NDIS", 0x1A] },
                                                             e => { "" => [0xDD, 0xCB, "NDIS", 0x1B] },
                                                             h => { "" => [0xDD, 0xCB, "NDIS", 0x1C] },
                                                             l => { "" => [0xDD, 0xCB, "NDIS", 0x1D] },
                                                           },
                                                  },
                                         },
                                       },
                              },
                        iy => {
                                ")" => {
                                         ""  => [0xFD, 0xCB, 0x00, 0x1E],
                                         "," => {
                                                  a => { "" => [0xFD, 0xCB, 0x00, 0x1F] },
                                                  b => { "" => [0xFD, 0xCB, 0x00, 0x18] },
                                                  c => { "" => [0xFD, 0xCB, 0x00, 0x19] },
                                                  d => { "" => [0xFD, 0xCB, 0x00, 0x1A] },
                                                  e => { "" => [0xFD, 0xCB, 0x00, 0x1B] },
                                                  h => { "" => [0xFD, 0xCB, 0x00, 0x1C] },
                                                  l => { "" => [0xFD, 0xCB, 0x00, 0x1D] },
                                                },
                                       },
                                "+" => {
                                         DIS => {
                                                  ")" => {
                                                           ""  => [0xFD, 0xCB, "DIS", 0x1E],
                                                           "," => {
                                                                    a => { "" => [0xFD, 0xCB, "DIS", 0x1F] },
                                                                    b => { "" => [0xFD, 0xCB, "DIS", 0x18] },
                                                                    c => { "" => [0xFD, 0xCB, "DIS", 0x19] },
                                                                    d => { "" => [0xFD, 0xCB, "DIS", 0x1A] },
                                                                    e => { "" => [0xFD, 0xCB, "DIS", 0x1B] },
                                                                    h => { "" => [0xFD, 0xCB, "DIS", 0x1C] },
                                                                    l => { "" => [0xFD, 0xCB, "DIS", 0x1D] },
                                                                  },
                                                         },
                                                },
                                       },
                                "-" => {
                                         NDIS => {
                                           ")" => {
                                                    ""  => [0xFD, 0xCB, "NDIS", 0x1E],
                                                    "," => {
                                                             a => { "" => [0xFD, 0xCB, "NDIS", 0x1F] },
                                                             b => { "" => [0xFD, 0xCB, "NDIS", 0x18] },
                                                             c => { "" => [0xFD, 0xCB, "NDIS", 0x19] },
                                                             d => { "" => [0xFD, 0xCB, "NDIS", 0x1A] },
                                                             e => { "" => [0xFD, 0xCB, "NDIS", 0x1B] },
                                                             h => { "" => [0xFD, 0xCB, "NDIS", 0x1C] },
                                                             l => { "" => [0xFD, 0xCB, "NDIS", 0x1D] },
                                                           },
                                                  },
                                         },
                                       },
                              },
                      },
              "["  => {
                        hl => { "]" => { "" => [0xCB, 0x1E] } },
                        ix => {
                                "+" => {
                                         DIS => {
                                                  "]" => {
                                                           ""  => [0xDD, 0xCB, "DIS", 0x1E],
                                                           "," => {
                                                                    a => { "" => [0xDD, 0xCB, "DIS", 0x1F] },
                                                                    b => { "" => [0xDD, 0xCB, "DIS", 0x18] },
                                                                    c => { "" => [0xDD, 0xCB, "DIS", 0x19] },
                                                                    d => { "" => [0xDD, 0xCB, "DIS", 0x1A] },
                                                                    e => { "" => [0xDD, 0xCB, "DIS", 0x1B] },
                                                                    h => { "" => [0xDD, 0xCB, "DIS", 0x1C] },
                                                                    l => { "" => [0xDD, 0xCB, "DIS", 0x1D] },
                                                                  },
                                                         },
                                                },
                                       },
                                "-" => {
                                         NDIS => {
                                           "]" => {
                                                    ""  => [0xDD, 0xCB, "NDIS", 0x1E],
                                                    "," => {
                                                             a => { "" => [0xDD, 0xCB, "NDIS", 0x1F] },
                                                             b => { "" => [0xDD, 0xCB, "NDIS", 0x18] },
                                                             c => { "" => [0xDD, 0xCB, "NDIS", 0x19] },
                                                             d => { "" => [0xDD, 0xCB, "NDIS", 0x1A] },
                                                             e => { "" => [0xDD, 0xCB, "NDIS", 0x1B] },
                                                             h => { "" => [0xDD, 0xCB, "NDIS", 0x1C] },
                                                             l => { "" => [0xDD, 0xCB, "NDIS", 0x1D] },
                                                           },
                                                  },
                                         },
                                       },
                                "]" => {
                                         ""  => [0xDD, 0xCB, 0x00, 0x1E],
                                         "," => {
                                                  a => { "" => [0xDD, 0xCB, 0x00, 0x1F] },
                                                  b => { "" => [0xDD, 0xCB, 0x00, 0x18] },
                                                  c => { "" => [0xDD, 0xCB, 0x00, 0x19] },
                                                  d => { "" => [0xDD, 0xCB, 0x00, 0x1A] },
                                                  e => { "" => [0xDD, 0xCB, 0x00, 0x1B] },
                                                  h => { "" => [0xDD, 0xCB, 0x00, 0x1C] },
                                                  l => { "" => [0xDD, 0xCB, 0x00, 0x1D] },
                                                },
                                       },
                              },
                        iy => {
                                "+" => {
                                         DIS => {
                                                  "]" => {
                                                           ""  => [0xFD, 0xCB, "DIS", 0x1E],
                                                           "," => {
                                                                    a => { "" => [0xFD, 0xCB, "DIS", 0x1F] },
                                                                    b => { "" => [0xFD, 0xCB, "DIS", 0x18] },
                                                                    c => { "" => [0xFD, 0xCB, "DIS", 0x19] },
                                                                    d => { "" => [0xFD, 0xCB, "DIS", 0x1A] },
                                                                    e => { "" => [0xFD, 0xCB, "DIS", 0x1B] },
                                                                    h => { "" => [0xFD, 0xCB, "DIS", 0x1C] },
                                                                    l => { "" => [0xFD, 0xCB, "DIS", 0x1D] },
                                                                  },
                                                         },
                                                },
                                       },
                                "-" => {
                                         NDIS => {
                                           "]" => {
                                                    ""  => [0xFD, 0xCB, "NDIS", 0x1E],
                                                    "," => {
                                                             a => { "" => [0xFD, 0xCB, "NDIS", 0x1F] },
                                                             b => { "" => [0xFD, 0xCB, "NDIS", 0x18] },
                                                             c => { "" => [0xFD, 0xCB, "NDIS", 0x19] },
                                                             d => { "" => [0xFD, 0xCB, "NDIS", 0x1A] },
                                                             e => { "" => [0xFD, 0xCB, "NDIS", 0x1B] },
                                                             h => { "" => [0xFD, 0xCB, "NDIS", 0x1C] },
                                                             l => { "" => [0xFD, 0xCB, "NDIS", 0x1D] },
                                                           },
                                                  },
                                         },
                                       },
                                "]" => {
                                         ""  => [0xFD, 0xCB, 0x00, 0x1E],
                                         "," => {
                                                  a => { "" => [0xFD, 0xCB, 0x00, 0x1F] },
                                                  b => { "" => [0xFD, 0xCB, 0x00, 0x18] },
                                                  c => { "" => [0xFD, 0xCB, 0x00, 0x19] },
                                                  d => { "" => [0xFD, 0xCB, 0x00, 0x1A] },
                                                  e => { "" => [0xFD, 0xCB, 0x00, 0x1B] },
                                                  h => { "" => [0xFD, 0xCB, 0x00, 0x1C] },
                                                  l => { "" => [0xFD, 0xCB, 0x00, 0x1D] },
                                                },
                                       },
                              },
                      },
              "a"  => { "" => [0xCB, 0x1F] },
              "b"  => { "" => [0xCB, 0x18] },
              "bc" => { "" => [0xCB, 0x18, 0xCB, 0x19] },
              "c"  => { "" => [0xCB, 0x19] },
              "d"  => { "" => [0xCB, 0x1A] },
              "de" => { "" => [0xCB, 0x1A, 0xCB, 0x1B] },
              "e"  => { "" => [0xCB, 0x1B] },
              "h"  => { "" => [0xCB, 0x1C] },
              "hl" => { "" => [0xCB, 0x1C, 0xCB, 0x1D] },
              "l"  => { "" => [0xCB, 0x1D] },
            },
    rra  => { "" => [0x1F] },
    rrc  => {
              "(" => {
                       hl => { ")" => { "" => [0xCB, 0x0E] } },
                       ix => {
                               ")" => {
                                        ""  => [0xDD, 0xCB, 0x00, 0x0E],
                                        "," => {
                                                 a => { "" => [0xDD, 0xCB, 0x00, 0x0F] },
                                                 b => { "" => [0xDD, 0xCB, 0x00, 0x08] },
                                                 c => { "" => [0xDD, 0xCB, 0x00, 0x09] },
                                                 d => { "" => [0xDD, 0xCB, 0x00, 0x0A] },
                                                 e => { "" => [0xDD, 0xCB, 0x00, 0x0B] },
                                                 h => { "" => [0xDD, 0xCB, 0x00, 0x0C] },
                                                 l => { "" => [0xDD, 0xCB, 0x00, 0x0D] },
                                               },
                                      },
                               "+" => {
                                        DIS => {
                                                 ")" => {
                                                          ""  => [0xDD, 0xCB, "DIS", 0x0E],
                                                          "," => {
                                                                   a => { "" => [0xDD, 0xCB, "DIS", 0x0F] },
                                                                   b => { "" => [0xDD, 0xCB, "DIS", 0x08] },
                                                                   c => { "" => [0xDD, 0xCB, "DIS", 0x09] },
                                                                   d => { "" => [0xDD, 0xCB, "DIS", 0x0A] },
                                                                   e => { "" => [0xDD, 0xCB, "DIS", 0x0B] },
                                                                   h => { "" => [0xDD, 0xCB, "DIS", 0x0C] },
                                                                   l => { "" => [0xDD, 0xCB, "DIS", 0x0D] },
                                                                 },
                                                        },
                                               },
                                      },
                               "-" => {
                                        NDIS => {
                                          ")" => {
                                                   ""  => [0xDD, 0xCB, "NDIS", 0x0E],
                                                   "," => {
                                                            a => { "" => [0xDD, 0xCB, "NDIS", 0x0F] },
                                                            b => { "" => [0xDD, 0xCB, "NDIS", 0x08] },
                                                            c => { "" => [0xDD, 0xCB, "NDIS", 0x09] },
                                                            d => { "" => [0xDD, 0xCB, "NDIS", 0x0A] },
                                                            e => { "" => [0xDD, 0xCB, "NDIS", 0x0B] },
                                                            h => { "" => [0xDD, 0xCB, "NDIS", 0x0C] },
                                                            l => { "" => [0xDD, 0xCB, "NDIS", 0x0D] },
                                                          },
                                                 },
                                        },
                                      },
                             },
                       iy => {
                               ")" => {
                                        ""  => [0xFD, 0xCB, 0x00, 0x0E],
                                        "," => {
                                                 a => { "" => [0xFD, 0xCB, 0x00, 0x0F] },
                                                 b => { "" => [0xFD, 0xCB, 0x00, 0x08] },
                                                 c => { "" => [0xFD, 0xCB, 0x00, 0x09] },
                                                 d => { "" => [0xFD, 0xCB, 0x00, 0x0A] },
                                                 e => { "" => [0xFD, 0xCB, 0x00, 0x0B] },
                                                 h => { "" => [0xFD, 0xCB, 0x00, 0x0C] },
                                                 l => { "" => [0xFD, 0xCB, 0x00, 0x0D] },
                                               },
                                      },
                               "+" => {
                                        DIS => {
                                                 ")" => {
                                                          ""  => [0xFD, 0xCB, "DIS", 0x0E],
                                                          "," => {
                                                                   a => { "" => [0xFD, 0xCB, "DIS", 0x0F] },
                                                                   b => { "" => [0xFD, 0xCB, "DIS", 0x08] },
                                                                   c => { "" => [0xFD, 0xCB, "DIS", 0x09] },
                                                                   d => { "" => [0xFD, 0xCB, "DIS", 0x0A] },
                                                                   e => { "" => [0xFD, 0xCB, "DIS", 0x0B] },
                                                                   h => { "" => [0xFD, 0xCB, "DIS", 0x0C] },
                                                                   l => { "" => [0xFD, 0xCB, "DIS", 0x0D] },
                                                                 },
                                                        },
                                               },
                                      },
                               "-" => {
                                        NDIS => {
                                          ")" => {
                                                   ""  => [0xFD, 0xCB, "NDIS", 0x0E],
                                                   "," => {
                                                            a => { "" => [0xFD, 0xCB, "NDIS", 0x0F] },
                                                            b => { "" => [0xFD, 0xCB, "NDIS", 0x08] },
                                                            c => { "" => [0xFD, 0xCB, "NDIS", 0x09] },
                                                            d => { "" => [0xFD, 0xCB, "NDIS", 0x0A] },
                                                            e => { "" => [0xFD, 0xCB, "NDIS", 0x0B] },
                                                            h => { "" => [0xFD, 0xCB, "NDIS", 0x0C] },
                                                            l => { "" => [0xFD, 0xCB, "NDIS", 0x0D] },
                                                          },
                                                 },
                                        },
                                      },
                             },
                     },
              "[" => {
                       hl => { "]" => { "" => [0xCB, 0x0E] } },
                       ix => {
                               "+" => {
                                        DIS => {
                                                 "]" => {
                                                          ""  => [0xDD, 0xCB, "DIS", 0x0E],
                                                          "," => {
                                                                   a => { "" => [0xDD, 0xCB, "DIS", 0x0F] },
                                                                   b => { "" => [0xDD, 0xCB, "DIS", 0x08] },
                                                                   c => { "" => [0xDD, 0xCB, "DIS", 0x09] },
                                                                   d => { "" => [0xDD, 0xCB, "DIS", 0x0A] },
                                                                   e => { "" => [0xDD, 0xCB, "DIS", 0x0B] },
                                                                   h => { "" => [0xDD, 0xCB, "DIS", 0x0C] },
                                                                   l => { "" => [0xDD, 0xCB, "DIS", 0x0D] },
                                                                 },
                                                        },
                                               },
                                      },
                               "-" => {
                                        NDIS => {
                                          "]" => {
                                                   ""  => [0xDD, 0xCB, "NDIS", 0x0E],
                                                   "," => {
                                                            a => { "" => [0xDD, 0xCB, "NDIS", 0x0F] },
                                                            b => { "" => [0xDD, 0xCB, "NDIS", 0x08] },
                                                            c => { "" => [0xDD, 0xCB, "NDIS", 0x09] },
                                                            d => { "" => [0xDD, 0xCB, "NDIS", 0x0A] },
                                                            e => { "" => [0xDD, 0xCB, "NDIS", 0x0B] },
                                                            h => { "" => [0xDD, 0xCB, "NDIS", 0x0C] },
                                                            l => { "" => [0xDD, 0xCB, "NDIS", 0x0D] },
                                                          },
                                                 },
                                        },
                                      },
                               "]" => {
                                        ""  => [0xDD, 0xCB, 0x00, 0x0E],
                                        "," => {
                                                 a => { "" => [0xDD, 0xCB, 0x00, 0x0F] },
                                                 b => { "" => [0xDD, 0xCB, 0x00, 0x08] },
                                                 c => { "" => [0xDD, 0xCB, 0x00, 0x09] },
                                                 d => { "" => [0xDD, 0xCB, 0x00, 0x0A] },
                                                 e => { "" => [0xDD, 0xCB, 0x00, 0x0B] },
                                                 h => { "" => [0xDD, 0xCB, 0x00, 0x0C] },
                                                 l => { "" => [0xDD, 0xCB, 0x00, 0x0D] },
                                               },
                                      },
                             },
                       iy => {
                               "+" => {
                                        DIS => {
                                                 "]" => {
                                                          ""  => [0xFD, 0xCB, "DIS", 0x0E],
                                                          "," => {
                                                                   a => { "" => [0xFD, 0xCB, "DIS", 0x0F] },
                                                                   b => { "" => [0xFD, 0xCB, "DIS", 0x08] },
                                                                   c => { "" => [0xFD, 0xCB, "DIS", 0x09] },
                                                                   d => { "" => [0xFD, 0xCB, "DIS", 0x0A] },
                                                                   e => { "" => [0xFD, 0xCB, "DIS", 0x0B] },
                                                                   h => { "" => [0xFD, 0xCB, "DIS", 0x0C] },
                                                                   l => { "" => [0xFD, 0xCB, "DIS", 0x0D] },
                                                                 },
                                                        },
                                               },
                                      },
                               "-" => {
                                        NDIS => {
                                          "]" => {
                                                   ""  => [0xFD, 0xCB, "NDIS", 0x0E],
                                                   "," => {
                                                            a => { "" => [0xFD, 0xCB, "NDIS", 0x0F] },
                                                            b => { "" => [0xFD, 0xCB, "NDIS", 0x08] },
                                                            c => { "" => [0xFD, 0xCB, "NDIS", 0x09] },
                                                            d => { "" => [0xFD, 0xCB, "NDIS", 0x0A] },
                                                            e => { "" => [0xFD, 0xCB, "NDIS", 0x0B] },
                                                            h => { "" => [0xFD, 0xCB, "NDIS", 0x0C] },
                                                            l => { "" => [0xFD, 0xCB, "NDIS", 0x0D] },
                                                          },
                                                 },
                                        },
                                      },
                               "]" => {
                                        ""  => [0xFD, 0xCB, 0x00, 0x0E],
                                        "," => {
                                                 a => { "" => [0xFD, 0xCB, 0x00, 0x0F] },
                                                 b => { "" => [0xFD, 0xCB, 0x00, 0x08] },
                                                 c => { "" => [0xFD, 0xCB, 0x00, 0x09] },
                                                 d => { "" => [0xFD, 0xCB, 0x00, 0x0A] },
                                                 e => { "" => [0xFD, 0xCB, 0x00, 0x0B] },
                                                 h => { "" => [0xFD, 0xCB, 0x00, 0x0C] },
                                                 l => { "" => [0xFD, 0xCB, 0x00, 0x0D] },
                                               },
                                      },
                             },
                     },
              "a" => { "" => [0xCB, 0x0F] },
              "b" => { "" => [0xCB, 0x08] },
              "c" => { "" => [0xCB, 0x09] },
              "d" => { "" => [0xCB, 0x0A] },
              "e" => { "" => [0xCB, 0x0B] },
              "h" => { "" => [0xCB, 0x0C] },
              "l" => { "" => [0xCB, 0x0D] },
            },
    rrca => { "" => [0x0F] },
    rrd  => { "" => [0xED, 0x67] },
    rst  => {
              0x00  => { "" => [0xC7] },
              0x01  => { "" => [0xCF] },
              0x02  => { "" => [0xD7] },
              0x03  => { "" => [0xDF] },
              0x04  => { "" => [0xE7] },
              0x05  => { "" => [0xEF] },
              0x06  => { "" => [0xF7] },
              0x07  => { "" => [0xFF] },
              0x08  => { "" => [0xCF] },
              0x10 => { "" => [0xD7] },
              0x18 => { "" => [0xDF] },
              0x20 => { "" => [0xE7] },
              0x28 => { "" => [0xEF] },
              0x30 => { "" => [0xF7] },
              0x38 => { "" => [0xFF] },
            },
    sbc  => {
              a  => {
                      "," => {
                               "("   => {
                                          hl => { ")" => { "" => [0x9E] } },
                                          ix => {
                                                  ")" => { "" => [0xDD, 0x9E, 0x00] },
                                                  "+" => { DIS => { ")" => { "" => [0xDD, 0x9E, "DIS"] } } },
                                                  "-" => { NDIS => { ")" => { "" => [0xDD, 0x9E, "NDIS"] } } },
                                                },
                                          iy => {
                                                  ")" => { "" => [0xFD, 0x9E, 0x00] },
                                                  "+" => { DIS => { ")" => { "" => [0xFD, 0x9E, "DIS"] } } },
                                                  "-" => { NDIS => { ")" => { "" => [0xFD, 0x9E, "NDIS"] } } },
                                                },
                                        },
                               "["   => {
                                          hl => { "]" => { "" => [0x9E] } },
                                          ix => {
                                                  "+" => { DIS => { "]" => { "" => [0xDD, 0x9E, "DIS"] } } },
                                                  "-" => { NDIS => { "]" => { "" => [0xDD, 0x9E, "NDIS"] } } },
                                                  "]" => { "" => [0xDD, 0x9E, 0x00] },
                                                },
                                          iy => {
                                                  "+" => { DIS => { "]" => { "" => [0xFD, 0x9E, "DIS"] } } },
                                                  "-" => { NDIS => { "]" => { "" => [0xFD, 0x9E, "NDIS"] } } },
                                                  "]" => { "" => [0xFD, 0x9E, 0x00] },
                                                },
                                        },
                               "a"   => { "" => [0x9F] },
                               "b"   => { "" => [0x98] },
                               "c"   => { "" => [0x99] },
                               "d"   => { "" => [0x9A] },
                               "e"   => { "" => [0x9B] },
                               "h"   => { "" => [0x9C] },
                               "hx"  => { "" => [0xDD, 0x9C] },
                               "hy"  => { "" => [0xFD, 0x9C] },
                               "ixh" => { "" => [0xDD, 0x9C] },
                               "ixl" => { "" => [0xDD, 0x9D] },
                               "iyh" => { "" => [0xFD, 0x9C] },
                               "iyl" => { "" => [0xFD, 0x9D] },
                               "l"   => { "" => [0x9D] },
                               "lx"  => { "" => [0xDD, 0x9D] },
                               "ly"  => { "" => [0xFD, 0x9D] },
                               "N"   => { "" => [0xDE, "N"] },
                               "xh"  => { "" => [0xDD, 0x9C] },
                               "xl"  => { "" => [0xDD, 0x9D] },
                               "yh"  => { "" => [0xFD, 0x9C] },
                               "yl"  => { "" => [0xFD, 0x9D] },
                             },
                    },
              hl => {
                      "," => {
                               bc => { "" => [0xED, 0x42] },
                               de => { "" => [0xED, 0x52] },
                               hl => { "" => [0xED, 0x62] },
                               sp => { "" => [0xED, 0x72] },
                             },
                    },
            },
    scf  => { "" => [0x37] },
    set  => {
              0x00 => {
                       "," => {
                                "(" => {
                                         hl => { ")" => { "" => [0xCB, 0xC6] } },
                                         ix => {
                                                 ")" => {
                                                          ""  => [0xDD, 0xCB, 0x00, 0xC6],
                                                          "," => {
                                                                   a => { "" => [0xDD, 0xCB, 0x00, 0xC7] },
                                                                   b => { "" => [0xDD, 0xCB, 0x00, 0xC0] },
                                                                   c => { "" => [0xDD, 0xCB, 0x00, 0xC1] },
                                                                   d => { "" => [0xDD, 0xCB, 0x00, 0xC2] },
                                                                   e => { "" => [0xDD, 0xCB, 0x00, 0xC3] },
                                                                   h => { "" => [0xDD, 0xCB, 0x00, 0xC4] },
                                                                   l => { "" => [0xDD, 0xCB, 0x00, 0xC5] },
                                                                 },
                                                        },
                                                 "+" => {
                                                          DIS => {
                                                                   ")" => {
                                                                            ""  => [0xDD, 0xCB, "DIS", 0xC6],
                                                                            "," => {
                                                                                     a => { "" => [0xDD, 0xCB, "DIS", 0xC7] },
                                                                                     b => { "" => [0xDD, 0xCB, "DIS", 0xC0] },
                                                                                     c => { "" => [0xDD, 0xCB, "DIS", 0xC1] },
                                                                                     d => { "" => [0xDD, 0xCB, "DIS", 0xC2] },
                                                                                     e => { "" => [0xDD, 0xCB, "DIS", 0xC3] },
                                                                                     h => { "" => [0xDD, 0xCB, "DIS", 0xC4] },
                                                                                     l => { "" => [0xDD, 0xCB, "DIS", 0xC5] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            ")" => {
                                                                     ""  => [0xDD, 0xCB, "NDIS", 0xC6],
                                                                     "," => {
                                                                              a => { "" => [0xDD, 0xCB, "NDIS", 0xC7] },
                                                                              b => { "" => [0xDD, 0xCB, "NDIS", 0xC0] },
                                                                              c => { "" => [0xDD, 0xCB, "NDIS", 0xC1] },
                                                                              d => { "" => [0xDD, 0xCB, "NDIS", 0xC2] },
                                                                              e => { "" => [0xDD, 0xCB, "NDIS", 0xC3] },
                                                                              h => { "" => [0xDD, 0xCB, "NDIS", 0xC4] },
                                                                              l => { "" => [0xDD, 0xCB, "NDIS", 0xC5] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                               },
                                         iy => {
                                                 ")" => {
                                                          ""  => [0xFD, 0xCB, 0x00, 0xC6],
                                                          "," => {
                                                                   a => { "" => [0xFD, 0xCB, 0x00, 0xC7] },
                                                                   b => { "" => [0xFD, 0xCB, 0x00, 0xC0] },
                                                                   c => { "" => [0xFD, 0xCB, 0x00, 0xC1] },
                                                                   d => { "" => [0xFD, 0xCB, 0x00, 0xC2] },
                                                                   e => { "" => [0xFD, 0xCB, 0x00, 0xC3] },
                                                                   h => { "" => [0xFD, 0xCB, 0x00, 0xC4] },
                                                                   l => { "" => [0xFD, 0xCB, 0x00, 0xC5] },
                                                                 },
                                                        },
                                                 "+" => {
                                                          DIS => {
                                                                   ")" => {
                                                                            ""  => [0xFD, 0xCB, "DIS", 0xC6],
                                                                            "," => {
                                                                                     a => { "" => [0xFD, 0xCB, "DIS", 0xC7] },
                                                                                     b => { "" => [0xFD, 0xCB, "DIS", 0xC0] },
                                                                                     c => { "" => [0xFD, 0xCB, "DIS", 0xC1] },
                                                                                     d => { "" => [0xFD, 0xCB, "DIS", 0xC2] },
                                                                                     e => { "" => [0xFD, 0xCB, "DIS", 0xC3] },
                                                                                     h => { "" => [0xFD, 0xCB, "DIS", 0xC4] },
                                                                                     l => { "" => [0xFD, 0xCB, "DIS", 0xC5] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            ")" => {
                                                                     ""  => [0xFD, 0xCB, "NDIS", 0xC6],
                                                                     "," => {
                                                                              a => { "" => [0xFD, 0xCB, "NDIS", 0xC7] },
                                                                              b => { "" => [0xFD, 0xCB, "NDIS", 0xC0] },
                                                                              c => { "" => [0xFD, 0xCB, "NDIS", 0xC1] },
                                                                              d => { "" => [0xFD, 0xCB, "NDIS", 0xC2] },
                                                                              e => { "" => [0xFD, 0xCB, "NDIS", 0xC3] },
                                                                              h => { "" => [0xFD, 0xCB, "NDIS", 0xC4] },
                                                                              l => { "" => [0xFD, 0xCB, "NDIS", 0xC5] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                               },
                                       },
                                "[" => {
                                         hl => { "]" => { "" => [0xCB, 0xC6] } },
                                         ix => {
                                                 "+" => {
                                                          DIS => {
                                                                   "]" => {
                                                                            ""  => [0xDD, 0xCB, "DIS", 0xC6],
                                                                            "," => {
                                                                                     a => { "" => [0xDD, 0xCB, "DIS", 0xC7] },
                                                                                     b => { "" => [0xDD, 0xCB, "DIS", 0xC0] },
                                                                                     c => { "" => [0xDD, 0xCB, "DIS", 0xC1] },
                                                                                     d => { "" => [0xDD, 0xCB, "DIS", 0xC2] },
                                                                                     e => { "" => [0xDD, 0xCB, "DIS", 0xC3] },
                                                                                     h => { "" => [0xDD, 0xCB, "DIS", 0xC4] },
                                                                                     l => { "" => [0xDD, 0xCB, "DIS", 0xC5] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            "]" => {
                                                                     ""  => [0xDD, 0xCB, "NDIS", 0xC6],
                                                                     "," => {
                                                                              a => { "" => [0xDD, 0xCB, "NDIS", 0xC7] },
                                                                              b => { "" => [0xDD, 0xCB, "NDIS", 0xC0] },
                                                                              c => { "" => [0xDD, 0xCB, "NDIS", 0xC1] },
                                                                              d => { "" => [0xDD, 0xCB, "NDIS", 0xC2] },
                                                                              e => { "" => [0xDD, 0xCB, "NDIS", 0xC3] },
                                                                              h => { "" => [0xDD, 0xCB, "NDIS", 0xC4] },
                                                                              l => { "" => [0xDD, 0xCB, "NDIS", 0xC5] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                                 "]" => {
                                                          ""  => [0xDD, 0xCB, 0x00, 0xC6],
                                                          "," => {
                                                                   a => { "" => [0xDD, 0xCB, 0x00, 0xC7] },
                                                                   b => { "" => [0xDD, 0xCB, 0x00, 0xC0] },
                                                                   c => { "" => [0xDD, 0xCB, 0x00, 0xC1] },
                                                                   d => { "" => [0xDD, 0xCB, 0x00, 0xC2] },
                                                                   e => { "" => [0xDD, 0xCB, 0x00, 0xC3] },
                                                                   h => { "" => [0xDD, 0xCB, 0x00, 0xC4] },
                                                                   l => { "" => [0xDD, 0xCB, 0x00, 0xC5] },
                                                                 },
                                                        },
                                               },
                                         iy => {
                                                 "+" => {
                                                          DIS => {
                                                                   "]" => {
                                                                            ""  => [0xFD, 0xCB, "DIS", 0xC6],
                                                                            "," => {
                                                                                     a => { "" => [0xFD, 0xCB, "DIS", 0xC7] },
                                                                                     b => { "" => [0xFD, 0xCB, "DIS", 0xC0] },
                                                                                     c => { "" => [0xFD, 0xCB, "DIS", 0xC1] },
                                                                                     d => { "" => [0xFD, 0xCB, "DIS", 0xC2] },
                                                                                     e => { "" => [0xFD, 0xCB, "DIS", 0xC3] },
                                                                                     h => { "" => [0xFD, 0xCB, "DIS", 0xC4] },
                                                                                     l => { "" => [0xFD, 0xCB, "DIS", 0xC5] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            "]" => {
                                                                     ""  => [0xFD, 0xCB, "NDIS", 0xC6],
                                                                     "," => {
                                                                              a => { "" => [0xFD, 0xCB, "NDIS", 0xC7] },
                                                                              b => { "" => [0xFD, 0xCB, "NDIS", 0xC0] },
                                                                              c => { "" => [0xFD, 0xCB, "NDIS", 0xC1] },
                                                                              d => { "" => [0xFD, 0xCB, "NDIS", 0xC2] },
                                                                              e => { "" => [0xFD, 0xCB, "NDIS", 0xC3] },
                                                                              h => { "" => [0xFD, 0xCB, "NDIS", 0xC4] },
                                                                              l => { "" => [0xFD, 0xCB, "NDIS", 0xC5] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                                 "]" => {
                                                          ""  => [0xFD, 0xCB, 0x00, 0xC6],
                                                          "," => {
                                                                   a => { "" => [0xFD, 0xCB, 0x00, 0xC7] },
                                                                   b => { "" => [0xFD, 0xCB, 0x00, 0xC0] },
                                                                   c => { "" => [0xFD, 0xCB, 0x00, 0xC1] },
                                                                   d => { "" => [0xFD, 0xCB, 0x00, 0xC2] },
                                                                   e => { "" => [0xFD, 0xCB, 0x00, 0xC3] },
                                                                   h => { "" => [0xFD, 0xCB, 0x00, 0xC4] },
                                                                   l => { "" => [0xFD, 0xCB, 0x00, 0xC5] },
                                                                 },
                                                        },
                                               },
                                       },
                                "a" => { "" => [0xCB, 0xC7] },
                                "b" => { "" => [0xCB, 0xC0] },
                                "c" => { "" => [0xCB, 0xC1] },
                                "d" => { "" => [0xCB, 0xC2] },
                                "e" => { "" => [0xCB, 0xC3] },
                                "h" => { "" => [0xCB, 0xC4] },
                                "l" => { "" => [0xCB, 0xC5] },
                              },
                     },
              0x01 => {
                       "," => {
                                "(" => {
                                         hl => { ")" => { "" => [0xCB, 0xCE] } },
                                         ix => {
                                                 ")" => {
                                                          ""  => [0xDD, 0xCB, 0x00, 0xCE],
                                                          "," => {
                                                                   a => { "" => [0xDD, 0xCB, 0x00, 0xCF] },
                                                                   b => { "" => [0xDD, 0xCB, 0x00, 0xC8] },
                                                                   c => { "" => [0xDD, 0xCB, 0x00, 0xC9] },
                                                                   d => { "" => [0xDD, 0xCB, 0x00, 0xCA] },
                                                                   e => { "" => [0xDD, 0xCB, 0x00, 0xCB] },
                                                                   h => { "" => [0xDD, 0xCB, 0x00, 0xCC] },
                                                                   l => { "" => [0xDD, 0xCB, 0x00, 0xCD] },
                                                                 },
                                                        },
                                                 "+" => {
                                                          DIS => {
                                                                   ")" => {
                                                                            ""  => [0xDD, 0xCB, "DIS", 0xCE],
                                                                            "," => {
                                                                                     a => { "" => [0xDD, 0xCB, "DIS", 0xCF] },
                                                                                     b => { "" => [0xDD, 0xCB, "DIS", 0xC8] },
                                                                                     c => { "" => [0xDD, 0xCB, "DIS", 0xC9] },
                                                                                     d => { "" => [0xDD, 0xCB, "DIS", 0xCA] },
                                                                                     e => { "" => [0xDD, 0xCB, "DIS", 0xCB] },
                                                                                     h => { "" => [0xDD, 0xCB, "DIS", 0xCC] },
                                                                                     l => { "" => [0xDD, 0xCB, "DIS", 0xCD] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            ")" => {
                                                                     ""  => [0xDD, 0xCB, "NDIS", 0xCE],
                                                                     "," => {
                                                                              a => { "" => [0xDD, 0xCB, "NDIS", 0xCF] },
                                                                              b => { "" => [0xDD, 0xCB, "NDIS", 0xC8] },
                                                                              c => { "" => [0xDD, 0xCB, "NDIS", 0xC9] },
                                                                              d => { "" => [0xDD, 0xCB, "NDIS", 0xCA] },
                                                                              e => { "" => [0xDD, 0xCB, "NDIS", 0xCB] },
                                                                              h => { "" => [0xDD, 0xCB, "NDIS", 0xCC] },
                                                                              l => { "" => [0xDD, 0xCB, "NDIS", 0xCD] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                               },
                                         iy => {
                                                 ")" => {
                                                          ""  => [0xFD, 0xCB, 0x00, 0xCE],
                                                          "," => {
                                                                   a => { "" => [0xFD, 0xCB, 0x00, 0xCF] },
                                                                   b => { "" => [0xFD, 0xCB, 0x00, 0xC8] },
                                                                   c => { "" => [0xFD, 0xCB, 0x00, 0xC9] },
                                                                   d => { "" => [0xFD, 0xCB, 0x00, 0xCA] },
                                                                   e => { "" => [0xFD, 0xCB, 0x00, 0xCB] },
                                                                   h => { "" => [0xFD, 0xCB, 0x00, 0xCC] },
                                                                   l => { "" => [0xFD, 0xCB, 0x00, 0xCD] },
                                                                 },
                                                        },
                                                 "+" => {
                                                          DIS => {
                                                                   ")" => {
                                                                            ""  => [0xFD, 0xCB, "DIS", 0xCE],
                                                                            "," => {
                                                                                     a => { "" => [0xFD, 0xCB, "DIS", 0xCF] },
                                                                                     b => { "" => [0xFD, 0xCB, "DIS", 0xC8] },
                                                                                     c => { "" => [0xFD, 0xCB, "DIS", 0xC9] },
                                                                                     d => { "" => [0xFD, 0xCB, "DIS", 0xCA] },
                                                                                     e => { "" => [0xFD, 0xCB, "DIS", 0xCB] },
                                                                                     h => { "" => [0xFD, 0xCB, "DIS", 0xCC] },
                                                                                     l => { "" => [0xFD, 0xCB, "DIS", 0xCD] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            ")" => {
                                                                     ""  => [0xFD, 0xCB, "NDIS", 0xCE],
                                                                     "," => {
                                                                              a => { "" => [0xFD, 0xCB, "NDIS", 0xCF] },
                                                                              b => { "" => [0xFD, 0xCB, "NDIS", 0xC8] },
                                                                              c => { "" => [0xFD, 0xCB, "NDIS", 0xC9] },
                                                                              d => { "" => [0xFD, 0xCB, "NDIS", 0xCA] },
                                                                              e => { "" => [0xFD, 0xCB, "NDIS", 0xCB] },
                                                                              h => { "" => [0xFD, 0xCB, "NDIS", 0xCC] },
                                                                              l => { "" => [0xFD, 0xCB, "NDIS", 0xCD] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                               },
                                       },
                                "[" => {
                                         hl => { "]" => { "" => [0xCB, 0xCE] } },
                                         ix => {
                                                 "+" => {
                                                          DIS => {
                                                                   "]" => {
                                                                            ""  => [0xDD, 0xCB, "DIS", 0xCE],
                                                                            "," => {
                                                                                     a => { "" => [0xDD, 0xCB, "DIS", 0xCF] },
                                                                                     b => { "" => [0xDD, 0xCB, "DIS", 0xC8] },
                                                                                     c => { "" => [0xDD, 0xCB, "DIS", 0xC9] },
                                                                                     d => { "" => [0xDD, 0xCB, "DIS", 0xCA] },
                                                                                     e => { "" => [0xDD, 0xCB, "DIS", 0xCB] },
                                                                                     h => { "" => [0xDD, 0xCB, "DIS", 0xCC] },
                                                                                     l => { "" => [0xDD, 0xCB, "DIS", 0xCD] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            "]" => {
                                                                     ""  => [0xDD, 0xCB, "NDIS", 0xCE],
                                                                     "," => {
                                                                              a => { "" => [0xDD, 0xCB, "NDIS", 0xCF] },
                                                                              b => { "" => [0xDD, 0xCB, "NDIS", 0xC8] },
                                                                              c => { "" => [0xDD, 0xCB, "NDIS", 0xC9] },
                                                                              d => { "" => [0xDD, 0xCB, "NDIS", 0xCA] },
                                                                              e => { "" => [0xDD, 0xCB, "NDIS", 0xCB] },
                                                                              h => { "" => [0xDD, 0xCB, "NDIS", 0xCC] },
                                                                              l => { "" => [0xDD, 0xCB, "NDIS", 0xCD] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                                 "]" => {
                                                          ""  => [0xDD, 0xCB, 0x00, 0xCE],
                                                          "," => {
                                                                   a => { "" => [0xDD, 0xCB, 0x00, 0xCF] },
                                                                   b => { "" => [0xDD, 0xCB, 0x00, 0xC8] },
                                                                   c => { "" => [0xDD, 0xCB, 0x00, 0xC9] },
                                                                   d => { "" => [0xDD, 0xCB, 0x00, 0xCA] },
                                                                   e => { "" => [0xDD, 0xCB, 0x00, 0xCB] },
                                                                   h => { "" => [0xDD, 0xCB, 0x00, 0xCC] },
                                                                   l => { "" => [0xDD, 0xCB, 0x00, 0xCD] },
                                                                 },
                                                        },
                                               },
                                         iy => {
                                                 "+" => {
                                                          DIS => {
                                                                   "]" => {
                                                                            ""  => [0xFD, 0xCB, "DIS", 0xCE],
                                                                            "," => {
                                                                                     a => { "" => [0xFD, 0xCB, "DIS", 0xCF] },
                                                                                     b => { "" => [0xFD, 0xCB, "DIS", 0xC8] },
                                                                                     c => { "" => [0xFD, 0xCB, "DIS", 0xC9] },
                                                                                     d => { "" => [0xFD, 0xCB, "DIS", 0xCA] },
                                                                                     e => { "" => [0xFD, 0xCB, "DIS", 0xCB] },
                                                                                     h => { "" => [0xFD, 0xCB, "DIS", 0xCC] },
                                                                                     l => { "" => [0xFD, 0xCB, "DIS", 0xCD] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            "]" => {
                                                                     ""  => [0xFD, 0xCB, "NDIS", 0xCE],
                                                                     "," => {
                                                                              a => { "" => [0xFD, 0xCB, "NDIS", 0xCF] },
                                                                              b => { "" => [0xFD, 0xCB, "NDIS", 0xC8] },
                                                                              c => { "" => [0xFD, 0xCB, "NDIS", 0xC9] },
                                                                              d => { "" => [0xFD, 0xCB, "NDIS", 0xCA] },
                                                                              e => { "" => [0xFD, 0xCB, "NDIS", 0xCB] },
                                                                              h => { "" => [0xFD, 0xCB, "NDIS", 0xCC] },
                                                                              l => { "" => [0xFD, 0xCB, "NDIS", 0xCD] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                                 "]" => {
                                                          ""  => [0xFD, 0xCB, 0x00, 0xCE],
                                                          "," => {
                                                                   a => { "" => [0xFD, 0xCB, 0x00, 0xCF] },
                                                                   b => { "" => [0xFD, 0xCB, 0x00, 0xC8] },
                                                                   c => { "" => [0xFD, 0xCB, 0x00, 0xC9] },
                                                                   d => { "" => [0xFD, 0xCB, 0x00, 0xCA] },
                                                                   e => { "" => [0xFD, 0xCB, 0x00, 0xCB] },
                                                                   h => { "" => [0xFD, 0xCB, 0x00, 0xCC] },
                                                                   l => { "" => [0xFD, 0xCB, 0x00, 0xCD] },
                                                                 },
                                                        },
                                               },
                                       },
                                "a" => { "" => [0xCB, 0xCF] },
                                "b" => { "" => [0xCB, 0xC8] },
                                "c" => { "" => [0xCB, 0xC9] },
                                "d" => { "" => [0xCB, 0xCA] },
                                "e" => { "" => [0xCB, 0xCB] },
                                "h" => { "" => [0xCB, 0xCC] },
                                "l" => { "" => [0xCB, 0xCD] },
                              },
                     },
              0x02 => {
                       "," => {
                                "(" => {
                                         hl => { ")" => { "" => [0xCB, 0xD6] } },
                                         ix => {
                                                 ")" => {
                                                          ""  => [0xDD, 0xCB, 0x00, 0xD6],
                                                          "," => {
                                                                   a => { "" => [0xDD, 0xCB, 0x00, 0xD7] },
                                                                   b => { "" => [0xDD, 0xCB, 0x00, 0xD0] },
                                                                   c => { "" => [0xDD, 0xCB, 0x00, 0xD1] },
                                                                   d => { "" => [0xDD, 0xCB, 0x00, 0xD2] },
                                                                   e => { "" => [0xDD, 0xCB, 0x00, 0xD3] },
                                                                   h => { "" => [0xDD, 0xCB, 0x00, 0xD4] },
                                                                   l => { "" => [0xDD, 0xCB, 0x00, 0xD5] },
                                                                 },
                                                        },
                                                 "+" => {
                                                          DIS => {
                                                                   ")" => {
                                                                            ""  => [0xDD, 0xCB, "DIS", 0xD6],
                                                                            "," => {
                                                                                     a => { "" => [0xDD, 0xCB, "DIS", 0xD7] },
                                                                                     b => { "" => [0xDD, 0xCB, "DIS", 0xD0] },
                                                                                     c => { "" => [0xDD, 0xCB, "DIS", 0xD1] },
                                                                                     d => { "" => [0xDD, 0xCB, "DIS", 0xD2] },
                                                                                     e => { "" => [0xDD, 0xCB, "DIS", 0xD3] },
                                                                                     h => { "" => [0xDD, 0xCB, "DIS", 0xD4] },
                                                                                     l => { "" => [0xDD, 0xCB, "DIS", 0xD5] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            ")" => {
                                                                     ""  => [0xDD, 0xCB, "NDIS", 0xD6],
                                                                     "," => {
                                                                              a => { "" => [0xDD, 0xCB, "NDIS", 0xD7] },
                                                                              b => { "" => [0xDD, 0xCB, "NDIS", 0xD0] },
                                                                              c => { "" => [0xDD, 0xCB, "NDIS", 0xD1] },
                                                                              d => { "" => [0xDD, 0xCB, "NDIS", 0xD2] },
                                                                              e => { "" => [0xDD, 0xCB, "NDIS", 0xD3] },
                                                                              h => { "" => [0xDD, 0xCB, "NDIS", 0xD4] },
                                                                              l => { "" => [0xDD, 0xCB, "NDIS", 0xD5] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                               },
                                         iy => {
                                                 ")" => {
                                                          ""  => [0xFD, 0xCB, 0x00, 0xD6],
                                                          "," => {
                                                                   a => { "" => [0xFD, 0xCB, 0x00, 0xD7] },
                                                                   b => { "" => [0xFD, 0xCB, 0x00, 0xD0] },
                                                                   c => { "" => [0xFD, 0xCB, 0x00, 0xD1] },
                                                                   d => { "" => [0xFD, 0xCB, 0x00, 0xD2] },
                                                                   e => { "" => [0xFD, 0xCB, 0x00, 0xD3] },
                                                                   h => { "" => [0xFD, 0xCB, 0x00, 0xD4] },
                                                                   l => { "" => [0xFD, 0xCB, 0x00, 0xD5] },
                                                                 },
                                                        },
                                                 "+" => {
                                                          DIS => {
                                                                   ")" => {
                                                                            ""  => [0xFD, 0xCB, "DIS", 0xD6],
                                                                            "," => {
                                                                                     a => { "" => [0xFD, 0xCB, "DIS", 0xD7] },
                                                                                     b => { "" => [0xFD, 0xCB, "DIS", 0xD0] },
                                                                                     c => { "" => [0xFD, 0xCB, "DIS", 0xD1] },
                                                                                     d => { "" => [0xFD, 0xCB, "DIS", 0xD2] },
                                                                                     e => { "" => [0xFD, 0xCB, "DIS", 0xD3] },
                                                                                     h => { "" => [0xFD, 0xCB, "DIS", 0xD4] },
                                                                                     l => { "" => [0xFD, 0xCB, "DIS", 0xD5] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            ")" => {
                                                                     ""  => [0xFD, 0xCB, "NDIS", 0xD6],
                                                                     "," => {
                                                                              a => { "" => [0xFD, 0xCB, "NDIS", 0xD7] },
                                                                              b => { "" => [0xFD, 0xCB, "NDIS", 0xD0] },
                                                                              c => { "" => [0xFD, 0xCB, "NDIS", 0xD1] },
                                                                              d => { "" => [0xFD, 0xCB, "NDIS", 0xD2] },
                                                                              e => { "" => [0xFD, 0xCB, "NDIS", 0xD3] },
                                                                              h => { "" => [0xFD, 0xCB, "NDIS", 0xD4] },
                                                                              l => { "" => [0xFD, 0xCB, "NDIS", 0xD5] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                               },
                                       },
                                "[" => {
                                         hl => { "]" => { "" => [0xCB, 0xD6] } },
                                         ix => {
                                                 "+" => {
                                                          DIS => {
                                                                   "]" => {
                                                                            ""  => [0xDD, 0xCB, "DIS", 0xD6],
                                                                            "," => {
                                                                                     a => { "" => [0xDD, 0xCB, "DIS", 0xD7] },
                                                                                     b => { "" => [0xDD, 0xCB, "DIS", 0xD0] },
                                                                                     c => { "" => [0xDD, 0xCB, "DIS", 0xD1] },
                                                                                     d => { "" => [0xDD, 0xCB, "DIS", 0xD2] },
                                                                                     e => { "" => [0xDD, 0xCB, "DIS", 0xD3] },
                                                                                     h => { "" => [0xDD, 0xCB, "DIS", 0xD4] },
                                                                                     l => { "" => [0xDD, 0xCB, "DIS", 0xD5] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            "]" => {
                                                                     ""  => [0xDD, 0xCB, "NDIS", 0xD6],
                                                                     "," => {
                                                                              a => { "" => [0xDD, 0xCB, "NDIS", 0xD7] },
                                                                              b => { "" => [0xDD, 0xCB, "NDIS", 0xD0] },
                                                                              c => { "" => [0xDD, 0xCB, "NDIS", 0xD1] },
                                                                              d => { "" => [0xDD, 0xCB, "NDIS", 0xD2] },
                                                                              e => { "" => [0xDD, 0xCB, "NDIS", 0xD3] },
                                                                              h => { "" => [0xDD, 0xCB, "NDIS", 0xD4] },
                                                                              l => { "" => [0xDD, 0xCB, "NDIS", 0xD5] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                                 "]" => {
                                                          ""  => [0xDD, 0xCB, 0x00, 0xD6],
                                                          "," => {
                                                                   a => { "" => [0xDD, 0xCB, 0x00, 0xD7] },
                                                                   b => { "" => [0xDD, 0xCB, 0x00, 0xD0] },
                                                                   c => { "" => [0xDD, 0xCB, 0x00, 0xD1] },
                                                                   d => { "" => [0xDD, 0xCB, 0x00, 0xD2] },
                                                                   e => { "" => [0xDD, 0xCB, 0x00, 0xD3] },
                                                                   h => { "" => [0xDD, 0xCB, 0x00, 0xD4] },
                                                                   l => { "" => [0xDD, 0xCB, 0x00, 0xD5] },
                                                                 },
                                                        },
                                               },
                                         iy => {
                                                 "+" => {
                                                          DIS => {
                                                                   "]" => {
                                                                            ""  => [0xFD, 0xCB, "DIS", 0xD6],
                                                                            "," => {
                                                                                     a => { "" => [0xFD, 0xCB, "DIS", 0xD7] },
                                                                                     b => { "" => [0xFD, 0xCB, "DIS", 0xD0] },
                                                                                     c => { "" => [0xFD, 0xCB, "DIS", 0xD1] },
                                                                                     d => { "" => [0xFD, 0xCB, "DIS", 0xD2] },
                                                                                     e => { "" => [0xFD, 0xCB, "DIS", 0xD3] },
                                                                                     h => { "" => [0xFD, 0xCB, "DIS", 0xD4] },
                                                                                     l => { "" => [0xFD, 0xCB, "DIS", 0xD5] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            "]" => {
                                                                     ""  => [0xFD, 0xCB, "NDIS", 0xD6],
                                                                     "," => {
                                                                              a => { "" => [0xFD, 0xCB, "NDIS", 0xD7] },
                                                                              b => { "" => [0xFD, 0xCB, "NDIS", 0xD0] },
                                                                              c => { "" => [0xFD, 0xCB, "NDIS", 0xD1] },
                                                                              d => { "" => [0xFD, 0xCB, "NDIS", 0xD2] },
                                                                              e => { "" => [0xFD, 0xCB, "NDIS", 0xD3] },
                                                                              h => { "" => [0xFD, 0xCB, "NDIS", 0xD4] },
                                                                              l => { "" => [0xFD, 0xCB, "NDIS", 0xD5] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                                 "]" => {
                                                          ""  => [0xFD, 0xCB, 0x00, 0xD6],
                                                          "," => {
                                                                   a => { "" => [0xFD, 0xCB, 0x00, 0xD7] },
                                                                   b => { "" => [0xFD, 0xCB, 0x00, 0xD0] },
                                                                   c => { "" => [0xFD, 0xCB, 0x00, 0xD1] },
                                                                   d => { "" => [0xFD, 0xCB, 0x00, 0xD2] },
                                                                   e => { "" => [0xFD, 0xCB, 0x00, 0xD3] },
                                                                   h => { "" => [0xFD, 0xCB, 0x00, 0xD4] },
                                                                   l => { "" => [0xFD, 0xCB, 0x00, 0xD5] },
                                                                 },
                                                        },
                                               },
                                       },
                                "a" => { "" => [0xCB, 0xD7] },
                                "b" => { "" => [0xCB, 0xD0] },
                                "c" => { "" => [0xCB, 0xD1] },
                                "d" => { "" => [0xCB, 0xD2] },
                                "e" => { "" => [0xCB, 0xD3] },
                                "h" => { "" => [0xCB, 0xD4] },
                                "l" => { "" => [0xCB, 0xD5] },
                              },
                     },
              0x03 => {
                       "," => {
                                "(" => {
                                         hl => { ")" => { "" => [0xCB, 0xDE] } },
                                         ix => {
                                                 ")" => {
                                                          ""  => [0xDD, 0xCB, 0x00, 0xDE],
                                                          "," => {
                                                                   a => { "" => [0xDD, 0xCB, 0x00, 0xDF] },
                                                                   b => { "" => [0xDD, 0xCB, 0x00, 0xD8] },
                                                                   c => { "" => [0xDD, 0xCB, 0x00, 0xD9] },
                                                                   d => { "" => [0xDD, 0xCB, 0x00, 0xDA] },
                                                                   e => { "" => [0xDD, 0xCB, 0x00, 0xDB] },
                                                                   h => { "" => [0xDD, 0xCB, 0x00, 0xDC] },
                                                                   l => { "" => [0xDD, 0xCB, 0x00, 0xDD] },
                                                                 },
                                                        },
                                                 "+" => {
                                                          DIS => {
                                                                   ")" => {
                                                                            ""  => [0xDD, 0xCB, "DIS", 0xDE],
                                                                            "," => {
                                                                                     a => { "" => [0xDD, 0xCB, "DIS", 0xDF] },
                                                                                     b => { "" => [0xDD, 0xCB, "DIS", 0xD8] },
                                                                                     c => { "" => [0xDD, 0xCB, "DIS", 0xD9] },
                                                                                     d => { "" => [0xDD, 0xCB, "DIS", 0xDA] },
                                                                                     e => { "" => [0xDD, 0xCB, "DIS", 0xDB] },
                                                                                     h => { "" => [0xDD, 0xCB, "DIS", 0xDC] },
                                                                                     l => { "" => [0xDD, 0xCB, "DIS", 0xDD] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            ")" => {
                                                                     ""  => [0xDD, 0xCB, "NDIS", 0xDE],
                                                                     "," => {
                                                                              a => { "" => [0xDD, 0xCB, "NDIS", 0xDF] },
                                                                              b => { "" => [0xDD, 0xCB, "NDIS", 0xD8] },
                                                                              c => { "" => [0xDD, 0xCB, "NDIS", 0xD9] },
                                                                              d => { "" => [0xDD, 0xCB, "NDIS", 0xDA] },
                                                                              e => { "" => [0xDD, 0xCB, "NDIS", 0xDB] },
                                                                              h => { "" => [0xDD, 0xCB, "NDIS", 0xDC] },
                                                                              l => { "" => [0xDD, 0xCB, "NDIS", 0xDD] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                               },
                                         iy => {
                                                 ")" => {
                                                          ""  => [0xFD, 0xCB, 0x00, 0xDE],
                                                          "," => {
                                                                   a => { "" => [0xFD, 0xCB, 0x00, 0xDF] },
                                                                   b => { "" => [0xFD, 0xCB, 0x00, 0xD8] },
                                                                   c => { "" => [0xFD, 0xCB, 0x00, 0xD9] },
                                                                   d => { "" => [0xFD, 0xCB, 0x00, 0xDA] },
                                                                   e => { "" => [0xFD, 0xCB, 0x00, 0xDB] },
                                                                   h => { "" => [0xFD, 0xCB, 0x00, 0xDC] },
                                                                   l => { "" => [0xFD, 0xCB, 0x00, 0xDD] },
                                                                 },
                                                        },
                                                 "+" => {
                                                          DIS => {
                                                                   ")" => {
                                                                            ""  => [0xFD, 0xCB, "DIS", 0xDE],
                                                                            "," => {
                                                                                     a => { "" => [0xFD, 0xCB, "DIS", 0xDF] },
                                                                                     b => { "" => [0xFD, 0xCB, "DIS", 0xD8] },
                                                                                     c => { "" => [0xFD, 0xCB, "DIS", 0xD9] },
                                                                                     d => { "" => [0xFD, 0xCB, "DIS", 0xDA] },
                                                                                     e => { "" => [0xFD, 0xCB, "DIS", 0xDB] },
                                                                                     h => { "" => [0xFD, 0xCB, "DIS", 0xDC] },
                                                                                     l => { "" => [0xFD, 0xCB, "DIS", 0xDD] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            ")" => {
                                                                     ""  => [0xFD, 0xCB, "NDIS", 0xDE],
                                                                     "," => {
                                                                              a => { "" => [0xFD, 0xCB, "NDIS", 0xDF] },
                                                                              b => { "" => [0xFD, 0xCB, "NDIS", 0xD8] },
                                                                              c => { "" => [0xFD, 0xCB, "NDIS", 0xD9] },
                                                                              d => { "" => [0xFD, 0xCB, "NDIS", 0xDA] },
                                                                              e => { "" => [0xFD, 0xCB, "NDIS", 0xDB] },
                                                                              h => { "" => [0xFD, 0xCB, "NDIS", 0xDC] },
                                                                              l => { "" => [0xFD, 0xCB, "NDIS", 0xDD] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                               },
                                       },
                                "[" => {
                                         hl => { "]" => { "" => [0xCB, 0xDE] } },
                                         ix => {
                                                 "+" => {
                                                          DIS => {
                                                                   "]" => {
                                                                            ""  => [0xDD, 0xCB, "DIS", 0xDE],
                                                                            "," => {
                                                                                     a => { "" => [0xDD, 0xCB, "DIS", 0xDF] },
                                                                                     b => { "" => [0xDD, 0xCB, "DIS", 0xD8] },
                                                                                     c => { "" => [0xDD, 0xCB, "DIS", 0xD9] },
                                                                                     d => { "" => [0xDD, 0xCB, "DIS", 0xDA] },
                                                                                     e => { "" => [0xDD, 0xCB, "DIS", 0xDB] },
                                                                                     h => { "" => [0xDD, 0xCB, "DIS", 0xDC] },
                                                                                     l => { "" => [0xDD, 0xCB, "DIS", 0xDD] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            "]" => {
                                                                     ""  => [0xDD, 0xCB, "NDIS", 0xDE],
                                                                     "," => {
                                                                              a => { "" => [0xDD, 0xCB, "NDIS", 0xDF] },
                                                                              b => { "" => [0xDD, 0xCB, "NDIS", 0xD8] },
                                                                              c => { "" => [0xDD, 0xCB, "NDIS", 0xD9] },
                                                                              d => { "" => [0xDD, 0xCB, "NDIS", 0xDA] },
                                                                              e => { "" => [0xDD, 0xCB, "NDIS", 0xDB] },
                                                                              h => { "" => [0xDD, 0xCB, "NDIS", 0xDC] },
                                                                              l => { "" => [0xDD, 0xCB, "NDIS", 0xDD] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                                 "]" => {
                                                          ""  => [0xDD, 0xCB, 0x00, 0xDE],
                                                          "," => {
                                                                   a => { "" => [0xDD, 0xCB, 0x00, 0xDF] },
                                                                   b => { "" => [0xDD, 0xCB, 0x00, 0xD8] },
                                                                   c => { "" => [0xDD, 0xCB, 0x00, 0xD9] },
                                                                   d => { "" => [0xDD, 0xCB, 0x00, 0xDA] },
                                                                   e => { "" => [0xDD, 0xCB, 0x00, 0xDB] },
                                                                   h => { "" => [0xDD, 0xCB, 0x00, 0xDC] },
                                                                   l => { "" => [0xDD, 0xCB, 0x00, 0xDD] },
                                                                 },
                                                        },
                                               },
                                         iy => {
                                                 "+" => {
                                                          DIS => {
                                                                   "]" => {
                                                                            ""  => [0xFD, 0xCB, "DIS", 0xDE],
                                                                            "," => {
                                                                                     a => { "" => [0xFD, 0xCB, "DIS", 0xDF] },
                                                                                     b => { "" => [0xFD, 0xCB, "DIS", 0xD8] },
                                                                                     c => { "" => [0xFD, 0xCB, "DIS", 0xD9] },
                                                                                     d => { "" => [0xFD, 0xCB, "DIS", 0xDA] },
                                                                                     e => { "" => [0xFD, 0xCB, "DIS", 0xDB] },
                                                                                     h => { "" => [0xFD, 0xCB, "DIS", 0xDC] },
                                                                                     l => { "" => [0xFD, 0xCB, "DIS", 0xDD] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            "]" => {
                                                                     ""  => [0xFD, 0xCB, "NDIS", 0xDE],
                                                                     "," => {
                                                                              a => { "" => [0xFD, 0xCB, "NDIS", 0xDF] },
                                                                              b => { "" => [0xFD, 0xCB, "NDIS", 0xD8] },
                                                                              c => { "" => [0xFD, 0xCB, "NDIS", 0xD9] },
                                                                              d => { "" => [0xFD, 0xCB, "NDIS", 0xDA] },
                                                                              e => { "" => [0xFD, 0xCB, "NDIS", 0xDB] },
                                                                              h => { "" => [0xFD, 0xCB, "NDIS", 0xDC] },
                                                                              l => { "" => [0xFD, 0xCB, "NDIS", 0xDD] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                                 "]" => {
                                                          ""  => [0xFD, 0xCB, 0x00, 0xDE],
                                                          "," => {
                                                                   a => { "" => [0xFD, 0xCB, 0x00, 0xDF] },
                                                                   b => { "" => [0xFD, 0xCB, 0x00, 0xD8] },
                                                                   c => { "" => [0xFD, 0xCB, 0x00, 0xD9] },
                                                                   d => { "" => [0xFD, 0xCB, 0x00, 0xDA] },
                                                                   e => { "" => [0xFD, 0xCB, 0x00, 0xDB] },
                                                                   h => { "" => [0xFD, 0xCB, 0x00, 0xDC] },
                                                                   l => { "" => [0xFD, 0xCB, 0x00, 0xDD] },
                                                                 },
                                                        },
                                               },
                                       },
                                "a" => { "" => [0xCB, 0xDF] },
                                "b" => { "" => [0xCB, 0xD8] },
                                "c" => { "" => [0xCB, 0xD9] },
                                "d" => { "" => [0xCB, 0xDA] },
                                "e" => { "" => [0xCB, 0xDB] },
                                "h" => { "" => [0xCB, 0xDC] },
                                "l" => { "" => [0xCB, 0xDD] },
                              },
                     },
              0x04 => {
                       "," => {
                                "(" => {
                                         hl => { ")" => { "" => [0xCB, 0xE6] } },
                                         ix => {
                                                 ")" => {
                                                          ""  => [0xDD, 0xCB, 0x00, 0xE6],
                                                          "," => {
                                                                   a => { "" => [0xDD, 0xCB, 0x00, 0xE7] },
                                                                   b => { "" => [0xDD, 0xCB, 0x00, 0xE0] },
                                                                   c => { "" => [0xDD, 0xCB, 0x00, 0xE1] },
                                                                   d => { "" => [0xDD, 0xCB, 0x00, 0xE2] },
                                                                   e => { "" => [0xDD, 0xCB, 0x00, 0xE3] },
                                                                   h => { "" => [0xDD, 0xCB, 0x00, 0xE4] },
                                                                   l => { "" => [0xDD, 0xCB, 0x00, 0xE5] },
                                                                 },
                                                        },
                                                 "+" => {
                                                          DIS => {
                                                                   ")" => {
                                                                            ""  => [0xDD, 0xCB, "DIS", 0xE6],
                                                                            "," => {
                                                                                     a => { "" => [0xDD, 0xCB, "DIS", 0xE7] },
                                                                                     b => { "" => [0xDD, 0xCB, "DIS", 0xE0] },
                                                                                     c => { "" => [0xDD, 0xCB, "DIS", 0xE1] },
                                                                                     d => { "" => [0xDD, 0xCB, "DIS", 0xE2] },
                                                                                     e => { "" => [0xDD, 0xCB, "DIS", 0xE3] },
                                                                                     h => { "" => [0xDD, 0xCB, "DIS", 0xE4] },
                                                                                     l => { "" => [0xDD, 0xCB, "DIS", 0xE5] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            ")" => {
                                                                     ""  => [0xDD, 0xCB, "NDIS", 0xE6],
                                                                     "," => {
                                                                              a => { "" => [0xDD, 0xCB, "NDIS", 0xE7] },
                                                                              b => { "" => [0xDD, 0xCB, "NDIS", 0xE0] },
                                                                              c => { "" => [0xDD, 0xCB, "NDIS", 0xE1] },
                                                                              d => { "" => [0xDD, 0xCB, "NDIS", 0xE2] },
                                                                              e => { "" => [0xDD, 0xCB, "NDIS", 0xE3] },
                                                                              h => { "" => [0xDD, 0xCB, "NDIS", 0xE4] },
                                                                              l => { "" => [0xDD, 0xCB, "NDIS", 0xE5] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                               },
                                         iy => {
                                                 ")" => {
                                                          ""  => [0xFD, 0xCB, 0x00, 0xE6],
                                                          "," => {
                                                                   a => { "" => [0xFD, 0xCB, 0x00, 0xE7] },
                                                                   b => { "" => [0xFD, 0xCB, 0x00, 0xE0] },
                                                                   c => { "" => [0xFD, 0xCB, 0x00, 0xE1] },
                                                                   d => { "" => [0xFD, 0xCB, 0x00, 0xE2] },
                                                                   e => { "" => [0xFD, 0xCB, 0x00, 0xE3] },
                                                                   h => { "" => [0xFD, 0xCB, 0x00, 0xE4] },
                                                                   l => { "" => [0xFD, 0xCB, 0x00, 0xE5] },
                                                                 },
                                                        },
                                                 "+" => {
                                                          DIS => {
                                                                   ")" => {
                                                                            ""  => [0xFD, 0xCB, "DIS", 0xE6],
                                                                            "," => {
                                                                                     a => { "" => [0xFD, 0xCB, "DIS", 0xE7] },
                                                                                     b => { "" => [0xFD, 0xCB, "DIS", 0xE0] },
                                                                                     c => { "" => [0xFD, 0xCB, "DIS", 0xE1] },
                                                                                     d => { "" => [0xFD, 0xCB, "DIS", 0xE2] },
                                                                                     e => { "" => [0xFD, 0xCB, "DIS", 0xE3] },
                                                                                     h => { "" => [0xFD, 0xCB, "DIS", 0xE4] },
                                                                                     l => { "" => [0xFD, 0xCB, "DIS", 0xE5] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            ")" => {
                                                                     ""  => [0xFD, 0xCB, "NDIS", 0xE6],
                                                                     "," => {
                                                                              a => { "" => [0xFD, 0xCB, "NDIS", 0xE7] },
                                                                              b => { "" => [0xFD, 0xCB, "NDIS", 0xE0] },
                                                                              c => { "" => [0xFD, 0xCB, "NDIS", 0xE1] },
                                                                              d => { "" => [0xFD, 0xCB, "NDIS", 0xE2] },
                                                                              e => { "" => [0xFD, 0xCB, "NDIS", 0xE3] },
                                                                              h => { "" => [0xFD, 0xCB, "NDIS", 0xE4] },
                                                                              l => { "" => [0xFD, 0xCB, "NDIS", 0xE5] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                               },
                                       },
                                "[" => {
                                         hl => { "]" => { "" => [0xCB, 0xE6] } },
                                         ix => {
                                                 "+" => {
                                                          DIS => {
                                                                   "]" => {
                                                                            ""  => [0xDD, 0xCB, "DIS", 0xE6],
                                                                            "," => {
                                                                                     a => { "" => [0xDD, 0xCB, "DIS", 0xE7] },
                                                                                     b => { "" => [0xDD, 0xCB, "DIS", 0xE0] },
                                                                                     c => { "" => [0xDD, 0xCB, "DIS", 0xE1] },
                                                                                     d => { "" => [0xDD, 0xCB, "DIS", 0xE2] },
                                                                                     e => { "" => [0xDD, 0xCB, "DIS", 0xE3] },
                                                                                     h => { "" => [0xDD, 0xCB, "DIS", 0xE4] },
                                                                                     l => { "" => [0xDD, 0xCB, "DIS", 0xE5] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            "]" => {
                                                                     ""  => [0xDD, 0xCB, "NDIS", 0xE6],
                                                                     "," => {
                                                                              a => { "" => [0xDD, 0xCB, "NDIS", 0xE7] },
                                                                              b => { "" => [0xDD, 0xCB, "NDIS", 0xE0] },
                                                                              c => { "" => [0xDD, 0xCB, "NDIS", 0xE1] },
                                                                              d => { "" => [0xDD, 0xCB, "NDIS", 0xE2] },
                                                                              e => { "" => [0xDD, 0xCB, "NDIS", 0xE3] },
                                                                              h => { "" => [0xDD, 0xCB, "NDIS", 0xE4] },
                                                                              l => { "" => [0xDD, 0xCB, "NDIS", 0xE5] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                                 "]" => {
                                                          ""  => [0xDD, 0xCB, 0x00, 0xE6],
                                                          "," => {
                                                                   a => { "" => [0xDD, 0xCB, 0x00, 0xE7] },
                                                                   b => { "" => [0xDD, 0xCB, 0x00, 0xE0] },
                                                                   c => { "" => [0xDD, 0xCB, 0x00, 0xE1] },
                                                                   d => { "" => [0xDD, 0xCB, 0x00, 0xE2] },
                                                                   e => { "" => [0xDD, 0xCB, 0x00, 0xE3] },
                                                                   h => { "" => [0xDD, 0xCB, 0x00, 0xE4] },
                                                                   l => { "" => [0xDD, 0xCB, 0x00, 0xE5] },
                                                                 },
                                                        },
                                               },
                                         iy => {
                                                 "+" => {
                                                          DIS => {
                                                                   "]" => {
                                                                            ""  => [0xFD, 0xCB, "DIS", 0xE6],
                                                                            "," => {
                                                                                     a => { "" => [0xFD, 0xCB, "DIS", 0xE7] },
                                                                                     b => { "" => [0xFD, 0xCB, "DIS", 0xE0] },
                                                                                     c => { "" => [0xFD, 0xCB, "DIS", 0xE1] },
                                                                                     d => { "" => [0xFD, 0xCB, "DIS", 0xE2] },
                                                                                     e => { "" => [0xFD, 0xCB, "DIS", 0xE3] },
                                                                                     h => { "" => [0xFD, 0xCB, "DIS", 0xE4] },
                                                                                     l => { "" => [0xFD, 0xCB, "DIS", 0xE5] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            "]" => {
                                                                     ""  => [0xFD, 0xCB, "NDIS", 0xE6],
                                                                     "," => {
                                                                              a => { "" => [0xFD, 0xCB, "NDIS", 0xE7] },
                                                                              b => { "" => [0xFD, 0xCB, "NDIS", 0xE0] },
                                                                              c => { "" => [0xFD, 0xCB, "NDIS", 0xE1] },
                                                                              d => { "" => [0xFD, 0xCB, "NDIS", 0xE2] },
                                                                              e => { "" => [0xFD, 0xCB, "NDIS", 0xE3] },
                                                                              h => { "" => [0xFD, 0xCB, "NDIS", 0xE4] },
                                                                              l => { "" => [0xFD, 0xCB, "NDIS", 0xE5] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                                 "]" => {
                                                          ""  => [0xFD, 0xCB, 0x00, 0xE6],
                                                          "," => {
                                                                   a => { "" => [0xFD, 0xCB, 0x00, 0xE7] },
                                                                   b => { "" => [0xFD, 0xCB, 0x00, 0xE0] },
                                                                   c => { "" => [0xFD, 0xCB, 0x00, 0xE1] },
                                                                   d => { "" => [0xFD, 0xCB, 0x00, 0xE2] },
                                                                   e => { "" => [0xFD, 0xCB, 0x00, 0xE3] },
                                                                   h => { "" => [0xFD, 0xCB, 0x00, 0xE4] },
                                                                   l => { "" => [0xFD, 0xCB, 0x00, 0xE5] },
                                                                 },
                                                        },
                                               },
                                       },
                                "a" => { "" => [0xCB, 0xE7] },
                                "b" => { "" => [0xCB, 0xE0] },
                                "c" => { "" => [0xCB, 0xE1] },
                                "d" => { "" => [0xCB, 0xE2] },
                                "e" => { "" => [0xCB, 0xE3] },
                                "h" => { "" => [0xCB, 0xE4] },
                                "l" => { "" => [0xCB, 0xE5] },
                              },
                     },
              0x05 => {
                       "," => {
                                "(" => {
                                         hl => { ")" => { "" => [0xCB, 0xEE] } },
                                         ix => {
                                                 ")" => {
                                                          ""  => [0xDD, 0xCB, 0x00, 0xEE],
                                                          "," => {
                                                                   a => { "" => [0xDD, 0xCB, 0x00, 0xEF] },
                                                                   b => { "" => [0xDD, 0xCB, 0x00, 0xE8] },
                                                                   c => { "" => [0xDD, 0xCB, 0x00, 0xE9] },
                                                                   d => { "" => [0xDD, 0xCB, 0x00, 0xEA] },
                                                                   e => { "" => [0xDD, 0xCB, 0x00, 0xEB] },
                                                                   h => { "" => [0xDD, 0xCB, 0x00, 0xEC] },
                                                                   l => { "" => [0xDD, 0xCB, 0x00, 0xED] },
                                                                 },
                                                        },
                                                 "+" => {
                                                          DIS => {
                                                                   ")" => {
                                                                            ""  => [0xDD, 0xCB, "DIS", 0xEE],
                                                                            "," => {
                                                                                     a => { "" => [0xDD, 0xCB, "DIS", 0xEF] },
                                                                                     b => { "" => [0xDD, 0xCB, "DIS", 0xE8] },
                                                                                     c => { "" => [0xDD, 0xCB, "DIS", 0xE9] },
                                                                                     d => { "" => [0xDD, 0xCB, "DIS", 0xEA] },
                                                                                     e => { "" => [0xDD, 0xCB, "DIS", 0xEB] },
                                                                                     h => { "" => [0xDD, 0xCB, "DIS", 0xEC] },
                                                                                     l => { "" => [0xDD, 0xCB, "DIS", 0xED] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            ")" => {
                                                                     ""  => [0xDD, 0xCB, "NDIS", 0xEE],
                                                                     "," => {
                                                                              a => { "" => [0xDD, 0xCB, "NDIS", 0xEF] },
                                                                              b => { "" => [0xDD, 0xCB, "NDIS", 0xE8] },
                                                                              c => { "" => [0xDD, 0xCB, "NDIS", 0xE9] },
                                                                              d => { "" => [0xDD, 0xCB, "NDIS", 0xEA] },
                                                                              e => { "" => [0xDD, 0xCB, "NDIS", 0xEB] },
                                                                              h => { "" => [0xDD, 0xCB, "NDIS", 0xEC] },
                                                                              l => { "" => [0xDD, 0xCB, "NDIS", 0xED] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                               },
                                         iy => {
                                                 ")" => {
                                                          ""  => [0xFD, 0xCB, 0x00, 0xEE],
                                                          "," => {
                                                                   a => { "" => [0xFD, 0xCB, 0x00, 0xEF] },
                                                                   b => { "" => [0xFD, 0xCB, 0x00, 0xE8] },
                                                                   c => { "" => [0xFD, 0xCB, 0x00, 0xE9] },
                                                                   d => { "" => [0xFD, 0xCB, 0x00, 0xEA] },
                                                                   e => { "" => [0xFD, 0xCB, 0x00, 0xEB] },
                                                                   h => { "" => [0xFD, 0xCB, 0x00, 0xEC] },
                                                                   l => { "" => [0xFD, 0xCB, 0x00, 0xED] },
                                                                 },
                                                        },
                                                 "+" => {
                                                          DIS => {
                                                                   ")" => {
                                                                            ""  => [0xFD, 0xCB, "DIS", 0xEE],
                                                                            "," => {
                                                                                     a => { "" => [0xFD, 0xCB, "DIS", 0xEF] },
                                                                                     b => { "" => [0xFD, 0xCB, "DIS", 0xE8] },
                                                                                     c => { "" => [0xFD, 0xCB, "DIS", 0xE9] },
                                                                                     d => { "" => [0xFD, 0xCB, "DIS", 0xEA] },
                                                                                     e => { "" => [0xFD, 0xCB, "DIS", 0xEB] },
                                                                                     h => { "" => [0xFD, 0xCB, "DIS", 0xEC] },
                                                                                     l => { "" => [0xFD, 0xCB, "DIS", 0xED] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            ")" => {
                                                                     ""  => [0xFD, 0xCB, "NDIS", 0xEE],
                                                                     "," => {
                                                                              a => { "" => [0xFD, 0xCB, "NDIS", 0xEF] },
                                                                              b => { "" => [0xFD, 0xCB, "NDIS", 0xE8] },
                                                                              c => { "" => [0xFD, 0xCB, "NDIS", 0xE9] },
                                                                              d => { "" => [0xFD, 0xCB, "NDIS", 0xEA] },
                                                                              e => { "" => [0xFD, 0xCB, "NDIS", 0xEB] },
                                                                              h => { "" => [0xFD, 0xCB, "NDIS", 0xEC] },
                                                                              l => { "" => [0xFD, 0xCB, "NDIS", 0xED] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                               },
                                       },
                                "[" => {
                                         hl => { "]" => { "" => [0xCB, 0xEE] } },
                                         ix => {
                                                 "+" => {
                                                          DIS => {
                                                                   "]" => {
                                                                            ""  => [0xDD, 0xCB, "DIS", 0xEE],
                                                                            "," => {
                                                                                     a => { "" => [0xDD, 0xCB, "DIS", 0xEF] },
                                                                                     b => { "" => [0xDD, 0xCB, "DIS", 0xE8] },
                                                                                     c => { "" => [0xDD, 0xCB, "DIS", 0xE9] },
                                                                                     d => { "" => [0xDD, 0xCB, "DIS", 0xEA] },
                                                                                     e => { "" => [0xDD, 0xCB, "DIS", 0xEB] },
                                                                                     h => { "" => [0xDD, 0xCB, "DIS", 0xEC] },
                                                                                     l => { "" => [0xDD, 0xCB, "DIS", 0xED] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            "]" => {
                                                                     ""  => [0xDD, 0xCB, "NDIS", 0xEE],
                                                                     "," => {
                                                                              a => { "" => [0xDD, 0xCB, "NDIS", 0xEF] },
                                                                              b => { "" => [0xDD, 0xCB, "NDIS", 0xE8] },
                                                                              c => { "" => [0xDD, 0xCB, "NDIS", 0xE9] },
                                                                              d => { "" => [0xDD, 0xCB, "NDIS", 0xEA] },
                                                                              e => { "" => [0xDD, 0xCB, "NDIS", 0xEB] },
                                                                              h => { "" => [0xDD, 0xCB, "NDIS", 0xEC] },
                                                                              l => { "" => [0xDD, 0xCB, "NDIS", 0xED] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                                 "]" => {
                                                          ""  => [0xDD, 0xCB, 0x00, 0xEE],
                                                          "," => {
                                                                   a => { "" => [0xDD, 0xCB, 0x00, 0xEF] },
                                                                   b => { "" => [0xDD, 0xCB, 0x00, 0xE8] },
                                                                   c => { "" => [0xDD, 0xCB, 0x00, 0xE9] },
                                                                   d => { "" => [0xDD, 0xCB, 0x00, 0xEA] },
                                                                   e => { "" => [0xDD, 0xCB, 0x00, 0xEB] },
                                                                   h => { "" => [0xDD, 0xCB, 0x00, 0xEC] },
                                                                   l => { "" => [0xDD, 0xCB, 0x00, 0xED] },
                                                                 },
                                                        },
                                               },
                                         iy => {
                                                 "+" => {
                                                          DIS => {
                                                                   "]" => {
                                                                            ""  => [0xFD, 0xCB, "DIS", 0xEE],
                                                                            "," => {
                                                                                     a => { "" => [0xFD, 0xCB, "DIS", 0xEF] },
                                                                                     b => { "" => [0xFD, 0xCB, "DIS", 0xE8] },
                                                                                     c => { "" => [0xFD, 0xCB, "DIS", 0xE9] },
                                                                                     d => { "" => [0xFD, 0xCB, "DIS", 0xEA] },
                                                                                     e => { "" => [0xFD, 0xCB, "DIS", 0xEB] },
                                                                                     h => { "" => [0xFD, 0xCB, "DIS", 0xEC] },
                                                                                     l => { "" => [0xFD, 0xCB, "DIS", 0xED] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            "]" => {
                                                                     ""  => [0xFD, 0xCB, "NDIS", 0xEE],
                                                                     "," => {
                                                                              a => { "" => [0xFD, 0xCB, "NDIS", 0xEF] },
                                                                              b => { "" => [0xFD, 0xCB, "NDIS", 0xE8] },
                                                                              c => { "" => [0xFD, 0xCB, "NDIS", 0xE9] },
                                                                              d => { "" => [0xFD, 0xCB, "NDIS", 0xEA] },
                                                                              e => { "" => [0xFD, 0xCB, "NDIS", 0xEB] },
                                                                              h => { "" => [0xFD, 0xCB, "NDIS", 0xEC] },
                                                                              l => { "" => [0xFD, 0xCB, "NDIS", 0xED] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                                 "]" => {
                                                          ""  => [0xFD, 0xCB, 0x00, 0xEE],
                                                          "," => {
                                                                   a => { "" => [0xFD, 0xCB, 0x00, 0xEF] },
                                                                   b => { "" => [0xFD, 0xCB, 0x00, 0xE8] },
                                                                   c => { "" => [0xFD, 0xCB, 0x00, 0xE9] },
                                                                   d => { "" => [0xFD, 0xCB, 0x00, 0xEA] },
                                                                   e => { "" => [0xFD, 0xCB, 0x00, 0xEB] },
                                                                   h => { "" => [0xFD, 0xCB, 0x00, 0xEC] },
                                                                   l => { "" => [0xFD, 0xCB, 0x00, 0xED] },
                                                                 },
                                                        },
                                               },
                                       },
                                "a" => { "" => [0xCB, 0xEF] },
                                "b" => { "" => [0xCB, 0xE8] },
                                "c" => { "" => [0xCB, 0xE9] },
                                "d" => { "" => [0xCB, 0xEA] },
                                "e" => { "" => [0xCB, 0xEB] },
                                "h" => { "" => [0xCB, 0xEC] },
                                "l" => { "" => [0xCB, 0xED] },
                              },
                     },
              0x06 => {
                       "," => {
                                "(" => {
                                         hl => { ")" => { "" => [0xCB, 0xF6] } },
                                         ix => {
                                                 ")" => {
                                                          ""  => [0xDD, 0xCB, 0x00, 0xF6],
                                                          "," => {
                                                                   a => { "" => [0xDD, 0xCB, 0x00, 0xF7] },
                                                                   b => { "" => [0xDD, 0xCB, 0x00, 0xF0] },
                                                                   c => { "" => [0xDD, 0xCB, 0x00, 0xF1] },
                                                                   d => { "" => [0xDD, 0xCB, 0x00, 0xF2] },
                                                                   e => { "" => [0xDD, 0xCB, 0x00, 0xF3] },
                                                                   h => { "" => [0xDD, 0xCB, 0x00, 0xF4] },
                                                                   l => { "" => [0xDD, 0xCB, 0x00, 0xF5] },
                                                                 },
                                                        },
                                                 "+" => {
                                                          DIS => {
                                                                   ")" => {
                                                                            ""  => [0xDD, 0xCB, "DIS", 0xF6],
                                                                            "," => {
                                                                                     a => { "" => [0xDD, 0xCB, "DIS", 0xF7] },
                                                                                     b => { "" => [0xDD, 0xCB, "DIS", 0xF0] },
                                                                                     c => { "" => [0xDD, 0xCB, "DIS", 0xF1] },
                                                                                     d => { "" => [0xDD, 0xCB, "DIS", 0xF2] },
                                                                                     e => { "" => [0xDD, 0xCB, "DIS", 0xF3] },
                                                                                     h => { "" => [0xDD, 0xCB, "DIS", 0xF4] },
                                                                                     l => { "" => [0xDD, 0xCB, "DIS", 0xF5] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            ")" => {
                                                                     ""  => [0xDD, 0xCB, "NDIS", 0xF6],
                                                                     "," => {
                                                                              a => { "" => [0xDD, 0xCB, "NDIS", 0xF7] },
                                                                              b => { "" => [0xDD, 0xCB, "NDIS", 0xF0] },
                                                                              c => { "" => [0xDD, 0xCB, "NDIS", 0xF1] },
                                                                              d => { "" => [0xDD, 0xCB, "NDIS", 0xF2] },
                                                                              e => { "" => [0xDD, 0xCB, "NDIS", 0xF3] },
                                                                              h => { "" => [0xDD, 0xCB, "NDIS", 0xF4] },
                                                                              l => { "" => [0xDD, 0xCB, "NDIS", 0xF5] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                               },
                                         iy => {
                                                 ")" => {
                                                          ""  => [0xFD, 0xCB, 0x00, 0xF6],
                                                          "," => {
                                                                   a => { "" => [0xFD, 0xCB, 0x00, 0xF7] },
                                                                   b => { "" => [0xFD, 0xCB, 0x00, 0xF0] },
                                                                   c => { "" => [0xFD, 0xCB, 0x00, 0xF1] },
                                                                   d => { "" => [0xFD, 0xCB, 0x00, 0xF2] },
                                                                   e => { "" => [0xFD, 0xCB, 0x00, 0xF3] },
                                                                   h => { "" => [0xFD, 0xCB, 0x00, 0xF4] },
                                                                   l => { "" => [0xFD, 0xCB, 0x00, 0xF5] },
                                                                 },
                                                        },
                                                 "+" => {
                                                          DIS => {
                                                                   ")" => {
                                                                            ""  => [0xFD, 0xCB, "DIS", 0xF6],
                                                                            "," => {
                                                                                     a => { "" => [0xFD, 0xCB, "DIS", 0xF7] },
                                                                                     b => { "" => [0xFD, 0xCB, "DIS", 0xF0] },
                                                                                     c => { "" => [0xFD, 0xCB, "DIS", 0xF1] },
                                                                                     d => { "" => [0xFD, 0xCB, "DIS", 0xF2] },
                                                                                     e => { "" => [0xFD, 0xCB, "DIS", 0xF3] },
                                                                                     h => { "" => [0xFD, 0xCB, "DIS", 0xF4] },
                                                                                     l => { "" => [0xFD, 0xCB, "DIS", 0xF5] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            ")" => {
                                                                     ""  => [0xFD, 0xCB, "NDIS", 0xF6],
                                                                     "," => {
                                                                              a => { "" => [0xFD, 0xCB, "NDIS", 0xF7] },
                                                                              b => { "" => [0xFD, 0xCB, "NDIS", 0xF0] },
                                                                              c => { "" => [0xFD, 0xCB, "NDIS", 0xF1] },
                                                                              d => { "" => [0xFD, 0xCB, "NDIS", 0xF2] },
                                                                              e => { "" => [0xFD, 0xCB, "NDIS", 0xF3] },
                                                                              h => { "" => [0xFD, 0xCB, "NDIS", 0xF4] },
                                                                              l => { "" => [0xFD, 0xCB, "NDIS", 0xF5] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                               },
                                       },
                                "[" => {
                                         hl => { "]" => { "" => [0xCB, 0xF6] } },
                                         ix => {
                                                 "+" => {
                                                          DIS => {
                                                                   "]" => {
                                                                            ""  => [0xDD, 0xCB, "DIS", 0xF6],
                                                                            "," => {
                                                                                     a => { "" => [0xDD, 0xCB, "DIS", 0xF7] },
                                                                                     b => { "" => [0xDD, 0xCB, "DIS", 0xF0] },
                                                                                     c => { "" => [0xDD, 0xCB, "DIS", 0xF1] },
                                                                                     d => { "" => [0xDD, 0xCB, "DIS", 0xF2] },
                                                                                     e => { "" => [0xDD, 0xCB, "DIS", 0xF3] },
                                                                                     h => { "" => [0xDD, 0xCB, "DIS", 0xF4] },
                                                                                     l => { "" => [0xDD, 0xCB, "DIS", 0xF5] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            "]" => {
                                                                     ""  => [0xDD, 0xCB, "NDIS", 0xF6],
                                                                     "," => {
                                                                              a => { "" => [0xDD, 0xCB, "NDIS", 0xF7] },
                                                                              b => { "" => [0xDD, 0xCB, "NDIS", 0xF0] },
                                                                              c => { "" => [0xDD, 0xCB, "NDIS", 0xF1] },
                                                                              d => { "" => [0xDD, 0xCB, "NDIS", 0xF2] },
                                                                              e => { "" => [0xDD, 0xCB, "NDIS", 0xF3] },
                                                                              h => { "" => [0xDD, 0xCB, "NDIS", 0xF4] },
                                                                              l => { "" => [0xDD, 0xCB, "NDIS", 0xF5] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                                 "]" => {
                                                          ""  => [0xDD, 0xCB, 0x00, 0xF6],
                                                          "," => {
                                                                   a => { "" => [0xDD, 0xCB, 0x00, 0xF7] },
                                                                   b => { "" => [0xDD, 0xCB, 0x00, 0xF0] },
                                                                   c => { "" => [0xDD, 0xCB, 0x00, 0xF1] },
                                                                   d => { "" => [0xDD, 0xCB, 0x00, 0xF2] },
                                                                   e => { "" => [0xDD, 0xCB, 0x00, 0xF3] },
                                                                   h => { "" => [0xDD, 0xCB, 0x00, 0xF4] },
                                                                   l => { "" => [0xDD, 0xCB, 0x00, 0xF5] },
                                                                 },
                                                        },
                                               },
                                         iy => {
                                                 "+" => {
                                                          DIS => {
                                                                   "]" => {
                                                                            ""  => [0xFD, 0xCB, "DIS", 0xF6],
                                                                            "," => {
                                                                                     a => { "" => [0xFD, 0xCB, "DIS", 0xF7] },
                                                                                     b => { "" => [0xFD, 0xCB, "DIS", 0xF0] },
                                                                                     c => { "" => [0xFD, 0xCB, "DIS", 0xF1] },
                                                                                     d => { "" => [0xFD, 0xCB, "DIS", 0xF2] },
                                                                                     e => { "" => [0xFD, 0xCB, "DIS", 0xF3] },
                                                                                     h => { "" => [0xFD, 0xCB, "DIS", 0xF4] },
                                                                                     l => { "" => [0xFD, 0xCB, "DIS", 0xF5] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            "]" => {
                                                                     ""  => [0xFD, 0xCB, "NDIS", 0xF6],
                                                                     "," => {
                                                                              a => { "" => [0xFD, 0xCB, "NDIS", 0xF7] },
                                                                              b => { "" => [0xFD, 0xCB, "NDIS", 0xF0] },
                                                                              c => { "" => [0xFD, 0xCB, "NDIS", 0xF1] },
                                                                              d => { "" => [0xFD, 0xCB, "NDIS", 0xF2] },
                                                                              e => { "" => [0xFD, 0xCB, "NDIS", 0xF3] },
                                                                              h => { "" => [0xFD, 0xCB, "NDIS", 0xF4] },
                                                                              l => { "" => [0xFD, 0xCB, "NDIS", 0xF5] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                                 "]" => {
                                                          ""  => [0xFD, 0xCB, 0x00, 0xF6],
                                                          "," => {
                                                                   a => { "" => [0xFD, 0xCB, 0x00, 0xF7] },
                                                                   b => { "" => [0xFD, 0xCB, 0x00, 0xF0] },
                                                                   c => { "" => [0xFD, 0xCB, 0x00, 0xF1] },
                                                                   d => { "" => [0xFD, 0xCB, 0x00, 0xF2] },
                                                                   e => { "" => [0xFD, 0xCB, 0x00, 0xF3] },
                                                                   h => { "" => [0xFD, 0xCB, 0x00, 0xF4] },
                                                                   l => { "" => [0xFD, 0xCB, 0x00, 0xF5] },
                                                                 },
                                                        },
                                               },
                                       },
                                "a" => { "" => [0xCB, 0xF7] },
                                "b" => { "" => [0xCB, 0xF0] },
                                "c" => { "" => [0xCB, 0xF1] },
                                "d" => { "" => [0xCB, 0xF2] },
                                "e" => { "" => [0xCB, 0xF3] },
                                "h" => { "" => [0xCB, 0xF4] },
                                "l" => { "" => [0xCB, 0xF5] },
                              },
                     },
              0x07 => {
                       "," => {
                                "(" => {
                                         hl => { ")" => { "" => [0xCB, 0xFE] } },
                                         ix => {
                                                 ")" => {
                                                          ""  => [0xDD, 0xCB, 0x00, 0xFE],
                                                          "," => {
                                                                   a => { "" => [0xDD, 0xCB, 0x00, 0xFF] },
                                                                   b => { "" => [0xDD, 0xCB, 0x00, 0xF8] },
                                                                   c => { "" => [0xDD, 0xCB, 0x00, 0xF9] },
                                                                   d => { "" => [0xDD, 0xCB, 0x00, 0xFA] },
                                                                   e => { "" => [0xDD, 0xCB, 0x00, 0xFB] },
                                                                   h => { "" => [0xDD, 0xCB, 0x00, 0xFC] },
                                                                   l => { "" => [0xDD, 0xCB, 0x00, 0xFD] },
                                                                 },
                                                        },
                                                 "+" => {
                                                          DIS => {
                                                                   ")" => {
                                                                            ""  => [0xDD, 0xCB, "DIS", 0xFE],
                                                                            "," => {
                                                                                     a => { "" => [0xDD, 0xCB, "DIS", 0xFF] },
                                                                                     b => { "" => [0xDD, 0xCB, "DIS", 0xF8] },
                                                                                     c => { "" => [0xDD, 0xCB, "DIS", 0xF9] },
                                                                                     d => { "" => [0xDD, 0xCB, "DIS", 0xFA] },
                                                                                     e => { "" => [0xDD, 0xCB, "DIS", 0xFB] },
                                                                                     h => { "" => [0xDD, 0xCB, "DIS", 0xFC] },
                                                                                     l => { "" => [0xDD, 0xCB, "DIS", 0xFD] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            ")" => {
                                                                     ""  => [0xDD, 0xCB, "NDIS", 0xFE],
                                                                     "," => {
                                                                              a => { "" => [0xDD, 0xCB, "NDIS", 0xFF] },
                                                                              b => { "" => [0xDD, 0xCB, "NDIS", 0xF8] },
                                                                              c => { "" => [0xDD, 0xCB, "NDIS", 0xF9] },
                                                                              d => { "" => [0xDD, 0xCB, "NDIS", 0xFA] },
                                                                              e => { "" => [0xDD, 0xCB, "NDIS", 0xFB] },
                                                                              h => { "" => [0xDD, 0xCB, "NDIS", 0xFC] },
                                                                              l => { "" => [0xDD, 0xCB, "NDIS", 0xFD] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                               },
                                         iy => {
                                                 ")" => {
                                                          ""  => [0xFD, 0xCB, 0x00, 0xFE],
                                                          "," => {
                                                                   a => { "" => [0xFD, 0xCB, 0x00, 0xFF] },
                                                                   b => { "" => [0xFD, 0xCB, 0x00, 0xF8] },
                                                                   c => { "" => [0xFD, 0xCB, 0x00, 0xF9] },
                                                                   d => { "" => [0xFD, 0xCB, 0x00, 0xFA] },
                                                                   e => { "" => [0xFD, 0xCB, 0x00, 0xFB] },
                                                                   h => { "" => [0xFD, 0xCB, 0x00, 0xFC] },
                                                                   l => { "" => [0xFD, 0xCB, 0x00, 0xFD] },
                                                                 },
                                                        },
                                                 "+" => {
                                                          DIS => {
                                                                   ")" => {
                                                                            ""  => [0xFD, 0xCB, "DIS", 0xFE],
                                                                            "," => {
                                                                                     a => { "" => [0xFD, 0xCB, "DIS", 0xFF] },
                                                                                     b => { "" => [0xFD, 0xCB, "DIS", 0xF8] },
                                                                                     c => { "" => [0xFD, 0xCB, "DIS", 0xF9] },
                                                                                     d => { "" => [0xFD, 0xCB, "DIS", 0xFA] },
                                                                                     e => { "" => [0xFD, 0xCB, "DIS", 0xFB] },
                                                                                     h => { "" => [0xFD, 0xCB, "DIS", 0xFC] },
                                                                                     l => { "" => [0xFD, 0xCB, "DIS", 0xFD] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            ")" => {
                                                                     ""  => [0xFD, 0xCB, "NDIS", 0xFE],
                                                                     "," => {
                                                                              a => { "" => [0xFD, 0xCB, "NDIS", 0xFF] },
                                                                              b => { "" => [0xFD, 0xCB, "NDIS", 0xF8] },
                                                                              c => { "" => [0xFD, 0xCB, "NDIS", 0xF9] },
                                                                              d => { "" => [0xFD, 0xCB, "NDIS", 0xFA] },
                                                                              e => { "" => [0xFD, 0xCB, "NDIS", 0xFB] },
                                                                              h => { "" => [0xFD, 0xCB, "NDIS", 0xFC] },
                                                                              l => { "" => [0xFD, 0xCB, "NDIS", 0xFD] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                               },
                                       },
                                "[" => {
                                         hl => { "]" => { "" => [0xCB, 0xFE] } },
                                         ix => {
                                                 "+" => {
                                                          DIS => {
                                                                   "]" => {
                                                                            ""  => [0xDD, 0xCB, "DIS", 0xFE],
                                                                            "," => {
                                                                                     a => { "" => [0xDD, 0xCB, "DIS", 0xFF] },
                                                                                     b => { "" => [0xDD, 0xCB, "DIS", 0xF8] },
                                                                                     c => { "" => [0xDD, 0xCB, "DIS", 0xF9] },
                                                                                     d => { "" => [0xDD, 0xCB, "DIS", 0xFA] },
                                                                                     e => { "" => [0xDD, 0xCB, "DIS", 0xFB] },
                                                                                     h => { "" => [0xDD, 0xCB, "DIS", 0xFC] },
                                                                                     l => { "" => [0xDD, 0xCB, "DIS", 0xFD] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            "]" => {
                                                                     ""  => [0xDD, 0xCB, "NDIS", 0xFE],
                                                                     "," => {
                                                                              a => { "" => [0xDD, 0xCB, "NDIS", 0xFF] },
                                                                              b => { "" => [0xDD, 0xCB, "NDIS", 0xF8] },
                                                                              c => { "" => [0xDD, 0xCB, "NDIS", 0xF9] },
                                                                              d => { "" => [0xDD, 0xCB, "NDIS", 0xFA] },
                                                                              e => { "" => [0xDD, 0xCB, "NDIS", 0xFB] },
                                                                              h => { "" => [0xDD, 0xCB, "NDIS", 0xFC] },
                                                                              l => { "" => [0xDD, 0xCB, "NDIS", 0xFD] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                                 "]" => {
                                                          ""  => [0xDD, 0xCB, 0x00, 0xFE],
                                                          "," => {
                                                                   a => { "" => [0xDD, 0xCB, 0x00, 0xFF] },
                                                                   b => { "" => [0xDD, 0xCB, 0x00, 0xF8] },
                                                                   c => { "" => [0xDD, 0xCB, 0x00, 0xF9] },
                                                                   d => { "" => [0xDD, 0xCB, 0x00, 0xFA] },
                                                                   e => { "" => [0xDD, 0xCB, 0x00, 0xFB] },
                                                                   h => { "" => [0xDD, 0xCB, 0x00, 0xFC] },
                                                                   l => { "" => [0xDD, 0xCB, 0x00, 0xFD] },
                                                                 },
                                                        },
                                               },
                                         iy => {
                                                 "+" => {
                                                          DIS => {
                                                                   "]" => {
                                                                            ""  => [0xFD, 0xCB, "DIS", 0xFE],
                                                                            "," => {
                                                                                     a => { "" => [0xFD, 0xCB, "DIS", 0xFF] },
                                                                                     b => { "" => [0xFD, 0xCB, "DIS", 0xF8] },
                                                                                     c => { "" => [0xFD, 0xCB, "DIS", 0xF9] },
                                                                                     d => { "" => [0xFD, 0xCB, "DIS", 0xFA] },
                                                                                     e => { "" => [0xFD, 0xCB, "DIS", 0xFB] },
                                                                                     h => { "" => [0xFD, 0xCB, "DIS", 0xFC] },
                                                                                     l => { "" => [0xFD, 0xCB, "DIS", 0xFD] },
                                                                                   },
                                                                          },
                                                                 },
                                                        },
                                                 "-" => {
                                                          NDIS => {
                                                            "]" => {
                                                                     ""  => [0xFD, 0xCB, "NDIS", 0xFE],
                                                                     "," => {
                                                                              a => { "" => [0xFD, 0xCB, "NDIS", 0xFF] },
                                                                              b => { "" => [0xFD, 0xCB, "NDIS", 0xF8] },
                                                                              c => { "" => [0xFD, 0xCB, "NDIS", 0xF9] },
                                                                              d => { "" => [0xFD, 0xCB, "NDIS", 0xFA] },
                                                                              e => { "" => [0xFD, 0xCB, "NDIS", 0xFB] },
                                                                              h => { "" => [0xFD, 0xCB, "NDIS", 0xFC] },
                                                                              l => { "" => [0xFD, 0xCB, "NDIS", 0xFD] },
                                                                            },
                                                                   },
                                                          },
                                                        },
                                                 "]" => {
                                                          ""  => [0xFD, 0xCB, 0x00, 0xFE],
                                                          "," => {
                                                                   a => { "" => [0xFD, 0xCB, 0x00, 0xFF] },
                                                                   b => { "" => [0xFD, 0xCB, 0x00, 0xF8] },
                                                                   c => { "" => [0xFD, 0xCB, 0x00, 0xF9] },
                                                                   d => { "" => [0xFD, 0xCB, 0x00, 0xFA] },
                                                                   e => { "" => [0xFD, 0xCB, 0x00, 0xFB] },
                                                                   h => { "" => [0xFD, 0xCB, 0x00, 0xFC] },
                                                                   l => { "" => [0xFD, 0xCB, 0x00, 0xFD] },
                                                                 },
                                                        },
                                               },
                                       },
                                "a" => { "" => [0xCB, 0xFF] },
                                "b" => { "" => [0xCB, 0xF8] },
                                "c" => { "" => [0xCB, 0xF9] },
                                "d" => { "" => [0xCB, 0xFA] },
                                "e" => { "" => [0xCB, 0xFB] },
                                "h" => { "" => [0xCB, 0xFC] },
                                "l" => { "" => [0xCB, 0xFD] },
                              },
                     },
            },
    sla  => {
              "("  => {
                        hl => { ")" => { "" => [0xCB, 0x26] } },
                        ix => {
                                ")" => {
                                         ""  => [0xDD, 0xCB, 0x00, 0x26],
                                         "," => {
                                                  a => { "" => [0xDD, 0xCB, 0x00, 0x27] },
                                                  b => { "" => [0xDD, 0xCB, 0x00, 0x20] },
                                                  c => { "" => [0xDD, 0xCB, 0x00, 0x21] },
                                                  d => { "" => [0xDD, 0xCB, 0x00, 0x22] },
                                                  e => { "" => [0xDD, 0xCB, 0x00, 0x23] },
                                                  h => { "" => [0xDD, 0xCB, 0x00, 0x24] },
                                                  l => { "" => [0xDD, 0xCB, 0x00, 0x25] },
                                                },
                                       },
                                "+" => {
                                         DIS => {
                                                  ")" => {
                                                           ""  => [0xDD, 0xCB, "DIS", 0x26],
                                                           "," => {
                                                                    a => { "" => [0xDD, 0xCB, "DIS", 0x27] },
                                                                    b => { "" => [0xDD, 0xCB, "DIS", 0x20] },
                                                                    c => { "" => [0xDD, 0xCB, "DIS", 0x21] },
                                                                    d => { "" => [0xDD, 0xCB, "DIS", 0x22] },
                                                                    e => { "" => [0xDD, 0xCB, "DIS", 0x23] },
                                                                    h => { "" => [0xDD, 0xCB, "DIS", 0x24] },
                                                                    l => { "" => [0xDD, 0xCB, "DIS", 0x25] },
                                                                  },
                                                         },
                                                },
                                       },
                                "-" => {
                                         NDIS => {
                                           ")" => {
                                                    ""  => [0xDD, 0xCB, "NDIS", 0x26],
                                                    "," => {
                                                             a => { "" => [0xDD, 0xCB, "NDIS", 0x27] },
                                                             b => { "" => [0xDD, 0xCB, "NDIS", 0x20] },
                                                             c => { "" => [0xDD, 0xCB, "NDIS", 0x21] },
                                                             d => { "" => [0xDD, 0xCB, "NDIS", 0x22] },
                                                             e => { "" => [0xDD, 0xCB, "NDIS", 0x23] },
                                                             h => { "" => [0xDD, 0xCB, "NDIS", 0x24] },
                                                             l => { "" => [0xDD, 0xCB, "NDIS", 0x25] },
                                                           },
                                                  },
                                         },
                                       },
                              },
                        iy => {
                                ")" => {
                                         ""  => [0xFD, 0xCB, 0x00, 0x26],
                                         "," => {
                                                  a => { "" => [0xFD, 0xCB, 0x00, 0x27] },
                                                  b => { "" => [0xFD, 0xCB, 0x00, 0x20] },
                                                  c => { "" => [0xFD, 0xCB, 0x00, 0x21] },
                                                  d => { "" => [0xFD, 0xCB, 0x00, 0x22] },
                                                  e => { "" => [0xFD, 0xCB, 0x00, 0x23] },
                                                  h => { "" => [0xFD, 0xCB, 0x00, 0x24] },
                                                  l => { "" => [0xFD, 0xCB, 0x00, 0x25] },
                                                },
                                       },
                                "+" => {
                                         DIS => {
                                                  ")" => {
                                                           ""  => [0xFD, 0xCB, "DIS", 0x26],
                                                           "," => {
                                                                    a => { "" => [0xFD, 0xCB, "DIS", 0x27] },
                                                                    b => { "" => [0xFD, 0xCB, "DIS", 0x20] },
                                                                    c => { "" => [0xFD, 0xCB, "DIS", 0x21] },
                                                                    d => { "" => [0xFD, 0xCB, "DIS", 0x22] },
                                                                    e => { "" => [0xFD, 0xCB, "DIS", 0x23] },
                                                                    h => { "" => [0xFD, 0xCB, "DIS", 0x24] },
                                                                    l => { "" => [0xFD, 0xCB, "DIS", 0x25] },
                                                                  },
                                                         },
                                                },
                                       },
                                "-" => {
                                         NDIS => {
                                           ")" => {
                                                    ""  => [0xFD, 0xCB, "NDIS", 0x26],
                                                    "," => {
                                                             a => { "" => [0xFD, 0xCB, "NDIS", 0x27] },
                                                             b => { "" => [0xFD, 0xCB, "NDIS", 0x20] },
                                                             c => { "" => [0xFD, 0xCB, "NDIS", 0x21] },
                                                             d => { "" => [0xFD, 0xCB, "NDIS", 0x22] },
                                                             e => { "" => [0xFD, 0xCB, "NDIS", 0x23] },
                                                             h => { "" => [0xFD, 0xCB, "NDIS", 0x24] },
                                                             l => { "" => [0xFD, 0xCB, "NDIS", 0x25] },
                                                           },
                                                  },
                                         },
                                       },
                              },
                      },
              "["  => {
                        hl => { "]" => { "" => [0xCB, 0x26] } },
                        ix => {
                                "+" => {
                                         DIS => {
                                                  "]" => {
                                                           ""  => [0xDD, 0xCB, "DIS", 0x26],
                                                           "," => {
                                                                    a => { "" => [0xDD, 0xCB, "DIS", 0x27] },
                                                                    b => { "" => [0xDD, 0xCB, "DIS", 0x20] },
                                                                    c => { "" => [0xDD, 0xCB, "DIS", 0x21] },
                                                                    d => { "" => [0xDD, 0xCB, "DIS", 0x22] },
                                                                    e => { "" => [0xDD, 0xCB, "DIS", 0x23] },
                                                                    h => { "" => [0xDD, 0xCB, "DIS", 0x24] },
                                                                    l => { "" => [0xDD, 0xCB, "DIS", 0x25] },
                                                                  },
                                                         },
                                                },
                                       },
                                "-" => {
                                         NDIS => {
                                           "]" => {
                                                    ""  => [0xDD, 0xCB, "NDIS", 0x26],
                                                    "," => {
                                                             a => { "" => [0xDD, 0xCB, "NDIS", 0x27] },
                                                             b => { "" => [0xDD, 0xCB, "NDIS", 0x20] },
                                                             c => { "" => [0xDD, 0xCB, "NDIS", 0x21] },
                                                             d => { "" => [0xDD, 0xCB, "NDIS", 0x22] },
                                                             e => { "" => [0xDD, 0xCB, "NDIS", 0x23] },
                                                             h => { "" => [0xDD, 0xCB, "NDIS", 0x24] },
                                                             l => { "" => [0xDD, 0xCB, "NDIS", 0x25] },
                                                           },
                                                  },
                                         },
                                       },
                                "]" => {
                                         ""  => [0xDD, 0xCB, 0x00, 0x26],
                                         "," => {
                                                  a => { "" => [0xDD, 0xCB, 0x00, 0x27] },
                                                  b => { "" => [0xDD, 0xCB, 0x00, 0x20] },
                                                  c => { "" => [0xDD, 0xCB, 0x00, 0x21] },
                                                  d => { "" => [0xDD, 0xCB, 0x00, 0x22] },
                                                  e => { "" => [0xDD, 0xCB, 0x00, 0x23] },
                                                  h => { "" => [0xDD, 0xCB, 0x00, 0x24] },
                                                  l => { "" => [0xDD, 0xCB, 0x00, 0x25] },
                                                },
                                       },
                              },
                        iy => {
                                "+" => {
                                         DIS => {
                                                  "]" => {
                                                           ""  => [0xFD, 0xCB, "DIS", 0x26],
                                                           "," => {
                                                                    a => { "" => [0xFD, 0xCB, "DIS", 0x27] },
                                                                    b => { "" => [0xFD, 0xCB, "DIS", 0x20] },
                                                                    c => { "" => [0xFD, 0xCB, "DIS", 0x21] },
                                                                    d => { "" => [0xFD, 0xCB, "DIS", 0x22] },
                                                                    e => { "" => [0xFD, 0xCB, "DIS", 0x23] },
                                                                    h => { "" => [0xFD, 0xCB, "DIS", 0x24] },
                                                                    l => { "" => [0xFD, 0xCB, "DIS", 0x25] },
                                                                  },
                                                         },
                                                },
                                       },
                                "-" => {
                                         NDIS => {
                                           "]" => {
                                                    ""  => [0xFD, 0xCB, "NDIS", 0x26],
                                                    "," => {
                                                             a => { "" => [0xFD, 0xCB, "NDIS", 0x27] },
                                                             b => { "" => [0xFD, 0xCB, "NDIS", 0x20] },
                                                             c => { "" => [0xFD, 0xCB, "NDIS", 0x21] },
                                                             d => { "" => [0xFD, 0xCB, "NDIS", 0x22] },
                                                             e => { "" => [0xFD, 0xCB, "NDIS", 0x23] },
                                                             h => { "" => [0xFD, 0xCB, "NDIS", 0x24] },
                                                             l => { "" => [0xFD, 0xCB, "NDIS", 0x25] },
                                                           },
                                                  },
                                         },
                                       },
                                "]" => {
                                         ""  => [0xFD, 0xCB, 0x00, 0x26],
                                         "," => {
                                                  a => { "" => [0xFD, 0xCB, 0x00, 0x27] },
                                                  b => { "" => [0xFD, 0xCB, 0x00, 0x20] },
                                                  c => { "" => [0xFD, 0xCB, 0x00, 0x21] },
                                                  d => { "" => [0xFD, 0xCB, 0x00, 0x22] },
                                                  e => { "" => [0xFD, 0xCB, 0x00, 0x23] },
                                                  h => { "" => [0xFD, 0xCB, 0x00, 0x24] },
                                                  l => { "" => [0xFD, 0xCB, 0x00, 0x25] },
                                                },
                                       },
                              },
                      },
              "a"  => { "" => [0xCB, 0x27] },
              "b"  => { "" => [0xCB, 0x20] },
              "bc" => { "" => [0xCB, 0x21, 0xCB, 0x10] },
              "c"  => { "" => [0xCB, 0x21] },
              "d"  => { "" => [0xCB, 0x22] },
              "de" => { "" => [0xCB, 0x23, 0xCB, 0x12] },
              "e"  => { "" => [0xCB, 0x23] },
              "h"  => { "" => [0xCB, 0x24] },
              "hl" => { "" => [0x29] },
              "l"  => { "" => [0xCB, 0x25] },
            },
    sli  => {
              "("  => {
                        hl => { ")" => { "" => [0xCB, 0x36] } },
                        ix => {
                                ")" => {
                                         ""  => [0xDD, 0xCB, 0x00, 0x36],
                                         "," => {
                                                  a => { "" => [0xDD, 0xCB, 0x00, 0x37] },
                                                  b => { "" => [0xDD, 0xCB, 0x00, 0x30] },
                                                  c => { "" => [0xDD, 0xCB, 0x00, 0x31] },
                                                  d => { "" => [0xDD, 0xCB, 0x00, 0x32] },
                                                  e => { "" => [0xDD, 0xCB, 0x00, 0x33] },
                                                  h => { "" => [0xDD, 0xCB, 0x00, 0x34] },
                                                  l => { "" => [0xDD, 0xCB, 0x00, 0x35] },
                                                },
                                       },
                                "+" => {
                                         DIS => {
                                                  ")" => {
                                                           ""  => [0xDD, 0xCB, "DIS", 0x36],
                                                           "," => {
                                                                    a => { "" => [0xDD, 0xCB, "DIS", 0x37] },
                                                                    b => { "" => [0xDD, 0xCB, "DIS", 0x30] },
                                                                    c => { "" => [0xDD, 0xCB, "DIS", 0x31] },
                                                                    d => { "" => [0xDD, 0xCB, "DIS", 0x32] },
                                                                    e => { "" => [0xDD, 0xCB, "DIS", 0x33] },
                                                                    h => { "" => [0xDD, 0xCB, "DIS", 0x34] },
                                                                    l => { "" => [0xDD, 0xCB, "DIS", 0x35] },
                                                                  },
                                                         },
                                                },
                                       },
                                "-" => {
                                         NDIS => {
                                           ")" => {
                                                    ""  => [0xDD, 0xCB, "NDIS", 0x36],
                                                    "," => {
                                                             a => { "" => [0xDD, 0xCB, "NDIS", 0x37] },
                                                             b => { "" => [0xDD, 0xCB, "NDIS", 0x30] },
                                                             c => { "" => [0xDD, 0xCB, "NDIS", 0x31] },
                                                             d => { "" => [0xDD, 0xCB, "NDIS", 0x32] },
                                                             e => { "" => [0xDD, 0xCB, "NDIS", 0x33] },
                                                             h => { "" => [0xDD, 0xCB, "NDIS", 0x34] },
                                                             l => { "" => [0xDD, 0xCB, "NDIS", 0x35] },
                                                           },
                                                  },
                                         },
                                       },
                              },
                        iy => {
                                ")" => {
                                         ""  => [0xFD, 0xCB, 0x00, 0x36],
                                         "," => {
                                                  a => { "" => [0xFD, 0xCB, 0x00, 0x37] },
                                                  b => { "" => [0xFD, 0xCB, 0x00, 0x30] },
                                                  c => { "" => [0xFD, 0xCB, 0x00, 0x31] },
                                                  d => { "" => [0xFD, 0xCB, 0x00, 0x32] },
                                                  e => { "" => [0xFD, 0xCB, 0x00, 0x33] },
                                                  h => { "" => [0xFD, 0xCB, 0x00, 0x34] },
                                                  l => { "" => [0xFD, 0xCB, 0x00, 0x35] },
                                                },
                                       },
                                "+" => {
                                         DIS => {
                                                  ")" => {
                                                           ""  => [0xFD, 0xCB, "DIS", 0x36],
                                                           "," => {
                                                                    a => { "" => [0xFD, 0xCB, "DIS", 0x37] },
                                                                    b => { "" => [0xFD, 0xCB, "DIS", 0x30] },
                                                                    c => { "" => [0xFD, 0xCB, "DIS", 0x31] },
                                                                    d => { "" => [0xFD, 0xCB, "DIS", 0x32] },
                                                                    e => { "" => [0xFD, 0xCB, "DIS", 0x33] },
                                                                    h => { "" => [0xFD, 0xCB, "DIS", 0x34] },
                                                                    l => { "" => [0xFD, 0xCB, "DIS", 0x35] },
                                                                  },
                                                         },
                                                },
                                       },
                                "-" => {
                                         NDIS => {
                                           ")" => {
                                                    ""  => [0xFD, 0xCB, "NDIS", 0x36],
                                                    "," => {
                                                             a => { "" => [0xFD, 0xCB, "NDIS", 0x37] },
                                                             b => { "" => [0xFD, 0xCB, "NDIS", 0x30] },
                                                             c => { "" => [0xFD, 0xCB, "NDIS", 0x31] },
                                                             d => { "" => [0xFD, 0xCB, "NDIS", 0x32] },
                                                             e => { "" => [0xFD, 0xCB, "NDIS", 0x33] },
                                                             h => { "" => [0xFD, 0xCB, "NDIS", 0x34] },
                                                             l => { "" => [0xFD, 0xCB, "NDIS", 0x35] },
                                                           },
                                                  },
                                         },
                                       },
                              },
                      },
              "["  => {
                        hl => { "]" => { "" => [0xCB, 0x36] } },
                        ix => {
                                "+" => {
                                         DIS => {
                                                  "]" => {
                                                           ""  => [0xDD, 0xCB, "DIS", 0x36],
                                                           "," => {
                                                                    a => { "" => [0xDD, 0xCB, "DIS", 0x37] },
                                                                    b => { "" => [0xDD, 0xCB, "DIS", 0x30] },
                                                                    c => { "" => [0xDD, 0xCB, "DIS", 0x31] },
                                                                    d => { "" => [0xDD, 0xCB, "DIS", 0x32] },
                                                                    e => { "" => [0xDD, 0xCB, "DIS", 0x33] },
                                                                    h => { "" => [0xDD, 0xCB, "DIS", 0x34] },
                                                                    l => { "" => [0xDD, 0xCB, "DIS", 0x35] },
                                                                  },
                                                         },
                                                },
                                       },
                                "-" => {
                                         NDIS => {
                                           "]" => {
                                                    ""  => [0xDD, 0xCB, "NDIS", 0x36],
                                                    "," => {
                                                             a => { "" => [0xDD, 0xCB, "NDIS", 0x37] },
                                                             b => { "" => [0xDD, 0xCB, "NDIS", 0x30] },
                                                             c => { "" => [0xDD, 0xCB, "NDIS", 0x31] },
                                                             d => { "" => [0xDD, 0xCB, "NDIS", 0x32] },
                                                             e => { "" => [0xDD, 0xCB, "NDIS", 0x33] },
                                                             h => { "" => [0xDD, 0xCB, "NDIS", 0x34] },
                                                             l => { "" => [0xDD, 0xCB, "NDIS", 0x35] },
                                                           },
                                                  },
                                         },
                                       },
                                "]" => {
                                         ""  => [0xDD, 0xCB, 0x00, 0x36],
                                         "," => {
                                                  a => { "" => [0xDD, 0xCB, 0x00, 0x37] },
                                                  b => { "" => [0xDD, 0xCB, 0x00, 0x30] },
                                                  c => { "" => [0xDD, 0xCB, 0x00, 0x31] },
                                                  d => { "" => [0xDD, 0xCB, 0x00, 0x32] },
                                                  e => { "" => [0xDD, 0xCB, 0x00, 0x33] },
                                                  h => { "" => [0xDD, 0xCB, 0x00, 0x34] },
                                                  l => { "" => [0xDD, 0xCB, 0x00, 0x35] },
                                                },
                                       },
                              },
                        iy => {
                                "+" => {
                                         DIS => {
                                                  "]" => {
                                                           ""  => [0xFD, 0xCB, "DIS", 0x36],
                                                           "," => {
                                                                    a => { "" => [0xFD, 0xCB, "DIS", 0x37] },
                                                                    b => { "" => [0xFD, 0xCB, "DIS", 0x30] },
                                                                    c => { "" => [0xFD, 0xCB, "DIS", 0x31] },
                                                                    d => { "" => [0xFD, 0xCB, "DIS", 0x32] },
                                                                    e => { "" => [0xFD, 0xCB, "DIS", 0x33] },
                                                                    h => { "" => [0xFD, 0xCB, "DIS", 0x34] },
                                                                    l => { "" => [0xFD, 0xCB, "DIS", 0x35] },
                                                                  },
                                                         },
                                                },
                                       },
                                "-" => {
                                         NDIS => {
                                           "]" => {
                                                    ""  => [0xFD, 0xCB, "NDIS", 0x36],
                                                    "," => {
                                                             a => { "" => [0xFD, 0xCB, "NDIS", 0x37] },
                                                             b => { "" => [0xFD, 0xCB, "NDIS", 0x30] },
                                                             c => { "" => [0xFD, 0xCB, "NDIS", 0x31] },
                                                             d => { "" => [0xFD, 0xCB, "NDIS", 0x32] },
                                                             e => { "" => [0xFD, 0xCB, "NDIS", 0x33] },
                                                             h => { "" => [0xFD, 0xCB, "NDIS", 0x34] },
                                                             l => { "" => [0xFD, 0xCB, "NDIS", 0x35] },
                                                           },
                                                  },
                                         },
                                       },
                                "]" => {
                                         ""  => [0xFD, 0xCB, 0x00, 0x36],
                                         "," => {
                                                  a => { "" => [0xFD, 0xCB, 0x00, 0x37] },
                                                  b => { "" => [0xFD, 0xCB, 0x00, 0x30] },
                                                  c => { "" => [0xFD, 0xCB, 0x00, 0x31] },
                                                  d => { "" => [0xFD, 0xCB, 0x00, 0x32] },
                                                  e => { "" => [0xFD, 0xCB, 0x00, 0x33] },
                                                  h => { "" => [0xFD, 0xCB, 0x00, 0x34] },
                                                  l => { "" => [0xFD, 0xCB, 0x00, 0x35] },
                                                },
                                       },
                              },
                      },
              "a"  => { "" => [0xCB, 0x37] },
              "b"  => { "" => [0xCB, 0x30] },
              "bc" => { "" => [0xCB, 0x31, 0xCB, 0x10] },
              "c"  => { "" => [0xCB, 0x31] },
              "d"  => { "" => [0xCB, 0x32] },
              "de" => { "" => [0xCB, 0x33, 0xCB, 0x12] },
              "e"  => { "" => [0xCB, 0x33] },
              "h"  => { "" => [0xCB, 0x34] },
              "hl" => { "" => [0xCB, 0x35, 0xCB, 0x14] },
              "l"  => { "" => [0xCB, 0x35] },
            },
    sll  => {
              "("  => {
                        hl => { ")" => { "" => [0xCB, 0x36] } },
                        ix => {
                                ")" => {
                                         ""  => [0xDD, 0xCB, 0x00, 0x36],
                                         "," => {
                                                  a => { "" => [0xDD, 0xCB, 0x00, 0x37] },
                                                  b => { "" => [0xDD, 0xCB, 0x00, 0x30] },
                                                  c => { "" => [0xDD, 0xCB, 0x00, 0x31] },
                                                  d => { "" => [0xDD, 0xCB, 0x00, 0x32] },
                                                  e => { "" => [0xDD, 0xCB, 0x00, 0x33] },
                                                  h => { "" => [0xDD, 0xCB, 0x00, 0x34] },
                                                  l => { "" => [0xDD, 0xCB, 0x00, 0x35] },
                                                },
                                       },
                                "+" => {
                                         DIS => {
                                                  ")" => {
                                                           ""  => [0xDD, 0xCB, "DIS", 0x36],
                                                           "," => {
                                                                    a => { "" => [0xDD, 0xCB, "DIS", 0x37] },
                                                                    b => { "" => [0xDD, 0xCB, "DIS", 0x30] },
                                                                    c => { "" => [0xDD, 0xCB, "DIS", 0x31] },
                                                                    d => { "" => [0xDD, 0xCB, "DIS", 0x32] },
                                                                    e => { "" => [0xDD, 0xCB, "DIS", 0x33] },
                                                                    h => { "" => [0xDD, 0xCB, "DIS", 0x34] },
                                                                    l => { "" => [0xDD, 0xCB, "DIS", 0x35] },
                                                                  },
                                                         },
                                                },
                                       },
                                "-" => {
                                         NDIS => {
                                           ")" => {
                                                    ""  => [0xDD, 0xCB, "NDIS", 0x36],
                                                    "," => {
                                                             a => { "" => [0xDD, 0xCB, "NDIS", 0x37] },
                                                             b => { "" => [0xDD, 0xCB, "NDIS", 0x30] },
                                                             c => { "" => [0xDD, 0xCB, "NDIS", 0x31] },
                                                             d => { "" => [0xDD, 0xCB, "NDIS", 0x32] },
                                                             e => { "" => [0xDD, 0xCB, "NDIS", 0x33] },
                                                             h => { "" => [0xDD, 0xCB, "NDIS", 0x34] },
                                                             l => { "" => [0xDD, 0xCB, "NDIS", 0x35] },
                                                           },
                                                  },
                                         },
                                       },
                              },
                        iy => {
                                ")" => {
                                         ""  => [0xFD, 0xCB, 0x00, 0x36],
                                         "," => {
                                                  a => { "" => [0xFD, 0xCB, 0x00, 0x37] },
                                                  b => { "" => [0xFD, 0xCB, 0x00, 0x30] },
                                                  c => { "" => [0xFD, 0xCB, 0x00, 0x31] },
                                                  d => { "" => [0xFD, 0xCB, 0x00, 0x32] },
                                                  e => { "" => [0xFD, 0xCB, 0x00, 0x33] },
                                                  h => { "" => [0xFD, 0xCB, 0x00, 0x34] },
                                                  l => { "" => [0xFD, 0xCB, 0x00, 0x35] },
                                                },
                                       },
                                "+" => {
                                         DIS => {
                                                  ")" => {
                                                           ""  => [0xFD, 0xCB, "DIS", 0x36],
                                                           "," => {
                                                                    a => { "" => [0xFD, 0xCB, "DIS", 0x37] },
                                                                    b => { "" => [0xFD, 0xCB, "DIS", 0x30] },
                                                                    c => { "" => [0xFD, 0xCB, "DIS", 0x31] },
                                                                    d => { "" => [0xFD, 0xCB, "DIS", 0x32] },
                                                                    e => { "" => [0xFD, 0xCB, "DIS", 0x33] },
                                                                    h => { "" => [0xFD, 0xCB, "DIS", 0x34] },
                                                                    l => { "" => [0xFD, 0xCB, "DIS", 0x35] },
                                                                  },
                                                         },
                                                },
                                       },
                                "-" => {
                                         NDIS => {
                                           ")" => {
                                                    ""  => [0xFD, 0xCB, "NDIS", 0x36],
                                                    "," => {
                                                             a => { "" => [0xFD, 0xCB, "NDIS", 0x37] },
                                                             b => { "" => [0xFD, 0xCB, "NDIS", 0x30] },
                                                             c => { "" => [0xFD, 0xCB, "NDIS", 0x31] },
                                                             d => { "" => [0xFD, 0xCB, "NDIS", 0x32] },
                                                             e => { "" => [0xFD, 0xCB, "NDIS", 0x33] },
                                                             h => { "" => [0xFD, 0xCB, "NDIS", 0x34] },
                                                             l => { "" => [0xFD, 0xCB, "NDIS", 0x35] },
                                                           },
                                                  },
                                         },
                                       },
                              },
                      },
              "["  => {
                        hl => { "]" => { "" => [0xCB, 0x36] } },
                        ix => {
                                "+" => {
                                         DIS => {
                                                  "]" => {
                                                           ""  => [0xDD, 0xCB, "DIS", 0x36],
                                                           "," => {
                                                                    a => { "" => [0xDD, 0xCB, "DIS", 0x37] },
                                                                    b => { "" => [0xDD, 0xCB, "DIS", 0x30] },
                                                                    c => { "" => [0xDD, 0xCB, "DIS", 0x31] },
                                                                    d => { "" => [0xDD, 0xCB, "DIS", 0x32] },
                                                                    e => { "" => [0xDD, 0xCB, "DIS", 0x33] },
                                                                    h => { "" => [0xDD, 0xCB, "DIS", 0x34] },
                                                                    l => { "" => [0xDD, 0xCB, "DIS", 0x35] },
                                                                  },
                                                         },
                                                },
                                       },
                                "-" => {
                                         NDIS => {
                                           "]" => {
                                                    ""  => [0xDD, 0xCB, "NDIS", 0x36],
                                                    "," => {
                                                             a => { "" => [0xDD, 0xCB, "NDIS", 0x37] },
                                                             b => { "" => [0xDD, 0xCB, "NDIS", 0x30] },
                                                             c => { "" => [0xDD, 0xCB, "NDIS", 0x31] },
                                                             d => { "" => [0xDD, 0xCB, "NDIS", 0x32] },
                                                             e => { "" => [0xDD, 0xCB, "NDIS", 0x33] },
                                                             h => { "" => [0xDD, 0xCB, "NDIS", 0x34] },
                                                             l => { "" => [0xDD, 0xCB, "NDIS", 0x35] },
                                                           },
                                                  },
                                         },
                                       },
                                "]" => {
                                         ""  => [0xDD, 0xCB, 0x00, 0x36],
                                         "," => {
                                                  a => { "" => [0xDD, 0xCB, 0x00, 0x37] },
                                                  b => { "" => [0xDD, 0xCB, 0x00, 0x30] },
                                                  c => { "" => [0xDD, 0xCB, 0x00, 0x31] },
                                                  d => { "" => [0xDD, 0xCB, 0x00, 0x32] },
                                                  e => { "" => [0xDD, 0xCB, 0x00, 0x33] },
                                                  h => { "" => [0xDD, 0xCB, 0x00, 0x34] },
                                                  l => { "" => [0xDD, 0xCB, 0x00, 0x35] },
                                                },
                                       },
                              },
                        iy => {
                                "+" => {
                                         DIS => {
                                                  "]" => {
                                                           ""  => [0xFD, 0xCB, "DIS", 0x36],
                                                           "," => {
                                                                    a => { "" => [0xFD, 0xCB, "DIS", 0x37] },
                                                                    b => { "" => [0xFD, 0xCB, "DIS", 0x30] },
                                                                    c => { "" => [0xFD, 0xCB, "DIS", 0x31] },
                                                                    d => { "" => [0xFD, 0xCB, "DIS", 0x32] },
                                                                    e => { "" => [0xFD, 0xCB, "DIS", 0x33] },
                                                                    h => { "" => [0xFD, 0xCB, "DIS", 0x34] },
                                                                    l => { "" => [0xFD, 0xCB, "DIS", 0x35] },
                                                                  },
                                                         },
                                                },
                                       },
                                "-" => {
                                         NDIS => {
                                           "]" => {
                                                    ""  => [0xFD, 0xCB, "NDIS", 0x36],
                                                    "," => {
                                                             a => { "" => [0xFD, 0xCB, "NDIS", 0x37] },
                                                             b => { "" => [0xFD, 0xCB, "NDIS", 0x30] },
                                                             c => { "" => [0xFD, 0xCB, "NDIS", 0x31] },
                                                             d => { "" => [0xFD, 0xCB, "NDIS", 0x32] },
                                                             e => { "" => [0xFD, 0xCB, "NDIS", 0x33] },
                                                             h => { "" => [0xFD, 0xCB, "NDIS", 0x34] },
                                                             l => { "" => [0xFD, 0xCB, "NDIS", 0x35] },
                                                           },
                                                  },
                                         },
                                       },
                                "]" => {
                                         ""  => [0xFD, 0xCB, 0x00, 0x36],
                                         "," => {
                                                  a => { "" => [0xFD, 0xCB, 0x00, 0x37] },
                                                  b => { "" => [0xFD, 0xCB, 0x00, 0x30] },
                                                  c => { "" => [0xFD, 0xCB, 0x00, 0x31] },
                                                  d => { "" => [0xFD, 0xCB, 0x00, 0x32] },
                                                  e => { "" => [0xFD, 0xCB, 0x00, 0x33] },
                                                  h => { "" => [0xFD, 0xCB, 0x00, 0x34] },
                                                  l => { "" => [0xFD, 0xCB, 0x00, 0x35] },
                                                },
                                       },
                              },
                      },
              "a"  => { "" => [0xCB, 0x37] },
              "b"  => { "" => [0xCB, 0x30] },
              "bc" => { "" => [0xCB, 0x31, 0xCB, 0x10] },
              "c"  => { "" => [0xCB, 0x31] },
              "d"  => { "" => [0xCB, 0x32] },
              "de" => { "" => [0xCB, 0x33, 0xCB, 0x12] },
              "e"  => { "" => [0xCB, 0x33] },
              "h"  => { "" => [0xCB, 0x34] },
              "hl" => { "" => [0xCB, 0x35, 0xCB, 0x14] },
              "l"  => { "" => [0xCB, 0x35] },
            },
    sra  => {
              "("  => {
                        hl => { ")" => { "" => [0xCB, 0x2E] } },
                        ix => {
                                ")" => {
                                         ""  => [0xDD, 0xCB, 0x00, 0x2E],
                                         "," => {
                                                  a => { "" => [0xDD, 0xCB, 0x00, 0x2F] },
                                                  b => { "" => [0xDD, 0xCB, 0x00, 0x28] },
                                                  c => { "" => [0xDD, 0xCB, 0x00, 0x29] },
                                                  d => { "" => [0xDD, 0xCB, 0x00, 0x2A] },
                                                  e => { "" => [0xDD, 0xCB, 0x00, 0x2B] },
                                                  h => { "" => [0xDD, 0xCB, 0x00, 0x2C] },
                                                  l => { "" => [0xDD, 0xCB, 0x00, 0x2D] },
                                                },
                                       },
                                "+" => {
                                         DIS => {
                                                  ")" => {
                                                           ""  => [0xDD, 0xCB, "DIS", 0x2E],
                                                           "," => {
                                                                    a => { "" => [0xDD, 0xCB, "DIS", 0x2F] },
                                                                    b => { "" => [0xDD, 0xCB, "DIS", 0x28] },
                                                                    c => { "" => [0xDD, 0xCB, "DIS", 0x29] },
                                                                    d => { "" => [0xDD, 0xCB, "DIS", 0x2A] },
                                                                    e => { "" => [0xDD, 0xCB, "DIS", 0x2B] },
                                                                    h => { "" => [0xDD, 0xCB, "DIS", 0x2C] },
                                                                    l => { "" => [0xDD, 0xCB, "DIS", 0x2D] },
                                                                  },
                                                         },
                                                },
                                       },
                                "-" => {
                                         NDIS => {
                                           ")" => {
                                                    ""  => [0xDD, 0xCB, "NDIS", 0x2E],
                                                    "," => {
                                                             a => { "" => [0xDD, 0xCB, "NDIS", 0x2F] },
                                                             b => { "" => [0xDD, 0xCB, "NDIS", 0x28] },
                                                             c => { "" => [0xDD, 0xCB, "NDIS", 0x29] },
                                                             d => { "" => [0xDD, 0xCB, "NDIS", 0x2A] },
                                                             e => { "" => [0xDD, 0xCB, "NDIS", 0x2B] },
                                                             h => { "" => [0xDD, 0xCB, "NDIS", 0x2C] },
                                                             l => { "" => [0xDD, 0xCB, "NDIS", 0x2D] },
                                                           },
                                                  },
                                         },
                                       },
                              },
                        iy => {
                                ")" => {
                                         ""  => [0xFD, 0xCB, 0x00, 0x2E],
                                         "," => {
                                                  a => { "" => [0xFD, 0xCB, 0x00, 0x2F] },
                                                  b => { "" => [0xFD, 0xCB, 0x00, 0x28] },
                                                  c => { "" => [0xFD, 0xCB, 0x00, 0x29] },
                                                  d => { "" => [0xFD, 0xCB, 0x00, 0x2A] },
                                                  e => { "" => [0xFD, 0xCB, 0x00, 0x2B] },
                                                  h => { "" => [0xFD, 0xCB, 0x00, 0x2C] },
                                                  l => { "" => [0xFD, 0xCB, 0x00, 0x2D] },
                                                },
                                       },
                                "+" => {
                                         DIS => {
                                                  ")" => {
                                                           ""  => [0xFD, 0xCB, "DIS", 0x2E],
                                                           "," => {
                                                                    a => { "" => [0xFD, 0xCB, "DIS", 0x2F] },
                                                                    b => { "" => [0xFD, 0xCB, "DIS", 0x28] },
                                                                    c => { "" => [0xFD, 0xCB, "DIS", 0x29] },
                                                                    d => { "" => [0xFD, 0xCB, "DIS", 0x2A] },
                                                                    e => { "" => [0xFD, 0xCB, "DIS", 0x2B] },
                                                                    h => { "" => [0xFD, 0xCB, "DIS", 0x2C] },
                                                                    l => { "" => [0xFD, 0xCB, "DIS", 0x2D] },
                                                                  },
                                                         },
                                                },
                                       },
                                "-" => {
                                         NDIS => {
                                           ")" => {
                                                    ""  => [0xFD, 0xCB, "NDIS", 0x2E],
                                                    "," => {
                                                             a => { "" => [0xFD, 0xCB, "NDIS", 0x2F] },
                                                             b => { "" => [0xFD, 0xCB, "NDIS", 0x28] },
                                                             c => { "" => [0xFD, 0xCB, "NDIS", 0x29] },
                                                             d => { "" => [0xFD, 0xCB, "NDIS", 0x2A] },
                                                             e => { "" => [0xFD, 0xCB, "NDIS", 0x2B] },
                                                             h => { "" => [0xFD, 0xCB, "NDIS", 0x2C] },
                                                             l => { "" => [0xFD, 0xCB, "NDIS", 0x2D] },
                                                           },
                                                  },
                                         },
                                       },
                              },
                      },
              "["  => {
                        hl => { "]" => { "" => [0xCB, 0x2E] } },
                        ix => {
                                "+" => {
                                         DIS => {
                                                  "]" => {
                                                           ""  => [0xDD, 0xCB, "DIS", 0x2E],
                                                           "," => {
                                                                    a => { "" => [0xDD, 0xCB, "DIS", 0x2F] },
                                                                    b => { "" => [0xDD, 0xCB, "DIS", 0x28] },
                                                                    c => { "" => [0xDD, 0xCB, "DIS", 0x29] },
                                                                    d => { "" => [0xDD, 0xCB, "DIS", 0x2A] },
                                                                    e => { "" => [0xDD, 0xCB, "DIS", 0x2B] },
                                                                    h => { "" => [0xDD, 0xCB, "DIS", 0x2C] },
                                                                    l => { "" => [0xDD, 0xCB, "DIS", 0x2D] },
                                                                  },
                                                         },
                                                },
                                       },
                                "-" => {
                                         NDIS => {
                                           "]" => {
                                                    ""  => [0xDD, 0xCB, "NDIS", 0x2E],
                                                    "," => {
                                                             a => { "" => [0xDD, 0xCB, "NDIS", 0x2F] },
                                                             b => { "" => [0xDD, 0xCB, "NDIS", 0x28] },
                                                             c => { "" => [0xDD, 0xCB, "NDIS", 0x29] },
                                                             d => { "" => [0xDD, 0xCB, "NDIS", 0x2A] },
                                                             e => { "" => [0xDD, 0xCB, "NDIS", 0x2B] },
                                                             h => { "" => [0xDD, 0xCB, "NDIS", 0x2C] },
                                                             l => { "" => [0xDD, 0xCB, "NDIS", 0x2D] },
                                                           },
                                                  },
                                         },
                                       },
                                "]" => {
                                         ""  => [0xDD, 0xCB, 0x00, 0x2E],
                                         "," => {
                                                  a => { "" => [0xDD, 0xCB, 0x00, 0x2F] },
                                                  b => { "" => [0xDD, 0xCB, 0x00, 0x28] },
                                                  c => { "" => [0xDD, 0xCB, 0x00, 0x29] },
                                                  d => { "" => [0xDD, 0xCB, 0x00, 0x2A] },
                                                  e => { "" => [0xDD, 0xCB, 0x00, 0x2B] },
                                                  h => { "" => [0xDD, 0xCB, 0x00, 0x2C] },
                                                  l => { "" => [0xDD, 0xCB, 0x00, 0x2D] },
                                                },
                                       },
                              },
                        iy => {
                                "+" => {
                                         DIS => {
                                                  "]" => {
                                                           ""  => [0xFD, 0xCB, "DIS", 0x2E],
                                                           "," => {
                                                                    a => { "" => [0xFD, 0xCB, "DIS", 0x2F] },
                                                                    b => { "" => [0xFD, 0xCB, "DIS", 0x28] },
                                                                    c => { "" => [0xFD, 0xCB, "DIS", 0x29] },
                                                                    d => { "" => [0xFD, 0xCB, "DIS", 0x2A] },
                                                                    e => { "" => [0xFD, 0xCB, "DIS", 0x2B] },
                                                                    h => { "" => [0xFD, 0xCB, "DIS", 0x2C] },
                                                                    l => { "" => [0xFD, 0xCB, "DIS", 0x2D] },
                                                                  },
                                                         },
                                                },
                                       },
                                "-" => {
                                         NDIS => {
                                           "]" => {
                                                    ""  => [0xFD, 0xCB, "NDIS", 0x2E],
                                                    "," => {
                                                             a => { "" => [0xFD, 0xCB, "NDIS", 0x2F] },
                                                             b => { "" => [0xFD, 0xCB, "NDIS", 0x28] },
                                                             c => { "" => [0xFD, 0xCB, "NDIS", 0x29] },
                                                             d => { "" => [0xFD, 0xCB, "NDIS", 0x2A] },
                                                             e => { "" => [0xFD, 0xCB, "NDIS", 0x2B] },
                                                             h => { "" => [0xFD, 0xCB, "NDIS", 0x2C] },
                                                             l => { "" => [0xFD, 0xCB, "NDIS", 0x2D] },
                                                           },
                                                  },
                                         },
                                       },
                                "]" => {
                                         ""  => [0xFD, 0xCB, 0x00, 0x2E],
                                         "," => {
                                                  a => { "" => [0xFD, 0xCB, 0x00, 0x2F] },
                                                  b => { "" => [0xFD, 0xCB, 0x00, 0x28] },
                                                  c => { "" => [0xFD, 0xCB, 0x00, 0x29] },
                                                  d => { "" => [0xFD, 0xCB, 0x00, 0x2A] },
                                                  e => { "" => [0xFD, 0xCB, 0x00, 0x2B] },
                                                  h => { "" => [0xFD, 0xCB, 0x00, 0x2C] },
                                                  l => { "" => [0xFD, 0xCB, 0x00, 0x2D] },
                                                },
                                       },
                              },
                      },
              "a"  => { "" => [0xCB, 0x2F] },
              "b"  => { "" => [0xCB, 0x28] },
              "bc" => { "" => [0xCB, 0x28, 0xCB, 0x19] },
              "c"  => { "" => [0xCB, 0x29] },
              "d"  => { "" => [0xCB, 0x2A] },
              "de" => { "" => [0xCB, 0x2A, 0xCB, 0x1B] },
              "e"  => { "" => [0xCB, 0x2B] },
              "h"  => { "" => [0xCB, 0x2C] },
              "hl" => { "" => [0xCB, 0x2C, 0xCB, 0x1D] },
              "l"  => { "" => [0xCB, 0x2D] },
            },
    srl  => {
              "("  => {
                        hl => { ")" => { "" => [0xCB, 0x3E] } },
                        ix => {
                                ")" => {
                                         ""  => [0xDD, 0xCB, 0x00, 0x3E],
                                         "," => {
                                                  a => { "" => [0xDD, 0xCB, 0x00, 0x3F] },
                                                  b => { "" => [0xDD, 0xCB, 0x00, 0x38] },
                                                  c => { "" => [0xDD, 0xCB, 0x00, 0x39] },
                                                  d => { "" => [0xDD, 0xCB, 0x00, 0x3A] },
                                                  e => { "" => [0xDD, 0xCB, 0x00, 0x3B] },
                                                  h => { "" => [0xDD, 0xCB, 0x00, 0x3C] },
                                                  l => { "" => [0xDD, 0xCB, 0x00, 0x3D] },
                                                },
                                       },
                                "+" => {
                                         DIS => {
                                                  ")" => {
                                                           ""  => [0xDD, 0xCB, "DIS", 0x3E],
                                                           "," => {
                                                                    a => { "" => [0xDD, 0xCB, "DIS", 0x3F] },
                                                                    b => { "" => [0xDD, 0xCB, "DIS", 0x38] },
                                                                    c => { "" => [0xDD, 0xCB, "DIS", 0x39] },
                                                                    d => { "" => [0xDD, 0xCB, "DIS", 0x3A] },
                                                                    e => { "" => [0xDD, 0xCB, "DIS", 0x3B] },
                                                                    h => { "" => [0xDD, 0xCB, "DIS", 0x3C] },
                                                                    l => { "" => [0xDD, 0xCB, "DIS", 0x3D] },
                                                                  },
                                                         },
                                                },
                                       },
                                "-" => {
                                         NDIS => {
                                           ")" => {
                                                    ""  => [0xDD, 0xCB, "NDIS", 0x3E],
                                                    "," => {
                                                             a => { "" => [0xDD, 0xCB, "NDIS", 0x3F] },
                                                             b => { "" => [0xDD, 0xCB, "NDIS", 0x38] },
                                                             c => { "" => [0xDD, 0xCB, "NDIS", 0x39] },
                                                             d => { "" => [0xDD, 0xCB, "NDIS", 0x3A] },
                                                             e => { "" => [0xDD, 0xCB, "NDIS", 0x3B] },
                                                             h => { "" => [0xDD, 0xCB, "NDIS", 0x3C] },
                                                             l => { "" => [0xDD, 0xCB, "NDIS", 0x3D] },
                                                           },
                                                  },
                                         },
                                       },
                              },
                        iy => {
                                ")" => {
                                         ""  => [0xFD, 0xCB, 0x00, 0x3E],
                                         "," => {
                                                  a => { "" => [0xFD, 0xCB, 0x00, 0x3F] },
                                                  b => { "" => [0xFD, 0xCB, 0x00, 0x38] },
                                                  c => { "" => [0xFD, 0xCB, 0x00, 0x39] },
                                                  d => { "" => [0xFD, 0xCB, 0x00, 0x3A] },
                                                  e => { "" => [0xFD, 0xCB, 0x00, 0x3B] },
                                                  h => { "" => [0xFD, 0xCB, 0x00, 0x3C] },
                                                  l => { "" => [0xFD, 0xCB, 0x00, 0x3D] },
                                                },
                                       },
                                "+" => {
                                         DIS => {
                                                  ")" => {
                                                           ""  => [0xFD, 0xCB, "DIS", 0x3E],
                                                           "," => {
                                                                    a => { "" => [0xFD, 0xCB, "DIS", 0x3F] },
                                                                    b => { "" => [0xFD, 0xCB, "DIS", 0x38] },
                                                                    c => { "" => [0xFD, 0xCB, "DIS", 0x39] },
                                                                    d => { "" => [0xFD, 0xCB, "DIS", 0x3A] },
                                                                    e => { "" => [0xFD, 0xCB, "DIS", 0x3B] },
                                                                    h => { "" => [0xFD, 0xCB, "DIS", 0x3C] },
                                                                    l => { "" => [0xFD, 0xCB, "DIS", 0x3D] },
                                                                  },
                                                         },
                                                },
                                       },
                                "-" => {
                                         NDIS => {
                                           ")" => {
                                                    ""  => [0xFD, 0xCB, "NDIS", 0x3E],
                                                    "," => {
                                                             a => { "" => [0xFD, 0xCB, "NDIS", 0x3F] },
                                                             b => { "" => [0xFD, 0xCB, "NDIS", 0x38] },
                                                             c => { "" => [0xFD, 0xCB, "NDIS", 0x39] },
                                                             d => { "" => [0xFD, 0xCB, "NDIS", 0x3A] },
                                                             e => { "" => [0xFD, 0xCB, "NDIS", 0x3B] },
                                                             h => { "" => [0xFD, 0xCB, "NDIS", 0x3C] },
                                                             l => { "" => [0xFD, 0xCB, "NDIS", 0x3D] },
                                                           },
                                                  },
                                         },
                                       },
                              },
                      },
              "["  => {
                        hl => { "]" => { "" => [0xCB, 0x3E] } },
                        ix => {
                                "+" => {
                                         DIS => {
                                                  "]" => {
                                                           ""  => [0xDD, 0xCB, "DIS", 0x3E],
                                                           "," => {
                                                                    a => { "" => [0xDD, 0xCB, "DIS", 0x3F] },
                                                                    b => { "" => [0xDD, 0xCB, "DIS", 0x38] },
                                                                    c => { "" => [0xDD, 0xCB, "DIS", 0x39] },
                                                                    d => { "" => [0xDD, 0xCB, "DIS", 0x3A] },
                                                                    e => { "" => [0xDD, 0xCB, "DIS", 0x3B] },
                                                                    h => { "" => [0xDD, 0xCB, "DIS", 0x3C] },
                                                                    l => { "" => [0xDD, 0xCB, "DIS", 0x3D] },
                                                                  },
                                                         },
                                                },
                                       },
                                "-" => {
                                         NDIS => {
                                           "]" => {
                                                    ""  => [0xDD, 0xCB, "NDIS", 0x3E],
                                                    "," => {
                                                             a => { "" => [0xDD, 0xCB, "NDIS", 0x3F] },
                                                             b => { "" => [0xDD, 0xCB, "NDIS", 0x38] },
                                                             c => { "" => [0xDD, 0xCB, "NDIS", 0x39] },
                                                             d => { "" => [0xDD, 0xCB, "NDIS", 0x3A] },
                                                             e => { "" => [0xDD, 0xCB, "NDIS", 0x3B] },
                                                             h => { "" => [0xDD, 0xCB, "NDIS", 0x3C] },
                                                             l => { "" => [0xDD, 0xCB, "NDIS", 0x3D] },
                                                           },
                                                  },
                                         },
                                       },
                                "]" => {
                                         ""  => [0xDD, 0xCB, 0x00, 0x3E],
                                         "," => {
                                                  a => { "" => [0xDD, 0xCB, 0x00, 0x3F] },
                                                  b => { "" => [0xDD, 0xCB, 0x00, 0x38] },
                                                  c => { "" => [0xDD, 0xCB, 0x00, 0x39] },
                                                  d => { "" => [0xDD, 0xCB, 0x00, 0x3A] },
                                                  e => { "" => [0xDD, 0xCB, 0x00, 0x3B] },
                                                  h => { "" => [0xDD, 0xCB, 0x00, 0x3C] },
                                                  l => { "" => [0xDD, 0xCB, 0x00, 0x3D] },
                                                },
                                       },
                              },
                        iy => {
                                "+" => {
                                         DIS => {
                                                  "]" => {
                                                           ""  => [0xFD, 0xCB, "DIS", 0x3E],
                                                           "," => {
                                                                    a => { "" => [0xFD, 0xCB, "DIS", 0x3F] },
                                                                    b => { "" => [0xFD, 0xCB, "DIS", 0x38] },
                                                                    c => { "" => [0xFD, 0xCB, "DIS", 0x39] },
                                                                    d => { "" => [0xFD, 0xCB, "DIS", 0x3A] },
                                                                    e => { "" => [0xFD, 0xCB, "DIS", 0x3B] },
                                                                    h => { "" => [0xFD, 0xCB, "DIS", 0x3C] },
                                                                    l => { "" => [0xFD, 0xCB, "DIS", 0x3D] },
                                                                  },
                                                         },
                                                },
                                       },
                                "-" => {
                                         NDIS => {
                                           "]" => {
                                                    ""  => [0xFD, 0xCB, "NDIS", 0x3E],
                                                    "," => {
                                                             a => { "" => [0xFD, 0xCB, "NDIS", 0x3F] },
                                                             b => { "" => [0xFD, 0xCB, "NDIS", 0x38] },
                                                             c => { "" => [0xFD, 0xCB, "NDIS", 0x39] },
                                                             d => { "" => [0xFD, 0xCB, "NDIS", 0x3A] },
                                                             e => { "" => [0xFD, 0xCB, "NDIS", 0x3B] },
                                                             h => { "" => [0xFD, 0xCB, "NDIS", 0x3C] },
                                                             l => { "" => [0xFD, 0xCB, "NDIS", 0x3D] },
                                                           },
                                                  },
                                         },
                                       },
                                "]" => {
                                         ""  => [0xFD, 0xCB, 0x00, 0x3E],
                                         "," => {
                                                  a => { "" => [0xFD, 0xCB, 0x00, 0x3F] },
                                                  b => { "" => [0xFD, 0xCB, 0x00, 0x38] },
                                                  c => { "" => [0xFD, 0xCB, 0x00, 0x39] },
                                                  d => { "" => [0xFD, 0xCB, 0x00, 0x3A] },
                                                  e => { "" => [0xFD, 0xCB, 0x00, 0x3B] },
                                                  h => { "" => [0xFD, 0xCB, 0x00, 0x3C] },
                                                  l => { "" => [0xFD, 0xCB, 0x00, 0x3D] },
                                                },
                                       },
                              },
                      },
              "a"  => { "" => [0xCB, 0x3F] },
              "b"  => { "" => [0xCB, 0x38] },
              "bc" => { "" => [0xCB, 0x38, 0xCB, 0x19] },
              "c"  => { "" => [0xCB, 0x39] },
              "d"  => { "" => [0xCB, 0x3A] },
              "de" => { "" => [0xCB, 0x3A, 0xCB, 0x1B] },
              "e"  => { "" => [0xCB, 0x3B] },
              "h"  => { "" => [0xCB, 0x3C] },
              "hl" => { "" => [0xCB, 0x3C, 0xCB, 0x1D] },
              "l"  => { "" => [0xCB, 0x3D] },
            },
    stop => { "" => [0xDD, 0xDD, 0x00] },
    sub  => {
              "("   => {
                         hl => { ")" => { "" => [0x96] } },
                         ix => {
                                 ")" => { "" => [0xDD, 0x96, 0x00] },
                                 "+" => { DIS => { ")" => { "" => [0xDD, 0x96, "DIS"] } } },
                                 "-" => { NDIS => { ")" => { "" => [0xDD, 0x96, "NDIS"] } } },
                               },
                         iy => {
                                 ")" => { "" => [0xFD, 0x96, 0x00] },
                                 "+" => { DIS => { ")" => { "" => [0xFD, 0x96, "DIS"] } } },
                                 "-" => { NDIS => { ")" => { "" => [0xFD, 0x96, "NDIS"] } } },
                               },
                       },
              "["   => {
                         hl => { "]" => { "" => [0x96] } },
                         ix => {
                                 "+" => { DIS => { "]" => { "" => [0xDD, 0x96, "DIS"] } } },
                                 "-" => { NDIS => { "]" => { "" => [0xDD, 0x96, "NDIS"] } } },
                                 "]" => { "" => [0xDD, 0x96, 0x00] },
                               },
                         iy => {
                                 "+" => { DIS => { "]" => { "" => [0xFD, 0x96, "DIS"] } } },
                                 "-" => { NDIS => { "]" => { "" => [0xFD, 0x96, "NDIS"] } } },
                                 "]" => { "" => [0xFD, 0x96, 0x00] },
                               },
                       },
              "a"   => { "" => [0x97] },
              "b"   => { "" => [0x90] },
              "c"   => { "" => [0x91] },
              "d"   => { "" => [0x92] },
              "e"   => { "" => [0x93] },
              "h"   => { "" => [0x94] },
              "hl"  => {
                         "," => {
                                  bc => { "" => [0xB7, 0xED, 0x42] },
                                  de => { "" => [0xB7, 0xED, 0x52] },
                                  hl => { "" => [0xB7, 0xED, 0x62] },
                                  sp => { "" => [0xB7, 0xED, 0x72] },
                                },
                       },
              "hx"  => { "" => [0xDD, 0x94] },
              "hy"  => { "" => [0xFD, 0x94] },
              "ixh" => { "" => [0xDD, 0x94] },
              "ixl" => { "" => [0xDD, 0x95] },
              "iyh" => { "" => [0xFD, 0x94] },
              "iyl" => { "" => [0xFD, 0x95] },
              "l"   => { "" => [0x95] },
              "lx"  => { "" => [0xDD, 0x95] },
              "ly"  => { "" => [0xFD, 0x95] },
              "N"   => { "" => [0xD6, "N"] },
              "xh"  => { "" => [0xDD, 0x94] },
              "xl"  => { "" => [0xDD, 0x95] },
              "yh"  => { "" => [0xFD, 0x94] },
              "yl"  => { "" => [0xFD, 0x95] },
            },
    xor  => {
              "("   => {
                         hl => { ")" => { "" => [0xAE] } },
                         ix => {
                                 ")" => { "" => [0xDD, 0xAE, 0x00] },
                                 "+" => { DIS => { ")" => { "" => [0xDD, 0xAE, "DIS"] } } },
                                 "-" => { NDIS => { ")" => { "" => [0xDD, 0xAE, "NDIS"] } } },
                               },
                         iy => {
                                 ")" => { "" => [0xFD, 0xAE, 0x00] },
                                 "+" => { DIS => { ")" => { "" => [0xFD, 0xAE, "DIS"] } } },
                                 "-" => { NDIS => { ")" => { "" => [0xFD, 0xAE, "NDIS"] } } },
                               },
                       },
              "["   => {
                         hl => { "]" => { "" => [0xAE] } },
                         ix => {
                                 "+" => { DIS => { "]" => { "" => [0xDD, 0xAE, "DIS"] } } },
                                 "-" => { NDIS => { "]" => { "" => [0xDD, 0xAE, "NDIS"] } } },
                                 "]" => { "" => [0xDD, 0xAE, 0x00] },
                               },
                         iy => {
                                 "+" => { DIS => { "]" => { "" => [0xFD, 0xAE, "DIS"] } } },
                                 "-" => { NDIS => { "]" => { "" => [0xFD, 0xAE, "NDIS"] } } },
                                 "]" => { "" => [0xFD, 0xAE, 0x00] },
                               },
                       },
              "a"   => { "" => [0xAF] },
              "b"   => { "" => [0xA8] },
              "c"   => { "" => [0xA9] },
              "d"   => { "" => [0xAA] },
              "e"   => { "" => [0xAB] },
              "h"   => { "" => [0xAC] },
              "hx"  => { "" => [0xDD, 0xAC] },
              "hy"  => { "" => [0xFD, 0xAC] },
              "ixh" => { "" => [0xDD, 0xAC] },
              "ixl" => { "" => [0xDD, 0xAD] },
              "iyh" => { "" => [0xFD, 0xAC] },
              "iyl" => { "" => [0xFD, 0xAD] },
              "l"   => { "" => [0xAD] },
              "lx"  => { "" => [0xDD, 0xAD] },
              "ly"  => { "" => [0xFD, 0xAD] },
              "N"   => { "" => [0xEE, "N"] },
              "xh"  => { "" => [0xDD, 0xAC] },
              "xl"  => { "" => [0xDD, 0xAD] },
              "yh"  => { "" => [0xFD, 0xAC] },
              "yl"  => { "" => [0xFD, 0xAD] },
            },
  },
  disasm => {
    0x00   => { "" => ["nop"] },
    0x01   => { NNl => { NNh => { "" => ["ld", "bc", ",", "NN"] } } },
    0x02   => {
               "" => ["ld", "(", "bc", ")", ",", "a"],
               0x0B => { "" => ["ldd", "(", "bc", ")", ",", "a"] },
               0x03 => { "" => ["ldi", "(", "bc", ")", ",", "a"] },
             },
    0x03   => { "" => ["inc", "bc"] },
    0x04   => { "" => ["inc", "b"] },
    0x05   => { "" => ["dec", "b"] },
    0x06   => { N => { "" => ["ld", "b", ",", "N"] } },
    0x07   => { "" => ["rlca"] },
    0x08   => { "" => ["ex", "af", ",", "af'"] },
    0x09   => { "" => ["add", "hl", ",", "bc"] },
    0x0A  => {
               "" => ["ld", "a", ",", "(", "bc", ")"],
               0x0B => { "" => ["ldd", "a", ",", "(", "bc", ")"] },
               0x03 => { "" => ["ldi", "a", ",", "(", "bc", ")"] },
             },
    0x0B  => { "" => ["dec", "bc"] },
    0x0C  => { "" => ["inc", "c"] },
    0x0D  => { "" => ["dec", "c"] },
    0x0E  => { N => { "" => ["ld", "c", ",", "N"] } },
    0x0F  => { "" => ["rrca"] },
    0x10  => { NNo => { "" => ["djnz", "NN"] } },
    0x11  => { NNl => { NNh => { "" => ["ld", "de", ",", "NN"] } } },
    0x12  => {
               "" => ["ld", "(", "de", ")", ",", "a"],
               0x13 => { "" => ["ldi", "(", "de", ")", ",", "a"] },
               0x1B => { "" => ["ldd", "(", "de", ")", ",", "a"] },
             },
    0x13  => { "" => ["inc", "de"] },
    0x14  => { "" => ["inc", "d"] },
    0x15  => { "" => ["dec", "d"] },
    0x16  => { N => { "" => ["ld", "d", ",", "N"] } },
    0x17  => { "" => ["rla"] },
    0x18  => { NNo => { "" => ["jr", "NN"] } },
    0x19  => { "" => ["add", "hl", ",", "de"] },
    0x1A  => {
               "" => ["ld", "a", ",", "(", "de", ")"],
               0x13 => { "" => ["ldi", "a", ",", "(", "de", ")"] },
               0x1B => { "" => ["ldd", "a", ",", "(", "de", ")"] },
             },
    0x1B  => { "" => ["dec", "de"] },
    0x1C  => { "" => ["inc", "e"] },
    0x1D  => { "" => ["dec", "e"] },
    0x1E  => { N => { "" => ["ld", "e", ",", "N"] } },
    0x1F  => { "" => ["rra"] },
    0x20  => { NNo => { "" => ["jr", "nz", ",", "NN"] } },
    0x21  => { NNl => { NNh => { "" => ["ld", "hl", ",", "NN"] } } },
    0x22  => { NNl => { NNh => { "" => ["ld", "(", "NN", ")", ",", "hl"] } } },
    0x23  => { "" => ["inc", "hl"] },
    0x24  => { "" => ["inc", "h"] },
    0x25  => { "" => ["dec", "h"] },
    0x26  => { N => { "" => ["ld", "h", ",", "N"] } },
    0x27  => { "" => ["daa"] },
    0x28  => { NNo => { "" => ["jr", "z", ",", "NN"] } },
    0x29  => { "" => ["add", "hl", ",", "hl"] },
    0x2A  => { NNl => { NNh => { "" => ["ld", "hl", ",", "(", "NN", ")"] } } },
    0x2B  => { "" => ["dec", "hl"] },
    0x2C  => { "" => ["inc", "l"] },
    0x2D  => { "" => ["dec", "l"] },
    0x2E  => { N => { "" => ["ld", "l", ",", "N"] } },
    0x2F  => { "" => ["cpl"] },
    0x30  => { NNo => { "" => ["jr", "nc", ",", "NN"] } },
    0x31  => { NNl => { NNh => { "" => ["ld", "sp", ",", "NN"] } } },
    0x32  => { NNl => { NNh => { "" => ["ld", "(", "NN", ")", ",", "a"] } } },
    0x33  => { "" => ["inc", "sp"] },
    0x34  => { "" => ["inc", "(", "hl", ")"] },
    0x35  => { "" => ["dec", "(", "hl", ")"] },
    0x36  => {
               N => {
                      "" => ["ld", "(", "hl", ")", ",", "N"],
                      0x23 => { "" => ["ldi", "(", "hl", ")", ",", "N"] },
                      0x2B => { "" => ["ldd", "(", "hl", ")", ",", "N"] },
                    },
             },
    0x37  => { "" => ["scf"] },
    0x38  => { NNo => { "" => ["jr", "c", ",", "NN"] } },
    0x39  => { "" => ["add", "hl", ",", "sp"] },
    0x3A  => { NNl => { NNh => { "" => ["ld", "a", ",", "(", "NN", ")"] } } },
    0x3B  => { "" => ["dec", "sp"] },
    0x3C  => { "" => ["inc", "a"] },
    0x3D  => { "" => ["dec", "a"] },
    0x3E  => { N => { "" => ["ld", "a", ",", "N"] } },
    0x3F  => { "" => ["ccf"] },
    0x40  => {
               "" => ["ld", "b", ",", "b"],
               0x49 => { "" => ["ld", "bc", ",", "bc"] },
             },
    0x41  => { "" => ["ld", "b", ",", "c"] },
    0x42  => {
               "" => ["ld", "b", ",", "d"],
               0x4B => { "" => ["ld", "bc", ",", "de"] },
             },
    0x43  => { "" => ["ld", "b", ",", "e"] },
    0x44  => {
               "" => ["ld", "b", ",", "h"],
               0x4D => { "" => ["ld", "bc", ",", "hl"] },
             },
    0x45  => { "" => ["ld", "b", ",", "l"] },
    0x46  => {
               "" => ["ld", "b", ",", "(", "hl", ")"],
               0x23 => { "" => ["ldi", "b", ",", "(", "hl", ")"] },
               0x2B => { "" => ["ldd", "b", ",", "(", "hl", ")"] },
             },
    0x47  => { "" => ["ld", "b", ",", "a"] },
    0x48  => { "" => ["ld", "c", ",", "b"] },
    0x49  => { "" => ["ld", "c", ",", "c"] },
    0x4A  => { "" => ["ld", "c", ",", "d"] },
    0x4B  => { "" => ["ld", "c", ",", "e"] },
    0x4C  => { "" => ["ld", "c", ",", "h"] },
    0x4D  => { "" => ["ld", "c", ",", "l"] },
    0x4E  => {
               "" => ["ld", "c", ",", "(", "hl", ")"],
               0x23 => {
                 "" => ["ldi", "c", ",", "(", "hl", ")"],
                 0x46 => {
                   0x23 => { "" => ["ldi", "bc", ",", "(", "hl", ")"] },
                   0x2B => { "" => ["ld", "bc", ",", "(", "hl", ")"] },
                 },
               },
               0x2B => { "" => ["ldd", "c", ",", "(", "hl", ")"] },
             },
    0x4F  => { "" => ["ld", "c", ",", "a"] },
    0x50  => {
               "" => ["ld", "d", ",", "b"],
               0x59 => { "" => ["ld", "de", ",", "bc"] },
             },
    0x51  => { "" => ["ld", "d", ",", "c"] },
    0x52  => {
               "" => ["ld", "d", ",", "d"],
               0x5B => { "" => ["ld", "de", ",", "de"] },
             },
    0x53  => { "" => ["ld", "d", ",", "e"] },
    0x54  => {
               "" => ["ld", "d", ",", "h"],
               0x5D => { "" => ["ld", "de", ",", "hl"] },
             },
    0x55  => { "" => ["ld", "d", ",", "l"] },
    0x56  => {
               "" => ["ld", "d", ",", "(", "hl", ")"],
               0x23 => { "" => ["ldi", "d", ",", "(", "hl", ")"] },
               0x2B => { "" => ["ldd", "d", ",", "(", "hl", ")"] },
             },
    0x57  => { "" => ["ld", "d", ",", "a"] },
    0x58  => { "" => ["ld", "e", ",", "b"] },
    0x59  => { "" => ["ld", "e", ",", "c"] },
    0x5A  => { "" => ["ld", "e", ",", "d"] },
    0x5B  => { "" => ["ld", "e", ",", "e"] },
    0x5C  => { "" => ["ld", "e", ",", "h"] },
    0x5D  => { "" => ["ld", "e", ",", "l"] },
    0x5E  => {
               "" => ["ld", "e", ",", "(", "hl", ")"],
               0x23 => {
                 "" => ["ldi", "e", ",", "(", "hl", ")"],
                 0x56 => {
                   0x23 => { "" => ["ldi", "de", ",", "(", "hl", ")"] },
                   0x2B => { "" => ["ld", "de", ",", "(", "hl", ")"] },
                 },
               },
               0x2B => { "" => ["ldd", "e", ",", "(", "hl", ")"] },
             },
    0x5F  => { "" => ["ld", "e", ",", "a"] },
    0x60  => {
               "" => ["ld", "h", ",", "b"],
               0x69 => { "" => ["ld", "hl", ",", "bc"] },
             },
    0x61  => { "" => ["ld", "h", ",", "c"] },
    0x62  => {
               "" => ["ld", "h", ",", "d"],
               0x6B => { "" => ["ld", "hl", ",", "de"] },
             },
    0x63  => { "" => ["ld", "h", ",", "e"] },
    0x64 => {
               "" => ["ld", "h", ",", "h"],
               0x6D => { "" => ["ld", "hl", ",", "hl"] },
             },
    0x65 => { "" => ["ld", "h", ",", "l"] },
    0x66 => {
               "" => ["ld", "h", ",", "(", "hl", ")"],
               0x23 => { "" => ["ldi", "h", ",", "(", "hl", ")"] },
               0x2B => { "" => ["ldd", "h", ",", "(", "hl", ")"] },
             },
    0x67 => { "" => ["ld", "h", ",", "a"] },
    0x68 => { "" => ["ld", "l", ",", "b"] },
    0x69 => { "" => ["ld", "l", ",", "c"] },
    0x6A => { "" => ["ld", "l", ",", "d"] },
    0x6B => { "" => ["ld", "l", ",", "e"] },
    0x6C => { "" => ["ld", "l", ",", "h"] },
    0x6D => { "" => ["ld", "l", ",", "l"] },
    0x6E => {
               "" => ["ld", "l", ",", "(", "hl", ")"],
               0x23 => { "" => ["ldi", "l", ",", "(", "hl", ")"] },
               0x2B => { "" => ["ldd", "l", ",", "(", "hl", ")"] },
             },
    0x6F => { "" => ["ld", "l", ",", "a"] },
    0x70 => {
               "" => ["ld", "(", "hl", ")", ",", "b"],
               0x23 => { "" => ["ldi", "(", "hl", ")", ",", "b"] },
               0x2B => { "" => ["ldd", "(", "hl", ")", ",", "b"] },
             },
    0x71 => {
               "" => ["ld", "(", "hl", ")", ",", "c"],
               0x23 => {
                 "" => ["ldi", "(", "hl", ")", ",", "c"],
                 0x70 => {
                   0x23 => { "" => ["ldi", "(", "hl", ")", ",", "bc"] },
                   0x2B => { "" => ["ld", "(", "hl", ")", ",", "bc"] },
                 },
               },
               0x2B => { "" => ["ldd", "(", "hl", ")", ",", "c"] },
             },
    0x72 => {
               "" => ["ld", "(", "hl", ")", ",", "d"],
               0x23 => { "" => ["ldi", "(", "hl", ")", ",", "d"] },
               0x2B => { "" => ["ldd", "(", "hl", ")", ",", "d"] },
             },
    0x73 => {
               "" => ["ld", "(", "hl", ")", ",", "e"],
               0x23 => {
                 "" => ["ldi", "(", "hl", ")", ",", "e"],
                 0x72 => {
                   0x23 => { "" => ["ldi", "(", "hl", ")", ",", "de"] },
                   0x2B => { "" => ["ld", "(", "hl", ")", ",", "de"] },
                 },
               },
               0x2B => { "" => ["ldd", "(", "hl", ")", ",", "e"] },
             },
    0x74 => {
               "" => ["ld", "(", "hl", ")", ",", "h"],
               0x23 => { "" => ["ldi", "(", "hl", ")", ",", "h"] },
               0x2B => { "" => ["ldd", "(", "hl", ")", ",", "h"] },
             },
    0x75 => {
               "" => ["ld", "(", "hl", ")", ",", "l"],
               0x23 => { "" => ["ldi", "(", "hl", ")", ",", "l"] },
               0x2B => { "" => ["ldd", "(", "hl", ")", ",", "l"] },
             },
    0x76 => { "" => ["halt"] },
    0x77 => {
               "" => ["ld", "(", "hl", ")", ",", "a"],
               0x23 => { "" => ["ldi", "(", "hl", ")", ",", "a"] },
               0x2B => { "" => ["ldd", "(", "hl", ")", ",", "a"] },
             },
    0x78 => { "" => ["ld", "a", ",", "b"] },
    0x79 => { "" => ["ld", "a", ",", "c"] },
    0x7A => { "" => ["ld", "a", ",", "d"] },
    0x7B => { "" => ["ld", "a", ",", "e"] },
    0x7C => { "" => ["ld", "a", ",", "h"] },
    0x7D => { "" => ["ld", "a", ",", "l"] },
    0x7E => {
               "" => ["ld", "a", ",", "(", "hl", ")"],
               0x23 => { "" => ["ldi", "a", ",", "(", "hl", ")"] },
               0x2B => { "" => ["ldd", "a", ",", "(", "hl", ")"] },
             },
    0x7F => { "" => ["ld", "a", ",", "a"] },
    0x80 => { "" => ["add", "a", ",", "b"] },
    0x81 => { "" => ["add", "a", ",", "c"] },
    0x82 => { "" => ["add", "a", ",", "d"] },
    0x83 => { "" => ["add", "a", ",", "e"] },
    0x84 => { "" => ["add", "a", ",", "h"] },
    0x85 => { "" => ["add", "a", ",", "l"] },
    0x86 => { "" => ["add", "a", ",", "(", "hl", ")"] },
    0x87 => { "" => ["add", "a", ",", "a"] },
    0x88 => { "" => ["adc", "a", ",", "b"] },
    0x89 => { "" => ["adc", "a", ",", "c"] },
    0x8A => { "" => ["adc", "a", ",", "d"] },
    0x8B => { "" => ["adc", "a", ",", "e"] },
    0x8C => { "" => ["adc", "a", ",", "h"] },
    0x8D => { "" => ["adc", "a", ",", "l"] },
    0x8E => { "" => ["adc", "a", ",", "(", "hl", ")"] },
    0x8F => { "" => ["adc", "a", ",", "a"] },
    0x90 => { "" => ["sub", "b"] },
    0x91 => { "" => ["sub", "c"] },
    0x92 => { "" => ["sub", "d"] },
    0x93 => { "" => ["sub", "e"] },
    0x94 => { "" => ["sub", "h"] },
    0x95 => { "" => ["sub", "l"] },
    0x96 => { "" => ["sub", "(", "hl", ")"] },
    0x97 => { "" => ["sub", "a"] },
    0x98 => { "" => ["sbc", "a", ",", "b"] },
    0x99 => { "" => ["sbc", "a", ",", "c"] },
    0x9A => { "" => ["sbc", "a", ",", "d"] },
    0x9B => { "" => ["sbc", "a", ",", "e"] },
    0x9C => { "" => ["sbc", "a", ",", "h"] },
    0x9D => { "" => ["sbc", "a", ",", "l"] },
    0x9E => { "" => ["sbc", "a", ",", "(", "hl", ")"] },
    0x9F => { "" => ["sbc", "a", ",", "a"] },
    0xA0 => { "" => ["and", "b"] },
    0xA1 => { "" => ["and", "c"] },
    0xA2 => { "" => ["and", "d"] },
    0xA3 => { "" => ["and", "e"] },
    0xA4 => { "" => ["and", "h"] },
    0xA5 => { "" => ["and", "l"] },
    0xA6 => { "" => ["and", "(", "hl", ")"] },
    0xA7 => { "" => ["and", "a"] },
    0xA8 => { "" => ["xor", "b"] },
    0xA9 => { "" => ["xor", "c"] },
    0xAA => { "" => ["xor", "d"] },
    0xAB => { "" => ["xor", "e"] },
    0xAC => { "" => ["xor", "h"] },
    0xAD => { "" => ["xor", "l"] },
    0xAE => { "" => ["xor", "(", "hl", ")"] },
    0xAF => { "" => ["xor", "a"] },
    0xB0 => { "" => ["or", "b"] },
    0xB1 => { "" => ["or", "c"] },
    0xB2 => { "" => ["or", "d"] },
    0xB3 => { "" => ["or", "e"] },
    0xB4 => { "" => ["or", "h"] },
    0xB5 => { "" => ["or", "l"] },
    0xB6 => { "" => ["or", "(", "hl", ")"] },
    0xB7 => {
               "" => ["or", "a"],
               0xED => {
                 0x42  => { "" => ["sub", "hl", ",", "bc"] },
                 0x52  => { "" => ["sub", "hl", ",", "de"] },
                 0x62  => { "" => ["sub", "hl", ",", "hl"] },
                 0x72 => { "" => ["sub", "hl", ",", "sp"] },
               },
             },
    0xB8 => { "" => ["cp", "b"] },
    0xB9 => { "" => ["cp", "c"] },
    0xBA => { "" => ["cp", "d"] },
    0xBB => { "" => ["cp", "e"] },
    0xBC => { "" => ["cp", "h"] },
    0xBD => { "" => ["cp", "l"] },
    0xBE => { "" => ["cp", "(", "hl", ")"] },
    0xBF => { "" => ["cp", "a"] },
    0xC0 => { "" => ["ret", "nz"] },
    0xC1 => { "" => ["pop", "bc"] },
    0xC2 => { NNl => { NNh => { "" => ["jp", "nz", ",", "NN"] } } },
    0xC3 => { NNl => { NNh => { "" => ["jp", "NN"] } } },
    0xC4 => { NNl => { NNh => { "" => ["call", "nz", ",", "NN"] } } },
    0xC5 => { "" => ["push", "bc"] },
    0xC6 => { N => { "" => ["add", "a", ",", "N"] } },
    0xC7 => { "" => ["rst", 0x00] },
    0xC8 => { "" => ["ret", "z"] },
    0xC9 => { "" => ["ret"] },
    0xCA => { NNl => { NNh => { "" => ["jp", "z", ",", "NN"] } } },
    0xCB => {
               0x00   => { "" => ["rlc", "b"] },
               0x01   => { "" => ["rlc", "c"] },
               0x02   => { "" => ["rlc", "d"] },
               0x03   => { "" => ["rlc", "e"] },
               0x04   => { "" => ["rlc", "h"] },
               0x05   => { "" => ["rlc", "l"] },
               0x06   => { "" => ["rlc", "(", "hl", ")"] },
               0x07   => { "" => ["rlc", "a"] },
               0x08   => { "" => ["rrc", "b"] },
               0x09   => { "" => ["rrc", "c"] },
               0x0A  => { "" => ["rrc", "d"] },
               0x0B  => { "" => ["rrc", "e"] },
               0x0C  => { "" => ["rrc", "h"] },
               0x0D  => { "" => ["rrc", "l"] },
               0x0E  => { "" => ["rrc", "(", "hl", ")"] },
               0x0F  => { "" => ["rrc", "a"] },
               0x10  => { "" => ["rl", "b"] },
               0x11  => { "" => ["rl", "c"], 0xCB => { 0x10 => { "" => ["rl", "bc"] } } },
               0x12  => { "" => ["rl", "d"] },
               0x13  => { "" => ["rl", "e"], 0xCB => { 0x12 => { "" => ["rl", "de"] } } },
               0x14  => { "" => ["rl", "h"] },
               0x15  => { "" => ["rl", "l"], 0xCB => { 0x14 => { "" => ["rl", "hl"] } } },
               0x16  => { "" => ["rl", "(", "hl", ")"] },
               0x17  => { "" => ["rl", "a"] },
               0x18  => { "" => ["rr", "b"], 0xCB => { 0x19 => { "" => ["rr", "bc"] } } },
               0x19  => { "" => ["rr", "c"] },
               0x1A  => { "" => ["rr", "d"], 0xCB => { 0x1B => { "" => ["rr", "de"] } } },
               0x1B  => { "" => ["rr", "e"] },
               0x1C  => { "" => ["rr", "h"], 0xCB => { 0x1D => { "" => ["rr", "hl"] } } },
               0x1D  => { "" => ["rr", "l"] },
               0x1E  => { "" => ["rr", "(", "hl", ")"] },
               0x1F  => { "" => ["rr", "a"] },
               0x20  => { "" => ["sla", "b"] },
               0x21  => { "" => ["sla", "c"], 0xCB => { 0x10 => { "" => ["sla", "bc"] } } },
               0x22  => { "" => ["sla", "d"] },
               0x23  => { "" => ["sla", "e"], 0xCB => { 0x12 => { "" => ["sla", "de"] } } },
               0x24  => { "" => ["sla", "h"] },
               0x25  => { "" => ["sla", "l"], 0xCB => { 0x14 => { "" => ["sla", "hl"] } } },
               0x26  => { "" => ["sla", "(", "hl", ")"] },
               0x27  => { "" => ["sla", "a"] },
               0x28  => { "" => ["sra", "b"], 0xCB => { 0x19 => { "" => ["sra", "bc"] } } },
               0x29  => { "" => ["sra", "c"] },
               0x2A  => { "" => ["sra", "d"], 0xCB => { 0x1B => { "" => ["sra", "de"] } } },
               0x2B  => { "" => ["sra", "e"] },
               0x2C  => { "" => ["sra", "h"], 0xCB => { 0x1D => { "" => ["sra", "hl"] } } },
               0x2D  => { "" => ["sra", "l"] },
               0x2E  => { "" => ["sra", "(", "hl", ")"] },
               0x2F  => { "" => ["sra", "a"] },
               0x30  => { "" => ["sll", "b"] },
               0x31  => { "" => ["sll", "c"], 0xCB => { 0x10 => { "" => ["sll", "bc"] } } },
               0x32  => { "" => ["sll", "d"] },
               0x33  => { "" => ["sll", "e"], 0xCB => { 0x12 => { "" => ["sll", "de"] } } },
               0x34  => { "" => ["sll", "h"] },
               0x35  => { "" => ["sll", "l"], 0xCB => { 0x14 => { "" => ["sll", "hl"] } } },
               0x36  => { "" => ["sll", "(", "hl", ")"] },
               0x37  => { "" => ["sll", "a"] },
               0x38  => { "" => ["srl", "b"], 0xCB => { 0x19 => { "" => ["srl", "bc"] } } },
               0x39  => { "" => ["srl", "c"] },
               0x3A  => { "" => ["srl", "d"], 0xCB => { 0x1B => { "" => ["srl", "de"] } } },
               0x3B  => { "" => ["srl", "e"] },
               0x3C  => { "" => ["srl", "h"], 0xCB => { 0x1D => { "" => ["srl", "hl"] } } },
               0x3D  => { "" => ["srl", "l"] },
               0x3E  => { "" => ["srl", "(", "hl", ")"] },
               0x3F  => { "" => ["srl", "a"] },
               0x40  => { "" => ["bit", 0x00, ",", "b"] },
               0x41  => { "" => ["bit", 0x00, ",", "c"] },
               0x42  => { "" => ["bit", 0x00, ",", "d"] },
               0x43  => { "" => ["bit", 0x00, ",", "e"] },
               0x44  => { "" => ["bit", 0x00, ",", "h"] },
               0x45  => { "" => ["bit", 0x00, ",", "l"] },
               0x46  => { "" => ["bit", 0x00, ",", "(", "hl", ")"] },
               0x47  => { "" => ["bit", 0x00, ",", "a"] },
               0x48  => { "" => ["bit", 0x01, ",", "b"] },
               0x49  => { "" => ["bit", 0x01, ",", "c"] },
               0x4A  => { "" => ["bit", 0x01, ",", "d"] },
               0x4B  => { "" => ["bit", 0x01, ",", "e"] },
               0x4C  => { "" => ["bit", 0x01, ",", "h"] },
               0x4D  => { "" => ["bit", 0x01, ",", "l"] },
               0x4E  => { "" => ["bit", 0x01, ",", "(", "hl", ")"] },
               0x4F  => { "" => ["bit", 0x01, ",", "a"] },
               0x50  => { "" => ["bit", 0x02, ",", "b"] },
               0x51  => { "" => ["bit", 0x02, ",", "c"] },
               0x52  => { "" => ["bit", 0x02, ",", "d"] },
               0x53  => { "" => ["bit", 0x02, ",", "e"] },
               0x54  => { "" => ["bit", 0x02, ",", "h"] },
               0x55  => { "" => ["bit", 0x02, ",", "l"] },
               0x56  => { "" => ["bit", 0x02, ",", "(", "hl", ")"] },
               0x57  => { "" => ["bit", 0x02, ",", "a"] },
               0x58  => { "" => ["bit", 0x03, ",", "b"] },
               0x59  => { "" => ["bit", 0x03, ",", "c"] },
               0x5A  => { "" => ["bit", 0x03, ",", "d"] },
               0x5B  => { "" => ["bit", 0x03, ",", "e"] },
               0x5C  => { "" => ["bit", 0x03, ",", "h"] },
               0x5D  => { "" => ["bit", 0x03, ",", "l"] },
               0x5E  => { "" => ["bit", 0x03, ",", "(", "hl", ")"] },
               0x5F  => { "" => ["bit", 0x03, ",", "a"] },
               0x60  => { "" => ["bit", 0x04, ",", "b"] },
               0x61  => { "" => ["bit", 0x04, ",", "c"] },
               0x62  => { "" => ["bit", 0x04, ",", "d"] },
               0x63  => { "" => ["bit", 0x04, ",", "e"] },
               0x64 => { "" => ["bit", 0x04, ",", "h"] },
               0x65 => { "" => ["bit", 0x04, ",", "l"] },
               0x66 => { "" => ["bit", 0x04, ",", "(", "hl", ")"] },
               0x67 => { "" => ["bit", 0x04, ",", "a"] },
               0x68 => { "" => ["bit", 0x05, ",", "b"] },
               0x69 => { "" => ["bit", 0x05, ",", "c"] },
               0x6A => { "" => ["bit", 0x05, ",", "d"] },
               0x6B => { "" => ["bit", 0x05, ",", "e"] },
               0x6C => { "" => ["bit", 0x05, ",", "h"] },
               0x6D => { "" => ["bit", 0x05, ",", "l"] },
               0x6E => { "" => ["bit", 0x05, ",", "(", "hl", ")"] },
               0x6F => { "" => ["bit", 0x05, ",", "a"] },
               0x70 => { "" => ["bit", 0x06, ",", "b"] },
               0x71 => { "" => ["bit", 0x06, ",", "c"] },
               0x72 => { "" => ["bit", 0x06, ",", "d"] },
               0x73 => { "" => ["bit", 0x06, ",", "e"] },
               0x74 => { "" => ["bit", 0x06, ",", "h"] },
               0x75 => { "" => ["bit", 0x06, ",", "l"] },
               0x76 => { "" => ["bit", 0x06, ",", "(", "hl", ")"] },
               0x77 => { "" => ["bit", 0x06, ",", "a"] },
               0x78 => { "" => ["bit", 0x07, ",", "b"] },
               0x79 => { "" => ["bit", 0x07, ",", "c"] },
               0x7A => { "" => ["bit", 0x07, ",", "d"] },
               0x7B => { "" => ["bit", 0x07, ",", "e"] },
               0x7C => { "" => ["bit", 0x07, ",", "h"] },
               0x7D => { "" => ["bit", 0x07, ",", "l"] },
               0x7E => { "" => ["bit", 0x07, ",", "(", "hl", ")"] },
               0x7F => { "" => ["bit", 0x07, ",", "a"] },
               0x80 => { "" => ["res", 0x00, ",", "b"] },
               0x81 => { "" => ["res", 0x00, ",", "c"] },
               0x82 => { "" => ["res", 0x00, ",", "d"] },
               0x83 => { "" => ["res", 0x00, ",", "e"] },
               0x84 => { "" => ["res", 0x00, ",", "h"] },
               0x85 => { "" => ["res", 0x00, ",", "l"] },
               0x86 => { "" => ["res", 0x00, ",", "(", "hl", ")"] },
               0x87 => { "" => ["res", 0x00, ",", "a"] },
               0x88 => { "" => ["res", 0x01, ",", "b"] },
               0x89 => { "" => ["res", 0x01, ",", "c"] },
               0x8A => { "" => ["res", 0x01, ",", "d"] },
               0x8B => { "" => ["res", 0x01, ",", "e"] },
               0x8C => { "" => ["res", 0x01, ",", "h"] },
               0x8D => { "" => ["res", 0x01, ",", "l"] },
               0x8E => { "" => ["res", 0x01, ",", "(", "hl", ")"] },
               0x8F => { "" => ["res", 0x01, ",", "a"] },
               0x90 => { "" => ["res", 0x02, ",", "b"] },
               0x91 => { "" => ["res", 0x02, ",", "c"] },
               0x92 => { "" => ["res", 0x02, ",", "d"] },
               0x93 => { "" => ["res", 0x02, ",", "e"] },
               0x94 => { "" => ["res", 0x02, ",", "h"] },
               0x95 => { "" => ["res", 0x02, ",", "l"] },
               0x96 => { "" => ["res", 0x02, ",", "(", "hl", ")"] },
               0x97 => { "" => ["res", 0x02, ",", "a"] },
               0x98 => { "" => ["res", 0x03, ",", "b"] },
               0x99 => { "" => ["res", 0x03, ",", "c"] },
               0x9A => { "" => ["res", 0x03, ",", "d"] },
               0x9B => { "" => ["res", 0x03, ",", "e"] },
               0x9C => { "" => ["res", 0x03, ",", "h"] },
               0x9D => { "" => ["res", 0x03, ",", "l"] },
               0x9E => { "" => ["res", 0x03, ",", "(", "hl", ")"] },
               0x9F => { "" => ["res", 0x03, ",", "a"] },
               0xA0 => { "" => ["res", 0x04, ",", "b"] },
               0xA1 => { "" => ["res", 0x04, ",", "c"] },
               0xA2 => { "" => ["res", 0x04, ",", "d"] },
               0xA3 => { "" => ["res", 0x04, ",", "e"] },
               0xA4 => { "" => ["res", 0x04, ",", "h"] },
               0xA5 => { "" => ["res", 0x04, ",", "l"] },
               0xA6 => { "" => ["res", 0x04, ",", "(", "hl", ")"] },
               0xA7 => { "" => ["res", 0x04, ",", "a"] },
               0xA8 => { "" => ["res", 0x05, ",", "b"] },
               0xA9 => { "" => ["res", 0x05, ",", "c"] },
               0xAA => { "" => ["res", 0x05, ",", "d"] },
               0xAB => { "" => ["res", 0x05, ",", "e"] },
               0xAC => { "" => ["res", 0x05, ",", "h"] },
               0xAD => { "" => ["res", 0x05, ",", "l"] },
               0xAE => { "" => ["res", 0x05, ",", "(", "hl", ")"] },
               0xAF => { "" => ["res", 0x05, ",", "a"] },
               0xB0 => { "" => ["res", 0x06, ",", "b"] },
               0xB1 => { "" => ["res", 0x06, ",", "c"] },
               0xB2 => { "" => ["res", 0x06, ",", "d"] },
               0xB3 => { "" => ["res", 0x06, ",", "e"] },
               0xB4 => { "" => ["res", 0x06, ",", "h"] },
               0xB5 => { "" => ["res", 0x06, ",", "l"] },
               0xB6 => { "" => ["res", 0x06, ",", "(", "hl", ")"] },
               0xB7 => { "" => ["res", 0x06, ",", "a"] },
               0xB8 => { "" => ["res", 0x07, ",", "b"] },
               0xB9 => { "" => ["res", 0x07, ",", "c"] },
               0xBA => { "" => ["res", 0x07, ",", "d"] },
               0xBB => { "" => ["res", 0x07, ",", "e"] },
               0xBC => { "" => ["res", 0x07, ",", "h"] },
               0xBD => { "" => ["res", 0x07, ",", "l"] },
               0xBE => { "" => ["res", 0x07, ",", "(", "hl", ")"] },
               0xBF => { "" => ["res", 0x07, ",", "a"] },
               0xC0 => { "" => ["set", 0x00, ",", "b"] },
               0xC1 => { "" => ["set", 0x00, ",", "c"] },
               0xC2 => { "" => ["set", 0x00, ",", "d"] },
               0xC3 => { "" => ["set", 0x00, ",", "e"] },
               0xC4 => { "" => ["set", 0x00, ",", "h"] },
               0xC5 => { "" => ["set", 0x00, ",", "l"] },
               0xC6 => { "" => ["set", 0x00, ",", "(", "hl", ")"] },
               0xC7 => { "" => ["set", 0x00, ",", "a"] },
               0xC8 => { "" => ["set", 0x01, ",", "b"] },
               0xC9 => { "" => ["set", 0x01, ",", "c"] },
               0xCA => { "" => ["set", 0x01, ",", "d"] },
               0xCB => { "" => ["set", 0x01, ",", "e"] },
               0xCC => { "" => ["set", 0x01, ",", "h"] },
               0xCD => { "" => ["set", 0x01, ",", "l"] },
               0xCE => { "" => ["set", 0x01, ",", "(", "hl", ")"] },
               0xCF => { "" => ["set", 0x01, ",", "a"] },
               0xD0 => { "" => ["set", 0x02, ",", "b"] },
               0xD1 => { "" => ["set", 0x02, ",", "c"] },
               0xD2 => { "" => ["set", 0x02, ",", "d"] },
               0xD3 => { "" => ["set", 0x02, ",", "e"] },
               0xD4 => { "" => ["set", 0x02, ",", "h"] },
               0xD5 => { "" => ["set", 0x02, ",", "l"] },
               0xD6 => { "" => ["set", 0x02, ",", "(", "hl", ")"] },
               0xD7 => { "" => ["set", 0x02, ",", "a"] },
               0xD8 => { "" => ["set", 0x03, ",", "b"] },
               0xD9 => { "" => ["set", 0x03, ",", "c"] },
               0xDA => { "" => ["set", 0x03, ",", "d"] },
               0xDB => { "" => ["set", 0x03, ",", "e"] },
               0xDC => { "" => ["set", 0x03, ",", "h"] },
               0xDD => { "" => ["set", 0x03, ",", "l"] },
               0xDE => { "" => ["set", 0x03, ",", "(", "hl", ")"] },
               0xDF => { "" => ["set", 0x03, ",", "a"] },
               0xE0 => { "" => ["set", 0x04, ",", "b"] },
               0xE1 => { "" => ["set", 0x04, ",", "c"] },
               0xE2 => { "" => ["set", 0x04, ",", "d"] },
               0xE3 => { "" => ["set", 0x04, ",", "e"] },
               0xE4 => { "" => ["set", 0x04, ",", "h"] },
               0xE5 => { "" => ["set", 0x04, ",", "l"] },
               0xE6 => { "" => ["set", 0x04, ",", "(", "hl", ")"] },
               0xE7 => { "" => ["set", 0x04, ",", "a"] },
               0xE8 => { "" => ["set", 0x05, ",", "b"] },
               0xE9 => { "" => ["set", 0x05, ",", "c"] },
               0xEA => { "" => ["set", 0x05, ",", "d"] },
               0xEB => { "" => ["set", 0x05, ",", "e"] },
               0xEC => { "" => ["set", 0x05, ",", "h"] },
               0xED => { "" => ["set", 0x05, ",", "l"] },
               0xEE => { "" => ["set", 0x05, ",", "(", "hl", ")"] },
               0xEF => { "" => ["set", 0x05, ",", "a"] },
               0xF0 => { "" => ["set", 0x06, ",", "b"] },
               0xF1 => { "" => ["set", 0x06, ",", "c"] },
               0xF2 => { "" => ["set", 0x06, ",", "d"] },
               0xF3 => { "" => ["set", 0x06, ",", "e"] },
               0xF4 => { "" => ["set", 0x06, ",", "h"] },
               0xF5 => { "" => ["set", 0x06, ",", "l"] },
               0xF6 => { "" => ["set", 0x06, ",", "(", "hl", ")"] },
               0xF7 => { "" => ["set", 0x06, ",", "a"] },
               0xF8 => { "" => ["set", 0x07, ",", "b"] },
               0xF9 => { "" => ["set", 0x07, ",", "c"] },
               0xFA => { "" => ["set", 0x07, ",", "d"] },
               0xFB => { "" => ["set", 0x07, ",", "e"] },
               0xFC => { "" => ["set", 0x07, ",", "h"] },
               0xFD => { "" => ["set", 0x07, ",", "l"] },
               0xFE => { "" => ["set", 0x07, ",", "(", "hl", ")"] },
               0xFF => { "" => ["set", 0x07, ",", "a"] },
             },
    0xCC => { NNl => { NNh => { "" => ["call", "z", ",", "NN"] } } },
    0xCD => { NNl => { NNh => { "" => ["call", "NN"] } } },
    0xCE => { N => { "" => ["adc", "a", ",", "N"] } },
    0xCF => { "" => ["rst", 0x08] },
    0xD0 => { "" => ["ret", "nc"] },
    0xD1 => { "" => ["pop", "de"] },
    0xD2 => { NNl => { NNh => { "" => ["jp", "nc", ",", "NN"] } } },
    0xD3 => { N => { "" => ["out", "(", "N", ")", ",", "a"] } },
    0xD4 => { NNl => { NNh => { "" => ["call", "nc", ",", "NN"] } } },
    0xD5 => { "" => ["push", "de"] },
    0xD6 => { N => { "" => ["sub", "N"] } },
    0xD7 => { "" => ["rst", 0x10] },
    0xD8 => { "" => ["ret", "c"] },
    0xD9 => { "" => ["exx"] },
    0xDA => { NNl => { NNh => { "" => ["jp", "c", ",", "NN"] } } },
    0xDB => { N => { "" => ["in", "a", ",", "(", "N", ")"] } },
    0xDC => { NNl => { NNh => { "" => ["call", "c", ",", "NN"] } } },
    0xDD => {
               0x03   => { "" => ["inc", "bc"] },
               0x04   => { "" => ["inc", "b"] },
               0x05   => { "" => ["dec", "b"] },
               0x06   => { N => { "" => ["ld", "b", ",", "N"] } },
               0x09   => { "" => ["add", "ix", ",", "bc"] },
               0x0B  => { "" => ["dec", "bc"] },
               0x0C  => { "" => ["inc", "c"] },
               0x0D  => { "" => ["dec", "c"] },
               0x0E  => { N => { "" => ["ld", "c", ",", "N"] } },
               0x13  => { "" => ["inc", "de"] },
               0x14  => { "" => ["inc", "d"] },
               0x15  => { "" => ["dec", "d"] },
               0x16  => { N => { "" => ["ld", "d", ",", "N"] } },
               0x19  => { "" => ["add", "ix", ",", "de"] },
               0x1B  => { "" => ["dec", "de"] },
               0x1C  => { "" => ["inc", "e"] },
               0x1D  => { "" => ["dec", "e"] },
               0x1E  => { N => { "" => ["ld", "e", ",", "N"] } },
               0x21  => { NNl => { NNh => { "" => ["ld", "ix", ",", "NN"] } } },
               0x22  => { NNl => { NNh => { "" => ["ld", "(", "NN", ")", ",", "ix"] } } },
               0x23  => { "" => ["inc", "ix"] },
               0x24  => { "" => ["inc", "ixh"] },
               0x25  => { "" => ["dec", "ixh"] },
               0x26  => { N => { "" => ["ld", "ixh", ",", "N"] } },
               0x29  => { "" => ["add", "ix", ",", "ix"] },
               0x2A  => { NNl => { NNh => { "" => ["ld", "ix", ",", "(", "NN", ")"] } } },
               0x2B  => { "" => ["dec", "ix"] },
               0x2C  => { "" => ["inc", "ixl"] },
               0x2D  => { "" => ["dec", "ixl"] },
               0x2E  => { N => { "" => ["ld", "ixl", ",", "N"] } },
               0x33  => { "" => ["inc", "sp"] },
               0x34  => {
                        0x00 => { "" => ["inc", "(", "ix", ")"] },
                        "DIS" => { "" => ["inc", "(", "ix", "+", "DIS", ")"] },
                        "NDIS" => { "" => ["inc", "(", "ix", "-", "NDIS", ")"] },
                      },
               0x35  => {
                        0x00 => { "" => ["dec", "(", "ix", ")"] },
                        "DIS" => { "" => ["dec", "(", "ix", "+", "DIS", ")"] },
                        "NDIS" => { "" => ["dec", "(", "ix", "-", "NDIS", ")"] },
                      },
               0x36  => {
                        0x00 => {
                          N => {
                                 "" => ["ld", "(", "ix", ")", ",", "N"],
                                 0xDD => {
                                   0x23 => { "" => ["ldi", "(", "ix", ")", ",", "N"] },
                                   0x2B => { "" => ["ldd", "(", "ix", ")", ",", "N"] },
                                 },
                               },
                        },
                        "DIS" => {
                          N => {
                                 "" => ["ld", "(", "ix", "+", "DIS", ")", ",", "N"],
                                 0xDD => {
                                   0x23 => { "" => ["ldi", "(", "ix", "+", "DIS", ")", ",", "N"] },
                                   0x2B => { "" => ["ldd", "(", "ix", "+", "DIS", ")", ",", "N"] },
                                 },
                               },
                        },
                        "NDIS" => {
                          N => {
                                 "" => ["ld", "(", "ix", "-", "NDIS", ")", ",", "N"],
                                 0xDD => {
                                   0x23 => { "" => ["ldi", "(", "ix", "-", "NDIS", ")", ",", "N"] },
                                   0x2B => { "" => ["ldd", "(", "ix", "-", "NDIS", ")", ",", "N"] },
                                 },
                               },
                        },
                      },
               0x39  => { "" => ["add", "ix", ",", "sp"] },
               0x3B  => { "" => ["dec", "sp"] },
               0x3C  => { "" => ["inc", "a"] },
               0x3D  => { "" => ["dec", "a"] },
               0x3E  => { N => { "" => ["ld", "a", ",", "N"] } },
               0x40  => { "" => ["ld", "b", ",", "b"] },
               0x41  => { "" => ["ld", "b", ",", "c"] },
               0x42  => { "" => ["ld", "b", ",", "d"] },
               0x43  => { "" => ["ld", "b", ",", "e"] },
               0x44  => {
                        "" => ["ld", "b", ",", "ixh"],
                        0xDD => { 0x4D => { "" => ["ld", "bc", ",", "ix"] } },
                      },
               0x45  => { "" => ["ld", "b", ",", "ixl"] },
               0x46  => {
                        0x00 => {
                          "" => ["ld", "b", ",", "(", "ix", ")"],
                          0xDD => {
                            0x23 => { "" => ["ldi", "b", ",", "(", "ix", ")"] },
                            0x2B => { "" => ["ldd", "b", ",", "(", "ix", ")"] },
                          },
                        },
                        "DIS" => {
                          "" => ["ld", "b", ",", "(", "ix", "+", "DIS", ")"],
                          0xDD => {
                            0x23 => { "" => ["ldi", "b", ",", "(", "ix", "+", "DIS", ")"] },
                            0x2B => { "" => ["ldd", "b", ",", "(", "ix", "+", "DIS", ")"] },
                          },
                        },
                        "NDIS" => {
                          "" => ["ld", "b", ",", "(", "ix", "-", "NDIS", ")"],
                          0xDD => {
                            0x23 => { "" => ["ldi", "b", ",", "(", "ix", "-", "NDIS", ")"] },
                            0x2B => { "" => ["ldd", "b", ",", "(", "ix", "-", "NDIS", ")"] },
                          },
                        },
                      },
               0x47  => { "" => ["ld", "b", ",", "a"] },
               0x48  => { "" => ["ld", "c", ",", "b"] },
               0x49  => { "" => ["ld", "c", ",", "c"] },
               0x4A  => { "" => ["ld", "c", ",", "d"] },
               0x4B  => { "" => ["ld", "c", ",", "e"] },
               0x4C  => { "" => ["ld", "c", ",", "ixh"] },
               0x4D  => { "" => ["ld", "c", ",", "ixl"] },
               0x4E  => {
                        0x00 => {
                          "" => ["ld", "c", ",", "(", "ix", ")"],
                          0xDD => {
                            0x23 => {
                                    "" => ["ldi", "c", ",", "(", "ix", ")"],
                                    0xDD => {
                                      0x46 => {
                                              0x00 => { 0xDD => { 0x23 => { "" => ["ldi", "bc", ",", "(", "ix", ")"] } } },
                                            },
                                    },
                                  },
                            0x2B => { "" => ["ldd", "c", ",", "(", "ix", ")"] },
                            0x46 => { 0x01 => { "" => ["ld", "bc", ",", "(", "ix", ")"] } },
                          },
                        },
                        "DIS" => {
                          "" => ["ld", "c", ",", "(", "ix", "+", "DIS", ")"],
                          0xDD => {
                            0x23 => {
                                    "" => ["ldi", "c", ",", "(", "ix", "+", "DIS", ")"],
                                    0xDD => {
                                      0x46 => {
                                              DIS => {
                                                       0xDD => { 0x23 => { "" => ["ldi", "bc", ",", "(", "ix", "+", "DIS", ")"] } },
                                                     },
                                            },
                                    },
                                  },
                            0x2B => { "" => ["ldd", "c", ",", "(", "ix", "+", "DIS", ")"] },
                            0x46 => {
                                    "DIS+0x01" => { "" => ["ld", "bc", ",", "(", "ix", "+", "DIS", ")"] },
                                  },
                          },
                        },
                        "NDIS" => {
                          "" => ["ld", "c", ",", "(", "ix", "-", "NDIS", ")"],
                          0xDD => {
                            0x23 => {
                                    "" => ["ldi", "c", ",", "(", "ix", "-", "NDIS", ")"],
                                    0xDD => {
                                      0x46 => {
                                              NDIS => {
                                                0xDD => { 0x23 => { "" => ["ldi", "bc", ",", "(", "ix", "-", "NDIS", ")"] } },
                                              },
                                            },
                                    },
                                  },
                            0x2B => { "" => ["ldd", "c", ",", "(", "ix", "-", "NDIS", ")"] },
                            0x46 => {
                                    "NDIS+0x01" => { "" => ["ld", "bc", ",", "(", "ix", "-", "NDIS", ")"] },
                                  },
                          },
                        },
                      },
               0x4F  => { "" => ["ld", "c", ",", "a"] },
               0x50  => { "" => ["ld", "d", ",", "b"] },
               0x51  => { "" => ["ld", "d", ",", "c"] },
               0x52  => { "" => ["ld", "d", ",", "d"] },
               0x53  => { "" => ["ld", "d", ",", "e"] },
               0x54  => {
                        "" => ["ld", "d", ",", "ixh"],
                        0xDD => { 0x5D => { "" => ["ld", "de", ",", "ix"] } },
                      },
               0x55  => { "" => ["ld", "d", ",", "ixl"] },
               0x56  => {
                        0x00 => {
                          "" => ["ld", "d", ",", "(", "ix", ")"],
                          0xDD => {
                            0x23 => { "" => ["ldi", "d", ",", "(", "ix", ")"] },
                            0x2B => { "" => ["ldd", "d", ",", "(", "ix", ")"] },
                          },
                        },
                        "DIS" => {
                          "" => ["ld", "d", ",", "(", "ix", "+", "DIS", ")"],
                          0xDD => {
                            0x23 => { "" => ["ldi", "d", ",", "(", "ix", "+", "DIS", ")"] },
                            0x2B => { "" => ["ldd", "d", ",", "(", "ix", "+", "DIS", ")"] },
                          },
                        },
                        "NDIS" => {
                          "" => ["ld", "d", ",", "(", "ix", "-", "NDIS", ")"],
                          0xDD => {
                            0x23 => { "" => ["ldi", "d", ",", "(", "ix", "-", "NDIS", ")"] },
                            0x2B => { "" => ["ldd", "d", ",", "(", "ix", "-", "NDIS", ")"] },
                          },
                        },
                      },
               0x57  => { "" => ["ld", "d", ",", "a"] },
               0x58  => { "" => ["ld", "e", ",", "b"] },
               0x59  => { "" => ["ld", "e", ",", "c"] },
               0x5A  => { "" => ["ld", "e", ",", "d"] },
               0x5B  => { "" => ["ld", "e", ",", "e"] },
               0x5C  => { "" => ["ld", "e", ",", "ixh"] },
               0x5D  => { "" => ["ld", "e", ",", "ixl"] },
               0x5E  => {
                        0x00 => {
                          "" => ["ld", "e", ",", "(", "ix", ")"],
                          0xDD => {
                            0x23 => {
                                    "" => ["ldi", "e", ",", "(", "ix", ")"],
                                    0xDD => {
                                      0x56 => {
                                              0x00 => { 0xDD => { 0x23 => { "" => ["ldi", "de", ",", "(", "ix", ")"] } } },
                                            },
                                    },
                                  },
                            0x2B => { "" => ["ldd", "e", ",", "(", "ix", ")"] },
                            0x56 => { 0x01 => { "" => ["ld", "de", ",", "(", "ix", ")"] } },
                          },
                        },
                        "DIS" => {
                          "" => ["ld", "e", ",", "(", "ix", "+", "DIS", ")"],
                          0xDD => {
                            0x23 => {
                                    "" => ["ldi", "e", ",", "(", "ix", "+", "DIS", ")"],
                                    0xDD => {
                                      0x56 => {
                                              DIS => {
                                                       0xDD => { 0x23 => { "" => ["ldi", "de", ",", "(", "ix", "+", "DIS", ")"] } },
                                                     },
                                            },
                                    },
                                  },
                            0x2B => { "" => ["ldd", "e", ",", "(", "ix", "+", "DIS", ")"] },
                            0x56 => {
                                    "DIS+0x01" => { "" => ["ld", "de", ",", "(", "ix", "+", "DIS", ")"] },
                                  },
                          },
                        },
                        "NDIS" => {
                          "" => ["ld", "e", ",", "(", "ix", "-", "NDIS", ")"],
                          0xDD => {
                            0x23 => {
                                    "" => ["ldi", "e", ",", "(", "ix", "-", "NDIS", ")"],
                                    0xDD => {
                                      0x56 => {
                                              NDIS => {
                                                0xDD => { 0x23 => { "" => ["ldi", "de", ",", "(", "ix", "-", "NDIS", ")"] } },
                                              },
                                            },
                                    },
                                  },
                            0x2B => { "" => ["ldd", "e", ",", "(", "ix", "-", "NDIS", ")"] },
                            0x56 => {
                                    "NDIS+0x01" => { "" => ["ld", "de", ",", "(", "ix", "-", "NDIS", ")"] },
                                  },
                          },
                        },
                      },
               0x5F  => { "" => ["ld", "e", ",", "a"] },
               0x60  => { "" => ["ld", "ixh", ",", "b"] },
               0x61  => { "" => ["ld", "ixh", ",", "c"] },
               0x62  => { "" => ["ld", "ixh", ",", "d"] },
               0x63  => { "" => ["ld", "ixh", ",", "e"] },
               0x64 => { "" => ["ld", "ixh", ",", "ixh"] },
               0x65 => { "" => ["ld", "ixh", ",", "ixl"] },
               0x66 => {
                        0x00 => {
                          "" => ["ld", "h", ",", "(", "ix", ")"],
                          0xDD => {
                            0x23 => { "" => ["ldi", "h", ",", "(", "ix", ")"] },
                            0x2B => { "" => ["ldd", "h", ",", "(", "ix", ")"] },
                          },
                        },
                        "DIS" => {
                          "" => ["ld", "h", ",", "(", "ix", "+", "DIS", ")"],
                          0xDD => {
                            0x23 => { "" => ["ldi", "h", ",", "(", "ix", "+", "DIS", ")"] },
                            0x2B => { "" => ["ldd", "h", ",", "(", "ix", "+", "DIS", ")"] },
                          },
                        },
                        "NDIS" => {
                          "" => ["ld", "h", ",", "(", "ix", "-", "NDIS", ")"],
                          0xDD => {
                            0x23 => { "" => ["ldi", "h", ",", "(", "ix", "-", "NDIS", ")"] },
                            0x2B => { "" => ["ldd", "h", ",", "(", "ix", "-", "NDIS", ")"] },
                          },
                        },
                      },
               0x67 => { "" => ["ld", "ixh", ",", "a"] },
               0x68 => { "" => ["ld", "ixl", ",", "b"] },
               0x69 => {
                        "" => ["ld", "ixl", ",", "c"],
                        0xDD => { 0x60 => { "" => ["ld", "ix", ",", "bc"] } },
                      },
               0x6A => { "" => ["ld", "ixl", ",", "d"] },
               0x6B => {
                        "" => ["ld", "ixl", ",", "e"],
                        0xDD => { 0x62 => { "" => ["ld", "ix", ",", "de"] } },
                      },
               0x6C => { "" => ["ld", "ixl", ",", "ixh"] },
               0x6D => {
                        "" => ["ld", "ixl", ",", "ixl"],
                        0xDD => { 0x64 => { "" => ["ld", "ix", ",", "ix"] } },
                      },
               0x6E => {
                        0x00 => {
                          "" => ["ld", "l", ",", "(", "ix", ")"],
                          0xDD => {
                            0x23  => {
                                     "" => ["ldi", "l", ",", "(", "ix", ")"],
                                     0xDD => {
                                       0x66 => {
                                                0x00 => { 0xDD => { 0x23 => { "" => ["ldi", "hl", ",", "(", "ix", ")"] } } },
                                              },
                                     },
                                   },
                            0x2B  => { "" => ["ldd", "l", ",", "(", "ix", ")"] },
                            0x66 => { 0x01 => { "" => ["ld", "hl", ",", "(", "ix", ")"] } },
                          },
                        },
                        "DIS" => {
                          "" => ["ld", "l", ",", "(", "ix", "+", "DIS", ")"],
                          0xDD => {
                            0x23  => {
                                     "" => ["ldi", "l", ",", "(", "ix", "+", "DIS", ")"],
                                     0xDD => {
                                       0x66 => {
                                                DIS => {
                                                         0xDD => { 0x23 => { "" => ["ldi", "hl", ",", "(", "ix", "+", "DIS", ")"] } },
                                                       },
                                              },
                                     },
                                   },
                            0x2B  => { "" => ["ldd", "l", ",", "(", "ix", "+", "DIS", ")"] },
                            0x66 => {
                                     "DIS+0x01" => { "" => ["ld", "hl", ",", "(", "ix", "+", "DIS", ")"] },
                                   },
                          },
                        },
                        "NDIS" => {
                          "" => ["ld", "l", ",", "(", "ix", "-", "NDIS", ")"],
                          0xDD => {
                            0x23  => {
                                     "" => ["ldi", "l", ",", "(", "ix", "-", "NDIS", ")"],
                                     0xDD => {
                                       0x66 => {
                                                NDIS => {
                                                  0xDD => { 0x23 => { "" => ["ldi", "hl", ",", "(", "ix", "-", "NDIS", ")"] } },
                                                },
                                              },
                                     },
                                   },
                            0x2B  => { "" => ["ldd", "l", ",", "(", "ix", "-", "NDIS", ")"] },
                            0x66 => {
                                     "NDIS+0x01" => { "" => ["ld", "hl", ",", "(", "ix", "-", "NDIS", ")"] },
                                   },
                          },
                        },
                      },
               0x6F => { "" => ["ld", "ixl", ",", "a"] },
               0x70 => {
                        0x00 => {
                          "" => ["ld", "(", "ix", ")", ",", "b"],
                          0xDD => {
                            0x23 => { "" => ["ldi", "(", "ix", ")", ",", "b"] },
                            0x2B => { "" => ["ldd", "(", "ix", ")", ",", "b"] },
                          },
                        },
                        "DIS" => {
                          "" => ["ld", "(", "ix", "+", "DIS", ")", ",", "b"],
                          0xDD => {
                            0x23 => { "" => ["ldi", "(", "ix", "+", "DIS", ")", ",", "b"] },
                            0x2B => { "" => ["ldd", "(", "ix", "+", "DIS", ")", ",", "b"] },
                          },
                        },
                        "NDIS" => {
                          "" => ["ld", "(", "ix", "-", "NDIS", ")", ",", "b"],
                          0xDD => {
                            0x23 => { "" => ["ldi", "(", "ix", "-", "NDIS", ")", ",", "b"] },
                            0x2B => { "" => ["ldd", "(", "ix", "-", "NDIS", ")", ",", "b"] },
                          },
                        },
                      },
               0x71 => {
                        0x00 => {
                          "" => ["ld", "(", "ix", ")", ",", "c"],
                          0xDD => {
                            0x23  => {
                                     "" => ["ldi", "(", "ix", ")", ",", "c"],
                                     0xDD => {
                                       0x70 => {
                                                0x00 => { 0xDD => { 0x23 => { "" => ["ldi", "(", "ix", ")", ",", "bc"] } } },
                                              },
                                     },
                                   },
                            0x2B  => { "" => ["ldd", "(", "ix", ")", ",", "c"] },
                            0x70 => { 0x01 => { "" => ["ld", "(", "ix", ")", ",", "bc"] } },
                          },
                        },
                        "DIS" => {
                          "" => ["ld", "(", "ix", "+", "DIS", ")", ",", "c"],
                          0xDD => {
                            0x23  => {
                                     "" => ["ldi", "(", "ix", "+", "DIS", ")", ",", "c"],
                                     0xDD => {
                                       0x70 => {
                                                DIS => {
                                                         0xDD => { 0x23 => { "" => ["ldi", "(", "ix", "+", "DIS", ")", ",", "bc"] } },
                                                       },
                                              },
                                     },
                                   },
                            0x2B  => { "" => ["ldd", "(", "ix", "+", "DIS", ")", ",", "c"] },
                            0x70 => {
                                     "DIS+0x01" => { "" => ["ld", "(", "ix", "+", "DIS", ")", ",", "bc"] },
                                   },
                          },
                        },
                        "NDIS" => {
                          "" => ["ld", "(", "ix", "-", "NDIS", ")", ",", "c"],
                          0xDD => {
                            0x23  => {
                                     "" => ["ldi", "(", "ix", "-", "NDIS", ")", ",", "c"],
                                     0xDD => {
                                       0x70 => {
                                                NDIS => {
                                                  0xDD => { 0x23 => { "" => ["ldi", "(", "ix", "-", "NDIS", ")", ",", "bc"] } },
                                                },
                                              },
                                     },
                                   },
                            0x2B  => { "" => ["ldd", "(", "ix", "-", "NDIS", ")", ",", "c"] },
                            0x70 => {
                                     "NDIS+0x01" => { "" => ["ld", "(", "ix", "-", "NDIS", ")", ",", "bc"] },
                                   },
                          },
                        },
                      },
               0x72 => {
                        0x00 => {
                          "" => ["ld", "(", "ix", ")", ",", "d"],
                          0xDD => {
                            0x23 => { "" => ["ldi", "(", "ix", ")", ",", "d"] },
                            0x2B => { "" => ["ldd", "(", "ix", ")", ",", "d"] },
                          },
                        },
                        "DIS" => {
                          "" => ["ld", "(", "ix", "+", "DIS", ")", ",", "d"],
                          0xDD => {
                            0x23 => { "" => ["ldi", "(", "ix", "+", "DIS", ")", ",", "d"] },
                            0x2B => { "" => ["ldd", "(", "ix", "+", "DIS", ")", ",", "d"] },
                          },
                        },
                        "NDIS" => {
                          "" => ["ld", "(", "ix", "-", "NDIS", ")", ",", "d"],
                          0xDD => {
                            0x23 => { "" => ["ldi", "(", "ix", "-", "NDIS", ")", ",", "d"] },
                            0x2B => { "" => ["ldd", "(", "ix", "-", "NDIS", ")", ",", "d"] },
                          },
                        },
                      },
               0x73 => {
                        0x00 => {
                          "" => ["ld", "(", "ix", ")", ",", "e"],
                          0xDD => {
                            0x23  => {
                                     "" => ["ldi", "(", "ix", ")", ",", "e"],
                                     0xDD => {
                                       0x72 => {
                                                0x00 => { 0xDD => { 0x23 => { "" => ["ldi", "(", "ix", ")", ",", "de"] } } },
                                              },
                                     },
                                   },
                            0x2B  => { "" => ["ldd", "(", "ix", ")", ",", "e"] },
                            0x72 => { 0x01 => { "" => ["ld", "(", "ix", ")", ",", "de"] } },
                          },
                        },
                        "DIS" => {
                          "" => ["ld", "(", "ix", "+", "DIS", ")", ",", "e"],
                          0xDD => {
                            0x23  => {
                                     "" => ["ldi", "(", "ix", "+", "DIS", ")", ",", "e"],
                                     0xDD => {
                                       0x72 => {
                                                DIS => {
                                                         0xDD => { 0x23 => { "" => ["ldi", "(", "ix", "+", "DIS", ")", ",", "de"] } },
                                                       },
                                              },
                                     },
                                   },
                            0x2B  => { "" => ["ldd", "(", "ix", "+", "DIS", ")", ",", "e"] },
                            0x72 => {
                                     "DIS+0x01" => { "" => ["ld", "(", "ix", "+", "DIS", ")", ",", "de"] },
                                   },
                          },
                        },
                        "NDIS" => {
                          "" => ["ld", "(", "ix", "-", "NDIS", ")", ",", "e"],
                          0xDD => {
                            0x23  => {
                                     "" => ["ldi", "(", "ix", "-", "NDIS", ")", ",", "e"],
                                     0xDD => {
                                       0x72 => {
                                                NDIS => {
                                                  0xDD => { 0x23 => { "" => ["ldi", "(", "ix", "-", "NDIS", ")", ",", "de"] } },
                                                },
                                              },
                                     },
                                   },
                            0x2B  => { "" => ["ldd", "(", "ix", "-", "NDIS", ")", ",", "e"] },
                            0x72 => {
                                     "NDIS+0x01" => { "" => ["ld", "(", "ix", "-", "NDIS", ")", ",", "de"] },
                                   },
                          },
                        },
                      },
               0x74 => {
                        0x00 => {
                          "" => ["ld", "(", "ix", ")", ",", "h"],
                          0xDD => {
                            0x23 => { "" => ["ldi", "(", "ix", ")", ",", "h"] },
                            0x2B => { "" => ["ldd", "(", "ix", ")", ",", "h"] },
                          },
                        },
                        "DIS" => {
                          "" => ["ld", "(", "ix", "+", "DIS", ")", ",", "h"],
                          0xDD => {
                            0x23 => { "" => ["ldi", "(", "ix", "+", "DIS", ")", ",", "h"] },
                            0x2B => { "" => ["ldd", "(", "ix", "+", "DIS", ")", ",", "h"] },
                          },
                        },
                        "NDIS" => {
                          "" => ["ld", "(", "ix", "-", "NDIS", ")", ",", "h"],
                          0xDD => {
                            0x23 => { "" => ["ldi", "(", "ix", "-", "NDIS", ")", ",", "h"] },
                            0x2B => { "" => ["ldd", "(", "ix", "-", "NDIS", ")", ",", "h"] },
                          },
                        },
                      },
               0x75 => {
                        0x00 => {
                          "" => ["ld", "(", "ix", ")", ",", "l"],
                          0xDD => {
                            0x23  => {
                                     "" => ["ldi", "(", "ix", ")", ",", "l"],
                                     0xDD => {
                                       0x74 => {
                                                0x00 => { 0xDD => { 0x23 => { "" => ["ldi", "(", "ix", ")", ",", "hl"] } } },
                                              },
                                     },
                                   },
                            0x2B  => { "" => ["ldd", "(", "ix", ")", ",", "l"] },
                            0x74 => { 0x01 => { "" => ["ld", "(", "ix", ")", ",", "hl"] } },
                          },
                        },
                        "DIS" => {
                          "" => ["ld", "(", "ix", "+", "DIS", ")", ",", "l"],
                          0xDD => {
                            0x23  => {
                                     "" => ["ldi", "(", "ix", "+", "DIS", ")", ",", "l"],
                                     0xDD => {
                                       0x74 => {
                                                DIS => {
                                                         0xDD => { 0x23 => { "" => ["ldi", "(", "ix", "+", "DIS", ")", ",", "hl"] } },
                                                       },
                                              },
                                     },
                                   },
                            0x2B  => { "" => ["ldd", "(", "ix", "+", "DIS", ")", ",", "l"] },
                            0x74 => {
                                     "DIS+0x01" => { "" => ["ld", "(", "ix", "+", "DIS", ")", ",", "hl"] },
                                   },
                          },
                        },
                        "NDIS" => {
                          "" => ["ld", "(", "ix", "-", "NDIS", ")", ",", "l"],
                          0xDD => {
                            0x23  => {
                                     "" => ["ldi", "(", "ix", "-", "NDIS", ")", ",", "l"],
                                     0xDD => {
                                       0x74 => {
                                                NDIS => {
                                                  0xDD => { 0x23 => { "" => ["ldi", "(", "ix", "-", "NDIS", ")", ",", "hl"] } },
                                                },
                                              },
                                     },
                                   },
                            0x2B  => { "" => ["ldd", "(", "ix", "-", "NDIS", ")", ",", "l"] },
                            0x74 => {
                                     "NDIS+0x01" => { "" => ["ld", "(", "ix", "-", "NDIS", ")", ",", "hl"] },
                                   },
                          },
                        },
                      },
               0x77 => {
                        0x00 => {
                          "" => ["ld", "(", "ix", ")", ",", "a"],
                          0xDD => {
                            0x23 => { "" => ["ldi", "(", "ix", ")", ",", "a"] },
                            0x2B => { "" => ["ldd", "(", "ix", ")", ",", "a"] },
                          },
                        },
                        "DIS" => {
                          "" => ["ld", "(", "ix", "+", "DIS", ")", ",", "a"],
                          0xDD => {
                            0x23 => { "" => ["ldi", "(", "ix", "+", "DIS", ")", ",", "a"] },
                            0x2B => { "" => ["ldd", "(", "ix", "+", "DIS", ")", ",", "a"] },
                          },
                        },
                        "NDIS" => {
                          "" => ["ld", "(", "ix", "-", "NDIS", ")", ",", "a"],
                          0xDD => {
                            0x23 => { "" => ["ldi", "(", "ix", "-", "NDIS", ")", ",", "a"] },
                            0x2B => { "" => ["ldd", "(", "ix", "-", "NDIS", ")", ",", "a"] },
                          },
                        },
                      },
               0x78 => { "" => ["ld", "a", ",", "b"] },
               0x79 => { "" => ["ld", "a", ",", "c"] },
               0x7A => { "" => ["ld", "a", ",", "d"] },
               0x7B => { "" => ["ld", "a", ",", "e"] },
               0x7C => { "" => ["ld", "a", ",", "ixh"] },
               0x7D => { "" => ["ld", "a", ",", "ixl"] },
               0x7E => {
                        0x00 => {
                          "" => ["ld", "a", ",", "(", "ix", ")"],
                          0xDD => {
                            0x23 => { "" => ["ldi", "a", ",", "(", "ix", ")"] },
                            0x2B => { "" => ["ldd", "a", ",", "(", "ix", ")"] },
                          },
                        },
                        "DIS" => {
                          "" => ["ld", "a", ",", "(", "ix", "+", "DIS", ")"],
                          0xDD => {
                            0x23 => { "" => ["ldi", "a", ",", "(", "ix", "+", "DIS", ")"] },
                            0x2B => { "" => ["ldd", "a", ",", "(", "ix", "+", "DIS", ")"] },
                          },
                        },
                        "NDIS" => {
                          "" => ["ld", "a", ",", "(", "ix", "-", "NDIS", ")"],
                          0xDD => {
                            0x23 => { "" => ["ldi", "a", ",", "(", "ix", "-", "NDIS", ")"] },
                            0x2B => { "" => ["ldd", "a", ",", "(", "ix", "-", "NDIS", ")"] },
                          },
                        },
                      },
               0x7F => { "" => ["ld", "a", ",", "a"] },
               0x80 => { "" => ["add", "a", ",", "b"] },
               0x81 => { "" => ["add", "a", ",", "c"] },
               0x82 => { "" => ["add", "a", ",", "d"] },
               0x83 => { "" => ["add", "a", ",", "e"] },
               0x84 => { "" => ["add", "a", ",", "ixh"] },
               0x85 => { "" => ["add", "a", ",", "ixl"] },
               0x86 => {
                        0x00 => { "" => ["add", "a", ",", "(", "ix", ")"] },
                        "DIS" => { "" => ["add", "a", ",", "(", "ix", "+", "DIS", ")"] },
                        "NDIS" => { "" => ["add", "a", ",", "(", "ix", "-", "NDIS", ")"] },
                      },
               0x87 => { "" => ["add", "a", ",", "a"] },
               0x88 => { "" => ["adc", "a", ",", "b"] },
               0x89 => { "" => ["adc", "a", ",", "c"] },
               0x8A => { "" => ["adc", "a", ",", "d"] },
               0x8B => { "" => ["adc", "a", ",", "e"] },
               0x8C => { "" => ["adc", "a", ",", "ixh"] },
               0x8D => { "" => ["adc", "a", ",", "ixl"] },
               0x8E => {
                        0x00 => { "" => ["adc", "a", ",", "(", "ix", ")"] },
                        "DIS" => { "" => ["adc", "a", ",", "(", "ix", "+", "DIS", ")"] },
                        "NDIS" => { "" => ["adc", "a", ",", "(", "ix", "-", "NDIS", ")"] },
                      },
               0x8F => { "" => ["adc", "a", ",", "a"] },
               0x90 => { "" => ["sub", "b"] },
               0x91 => { "" => ["sub", "c"] },
               0x92 => { "" => ["sub", "d"] },
               0x93 => { "" => ["sub", "e"] },
               0x94 => { "" => ["sub", "ixh"] },
               0x95 => { "" => ["sub", "ixl"] },
               0x96 => {
                        0x00 => { "" => ["sub", "(", "ix", ")"] },
                        "DIS" => { "" => ["sub", "(", "ix", "+", "DIS", ")"] },
                        "NDIS" => { "" => ["sub", "(", "ix", "-", "NDIS", ")"] },
                      },
               0x97 => { "" => ["sub", "a"] },
               0x98 => { "" => ["sbc", "a", ",", "b"] },
               0x99 => { "" => ["sbc", "a", ",", "c"] },
               0x9A => { "" => ["sbc", "a", ",", "d"] },
               0x9B => { "" => ["sbc", "a", ",", "e"] },
               0x9C => { "" => ["sbc", "a", ",", "ixh"] },
               0x9D => { "" => ["sbc", "a", ",", "ixl"] },
               0x9E => {
                        0x00 => { "" => ["sbc", "a", ",", "(", "ix", ")"] },
                        "DIS" => { "" => ["sbc", "a", ",", "(", "ix", "+", "DIS", ")"] },
                        "NDIS" => { "" => ["sbc", "a", ",", "(", "ix", "-", "NDIS", ")"] },
                      },
               0x9F => { "" => ["sbc", "a", ",", "a"] },
               0xA0 => { "" => ["and", "b"] },
               0xA1 => { "" => ["and", "c"] },
               0xA2 => { "" => ["and", "d"] },
               0xA3 => { "" => ["and", "e"] },
               0xA4 => { "" => ["and", "ixh"] },
               0xA5 => { "" => ["and", "ixl"] },
               0xA6 => {
                        0x00 => { "" => ["and", "(", "ix", ")"] },
                        "DIS" => { "" => ["and", "(", "ix", "+", "DIS", ")"] },
                        "NDIS" => { "" => ["and", "(", "ix", "-", "NDIS", ")"] },
                      },
               0xA7 => { "" => ["and", "a"] },
               0xA8 => { "" => ["xor", "b"] },
               0xA9 => { "" => ["xor", "c"] },
               0xAA => { "" => ["xor", "d"] },
               0xAB => { "" => ["xor", "e"] },
               0xAC => { "" => ["xor", "ixh"] },
               0xAD => { "" => ["xor", "ixl"] },
               0xAE => {
                        0x00 => { "" => ["xor", "(", "ix", ")"] },
                        "DIS" => { "" => ["xor", "(", "ix", "+", "DIS", ")"] },
                        "NDIS" => { "" => ["xor", "(", "ix", "-", "NDIS", ")"] },
                      },
               0xAF => { "" => ["xor", "a"] },
               0xB0 => { "" => ["or", "b"] },
               0xB1 => { "" => ["or", "c"] },
               0xB2 => { "" => ["or", "d"] },
               0xB3 => { "" => ["or", "e"] },
               0xB4 => { "" => ["or", "ixh"] },
               0xB5 => { "" => ["or", "ixl"] },
               0xB6 => {
                        0x00 => { "" => ["or", "(", "ix", ")"] },
                        "DIS" => { "" => ["or", "(", "ix", "+", "DIS", ")"] },
                        "NDIS" => { "" => ["or", "(", "ix", "-", "NDIS", ")"] },
                      },
               0xB7 => { "" => ["or", "a"] },
               0xB8 => { "" => ["cp", "b"] },
               0xB9 => { "" => ["cp", "c"] },
               0xBA => { "" => ["cp", "d"] },
               0xBB => { "" => ["cp", "e"] },
               0xBC => { "" => ["cp", "ixh"] },
               0xBD => { "" => ["cp", "ixl"] },
               0xBE => {
                        0x00 => { "" => ["cp", "(", "ix", ")"] },
                        "DIS" => { "" => ["cp", "(", "ix", "+", "DIS", ")"] },
                        "NDIS" => { "" => ["cp", "(", "ix", "-", "NDIS", ")"] },
                      },
               0xBF => { "" => ["cp", "a"] },
               0xCB => {
                        0x00 => {
                          0x00   => { "" => ["rlc", "(", "ix", ")", ",", "b"] },
                          0x01   => { "" => ["rlc", "(", "ix", ")", ",", "c"] },
                          0x02   => { "" => ["rlc", "(", "ix", ")", ",", "d"] },
                          0x03   => { "" => ["rlc", "(", "ix", ")", ",", "e"] },
                          0x04   => { "" => ["rlc", "(", "ix", ")", ",", "h"] },
                          0x05   => { "" => ["rlc", "(", "ix", ")", ",", "l"] },
                          0x06   => { "" => ["rlc", "(", "ix", ")"] },
                          0x07   => { "" => ["rlc", "(", "ix", ")", ",", "a"] },
                          0x08   => { "" => ["rrc", "(", "ix", ")", ",", "b"] },
                          0x09   => { "" => ["rrc", "(", "ix", ")", ",", "c"] },
                          0x0A  => { "" => ["rrc", "(", "ix", ")", ",", "d"] },
                          0x0B  => { "" => ["rrc", "(", "ix", ")", ",", "e"] },
                          0x0C  => { "" => ["rrc", "(", "ix", ")", ",", "h"] },
                          0x0D  => { "" => ["rrc", "(", "ix", ")", ",", "l"] },
                          0x0E  => { "" => ["rrc", "(", "ix", ")"] },
                          0x0F  => { "" => ["rrc", "(", "ix", ")", ",", "a"] },
                          0x10  => { "" => ["rl", "(", "ix", ")", ",", "b"] },
                          0x11  => { "" => ["rl", "(", "ix", ")", ",", "c"] },
                          0x12  => { "" => ["rl", "(", "ix", ")", ",", "d"] },
                          0x13  => { "" => ["rl", "(", "ix", ")", ",", "e"] },
                          0x14  => { "" => ["rl", "(", "ix", ")", ",", "h"] },
                          0x15  => { "" => ["rl", "(", "ix", ")", ",", "l"] },
                          0x16  => { "" => ["rl", "(", "ix", ")"] },
                          0x17  => { "" => ["rl", "(", "ix", ")", ",", "a"] },
                          0x18  => { "" => ["rr", "(", "ix", ")", ",", "b"] },
                          0x19  => { "" => ["rr", "(", "ix", ")", ",", "c"] },
                          0x1A  => { "" => ["rr", "(", "ix", ")", ",", "d"] },
                          0x1B  => { "" => ["rr", "(", "ix", ")", ",", "e"] },
                          0x1C  => { "" => ["rr", "(", "ix", ")", ",", "h"] },
                          0x1D  => { "" => ["rr", "(", "ix", ")", ",", "l"] },
                          0x1E  => { "" => ["rr", "(", "ix", ")"] },
                          0x1F  => { "" => ["rr", "(", "ix", ")", ",", "a"] },
                          0x20  => { "" => ["sla", "(", "ix", ")", ",", "b"] },
                          0x21  => { "" => ["sla", "(", "ix", ")", ",", "c"] },
                          0x22  => { "" => ["sla", "(", "ix", ")", ",", "d"] },
                          0x23  => { "" => ["sla", "(", "ix", ")", ",", "e"] },
                          0x24  => { "" => ["sla", "(", "ix", ")", ",", "h"] },
                          0x25  => { "" => ["sla", "(", "ix", ")", ",", "l"] },
                          0x26  => { "" => ["sla", "(", "ix", ")"] },
                          0x27  => { "" => ["sla", "(", "ix", ")", ",", "a"] },
                          0x28  => { "" => ["sra", "(", "ix", ")", ",", "b"] },
                          0x29  => { "" => ["sra", "(", "ix", ")", ",", "c"] },
                          0x2A  => { "" => ["sra", "(", "ix", ")", ",", "d"] },
                          0x2B  => { "" => ["sra", "(", "ix", ")", ",", "e"] },
                          0x2C  => { "" => ["sra", "(", "ix", ")", ",", "h"] },
                          0x2D  => { "" => ["sra", "(", "ix", ")", ",", "l"] },
                          0x2E  => { "" => ["sra", "(", "ix", ")"] },
                          0x2F  => { "" => ["sra", "(", "ix", ")", ",", "a"] },
                          0x30  => { "" => ["sll", "(", "ix", ")", ",", "b"] },
                          0x31  => { "" => ["sll", "(", "ix", ")", ",", "c"] },
                          0x32  => { "" => ["sll", "(", "ix", ")", ",", "d"] },
                          0x33  => { "" => ["sll", "(", "ix", ")", ",", "e"] },
                          0x34  => { "" => ["sll", "(", "ix", ")", ",", "h"] },
                          0x35  => { "" => ["sll", "(", "ix", ")", ",", "l"] },
                          0x36  => { "" => ["sll", "(", "ix", ")"] },
                          0x37  => { "" => ["sll", "(", "ix", ")", ",", "a"] },
                          0x38  => { "" => ["srl", "(", "ix", ")", ",", "b"] },
                          0x39  => { "" => ["srl", "(", "ix", ")", ",", "c"] },
                          0x3A  => { "" => ["srl", "(", "ix", ")", ",", "d"] },
                          0x3B  => { "" => ["srl", "(", "ix", ")", ",", "e"] },
                          0x3C  => { "" => ["srl", "(", "ix", ")", ",", "h"] },
                          0x3D  => { "" => ["srl", "(", "ix", ")", ",", "l"] },
                          0x3E  => { "" => ["srl", "(", "ix", ")"] },
                          0x3F  => { "" => ["srl", "(", "ix", ")", ",", "a"] },
                          0x46  => { "" => ["bit", 0x00, ",", "(", "ix", ")"] },
                          0x4E  => { "" => ["bit", 0x01, ",", "(", "ix", ")"] },
                          0x56  => { "" => ["bit", 0x02, ",", "(", "ix", ")"] },
                          0x5E  => { "" => ["bit", 0x03, ",", "(", "ix", ")"] },
                          0x66 => { "" => ["bit", 0x04, ",", "(", "ix", ")"] },
                          0x6E => { "" => ["bit", 0x05, ",", "(", "ix", ")"] },
                          0x76 => { "" => ["bit", 0x06, ",", "(", "ix", ")"] },
                          0x7E => { "" => ["bit", 0x07, ",", "(", "ix", ")"] },
                          0x80 => { "" => ["res", 0x00, ",", "(", "ix", ")", ",", "b"] },
                          0x81 => { "" => ["res", 0x00, ",", "(", "ix", ")", ",", "c"] },
                          0x82 => { "" => ["res", 0x00, ",", "(", "ix", ")", ",", "d"] },
                          0x83 => { "" => ["res", 0x00, ",", "(", "ix", ")", ",", "e"] },
                          0x84 => { "" => ["res", 0x00, ",", "(", "ix", ")", ",", "h"] },
                          0x85 => { "" => ["res", 0x00, ",", "(", "ix", ")", ",", "l"] },
                          0x86 => { "" => ["res", 0x00, ",", "(", "ix", ")"] },
                          0x87 => { "" => ["res", 0x00, ",", "(", "ix", ")", ",", "a"] },
                          0x88 => { "" => ["res", 0x01, ",", "(", "ix", ")", ",", "b"] },
                          0x89 => { "" => ["res", 0x01, ",", "(", "ix", ")", ",", "c"] },
                          0x8A => { "" => ["res", 0x01, ",", "(", "ix", ")", ",", "d"] },
                          0x8B => { "" => ["res", 0x01, ",", "(", "ix", ")", ",", "e"] },
                          0x8C => { "" => ["res", 0x01, ",", "(", "ix", ")", ",", "h"] },
                          0x8D => { "" => ["res", 0x01, ",", "(", "ix", ")", ",", "l"] },
                          0x8E => { "" => ["res", 0x01, ",", "(", "ix", ")"] },
                          0x8F => { "" => ["res", 0x01, ",", "(", "ix", ")", ",", "a"] },
                          0x90 => { "" => ["res", 0x02, ",", "(", "ix", ")", ",", "b"] },
                          0x91 => { "" => ["res", 0x02, ",", "(", "ix", ")", ",", "c"] },
                          0x92 => { "" => ["res", 0x02, ",", "(", "ix", ")", ",", "d"] },
                          0x93 => { "" => ["res", 0x02, ",", "(", "ix", ")", ",", "e"] },
                          0x94 => { "" => ["res", 0x02, ",", "(", "ix", ")", ",", "h"] },
                          0x95 => { "" => ["res", 0x02, ",", "(", "ix", ")", ",", "l"] },
                          0x96 => { "" => ["res", 0x02, ",", "(", "ix", ")"] },
                          0x97 => { "" => ["res", 0x02, ",", "(", "ix", ")", ",", "a"] },
                          0x98 => { "" => ["res", 0x03, ",", "(", "ix", ")", ",", "b"] },
                          0x99 => { "" => ["res", 0x03, ",", "(", "ix", ")", ",", "c"] },
                          0x9A => { "" => ["res", 0x03, ",", "(", "ix", ")", ",", "d"] },
                          0x9B => { "" => ["res", 0x03, ",", "(", "ix", ")", ",", "e"] },
                          0x9C => { "" => ["res", 0x03, ",", "(", "ix", ")", ",", "h"] },
                          0x9D => { "" => ["res", 0x03, ",", "(", "ix", ")", ",", "l"] },
                          0x9E => { "" => ["res", 0x03, ",", "(", "ix", ")"] },
                          0x9F => { "" => ["res", 0x03, ",", "(", "ix", ")", ",", "a"] },
                          0xA0 => { "" => ["res", 0x04, ",", "(", "ix", ")", ",", "b"] },
                          0xA1 => { "" => ["res", 0x04, ",", "(", "ix", ")", ",", "c"] },
                          0xA2 => { "" => ["res", 0x04, ",", "(", "ix", ")", ",", "d"] },
                          0xA3 => { "" => ["res", 0x04, ",", "(", "ix", ")", ",", "e"] },
                          0xA4 => { "" => ["res", 0x04, ",", "(", "ix", ")", ",", "h"] },
                          0xA5 => { "" => ["res", 0x04, ",", "(", "ix", ")", ",", "l"] },
                          0xA6 => { "" => ["res", 0x04, ",", "(", "ix", ")"] },
                          0xA7 => { "" => ["res", 0x04, ",", "(", "ix", ")", ",", "a"] },
                          0xA8 => { "" => ["res", 0x05, ",", "(", "ix", ")", ",", "b"] },
                          0xA9 => { "" => ["res", 0x05, ",", "(", "ix", ")", ",", "c"] },
                          0xAA => { "" => ["res", 0x05, ",", "(", "ix", ")", ",", "d"] },
                          0xAB => { "" => ["res", 0x05, ",", "(", "ix", ")", ",", "e"] },
                          0xAC => { "" => ["res", 0x05, ",", "(", "ix", ")", ",", "h"] },
                          0xAD => { "" => ["res", 0x05, ",", "(", "ix", ")", ",", "l"] },
                          0xAE => { "" => ["res", 0x05, ",", "(", "ix", ")"] },
                          0xAF => { "" => ["res", 0x05, ",", "(", "ix", ")", ",", "a"] },
                          0xB0 => { "" => ["res", 0x06, ",", "(", "ix", ")", ",", "b"] },
                          0xB1 => { "" => ["res", 0x06, ",", "(", "ix", ")", ",", "c"] },
                          0xB2 => { "" => ["res", 0x06, ",", "(", "ix", ")", ",", "d"] },
                          0xB3 => { "" => ["res", 0x06, ",", "(", "ix", ")", ",", "e"] },
                          0xB4 => { "" => ["res", 0x06, ",", "(", "ix", ")", ",", "h"] },
                          0xB5 => { "" => ["res", 0x06, ",", "(", "ix", ")", ",", "l"] },
                          0xB6 => { "" => ["res", 0x06, ",", "(", "ix", ")"] },
                          0xB7 => { "" => ["res", 0x06, ",", "(", "ix", ")", ",", "a"] },
                          0xB8 => { "" => ["res", 0x07, ",", "(", "ix", ")", ",", "b"] },
                          0xB9 => { "" => ["res", 0x07, ",", "(", "ix", ")", ",", "c"] },
                          0xBA => { "" => ["res", 0x07, ",", "(", "ix", ")", ",", "d"] },
                          0xBB => { "" => ["res", 0x07, ",", "(", "ix", ")", ",", "e"] },
                          0xBC => { "" => ["res", 0x07, ",", "(", "ix", ")", ",", "h"] },
                          0xBD => { "" => ["res", 0x07, ",", "(", "ix", ")", ",", "l"] },
                          0xBE => { "" => ["res", 0x07, ",", "(", "ix", ")"] },
                          0xBF => { "" => ["res", 0x07, ",", "(", "ix", ")", ",", "a"] },
                          0xC0 => { "" => ["set", 0x00, ",", "(", "ix", ")", ",", "b"] },
                          0xC1 => { "" => ["set", 0x00, ",", "(", "ix", ")", ",", "c"] },
                          0xC2 => { "" => ["set", 0x00, ",", "(", "ix", ")", ",", "d"] },
                          0xC3 => { "" => ["set", 0x00, ",", "(", "ix", ")", ",", "e"] },
                          0xC4 => { "" => ["set", 0x00, ",", "(", "ix", ")", ",", "h"] },
                          0xC5 => { "" => ["set", 0x00, ",", "(", "ix", ")", ",", "l"] },
                          0xC6 => { "" => ["set", 0x00, ",", "(", "ix", ")"] },
                          0xC7 => { "" => ["set", 0x00, ",", "(", "ix", ")", ",", "a"] },
                          0xC8 => { "" => ["set", 0x01, ",", "(", "ix", ")", ",", "b"] },
                          0xC9 => { "" => ["set", 0x01, ",", "(", "ix", ")", ",", "c"] },
                          0xCA => { "" => ["set", 0x01, ",", "(", "ix", ")", ",", "d"] },
                          0xCB => { "" => ["set", 0x01, ",", "(", "ix", ")", ",", "e"] },
                          0xCC => { "" => ["set", 0x01, ",", "(", "ix", ")", ",", "h"] },
                          0xCD => { "" => ["set", 0x01, ",", "(", "ix", ")", ",", "l"] },
                          0xCE => { "" => ["set", 0x01, ",", "(", "ix", ")"] },
                          0xCF => { "" => ["set", 0x01, ",", "(", "ix", ")", ",", "a"] },
                          0xD0 => { "" => ["set", 0x02, ",", "(", "ix", ")", ",", "b"] },
                          0xD1 => { "" => ["set", 0x02, ",", "(", "ix", ")", ",", "c"] },
                          0xD2 => { "" => ["set", 0x02, ",", "(", "ix", ")", ",", "d"] },
                          0xD3 => { "" => ["set", 0x02, ",", "(", "ix", ")", ",", "e"] },
                          0xD4 => { "" => ["set", 0x02, ",", "(", "ix", ")", ",", "h"] },
                          0xD5 => { "" => ["set", 0x02, ",", "(", "ix", ")", ",", "l"] },
                          0xD6 => { "" => ["set", 0x02, ",", "(", "ix", ")"] },
                          0xD7 => { "" => ["set", 0x02, ",", "(", "ix", ")", ",", "a"] },
                          0xD8 => { "" => ["set", 0x03, ",", "(", "ix", ")", ",", "b"] },
                          0xD9 => { "" => ["set", 0x03, ",", "(", "ix", ")", ",", "c"] },
                          0xDA => { "" => ["set", 0x03, ",", "(", "ix", ")", ",", "d"] },
                          0xDB => { "" => ["set", 0x03, ",", "(", "ix", ")", ",", "e"] },
                          0xDC => { "" => ["set", 0x03, ",", "(", "ix", ")", ",", "h"] },
                          0xDD => { "" => ["set", 0x03, ",", "(", "ix", ")", ",", "l"] },
                          0xDE => { "" => ["set", 0x03, ",", "(", "ix", ")"] },
                          0xDF => { "" => ["set", 0x03, ",", "(", "ix", ")", ",", "a"] },
                          0xE0 => { "" => ["set", 0x04, ",", "(", "ix", ")", ",", "b"] },
                          0xE1 => { "" => ["set", 0x04, ",", "(", "ix", ")", ",", "c"] },
                          0xE2 => { "" => ["set", 0x04, ",", "(", "ix", ")", ",", "d"] },
                          0xE3 => { "" => ["set", 0x04, ",", "(", "ix", ")", ",", "e"] },
                          0xE4 => { "" => ["set", 0x04, ",", "(", "ix", ")", ",", "h"] },
                          0xE5 => { "" => ["set", 0x04, ",", "(", "ix", ")", ",", "l"] },
                          0xE6 => { "" => ["set", 0x04, ",", "(", "ix", ")"] },
                          0xE7 => { "" => ["set", 0x04, ",", "(", "ix", ")", ",", "a"] },
                          0xE8 => { "" => ["set", 0x05, ",", "(", "ix", ")", ",", "b"] },
                          0xE9 => { "" => ["set", 0x05, ",", "(", "ix", ")", ",", "c"] },
                          0xEA => { "" => ["set", 0x05, ",", "(", "ix", ")", ",", "d"] },
                          0xEB => { "" => ["set", 0x05, ",", "(", "ix", ")", ",", "e"] },
                          0xEC => { "" => ["set", 0x05, ",", "(", "ix", ")", ",", "h"] },
                          0xED => { "" => ["set", 0x05, ",", "(", "ix", ")", ",", "l"] },
                          0xEE => { "" => ["set", 0x05, ",", "(", "ix", ")"] },
                          0xEF => { "" => ["set", 0x05, ",", "(", "ix", ")", ",", "a"] },
                          0xF0 => { "" => ["set", 0x06, ",", "(", "ix", ")", ",", "b"] },
                          0xF1 => { "" => ["set", 0x06, ",", "(", "ix", ")", ",", "c"] },
                          0xF2 => { "" => ["set", 0x06, ",", "(", "ix", ")", ",", "d"] },
                          0xF3 => { "" => ["set", 0x06, ",", "(", "ix", ")", ",", "e"] },
                          0xF4 => { "" => ["set", 0x06, ",", "(", "ix", ")", ",", "h"] },
                          0xF5 => { "" => ["set", 0x06, ",", "(", "ix", ")", ",", "l"] },
                          0xF6 => { "" => ["set", 0x06, ",", "(", "ix", ")"] },
                          0xF7 => { "" => ["set", 0x06, ",", "(", "ix", ")", ",", "a"] },
                          0xF8 => { "" => ["set", 0x07, ",", "(", "ix", ")", ",", "b"] },
                          0xF9 => { "" => ["set", 0x07, ",", "(", "ix", ")", ",", "c"] },
                          0xFA => { "" => ["set", 0x07, ",", "(", "ix", ")", ",", "d"] },
                          0xFB => { "" => ["set", 0x07, ",", "(", "ix", ")", ",", "e"] },
                          0xFC => { "" => ["set", 0x07, ",", "(", "ix", ")", ",", "h"] },
                          0xFD => { "" => ["set", 0x07, ",", "(", "ix", ")", ",", "l"] },
                          0xFE => { "" => ["set", 0x07, ",", "(", "ix", ")"] },
                          0xFF => { "" => ["set", 0x07, ",", "(", "ix", ")", ",", "a"] },
                        },
                        "DIS" => {
                          0x00   => { "" => ["rlc", "(", "ix", "+", "DIS", ")", ",", "b"] },
                          0x01   => { "" => ["rlc", "(", "ix", "+", "DIS", ")", ",", "c"] },
                          0x02   => { "" => ["rlc", "(", "ix", "+", "DIS", ")", ",", "d"] },
                          0x03   => { "" => ["rlc", "(", "ix", "+", "DIS", ")", ",", "e"] },
                          0x04   => { "" => ["rlc", "(", "ix", "+", "DIS", ")", ",", "h"] },
                          0x05   => { "" => ["rlc", "(", "ix", "+", "DIS", ")", ",", "l"] },
                          0x06   => { "" => ["rlc", "(", "ix", "+", "DIS", ")"] },
                          0x07   => { "" => ["rlc", "(", "ix", "+", "DIS", ")", ",", "a"] },
                          0x08   => { "" => ["rrc", "(", "ix", "+", "DIS", ")", ",", "b"] },
                          0x09   => { "" => ["rrc", "(", "ix", "+", "DIS", ")", ",", "c"] },
                          0x0A  => { "" => ["rrc", "(", "ix", "+", "DIS", ")", ",", "d"] },
                          0x0B  => { "" => ["rrc", "(", "ix", "+", "DIS", ")", ",", "e"] },
                          0x0C  => { "" => ["rrc", "(", "ix", "+", "DIS", ")", ",", "h"] },
                          0x0D  => { "" => ["rrc", "(", "ix", "+", "DIS", ")", ",", "l"] },
                          0x0E  => { "" => ["rrc", "(", "ix", "+", "DIS", ")"] },
                          0x0F  => { "" => ["rrc", "(", "ix", "+", "DIS", ")", ",", "a"] },
                          0x10  => { "" => ["rl", "(", "ix", "+", "DIS", ")", ",", "b"] },
                          0x11  => { "" => ["rl", "(", "ix", "+", "DIS", ")", ",", "c"] },
                          0x12  => { "" => ["rl", "(", "ix", "+", "DIS", ")", ",", "d"] },
                          0x13  => { "" => ["rl", "(", "ix", "+", "DIS", ")", ",", "e"] },
                          0x14  => { "" => ["rl", "(", "ix", "+", "DIS", ")", ",", "h"] },
                          0x15  => { "" => ["rl", "(", "ix", "+", "DIS", ")", ",", "l"] },
                          0x16  => { "" => ["rl", "(", "ix", "+", "DIS", ")"] },
                          0x17  => { "" => ["rl", "(", "ix", "+", "DIS", ")", ",", "a"] },
                          0x18  => { "" => ["rr", "(", "ix", "+", "DIS", ")", ",", "b"] },
                          0x19  => { "" => ["rr", "(", "ix", "+", "DIS", ")", ",", "c"] },
                          0x1A  => { "" => ["rr", "(", "ix", "+", "DIS", ")", ",", "d"] },
                          0x1B  => { "" => ["rr", "(", "ix", "+", "DIS", ")", ",", "e"] },
                          0x1C  => { "" => ["rr", "(", "ix", "+", "DIS", ")", ",", "h"] },
                          0x1D  => { "" => ["rr", "(", "ix", "+", "DIS", ")", ",", "l"] },
                          0x1E  => { "" => ["rr", "(", "ix", "+", "DIS", ")"] },
                          0x1F  => { "" => ["rr", "(", "ix", "+", "DIS", ")", ",", "a"] },
                          0x20  => { "" => ["sla", "(", "ix", "+", "DIS", ")", ",", "b"] },
                          0x21  => { "" => ["sla", "(", "ix", "+", "DIS", ")", ",", "c"] },
                          0x22  => { "" => ["sla", "(", "ix", "+", "DIS", ")", ",", "d"] },
                          0x23  => { "" => ["sla", "(", "ix", "+", "DIS", ")", ",", "e"] },
                          0x24  => { "" => ["sla", "(", "ix", "+", "DIS", ")", ",", "h"] },
                          0x25  => { "" => ["sla", "(", "ix", "+", "DIS", ")", ",", "l"] },
                          0x26  => { "" => ["sla", "(", "ix", "+", "DIS", ")"] },
                          0x27  => { "" => ["sla", "(", "ix", "+", "DIS", ")", ",", "a"] },
                          0x28  => { "" => ["sra", "(", "ix", "+", "DIS", ")", ",", "b"] },
                          0x29  => { "" => ["sra", "(", "ix", "+", "DIS", ")", ",", "c"] },
                          0x2A  => { "" => ["sra", "(", "ix", "+", "DIS", ")", ",", "d"] },
                          0x2B  => { "" => ["sra", "(", "ix", "+", "DIS", ")", ",", "e"] },
                          0x2C  => { "" => ["sra", "(", "ix", "+", "DIS", ")", ",", "h"] },
                          0x2D  => { "" => ["sra", "(", "ix", "+", "DIS", ")", ",", "l"] },
                          0x2E  => { "" => ["sra", "(", "ix", "+", "DIS", ")"] },
                          0x2F  => { "" => ["sra", "(", "ix", "+", "DIS", ")", ",", "a"] },
                          0x30  => { "" => ["sll", "(", "ix", "+", "DIS", ")", ",", "b"] },
                          0x31  => { "" => ["sll", "(", "ix", "+", "DIS", ")", ",", "c"] },
                          0x32  => { "" => ["sll", "(", "ix", "+", "DIS", ")", ",", "d"] },
                          0x33  => { "" => ["sll", "(", "ix", "+", "DIS", ")", ",", "e"] },
                          0x34  => { "" => ["sll", "(", "ix", "+", "DIS", ")", ",", "h"] },
                          0x35  => { "" => ["sll", "(", "ix", "+", "DIS", ")", ",", "l"] },
                          0x36  => { "" => ["sll", "(", "ix", "+", "DIS", ")"] },
                          0x37  => { "" => ["sll", "(", "ix", "+", "DIS", ")", ",", "a"] },
                          0x38  => { "" => ["srl", "(", "ix", "+", "DIS", ")", ",", "b"] },
                          0x39  => { "" => ["srl", "(", "ix", "+", "DIS", ")", ",", "c"] },
                          0x3A  => { "" => ["srl", "(", "ix", "+", "DIS", ")", ",", "d"] },
                          0x3B  => { "" => ["srl", "(", "ix", "+", "DIS", ")", ",", "e"] },
                          0x3C  => { "" => ["srl", "(", "ix", "+", "DIS", ")", ",", "h"] },
                          0x3D  => { "" => ["srl", "(", "ix", "+", "DIS", ")", ",", "l"] },
                          0x3E  => { "" => ["srl", "(", "ix", "+", "DIS", ")"] },
                          0x3F  => { "" => ["srl", "(", "ix", "+", "DIS", ")", ",", "a"] },
                          0x46  => { "" => ["bit", 0x00, ",", "(", "ix", "+", "DIS", ")"] },
                          0x4E  => { "" => ["bit", 0x01, ",", "(", "ix", "+", "DIS", ")"] },
                          0x56  => { "" => ["bit", 0x02, ",", "(", "ix", "+", "DIS", ")"] },
                          0x5E  => { "" => ["bit", 0x03, ",", "(", "ix", "+", "DIS", ")"] },
                          0x66 => { "" => ["bit", 0x04, ",", "(", "ix", "+", "DIS", ")"] },
                          0x6E => { "" => ["bit", 0x05, ",", "(", "ix", "+", "DIS", ")"] },
                          0x76 => { "" => ["bit", 0x06, ",", "(", "ix", "+", "DIS", ")"] },
                          0x7E => { "" => ["bit", 0x07, ",", "(", "ix", "+", "DIS", ")"] },
                          0x80 => { "" => ["res", 0x00, ",", "(", "ix", "+", "DIS", ")", ",", "b"] },
                          0x81 => { "" => ["res", 0x00, ",", "(", "ix", "+", "DIS", ")", ",", "c"] },
                          0x82 => { "" => ["res", 0x00, ",", "(", "ix", "+", "DIS", ")", ",", "d"] },
                          0x83 => { "" => ["res", 0x00, ",", "(", "ix", "+", "DIS", ")", ",", "e"] },
                          0x84 => { "" => ["res", 0x00, ",", "(", "ix", "+", "DIS", ")", ",", "h"] },
                          0x85 => { "" => ["res", 0x00, ",", "(", "ix", "+", "DIS", ")", ",", "l"] },
                          0x86 => { "" => ["res", 0x00, ",", "(", "ix", "+", "DIS", ")"] },
                          0x87 => { "" => ["res", 0x00, ",", "(", "ix", "+", "DIS", ")", ",", "a"] },
                          0x88 => { "" => ["res", 0x01, ",", "(", "ix", "+", "DIS", ")", ",", "b"] },
                          0x89 => { "" => ["res", 0x01, ",", "(", "ix", "+", "DIS", ")", ",", "c"] },
                          0x8A => { "" => ["res", 0x01, ",", "(", "ix", "+", "DIS", ")", ",", "d"] },
                          0x8B => { "" => ["res", 0x01, ",", "(", "ix", "+", "DIS", ")", ",", "e"] },
                          0x8C => { "" => ["res", 0x01, ",", "(", "ix", "+", "DIS", ")", ",", "h"] },
                          0x8D => { "" => ["res", 0x01, ",", "(", "ix", "+", "DIS", ")", ",", "l"] },
                          0x8E => { "" => ["res", 0x01, ",", "(", "ix", "+", "DIS", ")"] },
                          0x8F => { "" => ["res", 0x01, ",", "(", "ix", "+", "DIS", ")", ",", "a"] },
                          0x90 => { "" => ["res", 0x02, ",", "(", "ix", "+", "DIS", ")", ",", "b"] },
                          0x91 => { "" => ["res", 0x02, ",", "(", "ix", "+", "DIS", ")", ",", "c"] },
                          0x92 => { "" => ["res", 0x02, ",", "(", "ix", "+", "DIS", ")", ",", "d"] },
                          0x93 => { "" => ["res", 0x02, ",", "(", "ix", "+", "DIS", ")", ",", "e"] },
                          0x94 => { "" => ["res", 0x02, ",", "(", "ix", "+", "DIS", ")", ",", "h"] },
                          0x95 => { "" => ["res", 0x02, ",", "(", "ix", "+", "DIS", ")", ",", "l"] },
                          0x96 => { "" => ["res", 0x02, ",", "(", "ix", "+", "DIS", ")"] },
                          0x97 => { "" => ["res", 0x02, ",", "(", "ix", "+", "DIS", ")", ",", "a"] },
                          0x98 => { "" => ["res", 0x03, ",", "(", "ix", "+", "DIS", ")", ",", "b"] },
                          0x99 => { "" => ["res", 0x03, ",", "(", "ix", "+", "DIS", ")", ",", "c"] },
                          0x9A => { "" => ["res", 0x03, ",", "(", "ix", "+", "DIS", ")", ",", "d"] },
                          0x9B => { "" => ["res", 0x03, ",", "(", "ix", "+", "DIS", ")", ",", "e"] },
                          0x9C => { "" => ["res", 0x03, ",", "(", "ix", "+", "DIS", ")", ",", "h"] },
                          0x9D => { "" => ["res", 0x03, ",", "(", "ix", "+", "DIS", ")", ",", "l"] },
                          0x9E => { "" => ["res", 0x03, ",", "(", "ix", "+", "DIS", ")"] },
                          0x9F => { "" => ["res", 0x03, ",", "(", "ix", "+", "DIS", ")", ",", "a"] },
                          0xA0 => { "" => ["res", 0x04, ",", "(", "ix", "+", "DIS", ")", ",", "b"] },
                          0xA1 => { "" => ["res", 0x04, ",", "(", "ix", "+", "DIS", ")", ",", "c"] },
                          0xA2 => { "" => ["res", 0x04, ",", "(", "ix", "+", "DIS", ")", ",", "d"] },
                          0xA3 => { "" => ["res", 0x04, ",", "(", "ix", "+", "DIS", ")", ",", "e"] },
                          0xA4 => { "" => ["res", 0x04, ",", "(", "ix", "+", "DIS", ")", ",", "h"] },
                          0xA5 => { "" => ["res", 0x04, ",", "(", "ix", "+", "DIS", ")", ",", "l"] },
                          0xA6 => { "" => ["res", 0x04, ",", "(", "ix", "+", "DIS", ")"] },
                          0xA7 => { "" => ["res", 0x04, ",", "(", "ix", "+", "DIS", ")", ",", "a"] },
                          0xA8 => { "" => ["res", 0x05, ",", "(", "ix", "+", "DIS", ")", ",", "b"] },
                          0xA9 => { "" => ["res", 0x05, ",", "(", "ix", "+", "DIS", ")", ",", "c"] },
                          0xAA => { "" => ["res", 0x05, ",", "(", "ix", "+", "DIS", ")", ",", "d"] },
                          0xAB => { "" => ["res", 0x05, ",", "(", "ix", "+", "DIS", ")", ",", "e"] },
                          0xAC => { "" => ["res", 0x05, ",", "(", "ix", "+", "DIS", ")", ",", "h"] },
                          0xAD => { "" => ["res", 0x05, ",", "(", "ix", "+", "DIS", ")", ",", "l"] },
                          0xAE => { "" => ["res", 0x05, ",", "(", "ix", "+", "DIS", ")"] },
                          0xAF => { "" => ["res", 0x05, ",", "(", "ix", "+", "DIS", ")", ",", "a"] },
                          0xB0 => { "" => ["res", 0x06, ",", "(", "ix", "+", "DIS", ")", ",", "b"] },
                          0xB1 => { "" => ["res", 0x06, ",", "(", "ix", "+", "DIS", ")", ",", "c"] },
                          0xB2 => { "" => ["res", 0x06, ",", "(", "ix", "+", "DIS", ")", ",", "d"] },
                          0xB3 => { "" => ["res", 0x06, ",", "(", "ix", "+", "DIS", ")", ",", "e"] },
                          0xB4 => { "" => ["res", 0x06, ",", "(", "ix", "+", "DIS", ")", ",", "h"] },
                          0xB5 => { "" => ["res", 0x06, ",", "(", "ix", "+", "DIS", ")", ",", "l"] },
                          0xB6 => { "" => ["res", 0x06, ",", "(", "ix", "+", "DIS", ")"] },
                          0xB7 => { "" => ["res", 0x06, ",", "(", "ix", "+", "DIS", ")", ",", "a"] },
                          0xB8 => { "" => ["res", 0x07, ",", "(", "ix", "+", "DIS", ")", ",", "b"] },
                          0xB9 => { "" => ["res", 0x07, ",", "(", "ix", "+", "DIS", ")", ",", "c"] },
                          0xBA => { "" => ["res", 0x07, ",", "(", "ix", "+", "DIS", ")", ",", "d"] },
                          0xBB => { "" => ["res", 0x07, ",", "(", "ix", "+", "DIS", ")", ",", "e"] },
                          0xBC => { "" => ["res", 0x07, ",", "(", "ix", "+", "DIS", ")", ",", "h"] },
                          0xBD => { "" => ["res", 0x07, ",", "(", "ix", "+", "DIS", ")", ",", "l"] },
                          0xBE => { "" => ["res", 0x07, ",", "(", "ix", "+", "DIS", ")"] },
                          0xBF => { "" => ["res", 0x07, ",", "(", "ix", "+", "DIS", ")", ",", "a"] },
                          0xC0 => { "" => ["set", 0x00, ",", "(", "ix", "+", "DIS", ")", ",", "b"] },
                          0xC1 => { "" => ["set", 0x00, ",", "(", "ix", "+", "DIS", ")", ",", "c"] },
                          0xC2 => { "" => ["set", 0x00, ",", "(", "ix", "+", "DIS", ")", ",", "d"] },
                          0xC3 => { "" => ["set", 0x00, ",", "(", "ix", "+", "DIS", ")", ",", "e"] },
                          0xC4 => { "" => ["set", 0x00, ",", "(", "ix", "+", "DIS", ")", ",", "h"] },
                          0xC5 => { "" => ["set", 0x00, ",", "(", "ix", "+", "DIS", ")", ",", "l"] },
                          0xC6 => { "" => ["set", 0x00, ",", "(", "ix", "+", "DIS", ")"] },
                          0xC7 => { "" => ["set", 0x00, ",", "(", "ix", "+", "DIS", ")", ",", "a"] },
                          0xC8 => { "" => ["set", 0x01, ",", "(", "ix", "+", "DIS", ")", ",", "b"] },
                          0xC9 => { "" => ["set", 0x01, ",", "(", "ix", "+", "DIS", ")", ",", "c"] },
                          0xCA => { "" => ["set", 0x01, ",", "(", "ix", "+", "DIS", ")", ",", "d"] },
                          0xCB => { "" => ["set", 0x01, ",", "(", "ix", "+", "DIS", ")", ",", "e"] },
                          0xCC => { "" => ["set", 0x01, ",", "(", "ix", "+", "DIS", ")", ",", "h"] },
                          0xCD => { "" => ["set", 0x01, ",", "(", "ix", "+", "DIS", ")", ",", "l"] },
                          0xCE => { "" => ["set", 0x01, ",", "(", "ix", "+", "DIS", ")"] },
                          0xCF => { "" => ["set", 0x01, ",", "(", "ix", "+", "DIS", ")", ",", "a"] },
                          0xD0 => { "" => ["set", 0x02, ",", "(", "ix", "+", "DIS", ")", ",", "b"] },
                          0xD1 => { "" => ["set", 0x02, ",", "(", "ix", "+", "DIS", ")", ",", "c"] },
                          0xD2 => { "" => ["set", 0x02, ",", "(", "ix", "+", "DIS", ")", ",", "d"] },
                          0xD3 => { "" => ["set", 0x02, ",", "(", "ix", "+", "DIS", ")", ",", "e"] },
                          0xD4 => { "" => ["set", 0x02, ",", "(", "ix", "+", "DIS", ")", ",", "h"] },
                          0xD5 => { "" => ["set", 0x02, ",", "(", "ix", "+", "DIS", ")", ",", "l"] },
                          0xD6 => { "" => ["set", 0x02, ",", "(", "ix", "+", "DIS", ")"] },
                          0xD7 => { "" => ["set", 0x02, ",", "(", "ix", "+", "DIS", ")", ",", "a"] },
                          0xD8 => { "" => ["set", 0x03, ",", "(", "ix", "+", "DIS", ")", ",", "b"] },
                          0xD9 => { "" => ["set", 0x03, ",", "(", "ix", "+", "DIS", ")", ",", "c"] },
                          0xDA => { "" => ["set", 0x03, ",", "(", "ix", "+", "DIS", ")", ",", "d"] },
                          0xDB => { "" => ["set", 0x03, ",", "(", "ix", "+", "DIS", ")", ",", "e"] },
                          0xDC => { "" => ["set", 0x03, ",", "(", "ix", "+", "DIS", ")", ",", "h"] },
                          0xDD => { "" => ["set", 0x03, ",", "(", "ix", "+", "DIS", ")", ",", "l"] },
                          0xDE => { "" => ["set", 0x03, ",", "(", "ix", "+", "DIS", ")"] },
                          0xDF => { "" => ["set", 0x03, ",", "(", "ix", "+", "DIS", ")", ",", "a"] },
                          0xE0 => { "" => ["set", 0x04, ",", "(", "ix", "+", "DIS", ")", ",", "b"] },
                          0xE1 => { "" => ["set", 0x04, ",", "(", "ix", "+", "DIS", ")", ",", "c"] },
                          0xE2 => { "" => ["set", 0x04, ",", "(", "ix", "+", "DIS", ")", ",", "d"] },
                          0xE3 => { "" => ["set", 0x04, ",", "(", "ix", "+", "DIS", ")", ",", "e"] },
                          0xE4 => { "" => ["set", 0x04, ",", "(", "ix", "+", "DIS", ")", ",", "h"] },
                          0xE5 => { "" => ["set", 0x04, ",", "(", "ix", "+", "DIS", ")", ",", "l"] },
                          0xE6 => { "" => ["set", 0x04, ",", "(", "ix", "+", "DIS", ")"] },
                          0xE7 => { "" => ["set", 0x04, ",", "(", "ix", "+", "DIS", ")", ",", "a"] },
                          0xE8 => { "" => ["set", 0x05, ",", "(", "ix", "+", "DIS", ")", ",", "b"] },
                          0xE9 => { "" => ["set", 0x05, ",", "(", "ix", "+", "DIS", ")", ",", "c"] },
                          0xEA => { "" => ["set", 0x05, ",", "(", "ix", "+", "DIS", ")", ",", "d"] },
                          0xEB => { "" => ["set", 0x05, ",", "(", "ix", "+", "DIS", ")", ",", "e"] },
                          0xEC => { "" => ["set", 0x05, ",", "(", "ix", "+", "DIS", ")", ",", "h"] },
                          0xED => { "" => ["set", 0x05, ",", "(", "ix", "+", "DIS", ")", ",", "l"] },
                          0xEE => { "" => ["set", 0x05, ",", "(", "ix", "+", "DIS", ")"] },
                          0xEF => { "" => ["set", 0x05, ",", "(", "ix", "+", "DIS", ")", ",", "a"] },
                          0xF0 => { "" => ["set", 0x06, ",", "(", "ix", "+", "DIS", ")", ",", "b"] },
                          0xF1 => { "" => ["set", 0x06, ",", "(", "ix", "+", "DIS", ")", ",", "c"] },
                          0xF2 => { "" => ["set", 0x06, ",", "(", "ix", "+", "DIS", ")", ",", "d"] },
                          0xF3 => { "" => ["set", 0x06, ",", "(", "ix", "+", "DIS", ")", ",", "e"] },
                          0xF4 => { "" => ["set", 0x06, ",", "(", "ix", "+", "DIS", ")", ",", "h"] },
                          0xF5 => { "" => ["set", 0x06, ",", "(", "ix", "+", "DIS", ")", ",", "l"] },
                          0xF6 => { "" => ["set", 0x06, ",", "(", "ix", "+", "DIS", ")"] },
                          0xF7 => { "" => ["set", 0x06, ",", "(", "ix", "+", "DIS", ")", ",", "a"] },
                          0xF8 => { "" => ["set", 0x07, ",", "(", "ix", "+", "DIS", ")", ",", "b"] },
                          0xF9 => { "" => ["set", 0x07, ",", "(", "ix", "+", "DIS", ")", ",", "c"] },
                          0xFA => { "" => ["set", 0x07, ",", "(", "ix", "+", "DIS", ")", ",", "d"] },
                          0xFB => { "" => ["set", 0x07, ",", "(", "ix", "+", "DIS", ")", ",", "e"] },
                          0xFC => { "" => ["set", 0x07, ",", "(", "ix", "+", "DIS", ")", ",", "h"] },
                          0xFD => { "" => ["set", 0x07, ",", "(", "ix", "+", "DIS", ")", ",", "l"] },
                          0xFE => { "" => ["set", 0x07, ",", "(", "ix", "+", "DIS", ")"] },
                          0xFF => { "" => ["set", 0x07, ",", "(", "ix", "+", "DIS", ")", ",", "a"] },
                        },
                        "NDIS" => {
                          0x00   => { "" => ["rlc", "(", "ix", "-", "NDIS", ")", ",", "b"] },
                          0x01   => { "" => ["rlc", "(", "ix", "-", "NDIS", ")", ",", "c"] },
                          0x02   => { "" => ["rlc", "(", "ix", "-", "NDIS", ")", ",", "d"] },
                          0x03   => { "" => ["rlc", "(", "ix", "-", "NDIS", ")", ",", "e"] },
                          0x04   => { "" => ["rlc", "(", "ix", "-", "NDIS", ")", ",", "h"] },
                          0x05   => { "" => ["rlc", "(", "ix", "-", "NDIS", ")", ",", "l"] },
                          0x06   => { "" => ["rlc", "(", "ix", "-", "NDIS", ")"] },
                          0x07   => { "" => ["rlc", "(", "ix", "-", "NDIS", ")", ",", "a"] },
                          0x08   => { "" => ["rrc", "(", "ix", "-", "NDIS", ")", ",", "b"] },
                          0x09   => { "" => ["rrc", "(", "ix", "-", "NDIS", ")", ",", "c"] },
                          0x0A  => { "" => ["rrc", "(", "ix", "-", "NDIS", ")", ",", "d"] },
                          0x0B  => { "" => ["rrc", "(", "ix", "-", "NDIS", ")", ",", "e"] },
                          0x0C  => { "" => ["rrc", "(", "ix", "-", "NDIS", ")", ",", "h"] },
                          0x0D  => { "" => ["rrc", "(", "ix", "-", "NDIS", ")", ",", "l"] },
                          0x0E  => { "" => ["rrc", "(", "ix", "-", "NDIS", ")"] },
                          0x0F  => { "" => ["rrc", "(", "ix", "-", "NDIS", ")", ",", "a"] },
                          0x10  => { "" => ["rl", "(", "ix", "-", "NDIS", ")", ",", "b"] },
                          0x11  => { "" => ["rl", "(", "ix", "-", "NDIS", ")", ",", "c"] },
                          0x12  => { "" => ["rl", "(", "ix", "-", "NDIS", ")", ",", "d"] },
                          0x13  => { "" => ["rl", "(", "ix", "-", "NDIS", ")", ",", "e"] },
                          0x14  => { "" => ["rl", "(", "ix", "-", "NDIS", ")", ",", "h"] },
                          0x15  => { "" => ["rl", "(", "ix", "-", "NDIS", ")", ",", "l"] },
                          0x16  => { "" => ["rl", "(", "ix", "-", "NDIS", ")"] },
                          0x17  => { "" => ["rl", "(", "ix", "-", "NDIS", ")", ",", "a"] },
                          0x18  => { "" => ["rr", "(", "ix", "-", "NDIS", ")", ",", "b"] },
                          0x19  => { "" => ["rr", "(", "ix", "-", "NDIS", ")", ",", "c"] },
                          0x1A  => { "" => ["rr", "(", "ix", "-", "NDIS", ")", ",", "d"] },
                          0x1B  => { "" => ["rr", "(", "ix", "-", "NDIS", ")", ",", "e"] },
                          0x1C  => { "" => ["rr", "(", "ix", "-", "NDIS", ")", ",", "h"] },
                          0x1D  => { "" => ["rr", "(", "ix", "-", "NDIS", ")", ",", "l"] },
                          0x1E  => { "" => ["rr", "(", "ix", "-", "NDIS", ")"] },
                          0x1F  => { "" => ["rr", "(", "ix", "-", "NDIS", ")", ",", "a"] },
                          0x20  => { "" => ["sla", "(", "ix", "-", "NDIS", ")", ",", "b"] },
                          0x21  => { "" => ["sla", "(", "ix", "-", "NDIS", ")", ",", "c"] },
                          0x22  => { "" => ["sla", "(", "ix", "-", "NDIS", ")", ",", "d"] },
                          0x23  => { "" => ["sla", "(", "ix", "-", "NDIS", ")", ",", "e"] },
                          0x24  => { "" => ["sla", "(", "ix", "-", "NDIS", ")", ",", "h"] },
                          0x25  => { "" => ["sla", "(", "ix", "-", "NDIS", ")", ",", "l"] },
                          0x26  => { "" => ["sla", "(", "ix", "-", "NDIS", ")"] },
                          0x27  => { "" => ["sla", "(", "ix", "-", "NDIS", ")", ",", "a"] },
                          0x28  => { "" => ["sra", "(", "ix", "-", "NDIS", ")", ",", "b"] },
                          0x29  => { "" => ["sra", "(", "ix", "-", "NDIS", ")", ",", "c"] },
                          0x2A  => { "" => ["sra", "(", "ix", "-", "NDIS", ")", ",", "d"] },
                          0x2B  => { "" => ["sra", "(", "ix", "-", "NDIS", ")", ",", "e"] },
                          0x2C  => { "" => ["sra", "(", "ix", "-", "NDIS", ")", ",", "h"] },
                          0x2D  => { "" => ["sra", "(", "ix", "-", "NDIS", ")", ",", "l"] },
                          0x2E  => { "" => ["sra", "(", "ix", "-", "NDIS", ")"] },
                          0x2F  => { "" => ["sra", "(", "ix", "-", "NDIS", ")", ",", "a"] },
                          0x30  => { "" => ["sll", "(", "ix", "-", "NDIS", ")", ",", "b"] },
                          0x31  => { "" => ["sll", "(", "ix", "-", "NDIS", ")", ",", "c"] },
                          0x32  => { "" => ["sll", "(", "ix", "-", "NDIS", ")", ",", "d"] },
                          0x33  => { "" => ["sll", "(", "ix", "-", "NDIS", ")", ",", "e"] },
                          0x34  => { "" => ["sll", "(", "ix", "-", "NDIS", ")", ",", "h"] },
                          0x35  => { "" => ["sll", "(", "ix", "-", "NDIS", ")", ",", "l"] },
                          0x36  => { "" => ["sll", "(", "ix", "-", "NDIS", ")"] },
                          0x37  => { "" => ["sll", "(", "ix", "-", "NDIS", ")", ",", "a"] },
                          0x38  => { "" => ["srl", "(", "ix", "-", "NDIS", ")", ",", "b"] },
                          0x39  => { "" => ["srl", "(", "ix", "-", "NDIS", ")", ",", "c"] },
                          0x3A  => { "" => ["srl", "(", "ix", "-", "NDIS", ")", ",", "d"] },
                          0x3B  => { "" => ["srl", "(", "ix", "-", "NDIS", ")", ",", "e"] },
                          0x3C  => { "" => ["srl", "(", "ix", "-", "NDIS", ")", ",", "h"] },
                          0x3D  => { "" => ["srl", "(", "ix", "-", "NDIS", ")", ",", "l"] },
                          0x3E  => { "" => ["srl", "(", "ix", "-", "NDIS", ")"] },
                          0x3F  => { "" => ["srl", "(", "ix", "-", "NDIS", ")", ",", "a"] },
                          0x46  => { "" => ["bit", 0x00, ",", "(", "ix", "-", "NDIS", ")"] },
                          0x4E  => { "" => ["bit", 0x01, ",", "(", "ix", "-", "NDIS", ")"] },
                          0x56  => { "" => ["bit", 0x02, ",", "(", "ix", "-", "NDIS", ")"] },
                          0x5E  => { "" => ["bit", 0x03, ",", "(", "ix", "-", "NDIS", ")"] },
                          0x66 => { "" => ["bit", 0x04, ",", "(", "ix", "-", "NDIS", ")"] },
                          0x6E => { "" => ["bit", 0x05, ",", "(", "ix", "-", "NDIS", ")"] },
                          0x76 => { "" => ["bit", 0x06, ",", "(", "ix", "-", "NDIS", ")"] },
                          0x7E => { "" => ["bit", 0x07, ",", "(", "ix", "-", "NDIS", ")"] },
                          0x80 => { "" => ["res", 0x00, ",", "(", "ix", "-", "NDIS", ")", ",", "b"] },
                          0x81 => { "" => ["res", 0x00, ",", "(", "ix", "-", "NDIS", ")", ",", "c"] },
                          0x82 => { "" => ["res", 0x00, ",", "(", "ix", "-", "NDIS", ")", ",", "d"] },
                          0x83 => { "" => ["res", 0x00, ",", "(", "ix", "-", "NDIS", ")", ",", "e"] },
                          0x84 => { "" => ["res", 0x00, ",", "(", "ix", "-", "NDIS", ")", ",", "h"] },
                          0x85 => { "" => ["res", 0x00, ",", "(", "ix", "-", "NDIS", ")", ",", "l"] },
                          0x86 => { "" => ["res", 0x00, ",", "(", "ix", "-", "NDIS", ")"] },
                          0x87 => { "" => ["res", 0x00, ",", "(", "ix", "-", "NDIS", ")", ",", "a"] },
                          0x88 => { "" => ["res", 0x01, ",", "(", "ix", "-", "NDIS", ")", ",", "b"] },
                          0x89 => { "" => ["res", 0x01, ",", "(", "ix", "-", "NDIS", ")", ",", "c"] },
                          0x8A => { "" => ["res", 0x01, ",", "(", "ix", "-", "NDIS", ")", ",", "d"] },
                          0x8B => { "" => ["res", 0x01, ",", "(", "ix", "-", "NDIS", ")", ",", "e"] },
                          0x8C => { "" => ["res", 0x01, ",", "(", "ix", "-", "NDIS", ")", ",", "h"] },
                          0x8D => { "" => ["res", 0x01, ",", "(", "ix", "-", "NDIS", ")", ",", "l"] },
                          0x8E => { "" => ["res", 0x01, ",", "(", "ix", "-", "NDIS", ")"] },
                          0x8F => { "" => ["res", 0x01, ",", "(", "ix", "-", "NDIS", ")", ",", "a"] },
                          0x90 => { "" => ["res", 0x02, ",", "(", "ix", "-", "NDIS", ")", ",", "b"] },
                          0x91 => { "" => ["res", 0x02, ",", "(", "ix", "-", "NDIS", ")", ",", "c"] },
                          0x92 => { "" => ["res", 0x02, ",", "(", "ix", "-", "NDIS", ")", ",", "d"] },
                          0x93 => { "" => ["res", 0x02, ",", "(", "ix", "-", "NDIS", ")", ",", "e"] },
                          0x94 => { "" => ["res", 0x02, ",", "(", "ix", "-", "NDIS", ")", ",", "h"] },
                          0x95 => { "" => ["res", 0x02, ",", "(", "ix", "-", "NDIS", ")", ",", "l"] },
                          0x96 => { "" => ["res", 0x02, ",", "(", "ix", "-", "NDIS", ")"] },
                          0x97 => { "" => ["res", 0x02, ",", "(", "ix", "-", "NDIS", ")", ",", "a"] },
                          0x98 => { "" => ["res", 0x03, ",", "(", "ix", "-", "NDIS", ")", ",", "b"] },
                          0x99 => { "" => ["res", 0x03, ",", "(", "ix", "-", "NDIS", ")", ",", "c"] },
                          0x9A => { "" => ["res", 0x03, ",", "(", "ix", "-", "NDIS", ")", ",", "d"] },
                          0x9B => { "" => ["res", 0x03, ",", "(", "ix", "-", "NDIS", ")", ",", "e"] },
                          0x9C => { "" => ["res", 0x03, ",", "(", "ix", "-", "NDIS", ")", ",", "h"] },
                          0x9D => { "" => ["res", 0x03, ",", "(", "ix", "-", "NDIS", ")", ",", "l"] },
                          0x9E => { "" => ["res", 0x03, ",", "(", "ix", "-", "NDIS", ")"] },
                          0x9F => { "" => ["res", 0x03, ",", "(", "ix", "-", "NDIS", ")", ",", "a"] },
                          0xA0 => { "" => ["res", 0x04, ",", "(", "ix", "-", "NDIS", ")", ",", "b"] },
                          0xA1 => { "" => ["res", 0x04, ",", "(", "ix", "-", "NDIS", ")", ",", "c"] },
                          0xA2 => { "" => ["res", 0x04, ",", "(", "ix", "-", "NDIS", ")", ",", "d"] },
                          0xA3 => { "" => ["res", 0x04, ",", "(", "ix", "-", "NDIS", ")", ",", "e"] },
                          0xA4 => { "" => ["res", 0x04, ",", "(", "ix", "-", "NDIS", ")", ",", "h"] },
                          0xA5 => { "" => ["res", 0x04, ",", "(", "ix", "-", "NDIS", ")", ",", "l"] },
                          0xA6 => { "" => ["res", 0x04, ",", "(", "ix", "-", "NDIS", ")"] },
                          0xA7 => { "" => ["res", 0x04, ",", "(", "ix", "-", "NDIS", ")", ",", "a"] },
                          0xA8 => { "" => ["res", 0x05, ",", "(", "ix", "-", "NDIS", ")", ",", "b"] },
                          0xA9 => { "" => ["res", 0x05, ",", "(", "ix", "-", "NDIS", ")", ",", "c"] },
                          0xAA => { "" => ["res", 0x05, ",", "(", "ix", "-", "NDIS", ")", ",", "d"] },
                          0xAB => { "" => ["res", 0x05, ",", "(", "ix", "-", "NDIS", ")", ",", "e"] },
                          0xAC => { "" => ["res", 0x05, ",", "(", "ix", "-", "NDIS", ")", ",", "h"] },
                          0xAD => { "" => ["res", 0x05, ",", "(", "ix", "-", "NDIS", ")", ",", "l"] },
                          0xAE => { "" => ["res", 0x05, ",", "(", "ix", "-", "NDIS", ")"] },
                          0xAF => { "" => ["res", 0x05, ",", "(", "ix", "-", "NDIS", ")", ",", "a"] },
                          0xB0 => { "" => ["res", 0x06, ",", "(", "ix", "-", "NDIS", ")", ",", "b"] },
                          0xB1 => { "" => ["res", 0x06, ",", "(", "ix", "-", "NDIS", ")", ",", "c"] },
                          0xB2 => { "" => ["res", 0x06, ",", "(", "ix", "-", "NDIS", ")", ",", "d"] },
                          0xB3 => { "" => ["res", 0x06, ",", "(", "ix", "-", "NDIS", ")", ",", "e"] },
                          0xB4 => { "" => ["res", 0x06, ",", "(", "ix", "-", "NDIS", ")", ",", "h"] },
                          0xB5 => { "" => ["res", 0x06, ",", "(", "ix", "-", "NDIS", ")", ",", "l"] },
                          0xB6 => { "" => ["res", 0x06, ",", "(", "ix", "-", "NDIS", ")"] },
                          0xB7 => { "" => ["res", 0x06, ",", "(", "ix", "-", "NDIS", ")", ",", "a"] },
                          0xB8 => { "" => ["res", 0x07, ",", "(", "ix", "-", "NDIS", ")", ",", "b"] },
                          0xB9 => { "" => ["res", 0x07, ",", "(", "ix", "-", "NDIS", ")", ",", "c"] },
                          0xBA => { "" => ["res", 0x07, ",", "(", "ix", "-", "NDIS", ")", ",", "d"] },
                          0xBB => { "" => ["res", 0x07, ",", "(", "ix", "-", "NDIS", ")", ",", "e"] },
                          0xBC => { "" => ["res", 0x07, ",", "(", "ix", "-", "NDIS", ")", ",", "h"] },
                          0xBD => { "" => ["res", 0x07, ",", "(", "ix", "-", "NDIS", ")", ",", "l"] },
                          0xBE => { "" => ["res", 0x07, ",", "(", "ix", "-", "NDIS", ")"] },
                          0xBF => { "" => ["res", 0x07, ",", "(", "ix", "-", "NDIS", ")", ",", "a"] },
                          0xC0 => { "" => ["set", 0x00, ",", "(", "ix", "-", "NDIS", ")", ",", "b"] },
                          0xC1 => { "" => ["set", 0x00, ",", "(", "ix", "-", "NDIS", ")", ",", "c"] },
                          0xC2 => { "" => ["set", 0x00, ",", "(", "ix", "-", "NDIS", ")", ",", "d"] },
                          0xC3 => { "" => ["set", 0x00, ",", "(", "ix", "-", "NDIS", ")", ",", "e"] },
                          0xC4 => { "" => ["set", 0x00, ",", "(", "ix", "-", "NDIS", ")", ",", "h"] },
                          0xC5 => { "" => ["set", 0x00, ",", "(", "ix", "-", "NDIS", ")", ",", "l"] },
                          0xC6 => { "" => ["set", 0x00, ",", "(", "ix", "-", "NDIS", ")"] },
                          0xC7 => { "" => ["set", 0x00, ",", "(", "ix", "-", "NDIS", ")", ",", "a"] },
                          0xC8 => { "" => ["set", 0x01, ",", "(", "ix", "-", "NDIS", ")", ",", "b"] },
                          0xC9 => { "" => ["set", 0x01, ",", "(", "ix", "-", "NDIS", ")", ",", "c"] },
                          0xCA => { "" => ["set", 0x01, ",", "(", "ix", "-", "NDIS", ")", ",", "d"] },
                          0xCB => { "" => ["set", 0x01, ",", "(", "ix", "-", "NDIS", ")", ",", "e"] },
                          0xCC => { "" => ["set", 0x01, ",", "(", "ix", "-", "NDIS", ")", ",", "h"] },
                          0xCD => { "" => ["set", 0x01, ",", "(", "ix", "-", "NDIS", ")", ",", "l"] },
                          0xCE => { "" => ["set", 0x01, ",", "(", "ix", "-", "NDIS", ")"] },
                          0xCF => { "" => ["set", 0x01, ",", "(", "ix", "-", "NDIS", ")", ",", "a"] },
                          0xD0 => { "" => ["set", 0x02, ",", "(", "ix", "-", "NDIS", ")", ",", "b"] },
                          0xD1 => { "" => ["set", 0x02, ",", "(", "ix", "-", "NDIS", ")", ",", "c"] },
                          0xD2 => { "" => ["set", 0x02, ",", "(", "ix", "-", "NDIS", ")", ",", "d"] },
                          0xD3 => { "" => ["set", 0x02, ",", "(", "ix", "-", "NDIS", ")", ",", "e"] },
                          0xD4 => { "" => ["set", 0x02, ",", "(", "ix", "-", "NDIS", ")", ",", "h"] },
                          0xD5 => { "" => ["set", 0x02, ",", "(", "ix", "-", "NDIS", ")", ",", "l"] },
                          0xD6 => { "" => ["set", 0x02, ",", "(", "ix", "-", "NDIS", ")"] },
                          0xD7 => { "" => ["set", 0x02, ",", "(", "ix", "-", "NDIS", ")", ",", "a"] },
                          0xD8 => { "" => ["set", 0x03, ",", "(", "ix", "-", "NDIS", ")", ",", "b"] },
                          0xD9 => { "" => ["set", 0x03, ",", "(", "ix", "-", "NDIS", ")", ",", "c"] },
                          0xDA => { "" => ["set", 0x03, ",", "(", "ix", "-", "NDIS", ")", ",", "d"] },
                          0xDB => { "" => ["set", 0x03, ",", "(", "ix", "-", "NDIS", ")", ",", "e"] },
                          0xDC => { "" => ["set", 0x03, ",", "(", "ix", "-", "NDIS", ")", ",", "h"] },
                          0xDD => { "" => ["set", 0x03, ",", "(", "ix", "-", "NDIS", ")", ",", "l"] },
                          0xDE => { "" => ["set", 0x03, ",", "(", "ix", "-", "NDIS", ")"] },
                          0xDF => { "" => ["set", 0x03, ",", "(", "ix", "-", "NDIS", ")", ",", "a"] },
                          0xE0 => { "" => ["set", 0x04, ",", "(", "ix", "-", "NDIS", ")", ",", "b"] },
                          0xE1 => { "" => ["set", 0x04, ",", "(", "ix", "-", "NDIS", ")", ",", "c"] },
                          0xE2 => { "" => ["set", 0x04, ",", "(", "ix", "-", "NDIS", ")", ",", "d"] },
                          0xE3 => { "" => ["set", 0x04, ",", "(", "ix", "-", "NDIS", ")", ",", "e"] },
                          0xE4 => { "" => ["set", 0x04, ",", "(", "ix", "-", "NDIS", ")", ",", "h"] },
                          0xE5 => { "" => ["set", 0x04, ",", "(", "ix", "-", "NDIS", ")", ",", "l"] },
                          0xE6 => { "" => ["set", 0x04, ",", "(", "ix", "-", "NDIS", ")"] },
                          0xE7 => { "" => ["set", 0x04, ",", "(", "ix", "-", "NDIS", ")", ",", "a"] },
                          0xE8 => { "" => ["set", 0x05, ",", "(", "ix", "-", "NDIS", ")", ",", "b"] },
                          0xE9 => { "" => ["set", 0x05, ",", "(", "ix", "-", "NDIS", ")", ",", "c"] },
                          0xEA => { "" => ["set", 0x05, ",", "(", "ix", "-", "NDIS", ")", ",", "d"] },
                          0xEB => { "" => ["set", 0x05, ",", "(", "ix", "-", "NDIS", ")", ",", "e"] },
                          0xEC => { "" => ["set", 0x05, ",", "(", "ix", "-", "NDIS", ")", ",", "h"] },
                          0xED => { "" => ["set", 0x05, ",", "(", "ix", "-", "NDIS", ")", ",", "l"] },
                          0xEE => { "" => ["set", 0x05, ",", "(", "ix", "-", "NDIS", ")"] },
                          0xEF => { "" => ["set", 0x05, ",", "(", "ix", "-", "NDIS", ")", ",", "a"] },
                          0xF0 => { "" => ["set", 0x06, ",", "(", "ix", "-", "NDIS", ")", ",", "b"] },
                          0xF1 => { "" => ["set", 0x06, ",", "(", "ix", "-", "NDIS", ")", ",", "c"] },
                          0xF2 => { "" => ["set", 0x06, ",", "(", "ix", "-", "NDIS", ")", ",", "d"] },
                          0xF3 => { "" => ["set", 0x06, ",", "(", "ix", "-", "NDIS", ")", ",", "e"] },
                          0xF4 => { "" => ["set", 0x06, ",", "(", "ix", "-", "NDIS", ")", ",", "h"] },
                          0xF5 => { "" => ["set", 0x06, ",", "(", "ix", "-", "NDIS", ")", ",", "l"] },
                          0xF6 => { "" => ["set", 0x06, ",", "(", "ix", "-", "NDIS", ")"] },
                          0xF7 => { "" => ["set", 0x06, ",", "(", "ix", "-", "NDIS", ")", ",", "a"] },
                          0xF8 => { "" => ["set", 0x07, ",", "(", "ix", "-", "NDIS", ")", ",", "b"] },
                          0xF9 => { "" => ["set", 0x07, ",", "(", "ix", "-", "NDIS", ")", ",", "c"] },
                          0xFA => { "" => ["set", 0x07, ",", "(", "ix", "-", "NDIS", ")", ",", "d"] },
                          0xFB => { "" => ["set", 0x07, ",", "(", "ix", "-", "NDIS", ")", ",", "e"] },
                          0xFC => { "" => ["set", 0x07, ",", "(", "ix", "-", "NDIS", ")", ",", "h"] },
                          0xFD => { "" => ["set", 0x07, ",", "(", "ix", "-", "NDIS", ")", ",", "l"] },
                          0xFE => { "" => ["set", 0x07, ",", "(", "ix", "-", "NDIS", ")"] },
                          0xFF => { "" => ["set", 0x07, ",", "(", "ix", "-", "NDIS", ")", ",", "a"] },
                        },
                      },
               0xDD => { 0x00 => { "" => ["stop"] } },
               0xE1 => { "" => ["pop", "ix"] },
               0xE3 => { "" => ["ex", "(", "sp", ")", ",", "ix"] },
               0xE5 => {
                        "" => ["push", "ix"],
                        0xE1 => { "" => ["ld", "hl", ",", "ix"] },
                        0xFD => { 0xE1 => { "" => ["ld", "iy", ",", "ix"] } },
                      },
               0xE9 => { "" => ["jp", "(", "ix", ")"] },
               0xF9 => { "" => ["ld", "sp", ",", "ix"] },
             },
    0xDE => { N => { "" => ["sbc", "a", ",", "N"] } },
    0xDF => { "" => ["rst", 0x18] },
    0xE0 => { "" => ["ret", "po"] },
    0xE1 => { "" => ["pop", "hl"] },
    0xE2 => { NNl => { NNh => { "" => ["jp", "po", ",", "NN"] } } },
    0xE3 => { "" => ["ex", "(", "sp", ")", ",", "hl"] },
    0xE4 => { NNl => { NNh => { "" => ["call", "po", ",", "NN"] } } },
    0xE5 => {
               "" => ["push", "hl"],
               0xDD => { 0xE1 => { "" => ["ld", "ix", ",", "hl"] } },
               0xFD => { 0xE1 => { "" => ["ld", "iy", ",", "hl"] } },
             },
    0xE6 => { N => { "" => ["and", "N"] } },
    0xE7 => { "" => ["rst", 0x20] },
    0xE8 => { "" => ["ret", "pe"] },
    0xE9 => { "" => ["jp", "(", "hl", ")"] },
    0xEA => { NNl => { NNh => { "" => ["jp", "pe", ",", "NN"] } } },
    0xEB => { "" => ["ex", "de", ",", "hl"] },
    0xEC => { NNl => { NNh => { "" => ["call", "pe", ",", "NN"] } } },
    0xED => {
               0x40  => { "" => ["in", "b", ",", "(", "c", ")"] },
               0x41  => { "" => ["out", "(", "c", ")", ",", "b"] },
               0x42  => { "" => ["sbc", "hl", ",", "bc"] },
               0x43  => { NNl => { NNh => { "" => ["ld", "(", "NN", ")", ",", "bc"] } } },
               0x44  => { "" => ["neg"] },
               0x45  => { "" => ["retn"] },
               0x46  => { "" => ["im", 0x00] },
               0x47  => { "" => ["ld", "i", ",", "a"] },
               0x48  => { "" => ["in", "c", ",", "(", "c", ")"] },
               0x49  => { "" => ["out", "(", "c", ")", ",", "c"] },
               0x4A  => { "" => ["adc", "hl", ",", "bc"] },
               0x4B  => { NNl => { NNh => { "" => ["ld", "bc", ",", "(", "NN", ")"] } } },
               0x4D  => { "" => ["reti"] },
               0x4F  => { "" => ["ld", "r", ",", "a"] },
               0x50  => { "" => ["in", "d", ",", "(", "c", ")"] },
               0x51  => { "" => ["out", "(", "c", ")", ",", "d"] },
               0x52  => { "" => ["sbc", "hl", ",", "de"] },
               0x53  => { NNl => { NNh => { "" => ["ld", "(", "NN", ")", ",", "de"] } } },
               0x56  => { "" => ["im", 0x01] },
               0x57  => { "" => ["ld", "a", ",", "i"] },
               0x58  => { "" => ["in", "e", ",", "(", "c", ")"] },
               0x59  => { "" => ["out", "(", "c", ")", ",", "e"] },
               0x5A  => { "" => ["adc", "hl", ",", "de"] },
               0x5B  => { NNl => { NNh => { "" => ["ld", "de", ",", "(", "NN", ")"] } } },
               0x5E  => { "" => ["im", 0x02] },
               0x5F  => { "" => ["ld", "a", ",", "r"] },
               0x60  => { "" => ["in", "h", ",", "(", "c", ")"] },
               0x61  => { "" => ["out", "(", "c", ")", ",", "h"] },
               0x62  => { "" => ["sbc", "hl", ",", "hl"] },
               0x63  => { NNl => { NNh => { "" => ["ld", "(", "NN", ")", ",", "hl"] } } },
               0x67 => { "" => ["rrd"] },
               0x68 => { "" => ["in", "l", ",", "(", "c", ")"] },
               0x69 => { "" => ["out", "(", "c", ")", ",", "l"] },
               0x6A => { "" => ["adc", "hl", ",", "hl"] },
               0x6B => { NNl => { NNh => { "" => ["ld", "hl", ",", "(", "NN", ")"] } } },
               0x6F => { "" => ["rld"] },
               0x70 => { "" => ["in", "f", ",", "(", "c", ")"] },
               0x71 => { "" => ["out", "(", "c", ")", ",", 0x00] },
               0x72 => { "" => ["sbc", "hl", ",", "sp"] },
               0x73 => { NNl => { NNh => { "" => ["ld", "(", "NN", ")", ",", "sp"] } } },
               0x78 => { "" => ["in", "a", ",", "(", "c", ")"] },
               0x79 => { "" => ["out", "(", "c", ")", ",", "a"] },
               0x7A => { "" => ["adc", "hl", ",", "sp"] },
               0x7B => { NNl => { NNh => { "" => ["ld", "sp", ",", "(", "NN", ")"] } } },
               0xA0 => { "" => ["ldi"] },
               0xA1 => { "" => ["cpi"] },
               0xA2 => { "" => ["ini"] },
               0xA3 => { "" => ["outi"] },
               0xA8 => { "" => ["ldd"] },
               0xA9 => { "" => ["cpd"] },
               0xAA => { "" => ["ind"] },
               0xAB => { "" => ["outd"] },
               0xB0 => { "" => ["ldir"] },
               0xB1 => { "" => ["cpir"] },
               0xB2 => { "" => ["inir"] },
               0xB3 => { "" => ["otir"] },
               0xB8 => { "" => ["lddr"] },
               0xB9 => { "" => ["cpdr"] },
               0xBA => { "" => ["indr"] },
               0xBB => { "" => ["otdr"] },
             },
    0xEE => { N => { "" => ["xor", "N"] } },
    0xEF => { "" => ["rst", 0x28] },
    0xF0 => { "" => ["ret", "p"] },
    0xF1 => { "" => ["pop", "af"] },
    0xF2 => { NNl => { NNh => { "" => ["jp", "p", ",", "NN"] } } },
    0xF3 => { "" => ["di"] },
    0xF4 => { NNl => { NNh => { "" => ["call", "p", ",", "NN"] } } },
    0xF5 => { "" => ["push", "af"] },
    0xF6 => { N => { "" => ["or", "N"] } },
    0xF7 => { "" => ["rst", 0x30] },
    0xF8 => { "" => ["ret", "m"] },
    0xF9 => { "" => ["ld", "sp", ",", "hl"] },
    0xFA => { NNl => { NNh => { "" => ["jp", "m", ",", "NN"] } } },
    0xFB => { "" => ["ei"] },
    0xFC => { NNl => { NNh => { "" => ["call", "m", ",", "NN"] } } },
    0xFD => {
               0x03   => { "" => ["inc", "bc"] },
               0x04   => { "" => ["inc", "b"] },
               0x05   => { "" => ["dec", "b"] },
               0x06   => { N => { "" => ["ld", "b", ",", "N"] } },
               0x09   => { "" => ["add", "iy", ",", "bc"] },
               0x0B  => { "" => ["dec", "bc"] },
               0x0C  => { "" => ["inc", "c"] },
               0x0D  => { "" => ["dec", "c"] },
               0x0E  => { N => { "" => ["ld", "c", ",", "N"] } },
               0x13  => { "" => ["inc", "de"] },
               0x14  => { "" => ["inc", "d"] },
               0x15  => { "" => ["dec", "d"] },
               0x16  => { N => { "" => ["ld", "d", ",", "N"] } },
               0x19  => { "" => ["add", "iy", ",", "de"] },
               0x1B  => { "" => ["dec", "de"] },
               0x1C  => { "" => ["inc", "e"] },
               0x1D  => { "" => ["dec", "e"] },
               0x1E  => { N => { "" => ["ld", "e", ",", "N"] } },
               0x21  => { NNl => { NNh => { "" => ["ld", "iy", ",", "NN"] } } },
               0x22  => { NNl => { NNh => { "" => ["ld", "(", "NN", ")", ",", "iy"] } } },
               0x23  => { "" => ["inc", "iy"] },
               0x24  => { "" => ["inc", "iyh"] },
               0x25  => { "" => ["dec", "iyh"] },
               0x26  => { N => { "" => ["ld", "iyh", ",", "N"] } },
               0x29  => { "" => ["add", "iy", ",", "iy"] },
               0x2A  => { NNl => { NNh => { "" => ["ld", "iy", ",", "(", "NN", ")"] } } },
               0x2B  => { "" => ["dec", "iy"] },
               0x2C  => { "" => ["inc", "iyl"] },
               0x2D  => { "" => ["dec", "iyl"] },
               0x2E  => { N => { "" => ["ld", "iyl", ",", "N"] } },
               0x33  => { "" => ["inc", "sp"] },
               0x34  => {
                        0x00 => { "" => ["inc", "(", "iy", ")"] },
                        "DIS" => { "" => ["inc", "(", "iy", "+", "DIS", ")"] },
                        "NDIS" => { "" => ["inc", "(", "iy", "-", "NDIS", ")"] },
                      },
               0x35  => {
                        0x00 => { "" => ["dec", "(", "iy", ")"] },
                        "DIS" => { "" => ["dec", "(", "iy", "+", "DIS", ")"] },
                        "NDIS" => { "" => ["dec", "(", "iy", "-", "NDIS", ")"] },
                      },
               0x36  => {
                        0x00 => {
                          N => {
                                 "" => ["ld", "(", "iy", ")", ",", "N"],
                                 0xFD => {
                                   0x23 => { "" => ["ldi", "(", "iy", ")", ",", "N"] },
                                   0x2B => { "" => ["ldd", "(", "iy", ")", ",", "N"] },
                                 },
                               },
                        },
                        "DIS" => {
                          N => {
                                 "" => ["ld", "(", "iy", "+", "DIS", ")", ",", "N"],
                                 0xFD => {
                                   0x23 => { "" => ["ldi", "(", "iy", "+", "DIS", ")", ",", "N"] },
                                   0x2B => { "" => ["ldd", "(", "iy", "+", "DIS", ")", ",", "N"] },
                                 },
                               },
                        },
                        "NDIS" => {
                          N => {
                                 "" => ["ld", "(", "iy", "-", "NDIS", ")", ",", "N"],
                                 0xFD => {
                                   0x23 => { "" => ["ldi", "(", "iy", "-", "NDIS", ")", ",", "N"] },
                                   0x2B => { "" => ["ldd", "(", "iy", "-", "NDIS", ")", ",", "N"] },
                                 },
                               },
                        },
                      },
               0x39  => { "" => ["add", "iy", ",", "sp"] },
               0x3B  => { "" => ["dec", "sp"] },
               0x3C  => { "" => ["inc", "a"] },
               0x3D  => { "" => ["dec", "a"] },
               0x3E  => { N => { "" => ["ld", "a", ",", "N"] } },
               0x40  => { "" => ["ld", "b", ",", "b"] },
               0x41  => { "" => ["ld", "b", ",", "c"] },
               0x42  => { "" => ["ld", "b", ",", "d"] },
               0x43  => { "" => ["ld", "b", ",", "e"] },
               0x44  => {
                        "" => ["ld", "b", ",", "iyh"],
                        0xFD => { 0x4D => { "" => ["ld", "bc", ",", "iy"] } },
                      },
               0x45  => { "" => ["ld", "b", ",", "iyl"] },
               0x46  => {
                        0x00 => {
                          "" => ["ld", "b", ",", "(", "iy", ")"],
                          0xFD => {
                            0x23 => { "" => ["ldi", "b", ",", "(", "iy", ")"] },
                            0x2B => { "" => ["ldd", "b", ",", "(", "iy", ")"] },
                          },
                        },
                        "DIS" => {
                          "" => ["ld", "b", ",", "(", "iy", "+", "DIS", ")"],
                          0xFD => {
                            0x23 => { "" => ["ldi", "b", ",", "(", "iy", "+", "DIS", ")"] },
                            0x2B => { "" => ["ldd", "b", ",", "(", "iy", "+", "DIS", ")"] },
                          },
                        },
                        "NDIS" => {
                          "" => ["ld", "b", ",", "(", "iy", "-", "NDIS", ")"],
                          0xFD => {
                            0x23 => { "" => ["ldi", "b", ",", "(", "iy", "-", "NDIS", ")"] },
                            0x2B => { "" => ["ldd", "b", ",", "(", "iy", "-", "NDIS", ")"] },
                          },
                        },
                      },
               0x47  => { "" => ["ld", "b", ",", "a"] },
               0x48  => { "" => ["ld", "c", ",", "b"] },
               0x49  => { "" => ["ld", "c", ",", "c"] },
               0x4A  => { "" => ["ld", "c", ",", "d"] },
               0x4B  => { "" => ["ld", "c", ",", "e"] },
               0x4C  => { "" => ["ld", "c", ",", "iyh"] },
               0x4D  => { "" => ["ld", "c", ",", "iyl"] },
               0x4E  => {
                        0x00 => {
                          "" => ["ld", "c", ",", "(", "iy", ")"],
                          0xFD => {
                            0x23 => {
                                    "" => ["ldi", "c", ",", "(", "iy", ")"],
                                    0xFD => {
                                      0x46 => {
                                              0x00 => { 0xFD => { 0x23 => { "" => ["ldi", "bc", ",", "(", "iy", ")"] } } },
                                            },
                                    },
                                  },
                            0x2B => { "" => ["ldd", "c", ",", "(", "iy", ")"] },
                            0x46 => { 0x01 => { "" => ["ld", "bc", ",", "(", "iy", ")"] } },
                          },
                        },
                        "DIS" => {
                          "" => ["ld", "c", ",", "(", "iy", "+", "DIS", ")"],
                          0xFD => {
                            0x23 => {
                                    "" => ["ldi", "c", ",", "(", "iy", "+", "DIS", ")"],
                                    0xFD => {
                                      0x46 => {
                                              DIS => {
                                                       0xFD => { 0x23 => { "" => ["ldi", "bc", ",", "(", "iy", "+", "DIS", ")"] } },
                                                     },
                                            },
                                    },
                                  },
                            0x2B => { "" => ["ldd", "c", ",", "(", "iy", "+", "DIS", ")"] },
                            0x46 => {
                                    "DIS+0x01" => { "" => ["ld", "bc", ",", "(", "iy", "+", "DIS", ")"] },
                                  },
                          },
                        },
                        "NDIS" => {
                          "" => ["ld", "c", ",", "(", "iy", "-", "NDIS", ")"],
                          0xFD => {
                            0x23 => {
                                    "" => ["ldi", "c", ",", "(", "iy", "-", "NDIS", ")"],
                                    0xFD => {
                                      0x46 => {
                                              NDIS => {
                                                0xFD => { 0x23 => { "" => ["ldi", "bc", ",", "(", "iy", "-", "NDIS", ")"] } },
                                              },
                                            },
                                    },
                                  },
                            0x2B => { "" => ["ldd", "c", ",", "(", "iy", "-", "NDIS", ")"] },
                            0x46 => {
                                    "NDIS+0x01" => { "" => ["ld", "bc", ",", "(", "iy", "-", "NDIS", ")"] },
                                  },
                          },
                        },
                      },
               0x4F  => { "" => ["ld", "c", ",", "a"] },
               0x50  => { "" => ["ld", "d", ",", "b"] },
               0x51  => { "" => ["ld", "d", ",", "c"] },
               0x52  => { "" => ["ld", "d", ",", "d"] },
               0x53  => { "" => ["ld", "d", ",", "e"] },
               0x54  => {
                        "" => ["ld", "d", ",", "iyh"],
                        0xFD => { 0x5D => { "" => ["ld", "de", ",", "iy"] } },
                      },
               0x55  => { "" => ["ld", "d", ",", "iyl"] },
               0x56  => {
                        0x00 => {
                          "" => ["ld", "d", ",", "(", "iy", ")"],
                          0xFD => {
                            0x23 => { "" => ["ldi", "d", ",", "(", "iy", ")"] },
                            0x2B => { "" => ["ldd", "d", ",", "(", "iy", ")"] },
                          },
                        },
                        "DIS" => {
                          "" => ["ld", "d", ",", "(", "iy", "+", "DIS", ")"],
                          0xFD => {
                            0x23 => { "" => ["ldi", "d", ",", "(", "iy", "+", "DIS", ")"] },
                            0x2B => { "" => ["ldd", "d", ",", "(", "iy", "+", "DIS", ")"] },
                          },
                        },
                        "NDIS" => {
                          "" => ["ld", "d", ",", "(", "iy", "-", "NDIS", ")"],
                          0xFD => {
                            0x23 => { "" => ["ldi", "d", ",", "(", "iy", "-", "NDIS", ")"] },
                            0x2B => { "" => ["ldd", "d", ",", "(", "iy", "-", "NDIS", ")"] },
                          },
                        },
                      },
               0x57  => { "" => ["ld", "d", ",", "a"] },
               0x58  => { "" => ["ld", "e", ",", "b"] },
               0x59  => { "" => ["ld", "e", ",", "c"] },
               0x5A  => { "" => ["ld", "e", ",", "d"] },
               0x5B  => { "" => ["ld", "e", ",", "e"] },
               0x5C  => { "" => ["ld", "e", ",", "iyh"] },
               0x5D  => { "" => ["ld", "e", ",", "iyl"] },
               0x5E  => {
                        0x00 => {
                          "" => ["ld", "e", ",", "(", "iy", ")"],
                          0xFD => {
                            0x23 => {
                                    "" => ["ldi", "e", ",", "(", "iy", ")"],
                                    0xFD => {
                                      0x56 => {
                                              0x00 => { 0xFD => { 0x23 => { "" => ["ldi", "de", ",", "(", "iy", ")"] } } },
                                            },
                                    },
                                  },
                            0x2B => { "" => ["ldd", "e", ",", "(", "iy", ")"] },
                            0x56 => { 0x01 => { "" => ["ld", "de", ",", "(", "iy", ")"] } },
                          },
                        },
                        "DIS" => {
                          "" => ["ld", "e", ",", "(", "iy", "+", "DIS", ")"],
                          0xFD => {
                            0x23 => {
                                    "" => ["ldi", "e", ",", "(", "iy", "+", "DIS", ")"],
                                    0xFD => {
                                      0x56 => {
                                              DIS => {
                                                       0xFD => { 0x23 => { "" => ["ldi", "de", ",", "(", "iy", "+", "DIS", ")"] } },
                                                     },
                                            },
                                    },
                                  },
                            0x2B => { "" => ["ldd", "e", ",", "(", "iy", "+", "DIS", ")"] },
                            0x56 => {
                                    "DIS+0x01" => { "" => ["ld", "de", ",", "(", "iy", "+", "DIS", ")"] },
                                  },
                          },
                        },
                        "NDIS" => {
                          "" => ["ld", "e", ",", "(", "iy", "-", "NDIS", ")"],
                          0xFD => {
                            0x23 => {
                                    "" => ["ldi", "e", ",", "(", "iy", "-", "NDIS", ")"],
                                    0xFD => {
                                      0x56 => {
                                              NDIS => {
                                                0xFD => { 0x23 => { "" => ["ldi", "de", ",", "(", "iy", "-", "NDIS", ")"] } },
                                              },
                                            },
                                    },
                                  },
                            0x2B => { "" => ["ldd", "e", ",", "(", "iy", "-", "NDIS", ")"] },
                            0x56 => {
                                    "NDIS+0x01" => { "" => ["ld", "de", ",", "(", "iy", "-", "NDIS", ")"] },
                                  },
                          },
                        },
                      },
               0x5F  => { "" => ["ld", "e", ",", "a"] },
               0x60  => { "" => ["ld", "iyh", ",", "b"] },
               0x61  => { "" => ["ld", "iyh", ",", "c"] },
               0x62  => { "" => ["ld", "iyh", ",", "d"] },
               0x63  => { "" => ["ld", "iyh", ",", "e"] },
               0x64 => { "" => ["ld", "iyh", ",", "iyh"] },
               0x65 => { "" => ["ld", "iyh", ",", "iyl"] },
               0x66 => {
                        0x00 => {
                          "" => ["ld", "h", ",", "(", "iy", ")"],
                          0xFD => {
                            0x23 => { "" => ["ldi", "h", ",", "(", "iy", ")"] },
                            0x2B => { "" => ["ldd", "h", ",", "(", "iy", ")"] },
                          },
                        },
                        "DIS" => {
                          "" => ["ld", "h", ",", "(", "iy", "+", "DIS", ")"],
                          0xFD => {
                            0x23 => { "" => ["ldi", "h", ",", "(", "iy", "+", "DIS", ")"] },
                            0x2B => { "" => ["ldd", "h", ",", "(", "iy", "+", "DIS", ")"] },
                          },
                        },
                        "NDIS" => {
                          "" => ["ld", "h", ",", "(", "iy", "-", "NDIS", ")"],
                          0xFD => {
                            0x23 => { "" => ["ldi", "h", ",", "(", "iy", "-", "NDIS", ")"] },
                            0x2B => { "" => ["ldd", "h", ",", "(", "iy", "-", "NDIS", ")"] },
                          },
                        },
                      },
               0x67 => { "" => ["ld", "iyh", ",", "a"] },
               0x68 => { "" => ["ld", "iyl", ",", "b"] },
               0x69 => {
                        "" => ["ld", "iyl", ",", "c"],
                        0xFD => { 0x60 => { "" => ["ld", "iy", ",", "bc"] } },
                      },
               0x6A => { "" => ["ld", "iyl", ",", "d"] },
               0x6B => {
                        "" => ["ld", "iyl", ",", "e"],
                        0xFD => { 0x62 => { "" => ["ld", "iy", ",", "de"] } },
                      },
               0x6C => { "" => ["ld", "iyl", ",", "iyh"] },
               0x6D => {
                        "" => ["ld", "iyl", ",", "iyl"],
                        0xFD => { 0x64 => { "" => ["ld", "iy", ",", "iy"] } },
                      },
               0x6E => {
                        0x00 => {
                          "" => ["ld", "l", ",", "(", "iy", ")"],
                          0xFD => {
                            0x23  => {
                                     "" => ["ldi", "l", ",", "(", "iy", ")"],
                                     0xFD => {
                                       0x66 => {
                                                0x00 => { 0xFD => { 0x23 => { "" => ["ldi", "hl", ",", "(", "iy", ")"] } } },
                                              },
                                     },
                                   },
                            0x2B  => { "" => ["ldd", "l", ",", "(", "iy", ")"] },
                            0x66 => { 0x01 => { "" => ["ld", "hl", ",", "(", "iy", ")"] } },
                          },
                        },
                        "DIS" => {
                          "" => ["ld", "l", ",", "(", "iy", "+", "DIS", ")"],
                          0xFD => {
                            0x23  => {
                                     "" => ["ldi", "l", ",", "(", "iy", "+", "DIS", ")"],
                                     0xFD => {
                                       0x66 => {
                                                DIS => {
                                                         0xFD => { 0x23 => { "" => ["ldi", "hl", ",", "(", "iy", "+", "DIS", ")"] } },
                                                       },
                                              },
                                     },
                                   },
                            0x2B  => { "" => ["ldd", "l", ",", "(", "iy", "+", "DIS", ")"] },
                            0x66 => {
                                     "DIS+0x01" => { "" => ["ld", "hl", ",", "(", "iy", "+", "DIS", ")"] },
                                   },
                          },
                        },
                        "NDIS" => {
                          "" => ["ld", "l", ",", "(", "iy", "-", "NDIS", ")"],
                          0xFD => {
                            0x23  => {
                                     "" => ["ldi", "l", ",", "(", "iy", "-", "NDIS", ")"],
                                     0xFD => {
                                       0x66 => {
                                                NDIS => {
                                                  0xFD => { 0x23 => { "" => ["ldi", "hl", ",", "(", "iy", "-", "NDIS", ")"] } },
                                                },
                                              },
                                     },
                                   },
                            0x2B  => { "" => ["ldd", "l", ",", "(", "iy", "-", "NDIS", ")"] },
                            0x66 => {
                                     "NDIS+0x01" => { "" => ["ld", "hl", ",", "(", "iy", "-", "NDIS", ")"] },
                                   },
                          },
                        },
                      },
               0x6F => { "" => ["ld", "iyl", ",", "a"] },
               0x70 => {
                        0x00 => {
                          "" => ["ld", "(", "iy", ")", ",", "b"],
                          0xFD => {
                            0x23 => { "" => ["ldi", "(", "iy", ")", ",", "b"] },
                            0x2B => { "" => ["ldd", "(", "iy", ")", ",", "b"] },
                          },
                        },
                        "DIS" => {
                          "" => ["ld", "(", "iy", "+", "DIS", ")", ",", "b"],
                          0xFD => {
                            0x23 => { "" => ["ldi", "(", "iy", "+", "DIS", ")", ",", "b"] },
                            0x2B => { "" => ["ldd", "(", "iy", "+", "DIS", ")", ",", "b"] },
                          },
                        },
                        "NDIS" => {
                          "" => ["ld", "(", "iy", "-", "NDIS", ")", ",", "b"],
                          0xFD => {
                            0x23 => { "" => ["ldi", "(", "iy", "-", "NDIS", ")", ",", "b"] },
                            0x2B => { "" => ["ldd", "(", "iy", "-", "NDIS", ")", ",", "b"] },
                          },
                        },
                      },
               0x71 => {
                        0x00 => {
                          "" => ["ld", "(", "iy", ")", ",", "c"],
                          0xFD => {
                            0x23  => {
                                     "" => ["ldi", "(", "iy", ")", ",", "c"],
                                     0xFD => {
                                       0x70 => {
                                                0x00 => { 0xFD => { 0x23 => { "" => ["ldi", "(", "iy", ")", ",", "bc"] } } },
                                              },
                                     },
                                   },
                            0x2B  => { "" => ["ldd", "(", "iy", ")", ",", "c"] },
                            0x70 => { 0x01 => { "" => ["ld", "(", "iy", ")", ",", "bc"] } },
                          },
                        },
                        "DIS" => {
                          "" => ["ld", "(", "iy", "+", "DIS", ")", ",", "c"],
                          0xFD => {
                            0x23  => {
                                     "" => ["ldi", "(", "iy", "+", "DIS", ")", ",", "c"],
                                     0xFD => {
                                       0x70 => {
                                                DIS => {
                                                         0xFD => { 0x23 => { "" => ["ldi", "(", "iy", "+", "DIS", ")", ",", "bc"] } },
                                                       },
                                              },
                                     },
                                   },
                            0x2B  => { "" => ["ldd", "(", "iy", "+", "DIS", ")", ",", "c"] },
                            0x70 => {
                                     "DIS+0x01" => { "" => ["ld", "(", "iy", "+", "DIS", ")", ",", "bc"] },
                                   },
                          },
                        },
                        "NDIS" => {
                          "" => ["ld", "(", "iy", "-", "NDIS", ")", ",", "c"],
                          0xFD => {
                            0x23  => {
                                     "" => ["ldi", "(", "iy", "-", "NDIS", ")", ",", "c"],
                                     0xFD => {
                                       0x70 => {
                                                NDIS => {
                                                  0xFD => { 0x23 => { "" => ["ldi", "(", "iy", "-", "NDIS", ")", ",", "bc"] } },
                                                },
                                              },
                                     },
                                   },
                            0x2B  => { "" => ["ldd", "(", "iy", "-", "NDIS", ")", ",", "c"] },
                            0x70 => {
                                     "NDIS+0x01" => { "" => ["ld", "(", "iy", "-", "NDIS", ")", ",", "bc"] },
                                   },
                          },
                        },
                      },
               0x72 => {
                        0x00 => {
                          "" => ["ld", "(", "iy", ")", ",", "d"],
                          0xFD => {
                            0x23 => { "" => ["ldi", "(", "iy", ")", ",", "d"] },
                            0x2B => { "" => ["ldd", "(", "iy", ")", ",", "d"] },
                          },
                        },
                        "DIS" => {
                          "" => ["ld", "(", "iy", "+", "DIS", ")", ",", "d"],
                          0xFD => {
                            0x23 => { "" => ["ldi", "(", "iy", "+", "DIS", ")", ",", "d"] },
                            0x2B => { "" => ["ldd", "(", "iy", "+", "DIS", ")", ",", "d"] },
                          },
                        },
                        "NDIS" => {
                          "" => ["ld", "(", "iy", "-", "NDIS", ")", ",", "d"],
                          0xFD => {
                            0x23 => { "" => ["ldi", "(", "iy", "-", "NDIS", ")", ",", "d"] },
                            0x2B => { "" => ["ldd", "(", "iy", "-", "NDIS", ")", ",", "d"] },
                          },
                        },
                      },
               0x73 => {
                        0x00 => {
                          "" => ["ld", "(", "iy", ")", ",", "e"],
                          0xFD => {
                            0x23  => {
                                     "" => ["ldi", "(", "iy", ")", ",", "e"],
                                     0xFD => {
                                       0x72 => {
                                                0x00 => { 0xFD => { 0x23 => { "" => ["ldi", "(", "iy", ")", ",", "de"] } } },
                                              },
                                     },
                                   },
                            0x2B  => { "" => ["ldd", "(", "iy", ")", ",", "e"] },
                            0x72 => { 0x01 => { "" => ["ld", "(", "iy", ")", ",", "de"] } },
                          },
                        },
                        "DIS" => {
                          "" => ["ld", "(", "iy", "+", "DIS", ")", ",", "e"],
                          0xFD => {
                            0x23  => {
                                     "" => ["ldi", "(", "iy", "+", "DIS", ")", ",", "e"],
                                     0xFD => {
                                       0x72 => {
                                                DIS => {
                                                         0xFD => { 0x23 => { "" => ["ldi", "(", "iy", "+", "DIS", ")", ",", "de"] } },
                                                       },
                                              },
                                     },
                                   },
                            0x2B  => { "" => ["ldd", "(", "iy", "+", "DIS", ")", ",", "e"] },
                            0x72 => {
                                     "DIS+0x01" => { "" => ["ld", "(", "iy", "+", "DIS", ")", ",", "de"] },
                                   },
                          },
                        },
                        "NDIS" => {
                          "" => ["ld", "(", "iy", "-", "NDIS", ")", ",", "e"],
                          0xFD => {
                            0x23  => {
                                     "" => ["ldi", "(", "iy", "-", "NDIS", ")", ",", "e"],
                                     0xFD => {
                                       0x72 => {
                                                NDIS => {
                                                  0xFD => { 0x23 => { "" => ["ldi", "(", "iy", "-", "NDIS", ")", ",", "de"] } },
                                                },
                                              },
                                     },
                                   },
                            0x2B  => { "" => ["ldd", "(", "iy", "-", "NDIS", ")", ",", "e"] },
                            0x72 => {
                                     "NDIS+0x01" => { "" => ["ld", "(", "iy", "-", "NDIS", ")", ",", "de"] },
                                   },
                          },
                        },
                      },
               0x74 => {
                        0x00 => {
                          "" => ["ld", "(", "iy", ")", ",", "h"],
                          0xFD => {
                            0x23 => { "" => ["ldi", "(", "iy", ")", ",", "h"] },
                            0x2B => { "" => ["ldd", "(", "iy", ")", ",", "h"] },
                          },
                        },
                        "DIS" => {
                          "" => ["ld", "(", "iy", "+", "DIS", ")", ",", "h"],
                          0xFD => {
                            0x23 => { "" => ["ldi", "(", "iy", "+", "DIS", ")", ",", "h"] },
                            0x2B => { "" => ["ldd", "(", "iy", "+", "DIS", ")", ",", "h"] },
                          },
                        },
                        "NDIS" => {
                          "" => ["ld", "(", "iy", "-", "NDIS", ")", ",", "h"],
                          0xFD => {
                            0x23 => { "" => ["ldi", "(", "iy", "-", "NDIS", ")", ",", "h"] },
                            0x2B => { "" => ["ldd", "(", "iy", "-", "NDIS", ")", ",", "h"] },
                          },
                        },
                      },
               0x75 => {
                        0x00 => {
                          "" => ["ld", "(", "iy", ")", ",", "l"],
                          0xFD => {
                            0x23  => {
                                     "" => ["ldi", "(", "iy", ")", ",", "l"],
                                     0xFD => {
                                       0x74 => {
                                                0x00 => { 0xFD => { 0x23 => { "" => ["ldi", "(", "iy", ")", ",", "hl"] } } },
                                              },
                                     },
                                   },
                            0x2B  => { "" => ["ldd", "(", "iy", ")", ",", "l"] },
                            0x74 => { 0x01 => { "" => ["ld", "(", "iy", ")", ",", "hl"] } },
                          },
                        },
                        "DIS" => {
                          "" => ["ld", "(", "iy", "+", "DIS", ")", ",", "l"],
                          0xFD => {
                            0x23  => {
                                     "" => ["ldi", "(", "iy", "+", "DIS", ")", ",", "l"],
                                     0xFD => {
                                       0x74 => {
                                                DIS => {
                                                         0xFD => { 0x23 => { "" => ["ldi", "(", "iy", "+", "DIS", ")", ",", "hl"] } },
                                                       },
                                              },
                                     },
                                   },
                            0x2B  => { "" => ["ldd", "(", "iy", "+", "DIS", ")", ",", "l"] },
                            0x74 => {
                                     "DIS+0x01" => { "" => ["ld", "(", "iy", "+", "DIS", ")", ",", "hl"] },
                                   },
                          },
                        },
                        "NDIS" => {
                          "" => ["ld", "(", "iy", "-", "NDIS", ")", ",", "l"],
                          0xFD => {
                            0x23  => {
                                     "" => ["ldi", "(", "iy", "-", "NDIS", ")", ",", "l"],
                                     0xFD => {
                                       0x74 => {
                                                NDIS => {
                                                  0xFD => { 0x23 => { "" => ["ldi", "(", "iy", "-", "NDIS", ")", ",", "hl"] } },
                                                },
                                              },
                                     },
                                   },
                            0x2B  => { "" => ["ldd", "(", "iy", "-", "NDIS", ")", ",", "l"] },
                            0x74 => {
                                     "NDIS+0x01" => { "" => ["ld", "(", "iy", "-", "NDIS", ")", ",", "hl"] },
                                   },
                          },
                        },
                      },
               0x77 => {
                        0x00 => {
                          "" => ["ld", "(", "iy", ")", ",", "a"],
                          0xFD => {
                            0x23 => { "" => ["ldi", "(", "iy", ")", ",", "a"] },
                            0x2B => { "" => ["ldd", "(", "iy", ")", ",", "a"] },
                          },
                        },
                        "DIS" => {
                          "" => ["ld", "(", "iy", "+", "DIS", ")", ",", "a"],
                          0xFD => {
                            0x23 => { "" => ["ldi", "(", "iy", "+", "DIS", ")", ",", "a"] },
                            0x2B => { "" => ["ldd", "(", "iy", "+", "DIS", ")", ",", "a"] },
                          },
                        },
                        "NDIS" => {
                          "" => ["ld", "(", "iy", "-", "NDIS", ")", ",", "a"],
                          0xFD => {
                            0x23 => { "" => ["ldi", "(", "iy", "-", "NDIS", ")", ",", "a"] },
                            0x2B => { "" => ["ldd", "(", "iy", "-", "NDIS", ")", ",", "a"] },
                          },
                        },
                      },
               0x78 => { "" => ["ld", "a", ",", "b"] },
               0x79 => { "" => ["ld", "a", ",", "c"] },
               0x7A => { "" => ["ld", "a", ",", "d"] },
               0x7B => { "" => ["ld", "a", ",", "e"] },
               0x7C => { "" => ["ld", "a", ",", "iyh"] },
               0x7D => { "" => ["ld", "a", ",", "iyl"] },
               0x7E => {
                        0x00 => {
                          "" => ["ld", "a", ",", "(", "iy", ")"],
                          0xFD => {
                            0x23 => { "" => ["ldi", "a", ",", "(", "iy", ")"] },
                            0x2B => { "" => ["ldd", "a", ",", "(", "iy", ")"] },
                          },
                        },
                        "DIS" => {
                          "" => ["ld", "a", ",", "(", "iy", "+", "DIS", ")"],
                          0xFD => {
                            0x23 => { "" => ["ldi", "a", ",", "(", "iy", "+", "DIS", ")"] },
                            0x2B => { "" => ["ldd", "a", ",", "(", "iy", "+", "DIS", ")"] },
                          },
                        },
                        "NDIS" => {
                          "" => ["ld", "a", ",", "(", "iy", "-", "NDIS", ")"],
                          0xFD => {
                            0x23 => { "" => ["ldi", "a", ",", "(", "iy", "-", "NDIS", ")"] },
                            0x2B => { "" => ["ldd", "a", ",", "(", "iy", "-", "NDIS", ")"] },
                          },
                        },
                      },
               0x7F => { "" => ["ld", "a", ",", "a"] },
               0x80 => { "" => ["add", "a", ",", "b"] },
               0x81 => { "" => ["add", "a", ",", "c"] },
               0x82 => { "" => ["add", "a", ",", "d"] },
               0x83 => { "" => ["add", "a", ",", "e"] },
               0x84 => { "" => ["add", "a", ",", "iyh"] },
               0x85 => { "" => ["add", "a", ",", "iyl"] },
               0x86 => {
                        0x00 => { "" => ["add", "a", ",", "(", "iy", ")"] },
                        "DIS" => { "" => ["add", "a", ",", "(", "iy", "+", "DIS", ")"] },
                        "NDIS" => { "" => ["add", "a", ",", "(", "iy", "-", "NDIS", ")"] },
                      },
               0x87 => { "" => ["add", "a", ",", "a"] },
               0x88 => { "" => ["adc", "a", ",", "b"] },
               0x89 => { "" => ["adc", "a", ",", "c"] },
               0x8A => { "" => ["adc", "a", ",", "d"] },
               0x8B => { "" => ["adc", "a", ",", "e"] },
               0x8C => { "" => ["adc", "a", ",", "iyh"] },
               0x8D => { "" => ["adc", "a", ",", "iyl"] },
               0x8E => {
                        0x00 => { "" => ["adc", "a", ",", "(", "iy", ")"] },
                        "DIS" => { "" => ["adc", "a", ",", "(", "iy", "+", "DIS", ")"] },
                        "NDIS" => { "" => ["adc", "a", ",", "(", "iy", "-", "NDIS", ")"] },
                      },
               0x8F => { "" => ["adc", "a", ",", "a"] },
               0x90 => { "" => ["sub", "b"] },
               0x91 => { "" => ["sub", "c"] },
               0x92 => { "" => ["sub", "d"] },
               0x93 => { "" => ["sub", "e"] },
               0x94 => { "" => ["sub", "iyh"] },
               0x95 => { "" => ["sub", "iyl"] },
               0x96 => {
                        0x00 => { "" => ["sub", "(", "iy", ")"] },
                        "DIS" => { "" => ["sub", "(", "iy", "+", "DIS", ")"] },
                        "NDIS" => { "" => ["sub", "(", "iy", "-", "NDIS", ")"] },
                      },
               0x97 => { "" => ["sub", "a"] },
               0x98 => { "" => ["sbc", "a", ",", "b"] },
               0x99 => { "" => ["sbc", "a", ",", "c"] },
               0x9A => { "" => ["sbc", "a", ",", "d"] },
               0x9B => { "" => ["sbc", "a", ",", "e"] },
               0x9C => { "" => ["sbc", "a", ",", "iyh"] },
               0x9D => { "" => ["sbc", "a", ",", "iyl"] },
               0x9E => {
                        0x00 => { "" => ["sbc", "a", ",", "(", "iy", ")"] },
                        "DIS" => { "" => ["sbc", "a", ",", "(", "iy", "+", "DIS", ")"] },
                        "NDIS" => { "" => ["sbc", "a", ",", "(", "iy", "-", "NDIS", ")"] },
                      },
               0x9F => { "" => ["sbc", "a", ",", "a"] },
               0xA0 => { "" => ["and", "b"] },
               0xA1 => { "" => ["and", "c"] },
               0xA2 => { "" => ["and", "d"] },
               0xA3 => { "" => ["and", "e"] },
               0xA4 => { "" => ["and", "iyh"] },
               0xA5 => { "" => ["and", "iyl"] },
               0xA6 => {
                        0x00 => { "" => ["and", "(", "iy", ")"] },
                        "DIS" => { "" => ["and", "(", "iy", "+", "DIS", ")"] },
                        "NDIS" => { "" => ["and", "(", "iy", "-", "NDIS", ")"] },
                      },
               0xA7 => { "" => ["and", "a"] },
               0xA8 => { "" => ["xor", "b"] },
               0xA9 => { "" => ["xor", "c"] },
               0xAA => { "" => ["xor", "d"] },
               0xAB => { "" => ["xor", "e"] },
               0xAC => { "" => ["xor", "iyh"] },
               0xAD => { "" => ["xor", "iyl"] },
               0xAE => {
                        0x00 => { "" => ["xor", "(", "iy", ")"] },
                        "DIS" => { "" => ["xor", "(", "iy", "+", "DIS", ")"] },
                        "NDIS" => { "" => ["xor", "(", "iy", "-", "NDIS", ")"] },
                      },
               0xAF => { "" => ["xor", "a"] },
               0xB0 => { "" => ["or", "b"] },
               0xB1 => { "" => ["or", "c"] },
               0xB2 => { "" => ["or", "d"] },
               0xB3 => { "" => ["or", "e"] },
               0xB4 => { "" => ["or", "iyh"] },
               0xB5 => { "" => ["or", "iyl"] },
               0xB6 => {
                        0x00 => { "" => ["or", "(", "iy", ")"] },
                        "DIS" => { "" => ["or", "(", "iy", "+", "DIS", ")"] },
                        "NDIS" => { "" => ["or", "(", "iy", "-", "NDIS", ")"] },
                      },
               0xB7 => { "" => ["or", "a"] },
               0xB8 => { "" => ["cp", "b"] },
               0xB9 => { "" => ["cp", "c"] },
               0xBA => { "" => ["cp", "d"] },
               0xBB => { "" => ["cp", "e"] },
               0xBC => { "" => ["cp", "iyh"] },
               0xBD => { "" => ["cp", "iyl"] },
               0xBE => {
                        0x00 => { "" => ["cp", "(", "iy", ")"] },
                        "DIS" => { "" => ["cp", "(", "iy", "+", "DIS", ")"] },
                        "NDIS" => { "" => ["cp", "(", "iy", "-", "NDIS", ")"] },
                      },
               0xBF => { "" => ["cp", "a"] },
               0xCB => {
                        0x00 => {
                          0x00   => { "" => ["rlc", "(", "iy", ")", ",", "b"] },
                          0x01   => { "" => ["rlc", "(", "iy", ")", ",", "c"] },
                          0x02   => { "" => ["rlc", "(", "iy", ")", ",", "d"] },
                          0x03   => { "" => ["rlc", "(", "iy", ")", ",", "e"] },
                          0x04   => { "" => ["rlc", "(", "iy", ")", ",", "h"] },
                          0x05   => { "" => ["rlc", "(", "iy", ")", ",", "l"] },
                          0x06   => { "" => ["rlc", "(", "iy", ")"] },
                          0x07   => { "" => ["rlc", "(", "iy", ")", ",", "a"] },
                          0x08   => { "" => ["rrc", "(", "iy", ")", ",", "b"] },
                          0x09   => { "" => ["rrc", "(", "iy", ")", ",", "c"] },
                          0x0A  => { "" => ["rrc", "(", "iy", ")", ",", "d"] },
                          0x0B  => { "" => ["rrc", "(", "iy", ")", ",", "e"] },
                          0x0C  => { "" => ["rrc", "(", "iy", ")", ",", "h"] },
                          0x0D  => { "" => ["rrc", "(", "iy", ")", ",", "l"] },
                          0x0E  => { "" => ["rrc", "(", "iy", ")"] },
                          0x0F  => { "" => ["rrc", "(", "iy", ")", ",", "a"] },
                          0x10  => { "" => ["rl", "(", "iy", ")", ",", "b"] },
                          0x11  => { "" => ["rl", "(", "iy", ")", ",", "c"] },
                          0x12  => { "" => ["rl", "(", "iy", ")", ",", "d"] },
                          0x13  => { "" => ["rl", "(", "iy", ")", ",", "e"] },
                          0x14  => { "" => ["rl", "(", "iy", ")", ",", "h"] },
                          0x15  => { "" => ["rl", "(", "iy", ")", ",", "l"] },
                          0x16  => { "" => ["rl", "(", "iy", ")"] },
                          0x17  => { "" => ["rl", "(", "iy", ")", ",", "a"] },
                          0x18  => { "" => ["rr", "(", "iy", ")", ",", "b"] },
                          0x19  => { "" => ["rr", "(", "iy", ")", ",", "c"] },
                          0x1A  => { "" => ["rr", "(", "iy", ")", ",", "d"] },
                          0x1B  => { "" => ["rr", "(", "iy", ")", ",", "e"] },
                          0x1C  => { "" => ["rr", "(", "iy", ")", ",", "h"] },
                          0x1D  => { "" => ["rr", "(", "iy", ")", ",", "l"] },
                          0x1E  => { "" => ["rr", "(", "iy", ")"] },
                          0x1F  => { "" => ["rr", "(", "iy", ")", ",", "a"] },
                          0x20  => { "" => ["sla", "(", "iy", ")", ",", "b"] },
                          0x21  => { "" => ["sla", "(", "iy", ")", ",", "c"] },
                          0x22  => { "" => ["sla", "(", "iy", ")", ",", "d"] },
                          0x23  => { "" => ["sla", "(", "iy", ")", ",", "e"] },
                          0x24  => { "" => ["sla", "(", "iy", ")", ",", "h"] },
                          0x25  => { "" => ["sla", "(", "iy", ")", ",", "l"] },
                          0x26  => { "" => ["sla", "(", "iy", ")"] },
                          0x27  => { "" => ["sla", "(", "iy", ")", ",", "a"] },
                          0x28  => { "" => ["sra", "(", "iy", ")", ",", "b"] },
                          0x29  => { "" => ["sra", "(", "iy", ")", ",", "c"] },
                          0x2A  => { "" => ["sra", "(", "iy", ")", ",", "d"] },
                          0x2B  => { "" => ["sra", "(", "iy", ")", ",", "e"] },
                          0x2C  => { "" => ["sra", "(", "iy", ")", ",", "h"] },
                          0x2D  => { "" => ["sra", "(", "iy", ")", ",", "l"] },
                          0x2E  => { "" => ["sra", "(", "iy", ")"] },
                          0x2F  => { "" => ["sra", "(", "iy", ")", ",", "a"] },
                          0x30  => { "" => ["sll", "(", "iy", ")", ",", "b"] },
                          0x31  => { "" => ["sll", "(", "iy", ")", ",", "c"] },
                          0x32  => { "" => ["sll", "(", "iy", ")", ",", "d"] },
                          0x33  => { "" => ["sll", "(", "iy", ")", ",", "e"] },
                          0x34  => { "" => ["sll", "(", "iy", ")", ",", "h"] },
                          0x35  => { "" => ["sll", "(", "iy", ")", ",", "l"] },
                          0x36  => { "" => ["sll", "(", "iy", ")"] },
                          0x37  => { "" => ["sll", "(", "iy", ")", ",", "a"] },
                          0x38  => { "" => ["srl", "(", "iy", ")", ",", "b"] },
                          0x39  => { "" => ["srl", "(", "iy", ")", ",", "c"] },
                          0x3A  => { "" => ["srl", "(", "iy", ")", ",", "d"] },
                          0x3B  => { "" => ["srl", "(", "iy", ")", ",", "e"] },
                          0x3C  => { "" => ["srl", "(", "iy", ")", ",", "h"] },
                          0x3D  => { "" => ["srl", "(", "iy", ")", ",", "l"] },
                          0x3E  => { "" => ["srl", "(", "iy", ")"] },
                          0x3F  => { "" => ["srl", "(", "iy", ")", ",", "a"] },
                          0x46  => { "" => ["bit", 0x00, ",", "(", "iy", ")"] },
                          0x4E  => { "" => ["bit", 0x01, ",", "(", "iy", ")"] },
                          0x56  => { "" => ["bit", 0x02, ",", "(", "iy", ")"] },
                          0x5E  => { "" => ["bit", 0x03, ",", "(", "iy", ")"] },
                          0x66 => { "" => ["bit", 0x04, ",", "(", "iy", ")"] },
                          0x6E => { "" => ["bit", 0x05, ",", "(", "iy", ")"] },
                          0x76 => { "" => ["bit", 0x06, ",", "(", "iy", ")"] },
                          0x7E => { "" => ["bit", 0x07, ",", "(", "iy", ")"] },
                          0x80 => { "" => ["res", 0x00, ",", "(", "iy", ")", ",", "b"] },
                          0x81 => { "" => ["res", 0x00, ",", "(", "iy", ")", ",", "c"] },
                          0x82 => { "" => ["res", 0x00, ",", "(", "iy", ")", ",", "d"] },
                          0x83 => { "" => ["res", 0x00, ",", "(", "iy", ")", ",", "e"] },
                          0x84 => { "" => ["res", 0x00, ",", "(", "iy", ")", ",", "h"] },
                          0x85 => { "" => ["res", 0x00, ",", "(", "iy", ")", ",", "l"] },
                          0x86 => { "" => ["res", 0x00, ",", "(", "iy", ")"] },
                          0x87 => { "" => ["res", 0x00, ",", "(", "iy", ")", ",", "a"] },
                          0x88 => { "" => ["res", 0x01, ",", "(", "iy", ")", ",", "b"] },
                          0x89 => { "" => ["res", 0x01, ",", "(", "iy", ")", ",", "c"] },
                          0x8A => { "" => ["res", 0x01, ",", "(", "iy", ")", ",", "d"] },
                          0x8B => { "" => ["res", 0x01, ",", "(", "iy", ")", ",", "e"] },
                          0x8C => { "" => ["res", 0x01, ",", "(", "iy", ")", ",", "h"] },
                          0x8D => { "" => ["res", 0x01, ",", "(", "iy", ")", ",", "l"] },
                          0x8E => { "" => ["res", 0x01, ",", "(", "iy", ")"] },
                          0x8F => { "" => ["res", 0x01, ",", "(", "iy", ")", ",", "a"] },
                          0x90 => { "" => ["res", 0x02, ",", "(", "iy", ")", ",", "b"] },
                          0x91 => { "" => ["res", 0x02, ",", "(", "iy", ")", ",", "c"] },
                          0x92 => { "" => ["res", 0x02, ",", "(", "iy", ")", ",", "d"] },
                          0x93 => { "" => ["res", 0x02, ",", "(", "iy", ")", ",", "e"] },
                          0x94 => { "" => ["res", 0x02, ",", "(", "iy", ")", ",", "h"] },
                          0x95 => { "" => ["res", 0x02, ",", "(", "iy", ")", ",", "l"] },
                          0x96 => { "" => ["res", 0x02, ",", "(", "iy", ")"] },
                          0x97 => { "" => ["res", 0x02, ",", "(", "iy", ")", ",", "a"] },
                          0x98 => { "" => ["res", 0x03, ",", "(", "iy", ")", ",", "b"] },
                          0x99 => { "" => ["res", 0x03, ",", "(", "iy", ")", ",", "c"] },
                          0x9A => { "" => ["res", 0x03, ",", "(", "iy", ")", ",", "d"] },
                          0x9B => { "" => ["res", 0x03, ",", "(", "iy", ")", ",", "e"] },
                          0x9C => { "" => ["res", 0x03, ",", "(", "iy", ")", ",", "h"] },
                          0x9D => { "" => ["res", 0x03, ",", "(", "iy", ")", ",", "l"] },
                          0x9E => { "" => ["res", 0x03, ",", "(", "iy", ")"] },
                          0x9F => { "" => ["res", 0x03, ",", "(", "iy", ")", ",", "a"] },
                          0xA0 => { "" => ["res", 0x04, ",", "(", "iy", ")", ",", "b"] },
                          0xA1 => { "" => ["res", 0x04, ",", "(", "iy", ")", ",", "c"] },
                          0xA2 => { "" => ["res", 0x04, ",", "(", "iy", ")", ",", "d"] },
                          0xA3 => { "" => ["res", 0x04, ",", "(", "iy", ")", ",", "e"] },
                          0xA4 => { "" => ["res", 0x04, ",", "(", "iy", ")", ",", "h"] },
                          0xA5 => { "" => ["res", 0x04, ",", "(", "iy", ")", ",", "l"] },
                          0xA6 => { "" => ["res", 0x04, ",", "(", "iy", ")"] },
                          0xA7 => { "" => ["res", 0x04, ",", "(", "iy", ")", ",", "a"] },
                          0xA8 => { "" => ["res", 0x05, ",", "(", "iy", ")", ",", "b"] },
                          0xA9 => { "" => ["res", 0x05, ",", "(", "iy", ")", ",", "c"] },
                          0xAA => { "" => ["res", 0x05, ",", "(", "iy", ")", ",", "d"] },
                          0xAB => { "" => ["res", 0x05, ",", "(", "iy", ")", ",", "e"] },
                          0xAC => { "" => ["res", 0x05, ",", "(", "iy", ")", ",", "h"] },
                          0xAD => { "" => ["res", 0x05, ",", "(", "iy", ")", ",", "l"] },
                          0xAE => { "" => ["res", 0x05, ",", "(", "iy", ")"] },
                          0xAF => { "" => ["res", 0x05, ",", "(", "iy", ")", ",", "a"] },
                          0xB0 => { "" => ["res", 0x06, ",", "(", "iy", ")", ",", "b"] },
                          0xB1 => { "" => ["res", 0x06, ",", "(", "iy", ")", ",", "c"] },
                          0xB2 => { "" => ["res", 0x06, ",", "(", "iy", ")", ",", "d"] },
                          0xB3 => { "" => ["res", 0x06, ",", "(", "iy", ")", ",", "e"] },
                          0xB4 => { "" => ["res", 0x06, ",", "(", "iy", ")", ",", "h"] },
                          0xB5 => { "" => ["res", 0x06, ",", "(", "iy", ")", ",", "l"] },
                          0xB6 => { "" => ["res", 0x06, ",", "(", "iy", ")"] },
                          0xB7 => { "" => ["res", 0x06, ",", "(", "iy", ")", ",", "a"] },
                          0xB8 => { "" => ["res", 0x07, ",", "(", "iy", ")", ",", "b"] },
                          0xB9 => { "" => ["res", 0x07, ",", "(", "iy", ")", ",", "c"] },
                          0xBA => { "" => ["res", 0x07, ",", "(", "iy", ")", ",", "d"] },
                          0xBB => { "" => ["res", 0x07, ",", "(", "iy", ")", ",", "e"] },
                          0xBC => { "" => ["res", 0x07, ",", "(", "iy", ")", ",", "h"] },
                          0xBD => { "" => ["res", 0x07, ",", "(", "iy", ")", ",", "l"] },
                          0xBE => { "" => ["res", 0x07, ",", "(", "iy", ")"] },
                          0xBF => { "" => ["res", 0x07, ",", "(", "iy", ")", ",", "a"] },
                          0xC0 => { "" => ["set", 0x00, ",", "(", "iy", ")", ",", "b"] },
                          0xC1 => { "" => ["set", 0x00, ",", "(", "iy", ")", ",", "c"] },
                          0xC2 => { "" => ["set", 0x00, ",", "(", "iy", ")", ",", "d"] },
                          0xC3 => { "" => ["set", 0x00, ",", "(", "iy", ")", ",", "e"] },
                          0xC4 => { "" => ["set", 0x00, ",", "(", "iy", ")", ",", "h"] },
                          0xC5 => { "" => ["set", 0x00, ",", "(", "iy", ")", ",", "l"] },
                          0xC6 => { "" => ["set", 0x00, ",", "(", "iy", ")"] },
                          0xC7 => { "" => ["set", 0x00, ",", "(", "iy", ")", ",", "a"] },
                          0xC8 => { "" => ["set", 0x01, ",", "(", "iy", ")", ",", "b"] },
                          0xC9 => { "" => ["set", 0x01, ",", "(", "iy", ")", ",", "c"] },
                          0xCA => { "" => ["set", 0x01, ",", "(", "iy", ")", ",", "d"] },
                          0xCB => { "" => ["set", 0x01, ",", "(", "iy", ")", ",", "e"] },
                          0xCC => { "" => ["set", 0x01, ",", "(", "iy", ")", ",", "h"] },
                          0xCD => { "" => ["set", 0x01, ",", "(", "iy", ")", ",", "l"] },
                          0xCE => { "" => ["set", 0x01, ",", "(", "iy", ")"] },
                          0xCF => { "" => ["set", 0x01, ",", "(", "iy", ")", ",", "a"] },
                          0xD0 => { "" => ["set", 0x02, ",", "(", "iy", ")", ",", "b"] },
                          0xD1 => { "" => ["set", 0x02, ",", "(", "iy", ")", ",", "c"] },
                          0xD2 => { "" => ["set", 0x02, ",", "(", "iy", ")", ",", "d"] },
                          0xD3 => { "" => ["set", 0x02, ",", "(", "iy", ")", ",", "e"] },
                          0xD4 => { "" => ["set", 0x02, ",", "(", "iy", ")", ",", "h"] },
                          0xD5 => { "" => ["set", 0x02, ",", "(", "iy", ")", ",", "l"] },
                          0xD6 => { "" => ["set", 0x02, ",", "(", "iy", ")"] },
                          0xD7 => { "" => ["set", 0x02, ",", "(", "iy", ")", ",", "a"] },
                          0xD8 => { "" => ["set", 0x03, ",", "(", "iy", ")", ",", "b"] },
                          0xD9 => { "" => ["set", 0x03, ",", "(", "iy", ")", ",", "c"] },
                          0xDA => { "" => ["set", 0x03, ",", "(", "iy", ")", ",", "d"] },
                          0xDB => { "" => ["set", 0x03, ",", "(", "iy", ")", ",", "e"] },
                          0xDC => { "" => ["set", 0x03, ",", "(", "iy", ")", ",", "h"] },
                          0xDD => { "" => ["set", 0x03, ",", "(", "iy", ")", ",", "l"] },
                          0xDE => { "" => ["set", 0x03, ",", "(", "iy", ")"] },
                          0xDF => { "" => ["set", 0x03, ",", "(", "iy", ")", ",", "a"] },
                          0xE0 => { "" => ["set", 0x04, ",", "(", "iy", ")", ",", "b"] },
                          0xE1 => { "" => ["set", 0x04, ",", "(", "iy", ")", ",", "c"] },
                          0xE2 => { "" => ["set", 0x04, ",", "(", "iy", ")", ",", "d"] },
                          0xE3 => { "" => ["set", 0x04, ",", "(", "iy", ")", ",", "e"] },
                          0xE4 => { "" => ["set", 0x04, ",", "(", "iy", ")", ",", "h"] },
                          0xE5 => { "" => ["set", 0x04, ",", "(", "iy", ")", ",", "l"] },
                          0xE6 => { "" => ["set", 0x04, ",", "(", "iy", ")"] },
                          0xE7 => { "" => ["set", 0x04, ",", "(", "iy", ")", ",", "a"] },
                          0xE8 => { "" => ["set", 0x05, ",", "(", "iy", ")", ",", "b"] },
                          0xE9 => { "" => ["set", 0x05, ",", "(", "iy", ")", ",", "c"] },
                          0xEA => { "" => ["set", 0x05, ",", "(", "iy", ")", ",", "d"] },
                          0xEB => { "" => ["set", 0x05, ",", "(", "iy", ")", ",", "e"] },
                          0xEC => { "" => ["set", 0x05, ",", "(", "iy", ")", ",", "h"] },
                          0xED => { "" => ["set", 0x05, ",", "(", "iy", ")", ",", "l"] },
                          0xEE => { "" => ["set", 0x05, ",", "(", "iy", ")"] },
                          0xEF => { "" => ["set", 0x05, ",", "(", "iy", ")", ",", "a"] },
                          0xF0 => { "" => ["set", 0x06, ",", "(", "iy", ")", ",", "b"] },
                          0xF1 => { "" => ["set", 0x06, ",", "(", "iy", ")", ",", "c"] },
                          0xF2 => { "" => ["set", 0x06, ",", "(", "iy", ")", ",", "d"] },
                          0xF3 => { "" => ["set", 0x06, ",", "(", "iy", ")", ",", "e"] },
                          0xF4 => { "" => ["set", 0x06, ",", "(", "iy", ")", ",", "h"] },
                          0xF5 => { "" => ["set", 0x06, ",", "(", "iy", ")", ",", "l"] },
                          0xF6 => { "" => ["set", 0x06, ",", "(", "iy", ")"] },
                          0xF7 => { "" => ["set", 0x06, ",", "(", "iy", ")", ",", "a"] },
                          0xF8 => { "" => ["set", 0x07, ",", "(", "iy", ")", ",", "b"] },
                          0xF9 => { "" => ["set", 0x07, ",", "(", "iy", ")", ",", "c"] },
                          0xFA => { "" => ["set", 0x07, ",", "(", "iy", ")", ",", "d"] },
                          0xFB => { "" => ["set", 0x07, ",", "(", "iy", ")", ",", "e"] },
                          0xFC => { "" => ["set", 0x07, ",", "(", "iy", ")", ",", "h"] },
                          0xFD => { "" => ["set", 0x07, ",", "(", "iy", ")", ",", "l"] },
                          0xFE => { "" => ["set", 0x07, ",", "(", "iy", ")"] },
                          0xFF => { "" => ["set", 0x07, ",", "(", "iy", ")", ",", "a"] },
                        },
                        "DIS" => {
                          0x00   => { "" => ["rlc", "(", "iy", "+", "DIS", ")", ",", "b"] },
                          0x01   => { "" => ["rlc", "(", "iy", "+", "DIS", ")", ",", "c"] },
                          0x02   => { "" => ["rlc", "(", "iy", "+", "DIS", ")", ",", "d"] },
                          0x03   => { "" => ["rlc", "(", "iy", "+", "DIS", ")", ",", "e"] },
                          0x04   => { "" => ["rlc", "(", "iy", "+", "DIS", ")", ",", "h"] },
                          0x05   => { "" => ["rlc", "(", "iy", "+", "DIS", ")", ",", "l"] },
                          0x06   => { "" => ["rlc", "(", "iy", "+", "DIS", ")"] },
                          0x07   => { "" => ["rlc", "(", "iy", "+", "DIS", ")", ",", "a"] },
                          0x08   => { "" => ["rrc", "(", "iy", "+", "DIS", ")", ",", "b"] },
                          0x09   => { "" => ["rrc", "(", "iy", "+", "DIS", ")", ",", "c"] },
                          0x0A  => { "" => ["rrc", "(", "iy", "+", "DIS", ")", ",", "d"] },
                          0x0B  => { "" => ["rrc", "(", "iy", "+", "DIS", ")", ",", "e"] },
                          0x0C  => { "" => ["rrc", "(", "iy", "+", "DIS", ")", ",", "h"] },
                          0x0D  => { "" => ["rrc", "(", "iy", "+", "DIS", ")", ",", "l"] },
                          0x0E  => { "" => ["rrc", "(", "iy", "+", "DIS", ")"] },
                          0x0F  => { "" => ["rrc", "(", "iy", "+", "DIS", ")", ",", "a"] },
                          0x10  => { "" => ["rl", "(", "iy", "+", "DIS", ")", ",", "b"] },
                          0x11  => { "" => ["rl", "(", "iy", "+", "DIS", ")", ",", "c"] },
                          0x12  => { "" => ["rl", "(", "iy", "+", "DIS", ")", ",", "d"] },
                          0x13  => { "" => ["rl", "(", "iy", "+", "DIS", ")", ",", "e"] },
                          0x14  => { "" => ["rl", "(", "iy", "+", "DIS", ")", ",", "h"] },
                          0x15  => { "" => ["rl", "(", "iy", "+", "DIS", ")", ",", "l"] },
                          0x16  => { "" => ["rl", "(", "iy", "+", "DIS", ")"] },
                          0x17  => { "" => ["rl", "(", "iy", "+", "DIS", ")", ",", "a"] },
                          0x18  => { "" => ["rr", "(", "iy", "+", "DIS", ")", ",", "b"] },
                          0x19  => { "" => ["rr", "(", "iy", "+", "DIS", ")", ",", "c"] },
                          0x1A  => { "" => ["rr", "(", "iy", "+", "DIS", ")", ",", "d"] },
                          0x1B  => { "" => ["rr", "(", "iy", "+", "DIS", ")", ",", "e"] },
                          0x1C  => { "" => ["rr", "(", "iy", "+", "DIS", ")", ",", "h"] },
                          0x1D  => { "" => ["rr", "(", "iy", "+", "DIS", ")", ",", "l"] },
                          0x1E  => { "" => ["rr", "(", "iy", "+", "DIS", ")"] },
                          0x1F  => { "" => ["rr", "(", "iy", "+", "DIS", ")", ",", "a"] },
                          0x20  => { "" => ["sla", "(", "iy", "+", "DIS", ")", ",", "b"] },
                          0x21  => { "" => ["sla", "(", "iy", "+", "DIS", ")", ",", "c"] },
                          0x22  => { "" => ["sla", "(", "iy", "+", "DIS", ")", ",", "d"] },
                          0x23  => { "" => ["sla", "(", "iy", "+", "DIS", ")", ",", "e"] },
                          0x24  => { "" => ["sla", "(", "iy", "+", "DIS", ")", ",", "h"] },
                          0x25  => { "" => ["sla", "(", "iy", "+", "DIS", ")", ",", "l"] },
                          0x26  => { "" => ["sla", "(", "iy", "+", "DIS", ")"] },
                          0x27  => { "" => ["sla", "(", "iy", "+", "DIS", ")", ",", "a"] },
                          0x28  => { "" => ["sra", "(", "iy", "+", "DIS", ")", ",", "b"] },
                          0x29  => { "" => ["sra", "(", "iy", "+", "DIS", ")", ",", "c"] },
                          0x2A  => { "" => ["sra", "(", "iy", "+", "DIS", ")", ",", "d"] },
                          0x2B  => { "" => ["sra", "(", "iy", "+", "DIS", ")", ",", "e"] },
                          0x2C  => { "" => ["sra", "(", "iy", "+", "DIS", ")", ",", "h"] },
                          0x2D  => { "" => ["sra", "(", "iy", "+", "DIS", ")", ",", "l"] },
                          0x2E  => { "" => ["sra", "(", "iy", "+", "DIS", ")"] },
                          0x2F  => { "" => ["sra", "(", "iy", "+", "DIS", ")", ",", "a"] },
                          0x30  => { "" => ["sll", "(", "iy", "+", "DIS", ")", ",", "b"] },
                          0x31  => { "" => ["sll", "(", "iy", "+", "DIS", ")", ",", "c"] },
                          0x32  => { "" => ["sll", "(", "iy", "+", "DIS", ")", ",", "d"] },
                          0x33  => { "" => ["sll", "(", "iy", "+", "DIS", ")", ",", "e"] },
                          0x34  => { "" => ["sll", "(", "iy", "+", "DIS", ")", ",", "h"] },
                          0x35  => { "" => ["sll", "(", "iy", "+", "DIS", ")", ",", "l"] },
                          0x36  => { "" => ["sll", "(", "iy", "+", "DIS", ")"] },
                          0x37  => { "" => ["sll", "(", "iy", "+", "DIS", ")", ",", "a"] },
                          0x38  => { "" => ["srl", "(", "iy", "+", "DIS", ")", ",", "b"] },
                          0x39  => { "" => ["srl", "(", "iy", "+", "DIS", ")", ",", "c"] },
                          0x3A  => { "" => ["srl", "(", "iy", "+", "DIS", ")", ",", "d"] },
                          0x3B  => { "" => ["srl", "(", "iy", "+", "DIS", ")", ",", "e"] },
                          0x3C  => { "" => ["srl", "(", "iy", "+", "DIS", ")", ",", "h"] },
                          0x3D  => { "" => ["srl", "(", "iy", "+", "DIS", ")", ",", "l"] },
                          0x3E  => { "" => ["srl", "(", "iy", "+", "DIS", ")"] },
                          0x3F  => { "" => ["srl", "(", "iy", "+", "DIS", ")", ",", "a"] },
                          0x46  => { "" => ["bit", 0x00, ",", "(", "iy", "+", "DIS", ")"] },
                          0x4E  => { "" => ["bit", 0x01, ",", "(", "iy", "+", "DIS", ")"] },
                          0x56  => { "" => ["bit", 0x02, ",", "(", "iy", "+", "DIS", ")"] },
                          0x5E  => { "" => ["bit", 0x03, ",", "(", "iy", "+", "DIS", ")"] },
                          0x66 => { "" => ["bit", 0x04, ",", "(", "iy", "+", "DIS", ")"] },
                          0x6E => { "" => ["bit", 0x05, ",", "(", "iy", "+", "DIS", ")"] },
                          0x76 => { "" => ["bit", 0x06, ",", "(", "iy", "+", "DIS", ")"] },
                          0x7E => { "" => ["bit", 0x07, ",", "(", "iy", "+", "DIS", ")"] },
                          0x80 => { "" => ["res", 0x00, ",", "(", "iy", "+", "DIS", ")", ",", "b"] },
                          0x81 => { "" => ["res", 0x00, ",", "(", "iy", "+", "DIS", ")", ",", "c"] },
                          0x82 => { "" => ["res", 0x00, ",", "(", "iy", "+", "DIS", ")", ",", "d"] },
                          0x83 => { "" => ["res", 0x00, ",", "(", "iy", "+", "DIS", ")", ",", "e"] },
                          0x84 => { "" => ["res", 0x00, ",", "(", "iy", "+", "DIS", ")", ",", "h"] },
                          0x85 => { "" => ["res", 0x00, ",", "(", "iy", "+", "DIS", ")", ",", "l"] },
                          0x86 => { "" => ["res", 0x00, ",", "(", "iy", "+", "DIS", ")"] },
                          0x87 => { "" => ["res", 0x00, ",", "(", "iy", "+", "DIS", ")", ",", "a"] },
                          0x88 => { "" => ["res", 0x01, ",", "(", "iy", "+", "DIS", ")", ",", "b"] },
                          0x89 => { "" => ["res", 0x01, ",", "(", "iy", "+", "DIS", ")", ",", "c"] },
                          0x8A => { "" => ["res", 0x01, ",", "(", "iy", "+", "DIS", ")", ",", "d"] },
                          0x8B => { "" => ["res", 0x01, ",", "(", "iy", "+", "DIS", ")", ",", "e"] },
                          0x8C => { "" => ["res", 0x01, ",", "(", "iy", "+", "DIS", ")", ",", "h"] },
                          0x8D => { "" => ["res", 0x01, ",", "(", "iy", "+", "DIS", ")", ",", "l"] },
                          0x8E => { "" => ["res", 0x01, ",", "(", "iy", "+", "DIS", ")"] },
                          0x8F => { "" => ["res", 0x01, ",", "(", "iy", "+", "DIS", ")", ",", "a"] },
                          0x90 => { "" => ["res", 0x02, ",", "(", "iy", "+", "DIS", ")", ",", "b"] },
                          0x91 => { "" => ["res", 0x02, ",", "(", "iy", "+", "DIS", ")", ",", "c"] },
                          0x92 => { "" => ["res", 0x02, ",", "(", "iy", "+", "DIS", ")", ",", "d"] },
                          0x93 => { "" => ["res", 0x02, ",", "(", "iy", "+", "DIS", ")", ",", "e"] },
                          0x94 => { "" => ["res", 0x02, ",", "(", "iy", "+", "DIS", ")", ",", "h"] },
                          0x95 => { "" => ["res", 0x02, ",", "(", "iy", "+", "DIS", ")", ",", "l"] },
                          0x96 => { "" => ["res", 0x02, ",", "(", "iy", "+", "DIS", ")"] },
                          0x97 => { "" => ["res", 0x02, ",", "(", "iy", "+", "DIS", ")", ",", "a"] },
                          0x98 => { "" => ["res", 0x03, ",", "(", "iy", "+", "DIS", ")", ",", "b"] },
                          0x99 => { "" => ["res", 0x03, ",", "(", "iy", "+", "DIS", ")", ",", "c"] },
                          0x9A => { "" => ["res", 0x03, ",", "(", "iy", "+", "DIS", ")", ",", "d"] },
                          0x9B => { "" => ["res", 0x03, ",", "(", "iy", "+", "DIS", ")", ",", "e"] },
                          0x9C => { "" => ["res", 0x03, ",", "(", "iy", "+", "DIS", ")", ",", "h"] },
                          0x9D => { "" => ["res", 0x03, ",", "(", "iy", "+", "DIS", ")", ",", "l"] },
                          0x9E => { "" => ["res", 0x03, ",", "(", "iy", "+", "DIS", ")"] },
                          0x9F => { "" => ["res", 0x03, ",", "(", "iy", "+", "DIS", ")", ",", "a"] },
                          0xA0 => { "" => ["res", 0x04, ",", "(", "iy", "+", "DIS", ")", ",", "b"] },
                          0xA1 => { "" => ["res", 0x04, ",", "(", "iy", "+", "DIS", ")", ",", "c"] },
                          0xA2 => { "" => ["res", 0x04, ",", "(", "iy", "+", "DIS", ")", ",", "d"] },
                          0xA3 => { "" => ["res", 0x04, ",", "(", "iy", "+", "DIS", ")", ",", "e"] },
                          0xA4 => { "" => ["res", 0x04, ",", "(", "iy", "+", "DIS", ")", ",", "h"] },
                          0xA5 => { "" => ["res", 0x04, ",", "(", "iy", "+", "DIS", ")", ",", "l"] },
                          0xA6 => { "" => ["res", 0x04, ",", "(", "iy", "+", "DIS", ")"] },
                          0xA7 => { "" => ["res", 0x04, ",", "(", "iy", "+", "DIS", ")", ",", "a"] },
                          0xA8 => { "" => ["res", 0x05, ",", "(", "iy", "+", "DIS", ")", ",", "b"] },
                          0xA9 => { "" => ["res", 0x05, ",", "(", "iy", "+", "DIS", ")", ",", "c"] },
                          0xAA => { "" => ["res", 0x05, ",", "(", "iy", "+", "DIS", ")", ",", "d"] },
                          0xAB => { "" => ["res", 0x05, ",", "(", "iy", "+", "DIS", ")", ",", "e"] },
                          0xAC => { "" => ["res", 0x05, ",", "(", "iy", "+", "DIS", ")", ",", "h"] },
                          0xAD => { "" => ["res", 0x05, ",", "(", "iy", "+", "DIS", ")", ",", "l"] },
                          0xAE => { "" => ["res", 0x05, ",", "(", "iy", "+", "DIS", ")"] },
                          0xAF => { "" => ["res", 0x05, ",", "(", "iy", "+", "DIS", ")", ",", "a"] },
                          0xB0 => { "" => ["res", 0x06, ",", "(", "iy", "+", "DIS", ")", ",", "b"] },
                          0xB1 => { "" => ["res", 0x06, ",", "(", "iy", "+", "DIS", ")", ",", "c"] },
                          0xB2 => { "" => ["res", 0x06, ",", "(", "iy", "+", "DIS", ")", ",", "d"] },
                          0xB3 => { "" => ["res", 0x06, ",", "(", "iy", "+", "DIS", ")", ",", "e"] },
                          0xB4 => { "" => ["res", 0x06, ",", "(", "iy", "+", "DIS", ")", ",", "h"] },
                          0xB5 => { "" => ["res", 0x06, ",", "(", "iy", "+", "DIS", ")", ",", "l"] },
                          0xB6 => { "" => ["res", 0x06, ",", "(", "iy", "+", "DIS", ")"] },
                          0xB7 => { "" => ["res", 0x06, ",", "(", "iy", "+", "DIS", ")", ",", "a"] },
                          0xB8 => { "" => ["res", 0x07, ",", "(", "iy", "+", "DIS", ")", ",", "b"] },
                          0xB9 => { "" => ["res", 0x07, ",", "(", "iy", "+", "DIS", ")", ",", "c"] },
                          0xBA => { "" => ["res", 0x07, ",", "(", "iy", "+", "DIS", ")", ",", "d"] },
                          0xBB => { "" => ["res", 0x07, ",", "(", "iy", "+", "DIS", ")", ",", "e"] },
                          0xBC => { "" => ["res", 0x07, ",", "(", "iy", "+", "DIS", ")", ",", "h"] },
                          0xBD => { "" => ["res", 0x07, ",", "(", "iy", "+", "DIS", ")", ",", "l"] },
                          0xBE => { "" => ["res", 0x07, ",", "(", "iy", "+", "DIS", ")"] },
                          0xBF => { "" => ["res", 0x07, ",", "(", "iy", "+", "DIS", ")", ",", "a"] },
                          0xC0 => { "" => ["set", 0x00, ",", "(", "iy", "+", "DIS", ")", ",", "b"] },
                          0xC1 => { "" => ["set", 0x00, ",", "(", "iy", "+", "DIS", ")", ",", "c"] },
                          0xC2 => { "" => ["set", 0x00, ",", "(", "iy", "+", "DIS", ")", ",", "d"] },
                          0xC3 => { "" => ["set", 0x00, ",", "(", "iy", "+", "DIS", ")", ",", "e"] },
                          0xC4 => { "" => ["set", 0x00, ",", "(", "iy", "+", "DIS", ")", ",", "h"] },
                          0xC5 => { "" => ["set", 0x00, ",", "(", "iy", "+", "DIS", ")", ",", "l"] },
                          0xC6 => { "" => ["set", 0x00, ",", "(", "iy", "+", "DIS", ")"] },
                          0xC7 => { "" => ["set", 0x00, ",", "(", "iy", "+", "DIS", ")", ",", "a"] },
                          0xC8 => { "" => ["set", 0x01, ",", "(", "iy", "+", "DIS", ")", ",", "b"] },
                          0xC9 => { "" => ["set", 0x01, ",", "(", "iy", "+", "DIS", ")", ",", "c"] },
                          0xCA => { "" => ["set", 0x01, ",", "(", "iy", "+", "DIS", ")", ",", "d"] },
                          0xCB => { "" => ["set", 0x01, ",", "(", "iy", "+", "DIS", ")", ",", "e"] },
                          0xCC => { "" => ["set", 0x01, ",", "(", "iy", "+", "DIS", ")", ",", "h"] },
                          0xCD => { "" => ["set", 0x01, ",", "(", "iy", "+", "DIS", ")", ",", "l"] },
                          0xCE => { "" => ["set", 0x01, ",", "(", "iy", "+", "DIS", ")"] },
                          0xCF => { "" => ["set", 0x01, ",", "(", "iy", "+", "DIS", ")", ",", "a"] },
                          0xD0 => { "" => ["set", 0x02, ",", "(", "iy", "+", "DIS", ")", ",", "b"] },
                          0xD1 => { "" => ["set", 0x02, ",", "(", "iy", "+", "DIS", ")", ",", "c"] },
                          0xD2 => { "" => ["set", 0x02, ",", "(", "iy", "+", "DIS", ")", ",", "d"] },
                          0xD3 => { "" => ["set", 0x02, ",", "(", "iy", "+", "DIS", ")", ",", "e"] },
                          0xD4 => { "" => ["set", 0x02, ",", "(", "iy", "+", "DIS", ")", ",", "h"] },
                          0xD5 => { "" => ["set", 0x02, ",", "(", "iy", "+", "DIS", ")", ",", "l"] },
                          0xD6 => { "" => ["set", 0x02, ",", "(", "iy", "+", "DIS", ")"] },
                          0xD7 => { "" => ["set", 0x02, ",", "(", "iy", "+", "DIS", ")", ",", "a"] },
                          0xD8 => { "" => ["set", 0x03, ",", "(", "iy", "+", "DIS", ")", ",", "b"] },
                          0xD9 => { "" => ["set", 0x03, ",", "(", "iy", "+", "DIS", ")", ",", "c"] },
                          0xDA => { "" => ["set", 0x03, ",", "(", "iy", "+", "DIS", ")", ",", "d"] },
                          0xDB => { "" => ["set", 0x03, ",", "(", "iy", "+", "DIS", ")", ",", "e"] },
                          0xDC => { "" => ["set", 0x03, ",", "(", "iy", "+", "DIS", ")", ",", "h"] },
                          0xDD => { "" => ["set", 0x03, ",", "(", "iy", "+", "DIS", ")", ",", "l"] },
                          0xDE => { "" => ["set", 0x03, ",", "(", "iy", "+", "DIS", ")"] },
                          0xDF => { "" => ["set", 0x03, ",", "(", "iy", "+", "DIS", ")", ",", "a"] },
                          0xE0 => { "" => ["set", 0x04, ",", "(", "iy", "+", "DIS", ")", ",", "b"] },
                          0xE1 => { "" => ["set", 0x04, ",", "(", "iy", "+", "DIS", ")", ",", "c"] },
                          0xE2 => { "" => ["set", 0x04, ",", "(", "iy", "+", "DIS", ")", ",", "d"] },
                          0xE3 => { "" => ["set", 0x04, ",", "(", "iy", "+", "DIS", ")", ",", "e"] },
                          0xE4 => { "" => ["set", 0x04, ",", "(", "iy", "+", "DIS", ")", ",", "h"] },
                          0xE5 => { "" => ["set", 0x04, ",", "(", "iy", "+", "DIS", ")", ",", "l"] },
                          0xE6 => { "" => ["set", 0x04, ",", "(", "iy", "+", "DIS", ")"] },
                          0xE7 => { "" => ["set", 0x04, ",", "(", "iy", "+", "DIS", ")", ",", "a"] },
                          0xE8 => { "" => ["set", 0x05, ",", "(", "iy", "+", "DIS", ")", ",", "b"] },
                          0xE9 => { "" => ["set", 0x05, ",", "(", "iy", "+", "DIS", ")", ",", "c"] },
                          0xEA => { "" => ["set", 0x05, ",", "(", "iy", "+", "DIS", ")", ",", "d"] },
                          0xEB => { "" => ["set", 0x05, ",", "(", "iy", "+", "DIS", ")", ",", "e"] },
                          0xEC => { "" => ["set", 0x05, ",", "(", "iy", "+", "DIS", ")", ",", "h"] },
                          0xED => { "" => ["set", 0x05, ",", "(", "iy", "+", "DIS", ")", ",", "l"] },
                          0xEE => { "" => ["set", 0x05, ",", "(", "iy", "+", "DIS", ")"] },
                          0xEF => { "" => ["set", 0x05, ",", "(", "iy", "+", "DIS", ")", ",", "a"] },
                          0xF0 => { "" => ["set", 0x06, ",", "(", "iy", "+", "DIS", ")", ",", "b"] },
                          0xF1 => { "" => ["set", 0x06, ",", "(", "iy", "+", "DIS", ")", ",", "c"] },
                          0xF2 => { "" => ["set", 0x06, ",", "(", "iy", "+", "DIS", ")", ",", "d"] },
                          0xF3 => { "" => ["set", 0x06, ",", "(", "iy", "+", "DIS", ")", ",", "e"] },
                          0xF4 => { "" => ["set", 0x06, ",", "(", "iy", "+", "DIS", ")", ",", "h"] },
                          0xF5 => { "" => ["set", 0x06, ",", "(", "iy", "+", "DIS", ")", ",", "l"] },
                          0xF6 => { "" => ["set", 0x06, ",", "(", "iy", "+", "DIS", ")"] },
                          0xF7 => { "" => ["set", 0x06, ",", "(", "iy", "+", "DIS", ")", ",", "a"] },
                          0xF8 => { "" => ["set", 0x07, ",", "(", "iy", "+", "DIS", ")", ",", "b"] },
                          0xF9 => { "" => ["set", 0x07, ",", "(", "iy", "+", "DIS", ")", ",", "c"] },
                          0xFA => { "" => ["set", 0x07, ",", "(", "iy", "+", "DIS", ")", ",", "d"] },
                          0xFB => { "" => ["set", 0x07, ",", "(", "iy", "+", "DIS", ")", ",", "e"] },
                          0xFC => { "" => ["set", 0x07, ",", "(", "iy", "+", "DIS", ")", ",", "h"] },
                          0xFD => { "" => ["set", 0x07, ",", "(", "iy", "+", "DIS", ")", ",", "l"] },
                          0xFE => { "" => ["set", 0x07, ",", "(", "iy", "+", "DIS", ")"] },
                          0xFF => { "" => ["set", 0x07, ",", "(", "iy", "+", "DIS", ")", ",", "a"] },
                        },
                        "NDIS" => {
                          0x00   => { "" => ["rlc", "(", "iy", "-", "NDIS", ")", ",", "b"] },
                          0x01   => { "" => ["rlc", "(", "iy", "-", "NDIS", ")", ",", "c"] },
                          0x02   => { "" => ["rlc", "(", "iy", "-", "NDIS", ")", ",", "d"] },
                          0x03   => { "" => ["rlc", "(", "iy", "-", "NDIS", ")", ",", "e"] },
                          0x04   => { "" => ["rlc", "(", "iy", "-", "NDIS", ")", ",", "h"] },
                          0x05   => { "" => ["rlc", "(", "iy", "-", "NDIS", ")", ",", "l"] },
                          0x06   => { "" => ["rlc", "(", "iy", "-", "NDIS", ")"] },
                          0x07   => { "" => ["rlc", "(", "iy", "-", "NDIS", ")", ",", "a"] },
                          0x08   => { "" => ["rrc", "(", "iy", "-", "NDIS", ")", ",", "b"] },
                          0x09   => { "" => ["rrc", "(", "iy", "-", "NDIS", ")", ",", "c"] },
                          0x0A  => { "" => ["rrc", "(", "iy", "-", "NDIS", ")", ",", "d"] },
                          0x0B  => { "" => ["rrc", "(", "iy", "-", "NDIS", ")", ",", "e"] },
                          0x0C  => { "" => ["rrc", "(", "iy", "-", "NDIS", ")", ",", "h"] },
                          0x0D  => { "" => ["rrc", "(", "iy", "-", "NDIS", ")", ",", "l"] },
                          0x0E  => { "" => ["rrc", "(", "iy", "-", "NDIS", ")"] },
                          0x0F  => { "" => ["rrc", "(", "iy", "-", "NDIS", ")", ",", "a"] },
                          0x10  => { "" => ["rl", "(", "iy", "-", "NDIS", ")", ",", "b"] },
                          0x11  => { "" => ["rl", "(", "iy", "-", "NDIS", ")", ",", "c"] },
                          0x12  => { "" => ["rl", "(", "iy", "-", "NDIS", ")", ",", "d"] },
                          0x13  => { "" => ["rl", "(", "iy", "-", "NDIS", ")", ",", "e"] },
                          0x14  => { "" => ["rl", "(", "iy", "-", "NDIS", ")", ",", "h"] },
                          0x15  => { "" => ["rl", "(", "iy", "-", "NDIS", ")", ",", "l"] },
                          0x16  => { "" => ["rl", "(", "iy", "-", "NDIS", ")"] },
                          0x17  => { "" => ["rl", "(", "iy", "-", "NDIS", ")", ",", "a"] },
                          0x18  => { "" => ["rr", "(", "iy", "-", "NDIS", ")", ",", "b"] },
                          0x19  => { "" => ["rr", "(", "iy", "-", "NDIS", ")", ",", "c"] },
                          0x1A  => { "" => ["rr", "(", "iy", "-", "NDIS", ")", ",", "d"] },
                          0x1B  => { "" => ["rr", "(", "iy", "-", "NDIS", ")", ",", "e"] },
                          0x1C  => { "" => ["rr", "(", "iy", "-", "NDIS", ")", ",", "h"] },
                          0x1D  => { "" => ["rr", "(", "iy", "-", "NDIS", ")", ",", "l"] },
                          0x1E  => { "" => ["rr", "(", "iy", "-", "NDIS", ")"] },
                          0x1F  => { "" => ["rr", "(", "iy", "-", "NDIS", ")", ",", "a"] },
                          0x20  => { "" => ["sla", "(", "iy", "-", "NDIS", ")", ",", "b"] },
                          0x21  => { "" => ["sla", "(", "iy", "-", "NDIS", ")", ",", "c"] },
                          0x22  => { "" => ["sla", "(", "iy", "-", "NDIS", ")", ",", "d"] },
                          0x23  => { "" => ["sla", "(", "iy", "-", "NDIS", ")", ",", "e"] },
                          0x24  => { "" => ["sla", "(", "iy", "-", "NDIS", ")", ",", "h"] },
                          0x25  => { "" => ["sla", "(", "iy", "-", "NDIS", ")", ",", "l"] },
                          0x26  => { "" => ["sla", "(", "iy", "-", "NDIS", ")"] },
                          0x27  => { "" => ["sla", "(", "iy", "-", "NDIS", ")", ",", "a"] },
                          0x28  => { "" => ["sra", "(", "iy", "-", "NDIS", ")", ",", "b"] },
                          0x29  => { "" => ["sra", "(", "iy", "-", "NDIS", ")", ",", "c"] },
                          0x2A  => { "" => ["sra", "(", "iy", "-", "NDIS", ")", ",", "d"] },
                          0x2B  => { "" => ["sra", "(", "iy", "-", "NDIS", ")", ",", "e"] },
                          0x2C  => { "" => ["sra", "(", "iy", "-", "NDIS", ")", ",", "h"] },
                          0x2D  => { "" => ["sra", "(", "iy", "-", "NDIS", ")", ",", "l"] },
                          0x2E  => { "" => ["sra", "(", "iy", "-", "NDIS", ")"] },
                          0x2F  => { "" => ["sra", "(", "iy", "-", "NDIS", ")", ",", "a"] },
                          0x30  => { "" => ["sll", "(", "iy", "-", "NDIS", ")", ",", "b"] },
                          0x31  => { "" => ["sll", "(", "iy", "-", "NDIS", ")", ",", "c"] },
                          0x32  => { "" => ["sll", "(", "iy", "-", "NDIS", ")", ",", "d"] },
                          0x33  => { "" => ["sll", "(", "iy", "-", "NDIS", ")", ",", "e"] },
                          0x34  => { "" => ["sll", "(", "iy", "-", "NDIS", ")", ",", "h"] },
                          0x35  => { "" => ["sll", "(", "iy", "-", "NDIS", ")", ",", "l"] },
                          0x36  => { "" => ["sll", "(", "iy", "-", "NDIS", ")"] },
                          0x37  => { "" => ["sll", "(", "iy", "-", "NDIS", ")", ",", "a"] },
                          0x38  => { "" => ["srl", "(", "iy", "-", "NDIS", ")", ",", "b"] },
                          0x39  => { "" => ["srl", "(", "iy", "-", "NDIS", ")", ",", "c"] },
                          0x3A  => { "" => ["srl", "(", "iy", "-", "NDIS", ")", ",", "d"] },
                          0x3B  => { "" => ["srl", "(", "iy", "-", "NDIS", ")", ",", "e"] },
                          0x3C  => { "" => ["srl", "(", "iy", "-", "NDIS", ")", ",", "h"] },
                          0x3D  => { "" => ["srl", "(", "iy", "-", "NDIS", ")", ",", "l"] },
                          0x3E  => { "" => ["srl", "(", "iy", "-", "NDIS", ")"] },
                          0x3F  => { "" => ["srl", "(", "iy", "-", "NDIS", ")", ",", "a"] },
                          0x46  => { "" => ["bit", 0x00, ",", "(", "iy", "-", "NDIS", ")"] },
                          0x4E  => { "" => ["bit", 0x01, ",", "(", "iy", "-", "NDIS", ")"] },
                          0x56  => { "" => ["bit", 0x02, ",", "(", "iy", "-", "NDIS", ")"] },
                          0x5E  => { "" => ["bit", 0x03, ",", "(", "iy", "-", "NDIS", ")"] },
                          0x66 => { "" => ["bit", 0x04, ",", "(", "iy", "-", "NDIS", ")"] },
                          0x6E => { "" => ["bit", 0x05, ",", "(", "iy", "-", "NDIS", ")"] },
                          0x76 => { "" => ["bit", 0x06, ",", "(", "iy", "-", "NDIS", ")"] },
                          0x7E => { "" => ["bit", 0x07, ",", "(", "iy", "-", "NDIS", ")"] },
                          0x80 => { "" => ["res", 0x00, ",", "(", "iy", "-", "NDIS", ")", ",", "b"] },
                          0x81 => { "" => ["res", 0x00, ",", "(", "iy", "-", "NDIS", ")", ",", "c"] },
                          0x82 => { "" => ["res", 0x00, ",", "(", "iy", "-", "NDIS", ")", ",", "d"] },
                          0x83 => { "" => ["res", 0x00, ",", "(", "iy", "-", "NDIS", ")", ",", "e"] },
                          0x84 => { "" => ["res", 0x00, ",", "(", "iy", "-", "NDIS", ")", ",", "h"] },
                          0x85 => { "" => ["res", 0x00, ",", "(", "iy", "-", "NDIS", ")", ",", "l"] },
                          0x86 => { "" => ["res", 0x00, ",", "(", "iy", "-", "NDIS", ")"] },
                          0x87 => { "" => ["res", 0x00, ",", "(", "iy", "-", "NDIS", ")", ",", "a"] },
                          0x88 => { "" => ["res", 0x01, ",", "(", "iy", "-", "NDIS", ")", ",", "b"] },
                          0x89 => { "" => ["res", 0x01, ",", "(", "iy", "-", "NDIS", ")", ",", "c"] },
                          0x8A => { "" => ["res", 0x01, ",", "(", "iy", "-", "NDIS", ")", ",", "d"] },
                          0x8B => { "" => ["res", 0x01, ",", "(", "iy", "-", "NDIS", ")", ",", "e"] },
                          0x8C => { "" => ["res", 0x01, ",", "(", "iy", "-", "NDIS", ")", ",", "h"] },
                          0x8D => { "" => ["res", 0x01, ",", "(", "iy", "-", "NDIS", ")", ",", "l"] },
                          0x8E => { "" => ["res", 0x01, ",", "(", "iy", "-", "NDIS", ")"] },
                          0x8F => { "" => ["res", 0x01, ",", "(", "iy", "-", "NDIS", ")", ",", "a"] },
                          0x90 => { "" => ["res", 0x02, ",", "(", "iy", "-", "NDIS", ")", ",", "b"] },
                          0x91 => { "" => ["res", 0x02, ",", "(", "iy", "-", "NDIS", ")", ",", "c"] },
                          0x92 => { "" => ["res", 0x02, ",", "(", "iy", "-", "NDIS", ")", ",", "d"] },
                          0x93 => { "" => ["res", 0x02, ",", "(", "iy", "-", "NDIS", ")", ",", "e"] },
                          0x94 => { "" => ["res", 0x02, ",", "(", "iy", "-", "NDIS", ")", ",", "h"] },
                          0x95 => { "" => ["res", 0x02, ",", "(", "iy", "-", "NDIS", ")", ",", "l"] },
                          0x96 => { "" => ["res", 0x02, ",", "(", "iy", "-", "NDIS", ")"] },
                          0x97 => { "" => ["res", 0x02, ",", "(", "iy", "-", "NDIS", ")", ",", "a"] },
                          0x98 => { "" => ["res", 0x03, ",", "(", "iy", "-", "NDIS", ")", ",", "b"] },
                          0x99 => { "" => ["res", 0x03, ",", "(", "iy", "-", "NDIS", ")", ",", "c"] },
                          0x9A => { "" => ["res", 0x03, ",", "(", "iy", "-", "NDIS", ")", ",", "d"] },
                          0x9B => { "" => ["res", 0x03, ",", "(", "iy", "-", "NDIS", ")", ",", "e"] },
                          0x9C => { "" => ["res", 0x03, ",", "(", "iy", "-", "NDIS", ")", ",", "h"] },
                          0x9D => { "" => ["res", 0x03, ",", "(", "iy", "-", "NDIS", ")", ",", "l"] },
                          0x9E => { "" => ["res", 0x03, ",", "(", "iy", "-", "NDIS", ")"] },
                          0x9F => { "" => ["res", 0x03, ",", "(", "iy", "-", "NDIS", ")", ",", "a"] },
                          0xA0 => { "" => ["res", 0x04, ",", "(", "iy", "-", "NDIS", ")", ",", "b"] },
                          0xA1 => { "" => ["res", 0x04, ",", "(", "iy", "-", "NDIS", ")", ",", "c"] },
                          0xA2 => { "" => ["res", 0x04, ",", "(", "iy", "-", "NDIS", ")", ",", "d"] },
                          0xA3 => { "" => ["res", 0x04, ",", "(", "iy", "-", "NDIS", ")", ",", "e"] },
                          0xA4 => { "" => ["res", 0x04, ",", "(", "iy", "-", "NDIS", ")", ",", "h"] },
                          0xA5 => { "" => ["res", 0x04, ",", "(", "iy", "-", "NDIS", ")", ",", "l"] },
                          0xA6 => { "" => ["res", 0x04, ",", "(", "iy", "-", "NDIS", ")"] },
                          0xA7 => { "" => ["res", 0x04, ",", "(", "iy", "-", "NDIS", ")", ",", "a"] },
                          0xA8 => { "" => ["res", 0x05, ",", "(", "iy", "-", "NDIS", ")", ",", "b"] },
                          0xA9 => { "" => ["res", 0x05, ",", "(", "iy", "-", "NDIS", ")", ",", "c"] },
                          0xAA => { "" => ["res", 0x05, ",", "(", "iy", "-", "NDIS", ")", ",", "d"] },
                          0xAB => { "" => ["res", 0x05, ",", "(", "iy", "-", "NDIS", ")", ",", "e"] },
                          0xAC => { "" => ["res", 0x05, ",", "(", "iy", "-", "NDIS", ")", ",", "h"] },
                          0xAD => { "" => ["res", 0x05, ",", "(", "iy", "-", "NDIS", ")", ",", "l"] },
                          0xAE => { "" => ["res", 0x05, ",", "(", "iy", "-", "NDIS", ")"] },
                          0xAF => { "" => ["res", 0x05, ",", "(", "iy", "-", "NDIS", ")", ",", "a"] },
                          0xB0 => { "" => ["res", 0x06, ",", "(", "iy", "-", "NDIS", ")", ",", "b"] },
                          0xB1 => { "" => ["res", 0x06, ",", "(", "iy", "-", "NDIS", ")", ",", "c"] },
                          0xB2 => { "" => ["res", 0x06, ",", "(", "iy", "-", "NDIS", ")", ",", "d"] },
                          0xB3 => { "" => ["res", 0x06, ",", "(", "iy", "-", "NDIS", ")", ",", "e"] },
                          0xB4 => { "" => ["res", 0x06, ",", "(", "iy", "-", "NDIS", ")", ",", "h"] },
                          0xB5 => { "" => ["res", 0x06, ",", "(", "iy", "-", "NDIS", ")", ",", "l"] },
                          0xB6 => { "" => ["res", 0x06, ",", "(", "iy", "-", "NDIS", ")"] },
                          0xB7 => { "" => ["res", 0x06, ",", "(", "iy", "-", "NDIS", ")", ",", "a"] },
                          0xB8 => { "" => ["res", 0x07, ",", "(", "iy", "-", "NDIS", ")", ",", "b"] },
                          0xB9 => { "" => ["res", 0x07, ",", "(", "iy", "-", "NDIS", ")", ",", "c"] },
                          0xBA => { "" => ["res", 0x07, ",", "(", "iy", "-", "NDIS", ")", ",", "d"] },
                          0xBB => { "" => ["res", 0x07, ",", "(", "iy", "-", "NDIS", ")", ",", "e"] },
                          0xBC => { "" => ["res", 0x07, ",", "(", "iy", "-", "NDIS", ")", ",", "h"] },
                          0xBD => { "" => ["res", 0x07, ",", "(", "iy", "-", "NDIS", ")", ",", "l"] },
                          0xBE => { "" => ["res", 0x07, ",", "(", "iy", "-", "NDIS", ")"] },
                          0xBF => { "" => ["res", 0x07, ",", "(", "iy", "-", "NDIS", ")", ",", "a"] },
                          0xC0 => { "" => ["set", 0x00, ",", "(", "iy", "-", "NDIS", ")", ",", "b"] },
                          0xC1 => { "" => ["set", 0x00, ",", "(", "iy", "-", "NDIS", ")", ",", "c"] },
                          0xC2 => { "" => ["set", 0x00, ",", "(", "iy", "-", "NDIS", ")", ",", "d"] },
                          0xC3 => { "" => ["set", 0x00, ",", "(", "iy", "-", "NDIS", ")", ",", "e"] },
                          0xC4 => { "" => ["set", 0x00, ",", "(", "iy", "-", "NDIS", ")", ",", "h"] },
                          0xC5 => { "" => ["set", 0x00, ",", "(", "iy", "-", "NDIS", ")", ",", "l"] },
                          0xC6 => { "" => ["set", 0x00, ",", "(", "iy", "-", "NDIS", ")"] },
                          0xC7 => { "" => ["set", 0x00, ",", "(", "iy", "-", "NDIS", ")", ",", "a"] },
                          0xC8 => { "" => ["set", 0x01, ",", "(", "iy", "-", "NDIS", ")", ",", "b"] },
                          0xC9 => { "" => ["set", 0x01, ",", "(", "iy", "-", "NDIS", ")", ",", "c"] },
                          0xCA => { "" => ["set", 0x01, ",", "(", "iy", "-", "NDIS", ")", ",", "d"] },
                          0xCB => { "" => ["set", 0x01, ",", "(", "iy", "-", "NDIS", ")", ",", "e"] },
                          0xCC => { "" => ["set", 0x01, ",", "(", "iy", "-", "NDIS", ")", ",", "h"] },
                          0xCD => { "" => ["set", 0x01, ",", "(", "iy", "-", "NDIS", ")", ",", "l"] },
                          0xCE => { "" => ["set", 0x01, ",", "(", "iy", "-", "NDIS", ")"] },
                          0xCF => { "" => ["set", 0x01, ",", "(", "iy", "-", "NDIS", ")", ",", "a"] },
                          0xD0 => { "" => ["set", 0x02, ",", "(", "iy", "-", "NDIS", ")", ",", "b"] },
                          0xD1 => { "" => ["set", 0x02, ",", "(", "iy", "-", "NDIS", ")", ",", "c"] },
                          0xD2 => { "" => ["set", 0x02, ",", "(", "iy", "-", "NDIS", ")", ",", "d"] },
                          0xD3 => { "" => ["set", 0x02, ",", "(", "iy", "-", "NDIS", ")", ",", "e"] },
                          0xD4 => { "" => ["set", 0x02, ",", "(", "iy", "-", "NDIS", ")", ",", "h"] },
                          0xD5 => { "" => ["set", 0x02, ",", "(", "iy", "-", "NDIS", ")", ",", "l"] },
                          0xD6 => { "" => ["set", 0x02, ",", "(", "iy", "-", "NDIS", ")"] },
                          0xD7 => { "" => ["set", 0x02, ",", "(", "iy", "-", "NDIS", ")", ",", "a"] },
                          0xD8 => { "" => ["set", 0x03, ",", "(", "iy", "-", "NDIS", ")", ",", "b"] },
                          0xD9 => { "" => ["set", 0x03, ",", "(", "iy", "-", "NDIS", ")", ",", "c"] },
                          0xDA => { "" => ["set", 0x03, ",", "(", "iy", "-", "NDIS", ")", ",", "d"] },
                          0xDB => { "" => ["set", 0x03, ",", "(", "iy", "-", "NDIS", ")", ",", "e"] },
                          0xDC => { "" => ["set", 0x03, ",", "(", "iy", "-", "NDIS", ")", ",", "h"] },
                          0xDD => { "" => ["set", 0x03, ",", "(", "iy", "-", "NDIS", ")", ",", "l"] },
                          0xDE => { "" => ["set", 0x03, ",", "(", "iy", "-", "NDIS", ")"] },
                          0xDF => { "" => ["set", 0x03, ",", "(", "iy", "-", "NDIS", ")", ",", "a"] },
                          0xE0 => { "" => ["set", 0x04, ",", "(", "iy", "-", "NDIS", ")", ",", "b"] },
                          0xE1 => { "" => ["set", 0x04, ",", "(", "iy", "-", "NDIS", ")", ",", "c"] },
                          0xE2 => { "" => ["set", 0x04, ",", "(", "iy", "-", "NDIS", ")", ",", "d"] },
                          0xE3 => { "" => ["set", 0x04, ",", "(", "iy", "-", "NDIS", ")", ",", "e"] },
                          0xE4 => { "" => ["set", 0x04, ",", "(", "iy", "-", "NDIS", ")", ",", "h"] },
                          0xE5 => { "" => ["set", 0x04, ",", "(", "iy", "-", "NDIS", ")", ",", "l"] },
                          0xE6 => { "" => ["set", 0x04, ",", "(", "iy", "-", "NDIS", ")"] },
                          0xE7 => { "" => ["set", 0x04, ",", "(", "iy", "-", "NDIS", ")", ",", "a"] },
                          0xE8 => { "" => ["set", 0x05, ",", "(", "iy", "-", "NDIS", ")", ",", "b"] },
                          0xE9 => { "" => ["set", 0x05, ",", "(", "iy", "-", "NDIS", ")", ",", "c"] },
                          0xEA => { "" => ["set", 0x05, ",", "(", "iy", "-", "NDIS", ")", ",", "d"] },
                          0xEB => { "" => ["set", 0x05, ",", "(", "iy", "-", "NDIS", ")", ",", "e"] },
                          0xEC => { "" => ["set", 0x05, ",", "(", "iy", "-", "NDIS", ")", ",", "h"] },
                          0xED => { "" => ["set", 0x05, ",", "(", "iy", "-", "NDIS", ")", ",", "l"] },
                          0xEE => { "" => ["set", 0x05, ",", "(", "iy", "-", "NDIS", ")"] },
                          0xEF => { "" => ["set", 0x05, ",", "(", "iy", "-", "NDIS", ")", ",", "a"] },
                          0xF0 => { "" => ["set", 0x06, ",", "(", "iy", "-", "NDIS", ")", ",", "b"] },
                          0xF1 => { "" => ["set", 0x06, ",", "(", "iy", "-", "NDIS", ")", ",", "c"] },
                          0xF2 => { "" => ["set", 0x06, ",", "(", "iy", "-", "NDIS", ")", ",", "d"] },
                          0xF3 => { "" => ["set", 0x06, ",", "(", "iy", "-", "NDIS", ")", ",", "e"] },
                          0xF4 => { "" => ["set", 0x06, ",", "(", "iy", "-", "NDIS", ")", ",", "h"] },
                          0xF5 => { "" => ["set", 0x06, ",", "(", "iy", "-", "NDIS", ")", ",", "l"] },
                          0xF6 => { "" => ["set", 0x06, ",", "(", "iy", "-", "NDIS", ")"] },
                          0xF7 => { "" => ["set", 0x06, ",", "(", "iy", "-", "NDIS", ")", ",", "a"] },
                          0xF8 => { "" => ["set", 0x07, ",", "(", "iy", "-", "NDIS", ")", ",", "b"] },
                          0xF9 => { "" => ["set", 0x07, ",", "(", "iy", "-", "NDIS", ")", ",", "c"] },
                          0xFA => { "" => ["set", 0x07, ",", "(", "iy", "-", "NDIS", ")", ",", "d"] },
                          0xFB => { "" => ["set", 0x07, ",", "(", "iy", "-", "NDIS", ")", ",", "e"] },
                          0xFC => { "" => ["set", 0x07, ",", "(", "iy", "-", "NDIS", ")", ",", "h"] },
                          0xFD => { "" => ["set", 0x07, ",", "(", "iy", "-", "NDIS", ")", ",", "l"] },
                          0xFE => { "" => ["set", 0x07, ",", "(", "iy", "-", "NDIS", ")"] },
                          0xFF => { "" => ["set", 0x07, ",", "(", "iy", "-", "NDIS", ")", ",", "a"] },
                        },
                      },
               0xE1 => { "" => ["pop", "iy"] },
               0xE3 => { "" => ["ex", "(", "sp", ")", ",", "iy"] },
               0xE5 => {
                        "" => ["push", "iy"],
                        0xDD => { 0xE1 => { "" => ["ld", "ix", ",", "iy"] } },
                        0xE1 => { "" => ["ld", "hl", ",", "iy"] },
                      },
               0xE9 => { "" => ["jp", "(", "iy", ")"] },
               0xF9 => { "" => ["ld", "sp", ",", "iy"] },
             },
    0xFE => { N => { "" => ["cp", "N"] } },
    0xFF => { "" => ["rst", 0x38] },
  },
};

sub asm_table { return $table; }

1;
